@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Convert dicom file encoding
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:40:43 $
- *  CVS/RCS Revision: $Revision: 1.48 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:30 $
+ *  CVS/RCS Revision: $Revision: 1.72 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -42,7 +38,6 @@
 #endif
 
 #include "dcmtk/dcmdata/dctk.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/ofstd/ofconapp.h"
 #include "dcmtk/dcmdata/dcuid.h"       /* for dcmtk version name */
@@ -55,15 +50,42 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dcmconv"
 
+static OFLogger dcmconvLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
 // ********************************************
 
 
-#define SHORTCOL 4
+#define SHORTCOL 3
 #define LONGCOL 21
 
+static DcmTagKey parseTagKey(const char *tagName)
+{
+  unsigned int group = 0xffff;
+  unsigned int elem = 0xffff;
+  if (sscanf(tagName, "%x,%x", &group, &elem) != 2)
+  {
+    DcmTagKey tagKey;
+    /* it is a name */
+    const DcmDataDictionary &globalDataDict = dcmDataDict.rdlock();
+    const DcmDictEntry *dicent = globalDataDict.findEntry(tagName);
+    if (dicent == NULL)
+    {
+      OFLOG_ERROR(dcmconvLogger, "unrecognised tag name: '" << tagName << "'");
+      tagKey = DCM_UndefinedTagKey;
+    } else {
+      tagKey = dicent->getKey();
+    }
+    dcmDataDict.unlock();
+    return tagKey;
+  } else     /* tag name has format "gggg,eeee" */
+  {
+    return DcmTagKey(group,elem);
+  }
+}
+
 int main(int argc, char *argv[])
 {
 
@@ -72,15 +94,11 @@ int main(int argc, char *argv[])
   GUSISetup(GUSIwithInternetSockets);
 #endif
 
-  SetDebugLevel(( 0 ));
-
   const char *opt_ifname = NULL;
   const char *opt_ofname = NULL;
 
-  int opt_debugMode = 0;
-  OFBool opt_verbose = OFFalse;
-  OFBool opt_oDataset = OFFalse;
   E_FileReadMode opt_readMode = ERM_autoDetect;
+  E_FileWriteMode opt_writeMode = EWM_fileformat;
   E_TransferSyntax opt_ixfer = EXS_Unknown;
   E_TransferSyntax opt_oxfer = EXS_Unknown;
   E_GrpLenEncoding opt_oglenc = EGL_recalcGL;
@@ -91,6 +109,7 @@ int main(int argc, char *argv[])
 #ifdef WITH_ZLIB
   OFCmdUnsignedInt opt_compressionLevel = 0;
 #endif
+  OFBool opt_noInvalidGroups = OFFalse;
 
   OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "Convert DICOM file encoding", rcsid);
   OFCommandLine cmd;
@@ -101,43 +120,58 @@ int main(int argc, char *argv[])
   cmd.addParam("dcmfile-out", "DICOM output filename");
 
   cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-   cmd.addOption("--help",                   "-h",     "print this help text and exit");
-   cmd.addOption("--version",                          "print version information and exit", OFTrue /* exclusive */);
-   cmd.addOption("--verbose",                "-v",     "verbose mode, print processing details");
-   cmd.addOption("--debug",                  "-d",     "debug mode, print debug information");
+    cmd.addOption("--help",                  "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+    cmd.addOption("--version",                         "print version information and exit", OFCommandLine::AF_Exclusive);
+    OFLog::addOptions(cmd);
 
   cmd.addGroup("input options:");
     cmd.addSubGroup("input file format:");
-     cmd.addOption("--read-file",            "+f",     "read file format or data set (default)");
-     cmd.addOption("--read-file-only",       "+fo",    "read file format only");
-     cmd.addOption("--read-dataset",         "-f",     "read data set without file meta information");
+      cmd.addOption("--read-file",           "+f",     "read file format or data set (default)");
+      cmd.addOption("--read-file-only",      "+fo",    "read file format only");
+      cmd.addOption("--read-dataset",        "-f",     "read data set without file meta information");
     cmd.addSubGroup("input transfer syntax:", LONGCOL, SHORTCOL);
-     cmd.addOption("--read-xfer-auto",       "-t=",    "use TS recognition (default)");
-     cmd.addOption("--read-xfer-detect",     "-td",    "ignore TS specified in the file meta header");
-     cmd.addOption("--read-xfer-little",     "-te",    "read with explicit VR little endian TS");
-     cmd.addOption("--read-xfer-big",        "-tb",    "read with explicit VR big endian TS");
-     cmd.addOption("--read-xfer-implicit",   "-ti",    "read with implicit VR little endian TS");
+      cmd.addOption("--read-xfer-auto",      "-t=",    "use TS recognition (default)");
+      cmd.addOption("--read-xfer-detect",    "-td",    "ignore TS specified in the file meta header");
+      cmd.addOption("--read-xfer-little",    "-te",    "read with explicit VR little endian TS");
+      cmd.addOption("--read-xfer-big",       "-tb",    "read with explicit VR big endian TS");
+      cmd.addOption("--read-xfer-implicit",  "-ti",    "read with implicit VR little endian TS");
+    cmd.addSubGroup("parsing of file meta information:");
+      cmd.addOption("--use-meta-length",     "+ml",    "use file meta information group length (default)");
+      cmd.addOption("--ignore-meta-length",  "-ml",    "ignore file meta information group length");
     cmd.addSubGroup("parsing of odd-length attributes:");
-     cmd.addOption("--accept-odd-length",    "+ao",    "accept odd length attributes (default)");
-     cmd.addOption("--assume-even-length",   "+ae",    "assume real length is one byte larger");
+      cmd.addOption("--accept-odd-length",   "+ao",    "accept odd length attributes (default)");
+      cmd.addOption("--assume-even-length",  "+ae",    "assume real length is one byte larger");
+    cmd.addSubGroup("handling of non-standard VR:");
+      cmd.addOption("--treat-as-unknown",    "+vr",    "treat non-standard VR as unknown (default)");
+      cmd.addOption("--assume-implicit",     "-vr",    "try to read with implicit VR little endian TS");
     cmd.addSubGroup("handling of undefined length UN elements:");
-     cmd.addOption("--enable-cp246",         "+ui",    "read undefined len UN as implicit VR (default)");
-     cmd.addOption("--disable-cp246",        "-ui",    "read undefined len UN as explicit VR");
+      cmd.addOption("--enable-cp246",        "+ui",    "read undefined len UN as implicit VR (default)");
+      cmd.addOption("--disable-cp246",       "-ui",    "read undefined len UN as explicit VR");
     cmd.addSubGroup("handling of defined length UN elements:");
-     cmd.addOption("--retain-un",            "-uc",    "retain elements as UN (default)");
-     cmd.addOption("--convert-un",           "+uc",    "convert to real VR if known");
+      cmd.addOption("--retain-un",           "-uc",    "retain elements as UN (default)");
+      cmd.addOption("--convert-un",          "+uc",    "convert to real VR if known");
+    cmd.addSubGroup("handling of private max-length elements (implicit VR):");
+      cmd.addOption("--maxlength-dict",      "-sq",    "read as defined in dictionary (default)");
+      cmd.addOption("--maxlength-seq",       "+sq",    "read as sequence with undefined length");
+    cmd.addSubGroup("general handling of parser errors: ");
+      cmd.addOption("--ignore-parse-errors", "+Ep",    "try to recover from parse errors");
+      cmd.addOption("--handle-parse-errors", "-Ep",    "handle parse errors and stop parsing (default)");
+    cmd.addSubGroup("other parsing options:");
+      cmd.addOption("--stop-after-elem",     "+st", 1, "[t]ag: \"gggg,eeee\" or dictionary name",
+                                                       "stop parsing after element specified by t");
     cmd.addSubGroup("automatic data correction:");
-     cmd.addOption("--enable-correction",    "+dc",    "enable automatic data correction (default)");
-     cmd.addOption("--disable-correction",   "-dc",    "disable automatic data correction");
+      cmd.addOption("--enable-correction",   "+dc",    "enable automatic data correction (default)");
+      cmd.addOption("--disable-correction",  "-dc",    "disable automatic data correction");
 #ifdef WITH_ZLIB
     cmd.addSubGroup("bitstream format of deflated input:");
-     cmd.addOption("--bitstream-deflated",   "+bd",    "expect deflated bitstream (default)");
-     cmd.addOption("--bitstream-zlib",       "+bz",    "expect deflated zlib bitstream");
+      cmd.addOption("--bitstream-deflated",  "+bd",    "expect deflated bitstream (default)");
+      cmd.addOption("--bitstream-zlib",      "+bz",    "expect deflated zlib bitstream");
 #endif
 
   cmd.addGroup("output options:");
     cmd.addSubGroup("output file format:");
       cmd.addOption("--write-file",          "+F",     "write file format (default)");
+      cmd.addOption("--write-new-meta-info", "+Fm",    "write file format with new meta information");
       cmd.addOption("--write-dataset",       "-F",     "write data set without file meta information");
     cmd.addSubGroup("output transfer syntax:");
       cmd.addOption("--write-xfer-same",     "+t=",    "write with same TS as input (default)");
@@ -145,7 +179,7 @@ int main(int argc, char *argv[])
       cmd.addOption("--write-xfer-big",      "+tb",    "write with explicit VR big endian TS");
       cmd.addOption("--write-xfer-implicit", "+ti",    "write with implicit VR little endian TS");
 #ifdef WITH_ZLIB
-      cmd.addOption("--write-xfer-deflated", "+td",    "write with deflated expl. VR little endian TS");
+      cmd.addOption("--write-xfer-deflated", "+td",    "write with deflated explicit VR little endian TS");
 #endif
     cmd.addSubGroup("post-1993 value representations:");
       cmd.addOption("--enable-new-vr",       "+u",     "enable support for new VRs (UN/UT) (default)");
@@ -157,6 +191,8 @@ int main(int argc, char *argv[])
     cmd.addSubGroup("length encoding in sequences and items:");
       cmd.addOption("--length-explicit",     "+e",     "write with explicit lengths (default)");
       cmd.addOption("--length-undefined",    "-e",     "write with undefined lengths");
+      cmd.addOption("--write-oversized",     "+eo",    "write oversized explict length sequences\nand items with undefined length (default)");
+      cmd.addOption("--abort-oversized",     "-eo",    "abort on oversized explicit sequences/items");
     cmd.addSubGroup("data set trailing padding (not with --write-dataset):");
       cmd.addOption("--padding-retain",      "-p=",    "do not change padding\n(default if not --write-dataset)");
       cmd.addOption("--padding-off",         "-p",     "no padding (implicit if --write-dataset)");
@@ -164,29 +200,31 @@ int main(int argc, char *argv[])
                                                        "align file on multiple of f bytes\nand items on multiple of i bytes");
 #ifdef WITH_ZLIB
     cmd.addSubGroup("deflate compression level (only with --write-xfer-deflated):");
-      cmd.addOption("--compression-level",   "+cl", 1, "compression level: 0-9 (default 6)",
+      cmd.addOption("--compression-level",   "+cl", 1, "[l]evel: integer (default: 6)",
                                                        "0=uncompressed, 1=fastest, 9=best compression");
 #endif
 
+    cmd.addSubGroup("other output options:");
+      cmd.addOption("--no-invalid-groups",   "-ig",    "don't write elements with invalid group number");
+
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
-        if (cmd.findOption("--version"))
-        {
-            app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-            CERR << endl << "External libraries used:";
+          if (cmd.findOption("--version"))
+          {
+              app.printHeader(OFTrue /*print host identifier*/);
+              COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-            CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+              COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-            CERR << " none" << endl;
+              COUT << " none" << OFendl;
 #endif
-            return 0;
-         }
+              return 0;
+          }
       }
 
       /* command line parameters */
@@ -194,8 +232,7 @@ int main(int argc, char *argv[])
       cmd.getParam(1, opt_ifname);
       cmd.getParam(2, opt_ofname);
 
-      if (cmd.findOption("--verbose")) opt_verbose = OFTrue;
-      if (cmd.findOption("--debug")) opt_debugMode = 5;
+      OFLog::configureFromCommandLine(cmd, app);
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--read-file")) opt_readMode = ERM_autoDetect;
@@ -205,23 +242,34 @@ int main(int argc, char *argv[])
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--read-xfer-auto"))
-          opt_ixfer = EXS_Unknown;
+        opt_ixfer = EXS_Unknown;
       if (cmd.findOption("--read-xfer-detect"))
-          dcmAutoDetectDatasetXfer.set(OFTrue);
+        dcmAutoDetectDatasetXfer.set(OFTrue);
       if (cmd.findOption("--read-xfer-little"))
       {
-          app.checkDependence("--read-xfer-little", "--read-dataset", opt_readMode == ERM_dataset);
-          opt_ixfer = EXS_LittleEndianExplicit;
+        app.checkDependence("--read-xfer-little", "--read-dataset", opt_readMode == ERM_dataset);
+        opt_ixfer = EXS_LittleEndianExplicit;
       }
       if (cmd.findOption("--read-xfer-big"))
       {
-          app.checkDependence("--read-xfer-big", "--read-dataset", opt_readMode == ERM_dataset);
-          opt_ixfer = EXS_BigEndianExplicit;
+        app.checkDependence("--read-xfer-big", "--read-dataset", opt_readMode == ERM_dataset);
+        opt_ixfer = EXS_BigEndianExplicit;
       }
       if (cmd.findOption("--read-xfer-implicit"))
       {
-          app.checkDependence("--read-xfer-implicit", "--read-dataset", opt_readMode == ERM_dataset);
-          opt_ixfer = EXS_LittleEndianImplicit;
+        app.checkDependence("--read-xfer-implicit", "--read-dataset", opt_readMode == ERM_dataset);
+        opt_ixfer = EXS_LittleEndianImplicit;
+      }
+      cmd.endOptionBlock();
+
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--use-meta-length"))
+      {
+        dcmIgnoreFileMetaInformationGroupLength.set(OFFalse);
+      }
+      if (cmd.findOption("--ignore-meta-length"))
+      {
+        dcmIgnoreFileMetaInformationGroupLength.set(OFTrue);
       }
       cmd.endOptionBlock();
 
@@ -236,6 +284,16 @@ int main(int argc, char *argv[])
       }
       cmd.endOptionBlock();
 
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--treat-as-unknown"))
+      {
+        dcmAcceptUnexpectedImplicitEncoding.set(OFFalse);
+      }
+      if (cmd.findOption("--assume-implicit"))
+      {
+        dcmAcceptUnexpectedImplicitEncoding.set(OFTrue);
+      }
+
       cmd.beginOptionBlock();
       if (cmd.findOption("--enable-cp246"))
       {
@@ -258,6 +316,37 @@ int main(int argc, char *argv[])
       }
       cmd.endOptionBlock();
 
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--maxlength-dict"))
+      {
+        dcmReadImplPrivAttribMaxLengthAsSQ.set(OFFalse);
+      }
+      if (cmd.findOption("--maxlength-seq"))
+      {
+        dcmReadImplPrivAttribMaxLengthAsSQ.set(OFTrue);
+      }
+      cmd.endOptionBlock();
+      if (cmd.findOption("--ignore-parse-errors"))
+      {
+        dcmIgnoreParsingErrors.set(OFTrue);
+      }
+      if (cmd.findOption("--handle-parse-errors"))
+      {
+        dcmIgnoreParsingErrors.set(OFFalse);
+      }
+      cmd.endOptionBlock();
+
+      if (cmd.findOption("--stop-after-elem"))
+      {
+        const char *tagName = NULL;
+        app.checkValue(cmd.getValue(tagName));
+        DcmTagKey key = parseTagKey(tagName);
+        if (key != DCM_UndefinedTagKey)
+          dcmStopParsingAfterElement.set(key);
+        else
+          app.printError("no valid key given for option --stop-after-elem");
+      }
+
       cmd.beginOptionBlock();
       if (cmd.findOption("--enable-correction"))
       {
@@ -283,8 +372,9 @@ int main(int argc, char *argv[])
 #endif
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--write-file")) opt_oDataset = OFFalse;
-      if (cmd.findOption("--write-dataset")) opt_oDataset = OFTrue;
+      if (cmd.findOption("--write-file")) opt_writeMode = EWM_fileformat;
+      if (cmd.findOption("--write-new-meta-info")) opt_writeMode = EWM_createNewMeta;
+      if (cmd.findOption("--write-dataset")) opt_writeMode = EWM_dataset;
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
@@ -300,13 +390,13 @@ int main(int argc, char *argv[])
       cmd.beginOptionBlock();
       if (cmd.findOption("--enable-new-vr"))
       {
-          dcmEnableUnknownVRGeneration.set(OFTrue);
-          dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
+        dcmEnableUnknownVRGeneration.set(OFTrue);
+        dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
       }
       if (cmd.findOption("--disable-new-vr"))
       {
-          dcmEnableUnknownVRGeneration.set(OFFalse);
-          dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+        dcmEnableUnknownVRGeneration.set(OFFalse);
+        dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
       }
       cmd.endOptionBlock();
 
@@ -321,82 +411,86 @@ int main(int argc, char *argv[])
       if (cmd.findOption("--length-undefined")) opt_oenctype = EET_UndefinedLength;
       cmd.endOptionBlock();
 
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--write-oversized")) dcmWriteOversizedSeqsAndItemsUndefined.set(OFTrue);
+      if (cmd.findOption("--abort-oversized")) dcmWriteOversizedSeqsAndItemsUndefined.set(OFFalse);
+      cmd.endOptionBlock();
+
       cmd.beginOptionBlock();
       if (cmd.findOption("--padding-retain"))
       {
-          app.checkConflict("--padding-retain", "--write-dataset", opt_oDataset);
-          opt_opadenc = EPD_noChange;
+        app.checkConflict("--padding-retain", "--write-dataset", opt_writeMode == EWM_dataset);
+        opt_opadenc = EPD_noChange;
       }
       if (cmd.findOption("--padding-off")) opt_opadenc = EPD_withoutPadding;
       if (cmd.findOption("--padding-create"))
       {
-          app.checkConflict("--padding-create", "--write-dataset", opt_oDataset);
-          app.checkValue(cmd.getValueAndCheckMin(opt_filepad, 0));
-          app.checkValue(cmd.getValueAndCheckMin(opt_itempad, 0));
-          opt_opadenc = EPD_withPadding;
+        app.checkConflict("--padding-create", "--write-dataset", opt_writeMode == EWM_dataset);
+        app.checkValue(cmd.getValueAndCheckMin(opt_filepad, 0));
+        app.checkValue(cmd.getValueAndCheckMin(opt_itempad, 0));
+        opt_opadenc = EPD_withPadding;
       }
       cmd.endOptionBlock();
 
 #ifdef WITH_ZLIB
-      cmd.beginOptionBlock();
       if (cmd.findOption("--compression-level"))
       {
-          app.checkDependence("--compression-level", "--write-xfer-deflated", opt_oxfer == EXS_DeflatedLittleEndianExplicit);
-          app.checkValue(cmd.getValueAndCheckMinMax(opt_compressionLevel, 0, 9));
-          dcmZlibCompressionLevel.set(OFstatic_cast(int, opt_compressionLevel));
+        app.checkDependence("--compression-level", "--write-xfer-deflated", opt_oxfer == EXS_DeflatedLittleEndianExplicit);
+        app.checkValue(cmd.getValueAndCheckMinMax(opt_compressionLevel, 0, 9));
+        dcmZlibCompressionLevel.set(OFstatic_cast(int, opt_compressionLevel));
       }
-      cmd.endOptionBlock();
 #endif
 
+      if (cmd.findOption("--no-invalid-groups")) opt_noInvalidGroups = OFTrue;
     }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmconvLogger, rcsid << OFendl);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dcmconvLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     // open inputfile
     if ((opt_ifname == NULL) || (strlen(opt_ifname) == 0))
     {
-        CERR << "Error: invalid filename: <empty string>" << endl;
+        OFLOG_FATAL(dcmconvLogger, "invalid filename: <empty string>");
         return 1;
     }
 
     DcmFileFormat fileformat;
-    DcmDataset * dataset = fileformat.getDataset();
+    DcmDataset *dataset = fileformat.getDataset();
 
-    if (opt_verbose)
-        COUT << "open input file " << opt_ifname << endl;
+    OFLOG_INFO(dcmconvLogger, "open input file " << opt_ifname);
 
     OFCondition error = fileformat.loadFile(opt_ifname, opt_ixfer, EGL_noChange, DCM_MaxReadLength, opt_readMode);
 
     if (error.bad())
     {
-        CERR << "Error: "
-             << error.text()
-             << ": reading file: " <<  opt_ifname << endl;
+        OFLOG_FATAL(dcmconvLogger, error.text() << ": reading file: " <<  opt_ifname);
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "load all data into memory" << endl;
+    OFLOG_INFO(dcmconvLogger, "load all data into memory");
     /* make sure that pixel data is loaded before output file is created */
     dataset->loadAllDataIntoMemory();
 
+    if (opt_noInvalidGroups)
+    {
+        OFLOG_INFO(dcmconvLogger, "remove all elements with an invalid group number");
+        fileformat.removeInvalidGroups();
+    }
+
     if (opt_oxfer == EXS_Unknown)
     {
-        if (opt_verbose)
-            COUT << "set output transfer syntax to input transfer syntax" << endl;
+        OFLOG_INFO(dcmconvLogger, "set output transfer syntax to input transfer syntax");
         opt_oxfer = dataset->getOriginalXfer();
     }
 
-    if (opt_verbose)
-        COUT << "check if new output transfer syntax is possible" << endl;
+    OFLOG_INFO(dcmconvLogger, "check if new output transfer syntax is possible");
 
     DcmXfer opt_oxferSyn(opt_oxfer);
 
@@ -404,31 +498,24 @@ int main(int argc, char *argv[])
 
     if (dataset->canWriteXfer(opt_oxfer))
     {
-        if (opt_verbose)
-            COUT << "output transfer syntax " << opt_oxferSyn.getXferName()
-                 << " can be written" << endl;
+        OFLOG_INFO(dcmconvLogger, "output transfer syntax " << opt_oxferSyn.getXferName() << " can be written");
     } else {
-        CERR << "Error: no conversion to transfer syntax " << opt_oxferSyn.getXferName()
-             << " possible!" << endl;
+        OFLOG_FATAL(dcmconvLogger, "no conversion to transfer syntax " << opt_oxferSyn.getXferName() << " possible!");
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "create output file " << opt_ofname << endl;
+    OFLOG_INFO(dcmconvLogger, "create output file " << opt_ofname);
 
     error = fileformat.saveFile(opt_ofname, opt_oxfer, opt_oenctype, opt_oglenc, opt_opadenc,
-        OFstatic_cast(Uint32, opt_filepad), OFstatic_cast(Uint32, opt_itempad), opt_oDataset);
+        OFstatic_cast(Uint32, opt_filepad), OFstatic_cast(Uint32, opt_itempad), opt_writeMode);
 
     if (error.bad())
     {
-        CERR << "Error: "
-             << error.text()
-             << ": writing file: " <<  opt_ofname << endl;
+        OFLOG_FATAL(dcmconvLogger, error.text() << ": writing file: " <<  opt_ofname);
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "conversion successful" << endl;
+    OFLOG_INFO(dcmconvLogger, "conversion successful");
 
     return 0;
 }
@@ -437,6 +524,91 @@ int main(int argc, char *argv[])
 /*
 ** CVS/RCS Log:
 ** $Log: dcmconv.cc,v $
+** Revision 1.72  2010-10-14 13:13:30  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.71  2010-03-04 09:34:16  joergr
+** Fixed possible issue with read locks on global data dictionary.
+**
+** Revision 1.70  2009-11-13 13:20:23  joergr
+** Fixed minor issues in log output.
+**
+** Revision 1.69  2009-11-04 09:58:06  uli
+** Switched to logging mechanism provided by the "new" oflog module
+**
+** Revision 1.68  2009-08-26 10:12:42  joergr
+** Added new command line options --write-new-meta-info and --no-invalid-groups.
+**
+** Revision 1.67  2009-08-21 09:25:13  joergr
+** Added parameter 'writeMode' to save/write methods which allows for specifying
+** whether to write a dataset or fileformat as well as whether to update the
+** file meta information or to create a new file meta information header.
+**
+** Revision 1.66  2009-06-04 17:22:17  joergr
+** Fixed wrong name of command line option: used --impl-oversized instead of
+** --write-oversized.
+**
+** Revision 1.65  2009-06-04 16:50:18  joergr
+** Added new command line option that allows for ignoring the value of File Meta
+** Information Group Length (0002,0000).
+**
+** Revision 1.64  2009-04-24 12:20:41  joergr
+** Fixed minor inconsistencies regarding layout/formatting in syntax usage.
+**
+** Revision 1.63  2009-03-05 17:45:56  joergr
+** Fixed description of command line option.
+**
+** Revision 1.62  2009-03-05 14:07:48  onken
+** Fixed typo.
+**
+** Revision 1.61  2009-03-05 13:54:36  onken
+** Fixed typo.
+**
+** Revision 1.60  2009-03-05 13:39:26  onken
+** Added support for the new parser's global sequence/item length overflow flag.
+**
+** Revision 1.59  2009-02-11 16:55:31  joergr
+** Renamed option --stop-at-elem to --stop-after-elem and fixed typo.
+**
+** Revision 1.58  2009-02-11 13:16:17  onken
+** Added global parser flag permitting to stop parsing after a specific
+** element was parsed on dataset level (useful for removing garbage at
+** end of file).
+**
+** Revision 1.57  2009-02-04 14:07:10  onken
+** Added command line options making use of the parser's error ignoring flag.
+**
+** Revision 1.56  2009-01-29 15:36:52  onken
+** *** empty log message ***
+**
+** Revision 1.55  2009-01-05 15:30:15  joergr
+** Added command line options that allow for reading incorrectly encoded DICOM
+** datasets where particular data elements are encoded with a differing transfer
+** syntax (Implicit VR Little endian instead of Explicit VR encoding).
+**
+** Revision 1.54  2008-11-03 16:42:23  joergr
+** Removed "option block" encapsulation from option --compression-level.
+**
+** Revision 1.53  2008-11-03 15:33:06  joergr
+** Made documentation of --compression-level more consistent with other options.
+**
+** Revision 1.52  2008-09-25 14:38:48  joergr
+** Moved output of resource identifier in order to avoid printing the same
+** information twice.
+**
+** Revision 1.51  2008-09-25 11:19:48  joergr
+** Added support for printing the expanded command line arguments.
+** Always output the resource identifier of the command line tool in debug mode.
+**
+** Revision 1.50  2006/08/15 15:50:56  meichel
+** Updated all code in module dcmdata to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.49  2006/07/27 13:52:42  joergr
+** Changed parameter "exclusive" of method addOption() from type OFBool into an
+** integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+** Option "--help" is no longer an exclusive option by default.
+**
 ** Revision 1.48  2005/12/08 15:40:43  meichel
 ** Changed include path schema for all DCMTK header files
 **
