@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Compress DICOM file with RLE Transfer Syntax
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:40:44 $
- *  CVS/RCS Revision: $Revision: 1.11 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:30 $
+ *  CVS/RCS Revision: $Revision: 1.22 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -42,7 +38,6 @@
 #endif
 
 #include "dcmtk/dcmdata/dctk.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/ofstd/ofconapp.h"
 #include "dcmtk/dcmdata/dcuid.h"     /* for dcmtk version name */
@@ -54,13 +49,15 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dcmcrle"
 
+static OFLogger dcmcrleLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
 // ********************************************
 
 
-#define SHORTCOL 4
+#define SHORTCOL 3
 #define LONGCOL 21
 
 int main(int argc, char *argv[])
@@ -71,13 +68,9 @@ int main(int argc, char *argv[])
   GUSISetup(GUSIwithInternetSockets);
 #endif
 
-  SetDebugLevel(( 0 ));
-
   const char *opt_ifname = NULL;
   const char *opt_ofname = NULL;
 
-  int opt_debugMode = 0;
-  OFBool opt_verbose = OFFalse;
   E_FileReadMode opt_readMode = ERM_autoDetect;
   E_TransferSyntax opt_ixfer = EXS_Unknown;
   E_GrpLenEncoding opt_oglenc = EGL_recalcGL;
@@ -93,7 +86,7 @@ int main(int argc, char *argv[])
   OFBool           opt_uidcreation = OFFalse;
   OFBool           opt_secondarycapture = OFFalse;
 
-  OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "Encode DICOM file to RLE transfer syntax", rcsid);
+  OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, "Encode DICOM file to RLE transfer syntax", rcsid);
   OFCommandLine cmd;
   cmd.setOptionColumns(LONGCOL, SHORTCOL);
   cmd.setParamColumn(LONGCOL + SHORTCOL + 4);
@@ -102,76 +95,74 @@ int main(int argc, char *argv[])
   cmd.addParam("dcmfile-out", "DICOM output filename");
 
   cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-   cmd.addOption("--help",                      "-h",        "print this help text and exit");
-   cmd.addOption("--version",                                "print version information and exit", OFTrue /* exclusive */);
-   cmd.addOption("--verbose",                   "-v",        "verbose mode, print processing details");
-   cmd.addOption("--debug",                     "-d",        "debug mode, print debug information");
+    cmd.addOption("--help",                  "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+    cmd.addOption("--version",                         "print version information and exit", OFCommandLine::AF_Exclusive);
+    OFLog::addOptions(cmd);
 
   cmd.addGroup("input options:");
     cmd.addSubGroup("input file format:");
-      cmd.addOption("--read-file",              "+f",        "read file format or data set (default)");
-      cmd.addOption("--read-file-only",         "+fo",       "read file format only");
-      cmd.addOption("--read-dataset",           "-f",        "read data set without file meta information");
+      cmd.addOption("--read-file",           "+f",     "read file format or data set (default)");
+      cmd.addOption("--read-file-only",      "+fo",    "read file format only");
+      cmd.addOption("--read-dataset",        "-f",     "read data set without file meta information");
     cmd.addSubGroup("input transfer syntax:", LONGCOL, SHORTCOL);
-     cmd.addOption("--read-xfer-auto",          "-t=",       "use TS recognition (default)");
-     cmd.addOption("--read-xfer-detect",        "-td",       "ignore TS specified in the file meta header");
-     cmd.addOption("--read-xfer-little",        "-te",       "read with explicit VR little endian TS");
-     cmd.addOption("--read-xfer-big",           "-tb",       "read with explicit VR big endian TS");
-     cmd.addOption("--read-xfer-implicit",      "-ti",       "read with implicit VR little endian TS");
+      cmd.addOption("--read-xfer-auto",      "-t=",    "use TS recognition (default)");
+      cmd.addOption("--read-xfer-detect",    "-td",    "ignore TS specified in the file meta header");
+      cmd.addOption("--read-xfer-little",    "-te",    "read with explicit VR little endian TS");
+      cmd.addOption("--read-xfer-big",       "-tb",    "read with explicit VR big endian TS");
+      cmd.addOption("--read-xfer-implicit",  "-ti",    "read with implicit VR little endian TS");
 
   cmd.addGroup("encapsulated pixel data encoding options:");
-    cmd.addSubGroup("pixel data fragmentation options:");
-     cmd.addOption("--fragment-per-frame",      "+ff",       "encode each frame as one fragment (default)");
-     cmd.addOption("--fragment-size",           "+fs",    1, "[s]ize: integer",
-                                                             "limit fragment size to s kbytes (non-standard)");
-    cmd.addSubGroup("basic offset table encoding options:");
-     cmd.addOption("--offset-table-create",     "+ot",       "create offset table (default)");
-     cmd.addOption("--offset-table-empty",      "-ot",       "leave offset table empty");
+    cmd.addSubGroup("pixel data fragmentation:");
+      cmd.addOption("--fragment-per-frame",  "+ff",    "encode each frame as one fragment (default)");
+      cmd.addOption("--fragment-size",       "+fs", 1, "[s]ize: integer",
+                                                       "limit fragment size to s kbytes (non-standard)");
+    cmd.addSubGroup("basic offset table encoding:");
+      cmd.addOption("--offset-table-create", "+ot",    "create offset table (default)");
+      cmd.addOption("--offset-table-empty",  "-ot",    "leave offset table empty");
 
-    cmd.addSubGroup("SOP Class UID options:");
-     cmd.addOption("--class-default",      "+cd",     "keep SOP Class UID (default)");
-     cmd.addOption("--class-sc",           "+cs",     "convert to Secondary Capture Image\n(implies --uid-always)");
+    cmd.addSubGroup("SOP Class UID:");
+      cmd.addOption("--class-default",       "+cd",    "keep SOP Class UID (default)");
+      cmd.addOption("--class-sc",            "+cs",    "convert to Secondary Capture Image\n(implies --uid-always)");
 
-    cmd.addSubGroup("SOP Instance UID options:");
-     cmd.addOption("--uid-never",          "+un",     "never assign new UID (default)");
-     cmd.addOption("--uid-always",         "+ua",     "always assign new UID");
+    cmd.addSubGroup("SOP Instance UID:");
+      cmd.addOption("--uid-never",           "+un",    "never assign new UID (default)");
+      cmd.addOption("--uid-always",          "+ua",    "always assign new UID");
 
   cmd.addGroup("output options:");
     cmd.addSubGroup("post-1993 value representations:");
-      cmd.addOption("--enable-new-vr",          "+u",        "enable support for new VRs (UN/UT) (default)");
-      cmd.addOption("--disable-new-vr",         "-u",        "disable support for new VRs, convert to OB");
+      cmd.addOption("--enable-new-vr",       "+u",     "enable support for new VRs (UN/UT) (default)");
+      cmd.addOption("--disable-new-vr",      "-u",     "disable support for new VRs, convert to OB");
     cmd.addSubGroup("group length encoding:");
-      cmd.addOption("--group-length-recalc",    "+g=",       "recalculate group lengths if present (default)");
-      cmd.addOption("--group-length-create",    "+g",        "always write with group length elements");
-      cmd.addOption("--group-length-remove",    "-g",        "always write without group length elements");
+      cmd.addOption("--group-length-recalc", "+g=",    "recalculate group lengths if present (default)");
+      cmd.addOption("--group-length-create", "+g",     "always write with group length elements");
+      cmd.addOption("--group-length-remove", "-g",     "always write without group length elements");
     cmd.addSubGroup("length encoding in sequences and items:");
-      cmd.addOption("--length-explicit",        "+e",        "write with explicit lengths (default)");
-      cmd.addOption("--length-undefined",       "-e",        "write with undefined lengths");
+      cmd.addOption("--length-explicit",     "+e",     "write with explicit lengths (default)");
+      cmd.addOption("--length-undefined",    "-e",     "write with undefined lengths");
     cmd.addSubGroup("data set trailing padding:");
-      cmd.addOption("--padding-retain",         "-p=",       "do not change padding (default)");
-      cmd.addOption("--padding-off",            "-p",        "no padding");
-      cmd.addOption("--padding-create",         "+p",    2,  "[f]ile-pad [i]tem-pad: integer",
-                                                             "align file on multiple of f bytes\nand items on multiple of i bytes");
+      cmd.addOption("--padding-retain",      "-p=",    "do not change padding (default)");
+      cmd.addOption("--padding-off",         "-p",     "no padding");
+      cmd.addOption("--padding-create",      "+p",  2, "[f]ile-pad [i]tem-pad: integer",
+                                                       "align file on multiple of f bytes\nand items on multiple of i bytes");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
-        if (cmd.findOption("--version"))
-        {
-            app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-            CERR << endl << "External libraries used:";
+          if (cmd.findOption("--version"))
+          {
+              app.printHeader(OFTrue /*print host identifier*/);
+              COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-            CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+              COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-            CERR << " none" << endl;
+              COUT << " none" << OFendl;
 #endif
-            return 0;
-         }
+              return 0;
+          }
       }
 
       /* command line parameters */
@@ -179,8 +170,7 @@ int main(int argc, char *argv[])
       cmd.getParam(1, opt_ifname);
       cmd.getParam(2, opt_ofname);
 
-      if (cmd.findOption("--verbose")) opt_verbose = OFTrue;
-      if (cmd.findOption("--debug")) opt_debugMode = 5;
+      OFLog::configureFromCommandLine(cmd, app);
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--read-file")) opt_readMode = ERM_autoDetect;
@@ -225,7 +215,6 @@ int main(int argc, char *argv[])
       if (cmd.findOption("--offset-table-empty")) opt_createOffsetTable = OFFalse;
       cmd.endOptionBlock();
 
-
       cmd.beginOptionBlock();
       if (cmd.findOption("--class-default")) opt_secondarycapture = OFFalse;
       if (cmd.findOption("--class-sc")) opt_secondarycapture = OFTrue;
@@ -270,100 +259,90 @@ int main(int argc, char *argv[])
           opt_opadenc = EPD_withPadding;
       }
       cmd.endOptionBlock();
-
     }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmcrleLogger, rcsid << OFendl);
 
     // register RLE compression codec
-    DcmRLEEncoderRegistration::registerCodecs(opt_uidcreation, opt_verbose,
+    DcmRLEEncoderRegistration::registerCodecs(opt_uidcreation,
       opt_fragmentSize, opt_createOffsetTable, opt_secondarycapture);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dcmcrleLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     // open inputfile
     if ((opt_ifname == NULL) || (strlen(opt_ifname) == 0))
     {
-        CERR << "invalid filename: <empty string>" << endl;
+        OFLOG_FATAL(dcmcrleLogger, "invalid filename: <empty string>");
         return 1;
     }
 
     DcmFileFormat fileformat;
     DcmDataset * dataset = fileformat.getDataset();
 
-    if (opt_verbose)
-        COUT << "open input file " << opt_ifname << endl;
+    OFLOG_INFO(dcmcrleLogger, "open input file " << opt_ifname);
 
     OFCondition error = fileformat.loadFile(opt_ifname, opt_ixfer, EGL_noChange, DCM_MaxReadLength, opt_readMode);
 
     if (error.bad())
     {
-        CERR << "Error: "
-             << error.text()
-             << ": reading file: " <<  opt_ifname << endl;
+        OFLOG_FATAL(dcmcrleLogger, error.text() << ": reading file: " << opt_ifname);
         return 1;
     }
 
     DcmXfer original_xfer(dataset->getOriginalXfer());
     if (original_xfer.isEncapsulated())
     {
-      if (opt_verbose)
-        COUT << "DICOM file is already compressed, convert to uncompressed xfer syntax first\n";
+      OFLOG_INFO(dcmcrleLogger, "DICOM file is already compressed, converting to uncompressed transfer syntax first");
       if (EC_Normal != dataset->chooseRepresentation(EXS_LittleEndianExplicit, NULL))
       {
-        CERR << "No conversion from compressed original to uncompressed xfer syntax possible!\n";
+        OFLOG_FATAL(dcmcrleLogger, "No conversion from compressed original to uncompressed transfer syntax possible!");
         return 1;
       }
     }
+    
+    OFString sopClass;
+    if (fileformat.getMetaInfo()->findAndGetOFString(DCM_MediaStorageSOPClassUID, sopClass).good())
+    {
+        /* check for DICOMDIR files */
+        if (sopClass == UID_MediaStorageDirectoryStorage)
+        {
+            OFLOG_FATAL(dcmcrleLogger, "DICOMDIR files (Media Storage Directory Storage SOP Class) cannot be compressed!");
+            return 1;
+        }
+    }
 
-    if (opt_verbose)
-        COUT << "Convert DICOM file to compressed transfer syntax\n";
+    OFLOG_INFO(dcmcrleLogger, "Convert DICOM file to compressed transfer syntax");
 
     DcmXfer opt_oxferSyn(opt_oxfer);
 
     dataset->chooseRepresentation(opt_oxfer, NULL);
     if (dataset->canWriteXfer(opt_oxfer))
     {
-        if (opt_verbose)
-            COUT << "Output transfer syntax " << opt_oxferSyn.getXferName()
-                 << " can be written\n";
+        OFLOG_INFO(dcmcrleLogger, "Output transfer syntax " << opt_oxferSyn.getXferName() << " can be written");
     } else {
-        CERR << "No conversion to transfer syntax " << opt_oxferSyn.getXferName()
-             << " possible!\n";
+        OFLOG_FATAL(dcmcrleLogger, "No conversion to transfer syntax " << opt_oxferSyn.getXferName() << " possible!");
         return 1;
     }
 
-    // force meta-header to refresh SOP Class/Instance UIDs.
-    DcmItem *metaInfo = fileformat.getMetaInfo();
-    if (metaInfo)
-    {
-      delete metaInfo->remove(DCM_MediaStorageSOPClassUID);
-      delete metaInfo->remove(DCM_MediaStorageSOPInstanceUID);
-    }
-
-    if (opt_verbose)
-        COUT << "create output file " << opt_ofname << endl;
+    OFLOG_INFO(dcmcrleLogger, "create output file " << opt_ofname);
 
     fileformat.loadAllDataIntoMemory();
     error = fileformat.saveFile(opt_ofname, opt_oxfer, opt_oenctype, opt_oglenc, opt_opadenc,
-        OFstatic_cast(Uint32, opt_filepad), OFstatic_cast(Uint32, opt_itempad));
+        OFstatic_cast(Uint32, opt_filepad), OFstatic_cast(Uint32, opt_itempad), EWM_updateMeta);
 
     if (error.bad())
     {
-        CERR << "Error: "
-             << error.text()
-             << ": writing file: " <<  opt_ofname << endl;
+        OFLOG_FATAL(dcmcrleLogger, error.text() << ": writing file: " << opt_ofname);
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "conversion successful\n";
+    OFLOG_INFO(dcmcrleLogger, "conversion successful");
 
     // deregister RLE codec
     DcmRLEEncoderRegistration::cleanup();
@@ -375,6 +354,49 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcmcrle.cc,v $
+ * Revision 1.22  2010-10-14 13:13:30  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.21  2009-11-13 13:20:23  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.20  2009-11-04 09:58:06  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.19  2009-08-21 09:24:07  joergr
+ * Added parameter 'writeMode' to save/write methods which allows for specifying
+ * whether to write a dataset or fileformat as well as whether to update the
+ * file meta information or to create a new file meta information header.
+ * Added check making sure that a DICOMDIR file is never compressed.
+ * Use helper function checkConflict() where appropriate.
+ * Made error messages more consistent with other compression tools.
+ *
+ * Revision 1.18  2009-08-05 10:52:49  joergr
+ * Fixed various issues with syntax usage (e.g. layout and formatting).
+ *
+ * Revision 1.17  2009-04-21 14:02:49  joergr
+ * Fixed minor inconsistencies in manpage / syntax usage.
+ *
+ * Revision 1.16  2009-03-19 12:06:42  joergr
+ * Replaced '\n' by OFendl where appropriate.
+ *
+ * Revision 1.15  2008-09-25 14:38:48  joergr
+ * Moved output of resource identifier in order to avoid printing the same
+ * information twice.
+ *
+ * Revision 1.14  2008-09-25 11:19:48  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.13  2006/08/15 15:50:56  meichel
+ * Updated all code in module dcmdata to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.12  2006/07/27 13:52:42  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
  * Revision 1.11  2005/12/08 15:40:44  meichel
  * Changed include path schema for all DCMTK header files
  *
