@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: Test if a file uses DICOM Part 10 format.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:40:47 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmdata/apps/dcmftest.cc,v $
- *  CVS/RCS Revision: $Revision: 1.18 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:30 $
+ *  CVS/RCS Revision: $Revision: 1.22 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -58,8 +53,8 @@ int main(int argc, char *argv[])
 
     /* evaluate command line */
     cmd.addParam("file", OFCmdParam::PM_MultiMandatory);
-    app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards);
-    
+    app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards);
+
     int badCount = 0;
     int count = cmd.getParamCount();
     const char *fname = NULL;
@@ -73,7 +68,7 @@ int main(int argc, char *argv[])
             ok = OFFalse;
         } else {
             char signature[4];
-            if ((fseek(f, DCM_PreambleLen, SEEK_SET) < 0) || 
+            if ((fseek(f, DCM_PreambleLen, SEEK_SET) < 0) ||
                 (fread(signature, 1, DCM_MagicLen, f) != DCM_MagicLen)) {
                 ok = OFFalse;
             } else if (strncmp(signature, DCM_Magic, DCM_MagicLen) != 0) {
@@ -85,14 +80,14 @@ int main(int argc, char *argv[])
             fclose(f);
         }
         if (ok) {
-            COUT << "yes: " << fname << endl;
+            COUT << "yes: " << fname << OFendl;
         } else {
-            COUT << "no: " << fname << endl;
+            COUT << "no: " << fname << OFendl;
             badCount++;
         }
     }
 
-    /* 
+    /*
     ** if all files are ok then return zero, otherwise the
     ** number of non-dicom files.
     */
@@ -102,6 +97,19 @@ int main(int argc, char *argv[])
 /*
 ** CVS/RCS Log:
 ** $Log: dcmftest.cc,v $
+** Revision 1.22  2010-10-14 13:13:30  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.21  2009-11-04 09:58:06  uli
+** Switched to logging mechanism provided by the "new" oflog module
+**
+** Revision 1.20  2006-08-15 15:50:56  meichel
+** Updated all code in module dcmdata to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.19  2006/07/27 13:34:18  joergr
+** Prepended prefix "PF_" to parseLine() flags.
+**
 ** Revision 1.18  2005/12/08 15:40:47  meichel
 ** Changed include path schema for all DCMTK header files
 **
