@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -45,9 +41,9 @@
  *  There should be no need to set this compiler flag manually, just compile
  *  dcmjpeg/apps/dcmmkdir.cc.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:40:48 $
- *  CVS/RCS Revision: $Revision: 1.81 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:30 $
+ *  CVS/RCS Revision: $Revision: 1.95 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -58,19 +54,18 @@
 #include "dcmtk/config/osconfig.h"     /* make sure OS specific configuration is included first */
 
 #include "dcmtk/dcmdata/dctk.h"
-#include "dcmtk/dcmdata/dcuid.h"        /* for dcmtk version name */
-#include "dcmtk/dcmdata/dcddirif.h"     /* for class DicomDirInterface */
-#include "dcmtk/ofstd/ofstd.h"        /* for class OFStandard */
-#include "dcmtk/ofstd/ofconapp.h"     /* for class OFConsoleApplication */
-#include "dcmtk/ofstd/ofcond.h"       /* for class OFCondition */
-#include "dcmtk/dcmdata/dcdebug.h"
+#include "dcmtk/dcmdata/dcuid.h"       /* for dcmtk version name */
+#include "dcmtk/dcmdata/dcddirif.h"    /* for class DicomDirInterface */
+#include "dcmtk/ofstd/ofstd.h"         /* for class OFStandard */
+#include "dcmtk/ofstd/ofconapp.h"      /* for class OFConsoleApplication */
+#include "dcmtk/ofstd/ofcond.h"        /* for class OFCondition */
 
 #ifdef BUILD_DCMGPDIR_AS_DCMMKDIR
-#include "dcmtk/dcmimage/diregist.h"     /* include to support color images */
-#include "dcmtk/dcmdata/dcrledrg.h"     /* for DcmRLEDecoderRegistration */
-#include "dcmtk/dcmjpeg/djdecode.h"     /* for dcmjpeg decoders */
-#include "dcmtk/dcmjpeg/dipijpeg.h"     /* for dcmimage JPEG plugin */
-#include "dcmtk/dcmjpeg/ddpiimpl.h"     /* for class DicomDirImageImplementation */
+#include "dcmtk/dcmimage/diregist.h"   /* include to support color images */
+#include "dcmtk/dcmdata/dcrledrg.h"    /* for DcmRLEDecoderRegistration */
+#include "dcmtk/dcmjpeg/djdecode.h"    /* for dcmjpeg decoders */
+#include "dcmtk/dcmjpeg/dipijpeg.h"    /* for dcmimage JPEG plugin */
+#include "dcmtk/dcmjpeg/ddpiimpl.h"    /* for class DicomDirImageImplementation */
 #endif
 
 #ifdef WITH_ZLIB
@@ -93,6 +88,8 @@
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
+static OFLogger dcmgpdirLogger = OFLog::getLogger("dcmtk.dcmdata." OFFIS_CONSOLE_APPLICATION);
+
 #define SHORTCOL 4
 #define LONGCOL 23
 
@@ -100,9 +97,9 @@ static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
 
 int main(int argc, char *argv[])
 {
-    int opt_debug = 0;
     OFBool opt_write = OFTrue;
     OFBool opt_append = OFFalse;
+    OFBool opt_update = OFFalse;
     OFBool opt_recurse = OFFalse;
     E_EncodingType opt_enctype = EET_ExplicitLength;
     E_GrpLenEncoding opt_glenc = EGL_withoutGL;
@@ -110,21 +107,24 @@ int main(int argc, char *argv[])
     const char *opt_fileset = DEFAULT_FILESETID;
     const char *opt_descriptor = NULL;
     const char *opt_charset = DEFAULT_DESCRIPTOR_CHARSET;
-    const char *opt_directory = NULL;
-    const char *opt_pattern = NULL;
+    const char *opt_directory = "";
+    const char *opt_pattern = "";
     DicomDirInterface::E_ApplicationProfile opt_profile = DicomDirInterface::AP_GeneralPurpose;
 
 #ifdef BUILD_DCMGPDIR_AS_DCMMKDIR
     // register global decompression codecs (no verbose/debug mode set)
     DcmRLEDecoderRegistration::registerCodecs();
     DJDecoderRegistration::registerCodecs();
+    // enable the following lines for JPEG 2000 decompression support
+/*
+    D2JPEG2000Library::initialize();
+    D2DecoderRegistration::registerCodecs();
+*/
 #endif
 
     /* DICOMDIR interface (checks for JPEG/RLE availability) */
     DicomDirInterface ddir;
 
-    SetDebugLevel(( 0 ));
-
     /* set-up command line parameters and options */
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, OFFIS_CONSOLE_DESCRIPTION, rcsid);
     OFCommandLine cmd;
@@ -134,52 +134,53 @@ int main(int argc, char *argv[])
     cmd.addParam("dcmfile-in", "referenced DICOM file", OFCmdParam::PM_MultiOptional);
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-     cmd.addOption("--help",                     "-h",     "print this help text and exit");
-     cmd.addOption("--version",                            "print version information and exit", OFTrue /* exclusive */);
-     cmd.addOption("--verbose",                  "-v",     "verbose mode, print processing details");
-     cmd.addOption("--quiet",                    "-q",     "quiet mode, print no warnings and errors");
-     cmd.addOption("--debug",                    "-d",     "debug mode, print debug information");
+     cmd.addOption("--help",                     "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+     cmd.addOption("--version",                            "print version information and exit", OFCommandLine::AF_Exclusive);
+     OFLog::addOptions(cmd);
 
     cmd.addGroup("input options:");
       cmd.addSubGroup("DICOMDIR identifiers:");
-        cmd.addOption("--output-file",           "+D", 1,  "[f]ilename : string",
+        cmd.addOption("--output-file",           "+D",  1, "[f]ilename: string",
                                                            "generate specific DICOMDIR file\n(default: " DEFAULT_DICOMDIR_NAME " in current directory)");
-        cmd.addOption("--fileset-id",            "+F", 1,  "[i]d : string (default: " DEFAULT_FILESETID ")",
+        cmd.addOption("--fileset-id",            "+F",  1, "[i]d: string (default: " DEFAULT_FILESETID ")",
                                                            "use specific file set ID");
-        cmd.addOption("--descriptor",            "+R", 1,  "[f]ilename : string",
+        cmd.addOption("--descriptor",            "+R",  1, "[f]ilename: string",
                                                            "add a file set descriptor file ID\n(e.g. README, default: no descriptor)");
-        cmd.addOption("--char-set",              "+C", 1,  "[c]har-set : string",
+        cmd.addOption("--char-set",              "+C",  1, "[c]harset: string",
                                                            "add a specific character set for descriptor\n(default: \"" DEFAULT_DESCRIPTOR_CHARSET "\" if descriptor present)");
-      cmd.addSubGroup("type 1 attributes:");
-        cmd.addOption("--strict",                "-I",     "exit with error if DICOMDIR type 1 attributes\nare missing in DICOM file (default)");
-        cmd.addOption("--invent",                "+I",     "invent DICOMDIR type 1 attributes\nif missing in DICOM file");
       cmd.addSubGroup("reading:");
-        cmd.addOption("--input-directory",       "+id", 1, "[d]irectory : string",
+        cmd.addOption("--input-directory",       "+id", 1, "[d]irectory: string",
                                                            "read referenced DICOM files from directory d\n(default for --recurse: current directory)");
         cmd.addOption("--keep-filenames",        "-m",     "expect filenames to be in DICOM format (def.)");
         cmd.addOption("--map-filenames",         "+m",     "map to DICOM filenames (lowercase->uppercase,\nand remove trailing period)");
         cmd.addOption("--no-recurse",            "-r",     "do not recurse within directories (default)");
         cmd.addOption("--recurse",               "+r",     "recurse within filesystem directories");
 #ifdef PATTERN_MATCHING_AVAILABLE
-        cmd.addOption("--pattern",               "+p", 1,  "[p]attern : string (only with --recurse)",
+        cmd.addOption("--pattern",               "+p",  1, "[p]attern: string (only with --recurse)",
                                                            "pattern for filename matching (wildcards)");
 #endif
-      cmd.addSubGroup("checking:");
+    cmd.addGroup("processing options:");
+      cmd.addSubGroup("consistency check:");
         cmd.addOption("--no-consistency-check",  "-W",     "do not check files for consistency");
         cmd.addOption("--warn-inconsist-files",  "+W",     "warn about inconsistent files (default)");
         cmd.addOption("--abort-inconsist-file",  "-a",     "abort on first inconsistent file");
-        cmd.addOption("--invent-patient-id",     "+Ipi",   "invent new PatientID in case of inconsistent\nPatientsName attributes");
+      cmd.addSubGroup("type 1 attributes:");
+        cmd.addOption("--strict",                "-I",     "exit with error if DICOMDIR type 1 attributes\nare missing in DICOM file (default)");
+        cmd.addOption("--invent",                "+I",     "invent DICOMDIR type 1 attributes\nif missing in DICOM file");
+        cmd.addOption("--invent-patient-id",     "+Ipi",   "invent new PatientID in case of inconsistent\nPatientName attributes");
+      cmd.addSubGroup("other checks:");
+        cmd.addOption("--allow-retired-sop",     "+Nrs",   "allow retired SOP classes defined in previous\neditions of the DICOM standard");
+        cmd.addOption("--no-xfer-check",         "-Nxc",   "do not reject images with non-standard\ntransfer syntax (just warn)");
 #ifdef BUILD_DCMGPDIR_AS_DCMMKDIR
         cmd.addOption("--no-encoding-check",     "-Nec",   "do not reject images with non-standard\npixel encoding (just warn)");
         cmd.addOption("--no-resolution-check",   "-Nrc",   "do not reject images with non-standard\nspatial resolution (just warn)");
-        cmd.addOption("--no-xfer-check",         "-Nxc",   "do not reject images with non-standard\ntransfer syntax (just warn)");
       cmd.addSubGroup("icon images:");
         cmd.addOption("--add-icon-image",        "+X",     "add monochrome icon image on IMAGE level\n(default for cardiac profiles)");
-        cmd.addOption("--icon-image-size",       "-Xs", 1, "[s]ize : integer (1..128)",
+        cmd.addOption("--icon-image-size",       "-Xs", 1, "[s]ize: integer (1..128)",
                                                            "width and height of the icon image (in pixel)\n(fixed: 128 for XA, 64 for CT/MR profile)");
-        cmd.addOption("--icon-file-prefix",      "-Xi", 1, "[p]refix : string",
+        cmd.addOption("--icon-file-prefix",      "-Xi", 1, "[p]refix: string",
                                                            "use PGM image 'prefix'+'dcmfile-in' as icon\n(default: create icon from DICOM image)");
-        cmd.addOption("--default-icon",          "-Xd", 1, "[f]ilename : string",
+        cmd.addOption("--default-icon",          "-Xd", 1, "[f]ilename: string",
                                                            "use specified PGM image if icon cannot be\ncreated automatically (default: black image)");
 #endif
     cmd.addGroup("output options:");
@@ -207,6 +208,7 @@ int main(int argc, char *argv[])
       cmd.addSubGroup("writing:");
         cmd.addOption("--replace",               "-A",     "replace existing DICOMDIR (default)");
         cmd.addOption("--append",                "+A",     "append to existing DICOMDIR");
+        cmd.addOption("--update",                "+U",     "update existing DICOMDIR");
         cmd.addOption("--discard",               "-w",     "do not write out DICOMDIR");
         cmd.addOption("--no-backup",             "-nb",    "do not create a backup of existing DICOMDIR");
       cmd.addSubGroup("post-1993 value representations:");
@@ -221,47 +223,36 @@ int main(int argc, char *argv[])
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
         /* print help text and exit */
         if (cmd.getArgCount() == 0)
             app.printUsage();
 
         /* check exclusive options first */
-        if (cmd.getParamCount() == 0)
+        if (cmd.hasExclusiveOption())
         {
             if (cmd.findOption("--version"))
             {
-                app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-                CERR << endl << "External libraries used:";
+                app.printHeader(OFTrue /*print host identifier*/);
+                COUT << OFendl << "External libraries used:";
 #if !defined(WITH_ZLIB) && !defined(BUILD_DCMGPDIR_AS_DCMMKDIR)
-                CERR << " none" << endl;
+                COUT << " none" << OFendl;
 #else
-                CERR << endl;
+                COUT << OFendl;
 #endif
 #ifdef WITH_ZLIB
-                CERR << "- ZLIB, Version " << zlibVersion() << endl;
+                COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
 #ifdef BUILD_DCMGPDIR_AS_DCMMKDIR
-                CERR << "- " << DiJPEGPlugin::getLibraryVersionString() << endl;
+                COUT << "- " << DiJPEGPlugin::getLibraryVersionString() << OFendl;
 #endif
                 return 0;
             }
         }
 
         /* general options */
-        cmd.beginOptionBlock();
-        if (cmd.findOption("--verbose"))
-            ddir.enableVerboseMode();
-        if (cmd.findOption("--quiet"))
-        {
-            ddir.enableVerboseMode(OFFalse);
-            app.setQuietMode();
-        }
-        cmd.endOptionBlock();
-
-        if (cmd.findOption("--debug"))
-            opt_debug = 5;
+        OFLog::configureFromCommandLine(cmd, app);
 
         /* input options */
         if (cmd.findOption("--output-file"))
@@ -273,13 +264,6 @@ int main(int argc, char *argv[])
         if (cmd.findOption("--char-set"))
             app.checkValue(cmd.getValue(opt_charset));
 
-        cmd.beginOptionBlock();
-        if (cmd.findOption("--strict"))
-            ddir.enableInventMode(OFFalse);
-        if (cmd.findOption("--invent"))
-            ddir.enableInventMode(OFTrue);
-        cmd.endOptionBlock();
-
         if (cmd.findOption("--input-directory"))
             app.checkValue(cmd.getValue(opt_directory));
 
@@ -296,7 +280,7 @@ int main(int argc, char *argv[])
         if (cmd.findOption("--recurse"))
         {
             opt_recurse = OFTrue;
-            if (opt_directory == NULL)
+            if ((opt_directory == NULL) || (strlen(opt_directory) == 0))
                 opt_directory = ".";
         }
         cmd.endOptionBlock();
@@ -309,6 +293,7 @@ int main(int argc, char *argv[])
         }
 #endif
 
+        /* processing options */
         cmd.beginOptionBlock();
         if (cmd.findOption("--no-consistency-check"))
             ddir.disableConsistencyCheck();
@@ -317,16 +302,27 @@ int main(int argc, char *argv[])
         if (cmd.findOption("--abort-inconsist-file"))
             ddir.enableAbortMode(OFTrue);
         cmd.endOptionBlock();
+
+        cmd.beginOptionBlock();
+        if (cmd.findOption("--strict"))
+            ddir.enableInventMode(OFFalse);
+        if (cmd.findOption("--invent"))
+            ddir.enableInventMode(OFTrue);
+        cmd.endOptionBlock();
+
         if (cmd.findOption("--invent-patient-id"))
             ddir.enableInventPatientIDMode();
 
+        if (cmd.findOption("--allow-retired-sop"))
+            ddir.enableRetiredSOPClassSupport();
+        if (cmd.findOption("--no-xfer-check"))
+            ddir.disableTransferSyntaxCheck();
+
 #ifdef BUILD_DCMGPDIR_AS_DCMMKDIR
         if (cmd.findOption("--no-encoding-check"))
             ddir.disableEncodingCheck();
         if (cmd.findOption("--no-resolution-check"))
             ddir.disableResolutionCheck();
-        if (cmd.findOption("--no-xfer-check"))
-            ddir.disableTransferSyntaxCheck();
         if (cmd.findOption("--add-icon-image"))
             ddir.enableIconImageMode();
         if (cmd.findOption("--icon-image-size"))
@@ -360,8 +356,8 @@ int main(int argc, char *argv[])
             opt_profile = DicomDirInterface::AP_GeneralPurposeMIME;
         if (cmd.findOption("--usb-and-flash"))
             opt_profile = DicomDirInterface::AP_USBandFlash;
-        if (cmd.findOption("--mpeg2-mp-at-ml"))
-            opt_profile = DicomDirInterface::AP_MPEG2MPatML;
+        if (cmd.findOption("--mpeg2-mpml-dvd"))
+            opt_profile = DicomDirInterface::AP_MPEG2MPatMLDVD;
         if (cmd.findOption("--basic-cardiac"))
             opt_profile = DicomDirInterface::AP_BasicCardiac;
         if (cmd.findOption("--xray-angiographic"))
@@ -396,16 +392,25 @@ int main(int argc, char *argv[])
         {
             opt_write = OFTrue;
             opt_append = OFFalse;
+            opt_update = OFFalse;
         }
         if (cmd.findOption("--append"))
         {
             opt_write = OFTrue;
             opt_append = OFTrue;
+            opt_update = OFFalse;
+        }
+        if (cmd.findOption("--update"))
+        {
+            opt_write = OFTrue;
+            opt_append = OFFalse;
+            opt_update = OFTrue;
         }
         if (cmd.findOption("--discard"))
         {
             opt_write = OFFalse;
             opt_append = OFFalse;
+            opt_update = OFFalse;
         }
         cmd.endOptionBlock();
         if (cmd.findOption("--no-backup"))
@@ -447,21 +452,15 @@ int main(int argc, char *argv[])
         }
     }
 
-    /* set debug mode and stream for log messages */
-    SetDebugLevel((opt_debug));
-    if (!app.quietMode())
-        ddir.setLogStream(&ofConsole);
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmgpdirLogger, rcsid << OFendl);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        OFOStringStream oss;
-        oss << "no data dictionary loaded, check environment variable: "
-            << DCM_DICT_ENVIRONMENT_VARIABLE << OFStringStream_ends;
-        OFSTRINGSTREAM_GETSTR(oss, tmpString)
-        app.printError(tmpString);  /* calls exit(1) */
-        OFSTRINGSTREAM_FREESTR(tmpString)
-        return 1;  /* DcmDicomDir class dumps core when no data dictionary */
+        OFLOG_FATAL(dcmgpdirLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
+        return 1;  /* DcmDicomDir class dumps core when no data dictionary present */
     }
 
     /* create list of input files */
@@ -469,15 +468,17 @@ int main(int argc, char *argv[])
     OFString pathname;
     const char *param = NULL;
     const int count = cmd.getParamCount();
-    if (opt_recurse && ddir.verboseMode())
-        COUT << "determining input files ..." << endl;
+    if (opt_recurse)
+        OFLOG_INFO(dcmgpdirLogger, "determining input files ...");
     /* no parameters? */
     if (count == 0)
     {
         if (opt_recurse)
             OFStandard::searchDirectoryRecursively("", fileNames, opt_pattern, opt_directory);
-        else
-            app.printError("Missing parameter dcmfile-in");
+        else {
+            OFLOG_FATAL(dcmgpdirLogger, "missing parameter dcmfile-in");
+            return 1;
+        }
     } else {
         /* iterate over all input filenames */
         for (int i = 1; i <= count; i++)
@@ -494,7 +495,10 @@ int main(int argc, char *argv[])
     }
     /* check whether there are any input files */
     if (fileNames.empty())
-        app.printError("no input files: DICOMDIR not created");
+    {
+        OFLOG_FATAL(dcmgpdirLogger, "no input files: DICOMDIR not created");
+        return 1;
+    }
 
 #ifdef BUILD_DCMGPDIR_AS_DCMMKDIR
     // add image support to DICOMDIR class
@@ -503,9 +507,11 @@ int main(int argc, char *argv[])
 #endif
 
     OFCondition result;
-    /* create new general purpose DICOMDIR or append to existing one */
+    /* create new general purpose DICOMDIR, append to or update existing one */
     if (opt_append)
         result = ddir.appendToDicomDir(opt_profile, opt_output);
+    else if (opt_update)
+        result = ddir.updateDicomDir(opt_profile, opt_output);
     else
         result = ddir.createNewDicomDir(opt_profile, opt_output, opt_fileset);
     if (result.good())
@@ -539,7 +545,7 @@ int main(int argc, char *argv[])
             /* evaluate result of file checking/adding procedure */
             if (goodFiles == 0)
             {
-                app.printWarning("no good files: DICOMDIR not created", "error");
+                OFLOG_ERROR(dcmgpdirLogger, "no good files: DICOMDIR not created");
                 result = EC_IllegalCall;
             }
             else if (!badFiles.empty())
@@ -550,12 +556,12 @@ int main(int argc, char *argv[])
                 last = badFiles.end();
                 while (iter != last)
                 {
-                    oss << endl << OFString(strlen(OFFIS_CONSOLE_APPLICATION) + 2, ' ') << (*iter);
+                    oss << OFendl << "  " << (*iter);
                     ++iter;
                 }
                 oss << OFStringStream_ends;
                 OFSTRINGSTREAM_GETSTR(oss, tmpString)
-                app.printWarning(tmpString);
+                OFLOG_WARN(dcmgpdirLogger, tmpString);
                 OFSTRINGSTREAM_FREESTR(tmpString)
             }
             /* write DICOMDIR file */
@@ -568,6 +574,11 @@ int main(int argc, char *argv[])
     // deregister global decompression codecs
     DcmRLEDecoderRegistration::cleanup();
     DJDecoderRegistration::cleanup();
+    // enable the following lines for JPEG 2000 decompression support
+/*
+    D2DecoderRegistration::cleanup();
+    D2JPEG2000Library::cleanup();
+*/
 #endif
 
 #ifdef DEBUG
@@ -581,6 +592,64 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcmgpdir.cc,v $
+ * Revision 1.95  2010-10-14 13:13:30  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.94  2010-08-09 13:04:19  joergr
+ * Updated data dictionary to 2009 edition of the DICOM standard. From now on,
+ * the official "keyword" is used for the attribute name which results in a
+ * number of minor changes (e.g. "PatientsName" is now called "PatientName").
+ *
+ * Revision 1.93  2010-07-21 14:28:19  joergr
+ * Enhanced check of input directory variable (also check for empty string).
+ *
+ * Revision 1.92  2010-07-21 13:29:48  joergr
+ * Made sure that no NULL pointer is passed to the OFString constructor. This
+ * occurred when option --recurse was used without --pattern, or option
+ * --no-recurse was used without --input-directory.
+ *
+ * Revision 1.91  2010-03-23 15:17:24  joergr
+ * Use printError() method for command line parsing errors only. After the
+ * resource identifier has been printed to the log stream use "oflog" instead.
+ *
+ * Revision 1.90  2009-11-04 09:58:06  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.89  2009-04-21 14:02:49  joergr
+ * Fixed minor inconsistencies in manpage / syntax usage.
+ *
+ * Revision 1.88  2009-01-15 10:15:23  joergr
+ * Added support for optional JPEG 2000 decompression (currently uncommented).
+ *
+ * Revision 1.87  2008-09-25 14:38:48  joergr
+ * Moved output of resource identifier in order to avoid printing the same
+ * information twice.
+ *
+ * Revision 1.86  2008-09-25 11:19:48  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.85  2007/01/10 13:05:18  joergr
+ * Added new option that enables support for retired SOP classes.
+ * Re-ordered and re-structured command line options.
+ *
+ * Revision 1.84  2006/12/15 14:26:14  joergr
+ * Added new option that allows to update existing entries in a DICOMDIR. This
+ * also adds support for mixed media stored application profiles.
+ * Fixed wrong spelling of command line option which prevented the MPEG2-DVD
+ * application profile from working.
+ * Changed name of enum value for the MPEG2-DVD application profile in order to
+ * be more consistent with other names.
+ *
+ * Revision 1.83  2006/08/15 15:50:56  meichel
+ * Updated all code in module dcmdata to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.82  2006/07/27 13:52:42  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
  * Revision 1.81  2005/12/08 15:40:48  meichel
  * Changed include path schema for all DCMTK header files
  *
