@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2005, OFFIS
+ *  Copyright (C) 2005-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Convert PDF file to DICOM format
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:40:53 $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:30 $
+ *  CVS/RCS Revision: $Revision: 1.18 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -60,7 +56,6 @@ END_EXTERN_C
 #include "dcmtk/ofstd/ofstd.h"
 #include "dcmtk/ofstd/ofdatime.h"
 #include "dcmtk/dcmdata/dccodec.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 
 #ifdef WITH_ZLIB
 #include <zlib.h>        /* for zlibVersion() */
@@ -68,15 +63,17 @@ END_EXTERN_C
 
 #define OFFIS_CONSOLE_APPLICATION "pdf2dcm"
 
+static OFLogger pdf2dcmLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
 OFCondition createHeader(
   DcmItem *dataset,
-  const char *opt_patientsName,
+  const char *opt_patientName,
   const char *opt_patientID,
-  const char *opt_patientsBirthdate,
-  const char *opt_patientsSex,
+  const char *opt_patientBirthdate,
+  const char *opt_patientSex,
   OFBool opt_burnedInAnnotation,
   const char *opt_studyUID,
   const char *opt_seriesUID,
@@ -94,11 +91,11 @@ OFCondition createHeader(
     if (result.good()) result = dataset->insertEmptyElement(DCM_StudyTime);
     if (result.good()) result = dataset->insertEmptyElement(DCM_AccessionNumber);
     if (result.good()) result = dataset->insertEmptyElement(DCM_Manufacturer);
-    if (result.good()) result = dataset->insertEmptyElement(DCM_ReferringPhysiciansName);
+    if (result.good()) result = dataset->insertEmptyElement(DCM_ReferringPhysicianName);
     if (result.good()) result = dataset->insertEmptyElement(DCM_StudyID);
     if (result.good()) result = dataset->insertEmptyElement(DCM_ContentDate);
     if (result.good()) result = dataset->insertEmptyElement(DCM_ContentTime);
-    if (result.good()) result = dataset->insertEmptyElement(DCM_AcquisitionDatetime);
+    if (result.good()) result = dataset->insertEmptyElement(DCM_AcquisitionDateTime);
 
     if (result.good() && opt_conceptCSD && opt_conceptCV && opt_conceptCM)
     {
@@ -121,16 +118,16 @@ OFCondition createHeader(
 
     // insert variable value attributes
     if (result.good()) result = dataset->putAndInsertString(DCM_DocumentTitle,        opt_documentTitle);
-    if (result.good()) result = dataset->putAndInsertString(DCM_PatientsName,         opt_patientsName);
+    if (result.good()) result = dataset->putAndInsertString(DCM_PatientName,          opt_patientName);
     if (result.good()) result = dataset->putAndInsertString(DCM_PatientID,            opt_patientID);
-    if (result.good()) result = dataset->putAndInsertString(DCM_PatientsBirthDate,    opt_patientsBirthdate);
-    if (result.good()) result = dataset->putAndInsertString(DCM_PatientsSex,          opt_patientsSex);
+    if (result.good()) result = dataset->putAndInsertString(DCM_PatientBirthDate,     opt_patientBirthdate);
+    if (result.good()) result = dataset->putAndInsertString(DCM_PatientSex,           opt_patientSex);
     if (result.good()) result = dataset->putAndInsertString(DCM_BurnedInAnnotation,   opt_burnedInAnnotation ? "YES" : "NO");
 
     sprintf(buf, "%ld", OFstatic_cast(long, opt_instanceNumber));
     if (result.good()) result = dataset->putAndInsertString(DCM_InstanceNumber,       buf);
 
-    dcmGenerateUniqueIdentifier(buf);
+    dcmGenerateUniqueIdentifier(buf, SITE_INSTANCE_UID_ROOT);
     if (result.good()) result = dataset->putAndInsertString(DCM_StudyInstanceUID,     opt_studyUID);
     if (result.good()) result = dataset->putAndInsertString(DCM_SeriesInstanceUID,    opt_seriesUID);
     if (result.good()) result = dataset->putAndInsertString(DCM_SOPInstanceUID,       buf);
@@ -147,8 +144,7 @@ OFCondition createHeader(
 
 OFCondition insertPDFFile(
   DcmItem *dataset,
-  const char *filename,
-  OFBool opt_verbose)
+  const char *filename)
 {
     size_t fileSize = 0;
     struct stat fileStat;
@@ -157,23 +153,20 @@ OFCondition insertPDFFile(
     if (0 == stat(filename, &fileStat)) fileSize = OFstatic_cast(size_t, fileStat.st_size);
     else
     {
-      ofConsole.lockCerr() << "file " << filename << " not found" << endl;
-      ofConsole.unlockCerr();
+      OFLOG_ERROR(pdf2dcmLogger, "file " << filename << " not found");
       return EC_IllegalCall;
     }
 
     if (fileSize == 0)
     {
-      ofConsole.lockCerr() << "file " << filename << " is empty" << endl;
-      ofConsole.unlockCerr();
+      OFLOG_ERROR(pdf2dcmLogger, "file " << filename << " is empty");
       return EC_IllegalCall;
     }
 
     FILE *pdffile = fopen(filename, "rb");
     if (pdffile == NULL)
     {
-      ofConsole.lockCerr() << "unable to read file " << filename << endl;
-      ofConsole.unlockCerr();
+      OFLOG_ERROR(pdf2dcmLogger, "unable to read file " << filename);
       return EC_IllegalCall;
     }
 
@@ -181,8 +174,7 @@ OFCondition insertPDFFile(
     if (fileSize < buflen) buflen = fileSize;
     if (buflen != fread(buf, 1, buflen, pdffile))
     {
-      ofConsole.lockCerr() << "read error in file " << filename << endl;
-      ofConsole.unlockCerr();
+      OFLOG_ERROR(pdf2dcmLogger, "read error in file " << filename);
       fclose(pdffile);
       return EC_IllegalCall;
     }
@@ -190,8 +182,7 @@ OFCondition insertPDFFile(
     // check magic word for PDF file
     if (0 != strncmp("%PDF-", buf, 5))
     {
-      ofConsole.lockCerr() << "file " << filename << " is not a PDF file." << endl;
-      ofConsole.unlockCerr();
+      OFLOG_ERROR(pdf2dcmLogger, "file " << filename << " is not a PDF file");
       fclose(pdffile);
       return EC_IllegalCall;
     }
@@ -211,22 +202,16 @@ OFCondition insertPDFFile(
 
     if (! found)
     {
-      ofConsole.lockCerr() << "file " << filename << ": unable to decode PDF version number." << endl;
-      ofConsole.unlockCerr();
+      OFLOG_ERROR(pdf2dcmLogger, "file " << filename << ": unable to decode PDF version number");
       fclose(pdffile);
       return EC_IllegalCall;
     }
 
-    if (opt_verbose)
-    {
-      ofConsole.lockCout() << "file " << filename << ": PDF " << version << ", " << (fileSize+1023)/1024 << "kB" << endl;
-      ofConsole.unlockCout();
-    }
+    OFLOG_INFO(pdf2dcmLogger, "file " << filename << ": PDF " << version << ", " << (fileSize + 1023) / 1024 << "kB");
 
     if (0 != fseek(pdffile, 0, SEEK_SET))
     {
-      ofConsole.lockCerr() << "file " << filename << ": seek error." << endl;
-      ofConsole.unlockCerr();
+      OFLOG_ERROR(pdf2dcmLogger, "file " << filename << ": seek error");
       fclose(pdffile);
       return EC_IllegalCall;
     }
@@ -242,13 +227,12 @@ OFCondition insertPDFFile(
       if (result.good())
       {
         // blank pad byte
-      	bytes[numBytes-1] = 0;
+      	bytes[numBytes - 1] = 0;
 
         // read PDF content
         if (fileSize != fread(bytes, 1, fileSize, pdffile))
         {
-          ofConsole.lockCerr() << "read error in file " << filename << endl;
-          ofConsole.unlockCerr();
+          OFLOG_ERROR(pdf2dcmLogger, "read error in file " << filename);
           result = EC_IllegalCall;
         }
       }
@@ -269,10 +253,10 @@ void createIdentifiers(
   const char *opt_seriesFile,
   OFString& studyUID,
   OFString& seriesUID,
-  OFString& patientsName,
+  OFString& patientName,
   OFString& patientID,
-  OFString& patientsBirthDate,
-  OFString& patientsSex,
+  OFString& patientBirthDate,
+  OFString& patientSex,
   Sint32& incrementedInstance)
 {
   char buf[100];
@@ -282,8 +266,7 @@ void createIdentifiers(
     OFCondition cond = dfile.loadFile(opt_seriesFile, EXS_Unknown, EGL_noChange);
     if (cond.bad())
     {
-      ofConsole.lockCerr() << "warning: " << cond.text() << ": reading file: "<< opt_seriesFile << endl;
-      ofConsole.unlockCerr();
+      OFLOG_WARN(pdf2dcmLogger, cond.text() << ": reading file: "<< opt_seriesFile);
     }
     else
     {
@@ -293,13 +276,13 @@ void createIdentifiers(
       {
         // read patient attributes
         c = NULL;
-        if (dset->findAndGetString(DCM_PatientsName, c).good() && c) patientsName = c;
+        if (dset->findAndGetString(DCM_PatientName, c).good() && c) patientName = c;
         c = NULL;
         if (dset->findAndGetString(DCM_PatientID, c).good() && c) patientID = c;
         c = NULL;
-        if (dset->findAndGetString(DCM_PatientsBirthDate, c).good() && c) patientsBirthDate = c;
+        if (dset->findAndGetString(DCM_PatientBirthDate, c).good() && c) patientBirthDate = c;
         c = NULL;
-        if (dset->findAndGetString(DCM_PatientsSex, c).good() && c) patientsSex = c;
+        if (dset->findAndGetString(DCM_PatientSex, c).good() && c) patientSex = c;
 
         // read study attributes
         c = NULL;
@@ -317,12 +300,12 @@ void createIdentifiers(
   }
   if (studyUID.length() == 0)
   {
-    dcmGenerateUniqueIdentifier(buf);
+    dcmGenerateUniqueIdentifier(buf, SITE_STUDY_UID_ROOT);
     studyUID = buf;
   }
   if (seriesUID.length() == 0)
   {
-    dcmGenerateUniqueIdentifier(buf);
+    dcmGenerateUniqueIdentifier(buf, SITE_SERIES_UID_ROOT);
     seriesUID = buf;
   }
 }
@@ -339,13 +322,9 @@ int main(int argc, char *argv[])
   GUSISetup(GUSIwithInternetSockets);
 #endif
 
-  SetDebugLevel(( 0 ));
-
   const char *opt_ifname = NULL;
   const char *opt_ofname = NULL;
 
-  int opt_debugMode = 0;
-  OFBool opt_verbose = OFFalse;
   E_TransferSyntax opt_oxfer = EXS_LittleEndianExplicit;
   E_GrpLenEncoding opt_oglenc = EGL_withoutGL;
   E_EncodingType opt_oenctype = EET_ExplicitLength;
@@ -355,16 +334,16 @@ int main(int argc, char *argv[])
 
   // document specific options
   const char *   opt_seriesFile = NULL;
-  const char *   opt_patientsName = NULL;
+  const char *   opt_patientName = NULL;
   const char *   opt_patientID = NULL;
-  const char *   opt_patientsBirthdate = NULL;
+  const char *   opt_patientBirthdate = NULL;
   const char *   opt_documentTitle = NULL;
   const char *   opt_conceptCSD = NULL;
   const char *   opt_conceptCV = NULL;
   const char *   opt_conceptCM = NULL;
 
   OFBool         opt_readSeriesInfo = OFFalse;
-  const char *   opt_patientsSex = NULL;
+  const char *   opt_patientSex = NULL;
   OFBool         opt_annotation = OFTrue;
   OFCmdSignedInt opt_instance = 1;
   OFBool         opt_increment = OFFalse;
@@ -378,10 +357,9 @@ int main(int argc, char *argv[])
   cmd.addParam("dcmfile-out", "DICOM output filename");
 
   cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-   cmd.addOption("--help",                 "-h",     "print this help text and exit");
-   cmd.addOption("--version",                        "print version information and exit", OFTrue /* exclusive */);
-   cmd.addOption("--verbose",              "-v",     "verbose mode, print processing details");
-   cmd.addOption("--debug",                "-d",     "debug mode, print debug information");
+   cmd.addOption("--help",                 "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+   cmd.addOption("--version",                        "print version information and exit", OFCommandLine::AF_Exclusive);
+   OFLog::addOptions(cmd);
 
    cmd.addGroup("DICOM document options:");
     cmd.addSubGroup("burned-in annotation:");
@@ -389,51 +367,51 @@ int main(int argc, char *argv[])
       cmd.addOption("--annotation-no",     "-an",    "PDF does not contain patient identifying data");
 
     cmd.addSubGroup("document title:");
-      cmd.addOption("--title",             "+t",  1, "[t]itle : string (default: empty)",
+      cmd.addOption("--title",             "+t",  1, "[t]itle: string (default: empty)",
                                                      "document title");
-      cmd.addOption("--concept-name",      "+cn", 3, "[CSD], [CV], [CM]: string (default: empty)",
+      cmd.addOption("--concept-name",      "+cn", 3, "[CSD] [CV] [CM]: string (default: empty)",
                                                      "document title as concept name code sequence\n"
                                                      "with coding scheme designator CSD, code value CV\n"
                                                      "and code meaning CM");
     cmd.addSubGroup("patient data:");
-      cmd.addOption("--patient-name",      "+pn", 1, "[n]ame : string",
+      cmd.addOption("--patient-name",      "+pn", 1, "[n]ame: string",
                                                      "patient's name in DICOM PN syntax");
-      cmd.addOption("--patient-id",        "+pi", 1, "[i]d : string",
+      cmd.addOption("--patient-id",        "+pi", 1, "[i]d: string",
                                                      "patient identifier");
-      cmd.addOption("--patient-birthdate", "+pb", 1, "[d]ate : string (YYYYMMDD)",
+      cmd.addOption("--patient-birthdate", "+pb", 1, "[d]ate: string (YYYYMMDD)",
                                                      "patient's birth date");
-      cmd.addOption("--patient-sex",       "+ps", 1, "[s]ex : string (M, F or O)",
+      cmd.addOption("--patient-sex",       "+ps", 1, "[s]ex: string (M, F or O)",
                                                      "patient's sex");
 
     cmd.addSubGroup("study and series:");
-      cmd.addOption("--generate"       ,   "+sg",    "generate new study and series UIDs (default)");
-      cmd.addOption("--study-from",        "+st", 1, "[f]ilename : string",
+      cmd.addOption("--generate",          "+sg",    "generate new study and series UIDs (default)");
+      cmd.addOption("--study-from",        "+st", 1, "[f]ilename: string",
                                                      "read patient/study data from DICOM file");
-      cmd.addOption("--series-from",       "+se", 1, "[f]ilename : string",
+      cmd.addOption("--series-from",       "+se", 1, "[f]ilename: string",
                                                      "read patient/study/series data from DICOM file");
     cmd.addSubGroup("instance number:");
       cmd.addOption("--instance-one",      "+i1",    "use instance number 1 (default, not with +se)");
       cmd.addOption("--instance-inc",      "+ii",    "increment instance number (only with +se)");
-      cmd.addOption("--instance-set",      "+is", 1, "[i]nstance number : int", "use instance number i");
+      cmd.addOption("--instance-set",      "+is", 1, "[i]nstance number: integer", "use instance number i");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
           if (cmd.findOption("--version"))
           {
-              app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-              ofConsole.lockCerr() << endl << "External libraries used:";
-              ofConsole.unlockCerr();
+              app.printHeader(OFTrue /*print host identifier*/);
+              ofConsole.lockCout() << OFendl << "External libraries used:";
+              ofConsole.unlockCout();
 #ifdef WITH_ZLIB
-              ofConsole.lockCerr() << endl << "- ZLIB, Version " << zlibVersion() << endl;
-              ofConsole.unlockCerr();
+              ofConsole.lockCout() << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
+              ofConsole.unlockCout();
 #else
-              ofConsole.lockCerr() << " none" << endl;
-              ofConsole.unlockCerr();
+              ofConsole.lockCout() << " none" << OFendl;
+              ofConsole.unlockCout();
 #endif
               return 0;
           }
@@ -443,8 +421,7 @@ int main(int argc, char *argv[])
       cmd.getParam(1, opt_ifname);
       cmd.getParam(2, opt_ofname);
 
-      if (cmd.findOption("--verbose")) opt_verbose = OFTrue;
-      if (cmd.findOption("--debug")) opt_debugMode = 5;
+      OFLog::configureFromCommandLine(cmd, app);
 
       dcmEnableUnknownVRGeneration.set(OFTrue);
       dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
@@ -481,23 +458,23 @@ int main(int argc, char *argv[])
 
       if (cmd.findOption("--patient-name"))
       {
-        app.checkValue(cmd.getValue(opt_patientsName));
-        if (opt_seriesFile) app.printError("--patient-name not allowed with --study-from or --series-from");
+        app.checkValue(cmd.getValue(opt_patientName));
+        app.checkConflict("--patient-name", "--study-from or --series-from", opt_seriesFile != NULL);
       }
       if (cmd.findOption("--patient-id"))
       {
         app.checkValue(cmd.getValue(opt_patientID));
-        if (opt_seriesFile) app.printError("--patient-id not allowed with --study-from or --series-from");
+        app.checkConflict("--patient-id", "--study-from or --series-from", opt_seriesFile != NULL);
       }
       if (cmd.findOption("--patient-birthdate"))
       {
-        app.checkValue(cmd.getValue(opt_patientsBirthdate));
-        if (opt_seriesFile) app.printError("--patient-birthdate not allowed with --study-from or --series-from");
+        app.checkValue(cmd.getValue(opt_patientBirthdate));
+        app.checkConflict("--patient-birthdate", "--study-from or --series-from", opt_seriesFile != NULL);
       }
       if (cmd.findOption("--patient-sex"))
       {
-        app.checkValue(cmd.getValue(opt_patientsSex));
-        if (opt_seriesFile) app.printError("--patient-sex not allowed with --study-from or --series-from");
+        app.checkValue(cmd.getValue(opt_patientSex));
+        app.checkConflict("--patient-sex", "--study-from or --series-from", opt_seriesFile != NULL);
       }
 
       cmd.beginOptionBlock();
@@ -517,13 +494,13 @@ int main(int argc, char *argv[])
       cmd.beginOptionBlock();
       if (cmd.findOption("--instance-one"))
       {
-        if (opt_seriesFile && opt_readSeriesInfo) app.printError("--instance-one not allowed with --series-from");
+        app.checkConflict("--instance-one", "--series-from", (opt_seriesFile != NULL) && opt_readSeriesInfo);
         opt_increment = OFFalse;
         opt_instance = 1;
       }
       if (cmd.findOption("--instance-inc"))
       {
-        if (!opt_seriesFile || !opt_readSeriesInfo) app.printError("--instance-inc only allowed with --series-from");
+        app.checkDependence("--instance-inc", "--series-from", (opt_seriesFile != NULL) && opt_readSeriesInfo);
         opt_increment = OFTrue;
       }
       if (cmd.findOption("--instance-set"))
@@ -531,129 +508,95 @@ int main(int argc, char *argv[])
         opt_increment = OFFalse;
         app.checkValue(cmd.getValueAndCheckMin(opt_instance, 1));
       }
-   }
+    }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(pdf2dcmLogger, rcsid << OFendl);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        ofConsole.lockCerr() << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
-        ofConsole.unlockCerr();
+        OFLOG_WARN(pdf2dcmLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     // read raw file
     if ((opt_ifname == NULL) || (strlen(opt_ifname) == 0))
     {
-        ofConsole.lockCerr() << "invalid filename: <empty string>" << endl;
-        ofConsole.unlockCerr();
+        OFLOG_FATAL(pdf2dcmLogger, "invalid filename: <empty string>");
         return 1;
     }
 
     // create study and series UID
     OFString studyUID;
     OFString seriesUID;
-    OFString patientsName;
+    OFString patientName;
     OFString patientID;
-    OFString patientsBirthDate;
-    OFString patientsSex;
+    OFString patientBirthDate;
+    OFString patientSex;
     Sint32 incrementedInstance = 0;
 
-    if (opt_patientsName) patientsName = opt_patientsName;
+    if (opt_patientName) patientName = opt_patientName;
     if (opt_patientID) patientID = opt_patientID;
-    if (opt_patientsBirthdate) patientsBirthDate = opt_patientsBirthdate;
-    if (opt_patientsSex) patientsSex = opt_patientsSex;
+    if (opt_patientBirthdate) patientBirthDate = opt_patientBirthdate;
+    if (opt_patientSex) patientSex = opt_patientSex;
 
-    createIdentifiers(opt_readSeriesInfo, opt_seriesFile, studyUID, seriesUID, patientsName, patientID, patientsBirthDate, patientsSex, incrementedInstance);
+    createIdentifiers(opt_readSeriesInfo, opt_seriesFile, studyUID, seriesUID, patientName, patientID, patientBirthDate, patientSex, incrementedInstance);
     if (opt_increment) opt_instance = incrementedInstance;
 
-    if (opt_verbose)
-    {
-      ofConsole.lockCout() << "creating encapsulated PDF object" << endl;
-      ofConsole.unlockCout();
-    }
+    OFLOG_INFO(pdf2dcmLogger, "creating encapsulated PDF object");
 
     DcmFileFormat fileformat;
 
-    OFCondition result = insertPDFFile(fileformat.getDataset(), opt_ifname, opt_verbose);
+    OFCondition result = insertPDFFile(fileformat.getDataset(), opt_ifname);
     if (result.bad())
     {
-         ofConsole.lockCerr() << "unable to create PDF DICOM encapsulation" << endl;
-         ofConsole.unlockCerr();
-    	 return 10;
+        OFLOG_ERROR(pdf2dcmLogger, "unable to create PDF DICOM encapsulation");
+        return 10;
     }
     if (result.bad()) return 10;
 
     // now we need to generate an instance number that is guaranteed to be unique within a series.
 
-    result = createHeader(fileformat.getDataset(), patientsName.c_str(), patientID.c_str(),
-      patientsBirthDate.c_str(), patientsSex.c_str(), opt_annotation, studyUID.c_str(),
+    result = createHeader(fileformat.getDataset(), patientName.c_str(), patientID.c_str(),
+      patientBirthDate.c_str(), patientSex.c_str(), opt_annotation, studyUID.c_str(),
       seriesUID.c_str(), opt_documentTitle, opt_conceptCSD, opt_conceptCV, opt_conceptCM, OFstatic_cast(Sint32, opt_instance));
 
     if (result.bad())
     {
-         ofConsole.lockCerr() << "unable to create DICOM header" << endl
-             << "Error: " << result.text() << endl;
-         ofConsole.unlockCerr();
-    	 return 10;
+        OFLOG_ERROR(pdf2dcmLogger, "unable to create DICOM header: " << result.text());
+        return 10;
     }
 
-    if (opt_verbose)
-    {
-      ofConsole.lockCout() << "writing encapsulated PDF object as file " << opt_ofname << endl;
-      ofConsole.unlockCout();
-    }
+    OFLOG_INFO(pdf2dcmLogger, "writing encapsulated PDF object as file " << opt_ofname);
 
     OFCondition error = EC_Normal;
 
-    if (opt_verbose)
-    {
-      ofConsole.lockCout() << "Check if new output transfer syntax is possible\n";
-      ofConsole.unlockCout();
-    }
+    OFLOG_INFO(pdf2dcmLogger, "Check if new output transfer syntax is possible");
 
     DcmXfer opt_oxferSyn(opt_oxfer);
 
     fileformat.getDataset()->chooseRepresentation(opt_oxfer, NULL);
     if (fileformat.getDataset()->canWriteXfer(opt_oxfer))
     {
-        if (opt_verbose)
-        {
-            ofConsole.lockCout() << "Output transfer syntax " << opt_oxferSyn.getXferName()
-                 << " can be written\n";
-            ofConsole.unlockCout();
-        }
+        OFLOG_INFO(pdf2dcmLogger, "Output transfer syntax " << opt_oxferSyn.getXferName() << " can be written");
     } else {
-        ofConsole.lockCerr() << "No conversion to transfer syntax " << opt_oxferSyn.getXferName()
-             << " possible!\n";
-        ofConsole.unlockCerr();
+        OFLOG_ERROR(pdf2dcmLogger, "No conversion to transfer syntax " << opt_oxferSyn.getXferName() << " possible!");
         return 1;
     }
 
-    if (opt_verbose)
-    {
-      ofConsole.lockCout() << "write converted DICOM file with metaheader\n";
-      ofConsole.unlockCout();
-    }
+    OFLOG_INFO(pdf2dcmLogger, "write converted DICOM file with metaheader");
 
-    error = fileformat.saveFile(opt_ofname, opt_oxfer, opt_oenctype, opt_oglenc,
-              opt_opadenc, (Uint32) opt_filepad, (Uint32) opt_itempad);
+    error = fileformat.saveFile(opt_ofname, opt_oxfer, opt_oenctype, opt_oglenc, opt_opadenc,
+        OFstatic_cast(Uint32, opt_filepad), OFstatic_cast(Uint32, opt_itempad));
 
     if (error.bad())
     {
-        ofConsole.lockCerr() << "Error: " << error.text()
-             << ": writing file: " << opt_ofname << endl;
-        ofConsole.unlockCerr();
+        OFLOG_ERROR(pdf2dcmLogger, error.text() << ": writing file: " << opt_ofname);
         return 1;
     }
 
-    if (opt_verbose)
-    {
-        ofConsole.lockCout() << "conversion successful\n";
-        ofConsole.unlockCout();
-    }
+    OFLOG_INFO(pdf2dcmLogger, "conversion successful");
 
     return 0;
 }
@@ -662,6 +605,57 @@ int main(int argc, char *argv[])
 /*
 ** CVS/RCS Log:
 ** $Log: pdf2dcm.cc,v $
+** Revision 1.18  2010-10-14 13:13:30  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.17  2010-08-09 13:04:19  joergr
+** Updated data dictionary to 2009 edition of the DICOM standard. From now on,
+** the official "keyword" is used for the attribute name which results in a
+** number of minor changes (e.g. "PatientsName" is now called "PatientName").
+**
+** Revision 1.16  2009-11-13 13:20:23  joergr
+** Fixed minor issues in log output.
+**
+** Revision 1.15  2009-11-04 09:58:06  uli
+** Switched to logging mechanism provided by the "new" oflog module
+**
+** Revision 1.14  2009-10-12 09:35:43  joergr
+** Changed prefix of UIDs created for series and studies (now using constants
+** SITE_SERIES_UID_ROOT and SITE_STUDY_UID_ROOT which are supposed to be used
+** in these cases).
+**
+** Revision 1.13  2009-08-11 08:13:35  joergr
+** Slightly modified code in order to avoid warning messages on MSVC compiler.
+**
+** Revision 1.12  2009-08-10 11:04:22  joergr
+** Use helper functions checkDependence() and checkConflict() where appropriate.
+**
+** Revision 1.11  2009-08-10 10:25:23  joergr
+** Replaced '\n' by OFendl where appropriate.
+**
+** Revision 1.10  2009-04-21 14:02:49  joergr
+** Fixed minor inconsistencies in manpage / syntax usage.
+**
+** Revision 1.9  2008-09-25 14:38:48  joergr
+** Moved output of resource identifier in order to avoid printing the same
+** information twice.
+**
+** Revision 1.8  2008-09-25 11:19:48  joergr
+** Added support for printing the expanded command line arguments.
+** Always output the resource identifier of the command line tool in debug mode.
+**
+** Revision 1.7  2008-04-30 12:38:42  meichel
+** Fixed compile errors due to changes in attribute tag names
+**
+** Revision 1.6  2006/08/15 15:50:56  meichel
+** Updated all code in module dcmdata to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.5  2006/07/27 13:52:42  joergr
+** Changed parameter "exclusive" of method addOption() from type OFBool into an
+** integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+** Option "--help" is no longer an exclusive option by default.
+**
 ** Revision 1.4  2005/12/08 15:40:53  meichel
 ** Changed include path schema for all DCMTK header files
 **
