@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1997-2004, OFFIS
+ *  Copyright (C) 1997-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -22,27 +18,31 @@
  *  Purpose: abstract class DcmCodec and the class DcmCodecStruct
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2004/02/04 16:11:42 $
- *  CVS/RCS Revision: $Revision: 1.12 $
+ *  Update Date:      $Date: 2010-10-14 13:14:07 $
+ *  CVS/RCS Revision: $Revision: 1.22 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
  *
  */
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
-#include "dccodec.h"
-#include "oflist.h"
-#include "ofthread.h"
-#include "dcdeftag.h"  /* for tag constants */
-#include "dcuid.h"     /* for dcmGenerateUniqueIdentifer()*/
-#include "dcitem.h"    /* for class DcmItem */
-#include "dcsequen.h"  /* for DcmSequenceOfItems */
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/dcmdata/dccodec.h"
+#include "dcmtk/ofstd/oflist.h"
+#include "dcmtk/ofstd/ofthread.h"
+#include "dcmtk/dcmdata/dcdeftag.h"  /* for tag constants */
+#include "dcmtk/dcmdata/dcuid.h"     /* for dcmGenerateUniqueIdentifer()*/
+#include "dcmtk/dcmdata/dcitem.h"    /* for class DcmItem */
+#include "dcmtk/dcmdata/dcsequen.h"  /* for DcmSequenceOfItems */
+#include "dcmtk/dcmdata/dcpixseq.h"  /* for DcmPixelSequence */
+#include "dcmtk/dcmdata/dcpxitem.h"  /* for DcmPixelItem */
+#include "dcmtk/dcmdata/dcswap.h"    /* for swapIfNecessary */
+#include "dcmtk/dcmdata/dcvrui.h"    /* for DcmUniqueIdentifier */
 
 // static member variables
 OFList<DcmCodecList *> DcmCodecList::registeredCodecs;
 
-#ifdef _REENTRANT
+#ifdef WITH_THREADS
 OFReadWriteLock DcmCodecList::codecLock;
 #endif
 
@@ -60,6 +60,7 @@ OFCondition DcmCodec::insertStringIfMissing(DcmItem *dataset, const DcmTagKey& t
   return EC_Normal;
 }
 
+
 OFCondition DcmCodec::convertToSecondaryCapture(DcmItem *dataset)
 {
   if (dataset == NULL) return EC_IllegalCall;
@@ -83,14 +84,14 @@ OFCondition DcmCodec::convertToSecondaryCapture(DcmItem *dataset)
   if (result.good()) result = insertStringIfMissing(dataset, DCM_Modality, "OT");
 
   // Type 2 attributes - insert without value if missing
-  if (result.good()) result = insertStringIfMissing(dataset, DCM_PatientsName, NULL);
+  if (result.good()) result = insertStringIfMissing(dataset, DCM_PatientName, NULL);
   if (result.good()) result = insertStringIfMissing(dataset, DCM_PatientID, NULL);
-  if (result.good()) result = insertStringIfMissing(dataset, DCM_PatientsBirthDate, NULL);
-  if (result.good()) result = insertStringIfMissing(dataset, DCM_PatientsSex, NULL);
+  if (result.good()) result = insertStringIfMissing(dataset, DCM_PatientBirthDate, NULL);
+  if (result.good()) result = insertStringIfMissing(dataset, DCM_PatientSex, NULL);
   if (result.good()) result = insertStringIfMissing(dataset, DCM_PatientOrientation, NULL);
   if (result.good()) result = insertStringIfMissing(dataset, DCM_StudyDate, NULL);
   if (result.good()) result = insertStringIfMissing(dataset, DCM_StudyTime, NULL);
-  if (result.good()) result = insertStringIfMissing(dataset, DCM_ReferringPhysiciansName, NULL);
+  if (result.good()) result = insertStringIfMissing(dataset, DCM_ReferringPhysicianName, NULL);
   if (result.good()) result = insertStringIfMissing(dataset, DCM_StudyID, NULL);
   if (result.good()) result = insertStringIfMissing(dataset, DCM_AccessionNumber, NULL);
   if (result.good()) result = insertStringIfMissing(dataset, DCM_SeriesNumber, NULL);
@@ -99,7 +100,43 @@ OFCondition DcmCodec::convertToSecondaryCapture(DcmItem *dataset)
   return result;
 }
 
-OFCondition DcmCodec::newInstance(DcmItem *dataset)
+
+OFCondition DcmCodec::insertCodeSequence(
+  DcmItem *dataset,
+  const DcmTagKey &tagKey,
+  const char *codingSchemeDesignator,
+  const char *codeValue,
+  const char *codeMeaning)
+{
+  if (dataset == NULL || codingSchemeDesignator == NULL ||
+     codeValue == NULL || codeMeaning == NULL) return EC_IllegalCall;
+
+  OFCondition result = EC_Normal;
+  DcmSequenceOfItems *dseq = new DcmSequenceOfItems(tagKey);
+  if (dseq)
+  {
+    DcmItem *ditem = new DcmItem();
+    if (ditem)
+    {
+      dseq->insert(ditem);
+      result = ditem->putAndInsertString(DCM_CodingSchemeDesignator, codingSchemeDesignator);
+      if (result.good()) result = ditem->putAndInsertString(DCM_CodeValue, codeValue);
+      if (result.good()) result = ditem->putAndInsertString(DCM_CodeMeaning, codeMeaning);
+    } else result = EC_MemoryExhausted;
+
+    // insert sequence into dataset if everything went well
+    if (result.good()) dataset->insert(dseq, OFTrue /*replaceOld*/); else delete dseq;
+  } else result = EC_MemoryExhausted;
+
+  return result;
+}
+
+
+OFCondition DcmCodec::newInstance(
+  DcmItem *dataset,
+  const char *purposeOfReferenceCodingScheme,
+  const char *purposeOfReferenceCodeValue,
+  const char *purposeOfReferenceCodeMeaning)
 {
   if (dataset == NULL) return EC_IllegalCall;
   OFCondition result = EC_Normal;
@@ -136,6 +173,14 @@ OFCondition DcmCodec::newInstance(DcmItem *dataset)
             } else result = EC_MemoryExhausted;
           }
         } else result = EC_MemoryExhausted;
+
+        if (result.good() && purposeOfReferenceCodingScheme &&
+           purposeOfReferenceCodeValue && purposeOfReferenceCodeMeaning)
+        {
+          // add purpose of reference code sequence
+          result = DcmCodec::insertCodeSequence(ditem, DCM_PurposeOfReferenceCodeSequence,
+            purposeOfReferenceCodingScheme, purposeOfReferenceCodeValue, purposeOfReferenceCodeMeaning);
+        }
       } else result = EC_MemoryExhausted;
       if (result.good()) dataset->insert(dseq, OFTrue); else delete dseq;
     } else result = EC_MemoryExhausted;
@@ -163,7 +208,7 @@ OFCondition DcmCodec::updateImageType(DcmItem *dataset)
   if (dataset == NULL) return EC_IllegalCall;
 
   DcmStack stack;
-  OFString imageType("DERIVED\\SECONDARY");
+  OFString imageType("DERIVED");
   OFString a;
 
   /* find existing Image Type element */
@@ -171,9 +216,9 @@ OFCondition DcmCodec::updateImageType(DcmItem *dataset)
   if (status.good())
   {
     DcmElement *elem = OFstatic_cast(DcmElement *, stack.top());
-    unsigned long pos = 2;
+    unsigned long pos = 1;
 
-    // append old image type information beginning with third entry
+    // append old image type information beginning with second entry
     while ((elem->getOFString(a, pos++)).good())
     {
       imageType += "\\";
@@ -185,12 +230,92 @@ OFCondition DcmCodec::updateImageType(DcmItem *dataset)
   return dataset->putAndInsertString(DCM_ImageType, imageType.c_str(), OFTrue);
 }
 
+
+OFCondition DcmCodec::determineStartFragment(
+  Uint32 frameNo,
+  Sint32 numberOfFrames,
+  DcmPixelSequence * fromPixSeq,
+  Uint32& currentItem)
+{
+  Uint32 numberOfFragments = fromPixSeq->card();
+  if (numberOfFrames < 1 || numberOfFragments <= OFstatic_cast(Uint32, numberOfFrames) || frameNo >= OFstatic_cast(Uint32, numberOfFrames)) return EC_IllegalCall;
+
+  if (frameNo == 0)
+  {
+    // simple case: first frame is always at second fragment
+    currentItem = 1;
+    return EC_Normal;
+  }
+
+  if (numberOfFragments == OFstatic_cast(Uint32, numberOfFrames) + 1)
+  {
+    // standard case: there is one fragment per frame.
+    currentItem = frameNo + 1;
+    return EC_Normal;
+  }
+
+  // non-standard case: multiple fragments per frame.
+  // We now try to consult the offset table.
+  DcmPixelItem *pixItem = NULL;
+  Uint8 * rawOffsetTable = NULL;
+
+  // get first pixel item, i.e. the fragment containing the offset table
+  OFCondition result = fromPixSeq->getItem(pixItem, 0);
+  if (result.good())
+  {
+    Uint32 tableLength = pixItem->getLength();
+    result = pixItem->getUint8Array(rawOffsetTable);
+    if (result.good())
+    {
+      // check if the offset table has the right size: 4 bytes for each frame (not fragment!)
+      if (tableLength != 4* OFstatic_cast(Uint32, numberOfFrames)) return EC_IllegalCall;
+
+      // byte swap offset table into local byte order. In file, the offset table is always in little endian
+      swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawOffsetTable, tableLength, sizeof(Uint32));
+
+      // cast offset table to Uint32.
+      Uint32 *offsetTable = OFreinterpret_cast(Uint32 *, rawOffsetTable);
+
+      // now access offset of the frame we're looking for
+      Uint32 offset = offsetTable[frameNo];
+
+      // OK, now let's look if we can find a fragment that actually corresponds to that offset.
+      // In counter we compute the offset for each frame by adding all fragment lenghts
+      Uint32 counter = 0;
+      // now iterate over all fragments except the index table. The start of the first fragment
+      // is defined as zero.
+      for (Uint32 idx = 1; idx < numberOfFragments; ++idx)
+      {
+        if (counter == offset)
+        {
+          // hooray, we are lucky. We have found the fragment we're looking for
+          currentItem = idx;
+          return EC_Normal;
+        }
+
+        // access pixel item in order to determine its length
+        result = fromPixSeq->getItem(pixItem, idx);
+        if (result.bad()) return result;
+
+        // add pixel item length plus 8 bytes overhead for the item tag and length field
+        counter += pixItem->getLength() + 8;
+      }
+
+      // bad luck. We have not found a fragment corresponding to the offset in the offset table.
+      // Either we cannot correctly add numbers, or they cannot :-)
+      return EC_TagNotFound;
+    }
+  }
+  return result;
+}
+
+
 /* --------------------------------------------------------------- */
 
 DcmCodecList::DcmCodecList(
-    const DcmCodec *aCodec,
-    const DcmRepresentationParameter *aDefaultRepParam,
-    const DcmCodecParameter *aCodecParameter)
+  const DcmCodec *aCodec,
+  const DcmRepresentationParameter *aDefaultRepParam,
+  const DcmCodecParameter *aCodecParameter)
 : codec(aCodec)
 , defaultRepParam(aDefaultRepParam)
 , codecParameter(aCodecParameter)
@@ -202,19 +327,20 @@ DcmCodecList::~DcmCodecList()
 }
 
 OFCondition DcmCodecList::registerCodec(
-    const DcmCodec *aCodec,
-    const DcmRepresentationParameter *aDefaultRepParam,
-    const DcmCodecParameter *aCodecParameter)
+  const DcmCodec *aCodec,
+  const DcmRepresentationParameter *aDefaultRepParam,
+  const DcmCodecParameter *aCodecParameter)
 {
   if ((aCodec == NULL)||(aCodecParameter == NULL)) return EC_IllegalParameter;
-#ifdef _REENTRANT
+#ifdef WITH_THREADS
   if (! codecLock.initialized()) return EC_IllegalCall; // should never happen
 #endif
 
   // acquire write lock on codec list.  Will block if some codec is currently active.
   OFCondition result = EC_Normal;
-#ifdef _REENTRANT
-  if (0 == codecLock.wrlock())
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.wrlock())
   {
 #endif
     DcmCodecList *listEntry = new DcmCodecList(aCodec, aDefaultRepParam, aCodecParameter);
@@ -234,8 +360,7 @@ OFCondition DcmCodecList::registerCodec(
       }
       if (result.good()) registeredCodecs.push_back(listEntry); else delete listEntry;
     } else result = EC_MemoryExhausted;
-#ifdef _REENTRANT
-    codecLock.unlock();
+#ifdef WITH_THREADS
   } else result = EC_IllegalCall;
 #endif
   return result;
@@ -244,14 +369,15 @@ OFCondition DcmCodecList::registerCodec(
 OFCondition DcmCodecList::deregisterCodec(const DcmCodec *aCodec)
 {
   if (aCodec == NULL) return EC_IllegalParameter;
-#ifdef _REENTRANT
+#ifdef WITH_THREADS
   if (! codecLock.initialized()) return EC_IllegalCall; // should never happen
 #endif
   // acquire write lock on codec list.  Will block if some codec is currently active.
   OFCondition result = EC_Normal;
 
-#ifdef _REENTRANT
-  if (0 == codecLock.wrlock())
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.wrlock())
   {
 #endif
     OFListIterator(DcmCodecList *) first = registeredCodecs.begin();
@@ -260,30 +386,30 @@ OFCondition DcmCodecList::deregisterCodec(const DcmCodec *aCodec)
     {
       if ((*first)->codec == aCodec)
       {
-      	delete *first;
-      	first = registeredCodecs.erase(first);
+        delete *first;
+        first = registeredCodecs.erase(first);
       } else ++first;
     }
-#ifdef _REENTRANT
-    codecLock.unlock();
+#ifdef WITH_THREADS
   } else result = EC_IllegalCall;
 #endif
   return result;
 }
 
 OFCondition DcmCodecList::updateCodecParameter(
-    const DcmCodec *aCodec,
-    const DcmCodecParameter *aCodecParameter)
+  const DcmCodec *aCodec,
+  const DcmCodecParameter *aCodecParameter)
 {
   if ((aCodec == NULL)||(aCodecParameter == NULL)) return EC_IllegalParameter;
-#ifdef _REENTRANT
+#ifdef WITH_THREADS
   if (! codecLock.initialized()) return EC_IllegalCall; // should never happen
 #endif
   // acquire write lock on codec list.  Will block if some codec is currently active.
   OFCondition result = EC_Normal;
 
-#ifdef _REENTRANT
-  if (0 == codecLock.wrlock())
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.wrlock())
   {
 #endif
     OFListIterator(DcmCodecList *) first = registeredCodecs.begin();
@@ -293,8 +419,7 @@ OFCondition DcmCodecList::updateCodecParameter(
       if ((*first)->codec == aCodec) (*first)->codecParameter = aCodecParameter;
       ++first;
     }
-#ifdef _REENTRANT
-    codecLock.unlock();
+#ifdef WITH_THREADS
   } else result = EC_IllegalCall;
 #endif
   return result;
@@ -302,20 +427,21 @@ OFCondition DcmCodecList::updateCodecParameter(
 
 
 OFCondition DcmCodecList::decode(
-    const DcmXfer & fromType,
-    const DcmRepresentationParameter * fromParam,
-    DcmPixelSequence * fromPixSeq,
-    DcmPolymorphOBOW& uncompressedPixelData,
-    DcmStack & pixelStack)
+  const DcmXfer & fromType,
+  const DcmRepresentationParameter * fromParam,
+  DcmPixelSequence * fromPixSeq,
+  DcmPolymorphOBOW& uncompressedPixelData,
+  DcmStack & pixelStack)
 {
-#ifdef _REENTRANT
+#ifdef WITH_THREADS
   if (! codecLock.initialized()) return EC_IllegalCall; // should never happen
 #endif
   OFCondition result = EC_CannotChangeRepresentation;
 
   // acquire write lock on codec list.  Will block if some write lock is currently active.
-#ifdef _REENTRANT
-  if (0 == codecLock.rdlock())
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.rdlock())
   {
 #endif
     E_TransferSyntax fromXfer = fromType.getXfer();
@@ -329,31 +455,73 @@ OFCondition DcmCodecList::decode(
         first = last;
       } else ++first;
     }
-#ifdef _REENTRANT
-    codecLock.unlock();
+#ifdef WITH_THREADS
   } else result = EC_IllegalCall;
 #endif
   return result;
 }
 
-OFCondition DcmCodecList::encode(
-    const E_TransferSyntax fromRepType,
-    const DcmRepresentationParameter * fromParam,
-    DcmPixelSequence * fromPixSeq,
-    const E_TransferSyntax toRepType,
-    const DcmRepresentationParameter * toRepParam,
-    DcmPixelSequence * & toPixSeq,
-    DcmStack & pixelStack)
+
+OFCondition DcmCodecList::decodeFrame(
+  const DcmXfer & fromType,
+  const DcmRepresentationParameter * fromParam,
+  DcmPixelSequence * fromPixSeq,
+  DcmItem *dataset,
+  Uint32 frameNo,
+  Uint32& startFragment,
+  void *buffer,
+  Uint32 bufSize,
+  OFString& decompressedColorModel)
 {
-  toPixSeq = NULL;
-#ifdef _REENTRANT
+#ifdef WITH_THREADS
   if (! codecLock.initialized()) return EC_IllegalCall; // should never happen
 #endif
   OFCondition result = EC_CannotChangeRepresentation;
 
   // acquire write lock on codec list.  Will block if some write lock is currently active.
-#ifdef _REENTRANT
-  if (0 == codecLock.rdlock())
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.rdlock())
+  {
+#endif
+    E_TransferSyntax fromXfer = fromType.getXfer();
+    OFListIterator(DcmCodecList *) first = registeredCodecs.begin();
+    OFListIterator(DcmCodecList *) last = registeredCodecs.end();
+    while (first != last)
+    {
+      if ((*first)->codec->canChangeCoding(fromXfer, EXS_LittleEndianExplicit))
+      {
+        result = (*first)->codec->decodeFrame(fromParam, fromPixSeq, (*first)->codecParameter,
+                 dataset, frameNo, startFragment, buffer, bufSize, decompressedColorModel);
+        first = last;
+      } else ++first;
+    }
+#ifdef WITH_THREADS
+  } else result = EC_IllegalCall;
+#endif
+  return result;
+}
+
+
+OFCondition DcmCodecList::encode(
+  const E_TransferSyntax fromRepType,
+  const DcmRepresentationParameter * fromParam,
+  DcmPixelSequence * fromPixSeq,
+  const E_TransferSyntax toRepType,
+  const DcmRepresentationParameter * toRepParam,
+  DcmPixelSequence * & toPixSeq,
+  DcmStack & pixelStack)
+{
+  toPixSeq = NULL;
+#ifdef WITH_THREADS
+  if (! codecLock.initialized()) return EC_IllegalCall; // should never happen
+#endif
+  OFCondition result = EC_CannotChangeRepresentation;
+
+  // acquire write lock on codec list.  Will block if some write lock is currently active.
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.rdlock())
   {
 #endif
     OFListIterator(DcmCodecList *) first = registeredCodecs.begin();
@@ -368,8 +536,7 @@ OFCondition DcmCodecList::encode(
         first = last;
       } else ++first;
     }
-#ifdef _REENTRANT
-    codecLock.unlock();
+#ifdef WITH_THREADS
   } else result = EC_IllegalCall;
 #endif
 
@@ -377,23 +544,24 @@ OFCondition DcmCodecList::encode(
 }
 
 OFCondition DcmCodecList::encode(
-    const E_TransferSyntax fromRepType,
-    const Uint16 * pixelData,
-    const Uint32 length,
-    const E_TransferSyntax toRepType,
-    const DcmRepresentationParameter * toRepParam,
-    DcmPixelSequence * & toPixSeq,
-    DcmStack & pixelStack)
+  const E_TransferSyntax fromRepType,
+  const Uint16 * pixelData,
+  const Uint32 length,
+  const E_TransferSyntax toRepType,
+  const DcmRepresentationParameter * toRepParam,
+  DcmPixelSequence * & toPixSeq,
+  DcmStack & pixelStack)
 {
   toPixSeq = NULL;
-#ifdef _REENTRANT
+#ifdef WITH_THREADS
   if (! codecLock.initialized()) return EC_IllegalCall; // should never happen
 #endif
   OFCondition result = EC_CannotChangeRepresentation;
 
   // acquire write lock on codec list.  Will block if some write lock is currently active.
-#ifdef _REENTRANT
-  if (0 == codecLock.rdlock())
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.rdlock())
   {
 #endif
     OFListIterator(DcmCodecList *) first = registeredCodecs.begin();
@@ -408,8 +576,7 @@ OFCondition DcmCodecList::encode(
         first = last;
       } else ++first;
     }
-#ifdef _REENTRANT
-    codecLock.unlock();
+#ifdef WITH_THREADS
   } else result = EC_IllegalCall;
 #endif
 
@@ -417,17 +584,18 @@ OFCondition DcmCodecList::encode(
 }
 
 OFBool DcmCodecList::canChangeCoding(
-    const E_TransferSyntax fromRepType,
-    const E_TransferSyntax toRepType)
+  const E_TransferSyntax fromRepType,
+  const E_TransferSyntax toRepType)
 {
-#ifdef _REENTRANT
+#ifdef WITH_THREADS
   if (! codecLock.initialized()) return OFFalse; // should never happen
 #endif
   OFBool result = OFFalse;
 
   // acquire write lock on codec list.  Will block if some write lock is currently active.
-#ifdef _REENTRANT
-  if (0 == codecLock.rdlock())
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.rdlock())
   {
 #endif
     OFListIterator(DcmCodecList *) first = registeredCodecs.begin();
@@ -436,21 +604,98 @@ OFBool DcmCodecList::canChangeCoding(
     {
       if ((*first)->codec->canChangeCoding(fromRepType, toRepType))
       {
-      	result = OFTrue;
+        result = OFTrue;
         first = last;
       } else ++first;
     }
-#ifdef _REENTRANT
-    codecLock.unlock();
+#ifdef WITH_THREADS
   }
 #endif
 
   return result;
 }
 
+OFCondition DcmCodecList::determineDecompressedColorModel(
+  const DcmXfer &fromType,
+  const DcmRepresentationParameter *fromParam,
+  DcmPixelSequence *fromPixSeq,
+  DcmItem *dataset,
+  OFString &decompressedColorModel)
+{
+#ifdef WITH_THREADS
+  if (! codecLock.initialized()) return EC_IllegalCall; // should never happen
+#endif
+  OFCondition result = EC_CannotChangeRepresentation;
+
+  // acquire write lock on codec list.  Will block if some write lock is currently active.
+#ifdef WITH_THREADS
+  OFReadWriteLocker locker(codecLock);
+  if (0 == locker.rdlock())
+  {
+#endif
+    E_TransferSyntax fromXfer = fromType.getXfer();
+    OFListIterator(DcmCodecList *) first = registeredCodecs.begin();
+    OFListIterator(DcmCodecList *) last = registeredCodecs.end();
+    while (first != last)
+    {
+      if ((*first)->codec->canChangeCoding(fromXfer, EXS_LittleEndianExplicit))
+      {
+        result = (*first)->codec->determineDecompressedColorModel(fromParam, fromPixSeq, (*first)->codecParameter,
+                 dataset, decompressedColorModel);
+        first = last;
+      } else ++first;
+    }
+#ifdef WITH_THREADS
+  } else result = EC_IllegalCall;
+#endif
+  return result;
+}
+
+
 /*
 ** CVS/RCS Log:
 ** $Log: dccodec.cc,v $
+** Revision 1.22  2010-10-14 13:14:07  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.21  2010-10-04 14:26:19  joergr
+** Fixed issue with codec registry when compiled on Linux x86_64 with "configure
+** --disable-threads" (replaced "#ifdef _REENTRANT" by "#ifdef WITH_THREADS").
+**
+** Revision 1.20  2010-08-09 13:01:22  joergr
+** Updated data dictionary to 2009 edition of the DICOM standard. From now on,
+** the official "keyword" is used for the attribute name which results in a
+** number of minor changes (e.g. "PatientsName" is now called "PatientName").
+**
+** Revision 1.19  2010-06-04 14:22:39  uli
+** Use new OFReadWriteLocker to avoid dead locks when we return from a codec
+** via an exception.
+**
+** Revision 1.18  2010-03-01 09:08:45  uli
+** Removed some unnecessary include directives in the headers.
+**
+** Revision 1.17  2009-11-17 16:41:26  joergr
+** Added new method that allows for determining the color model of the
+** decompressed image.
+**
+** Revision 1.16  2008-11-03 14:34:10  joergr
+** Fixed typo.
+**
+** Revision 1.15  2008-05-29 10:46:16  meichel
+** Implemented new method DcmPixelData::getUncompressedFrame
+**   that permits frame-wise access to compressed and uncompressed
+**   objects without ever loading the complete object into main memory.
+**   For this new method to work with compressed images, all classes derived from
+**   DcmCodec need to implement a new method decodeFrame(). For now, only
+**   dummy implementations returning an error code have been defined.
+**
+** Revision 1.14  2005/12/08 15:40:58  meichel
+** Changed include path schema for all DCMTK header files
+**
+** Revision 1.13  2004/08/24 14:54:20  meichel
+**  Updated compression helper methods. Image type is not set to SECONDARY
+**   any more, support for the purpose of reference code sequence added.
+**
 ** Revision 1.12  2004/02/04 16:11:42  joergr
 ** Adapted type casts to new-style typecast operators defined in ofcast.h.
 **
