@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2004, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -22,8 +18,8 @@
  *  Purpose: Implementation of class DcmDataset
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2004/02/04 16:19:15 $
- *  CVS/RCS Revision: $Revision: 1.34 $
+ *  Update Date:      $Date: 2010-11-12 12:16:11 $
+ *  CVS/RCS Revision: $Revision: 1.52 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -31,27 +27,27 @@
  */
 
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTDIO
 #define INCLUDE_CSTRING
-#include "ofstdinc.h"
+#include "dcmtk/ofstd/ofstdinc.h"
 
-#include "ofstream.h"
-#include "ofstack.h"
-#include "ofstd.h"
+#include "dcmtk/ofstd/ofstream.h"
+#include "dcmtk/ofstd/ofstack.h"
+#include "dcmtk/ofstd/ofstd.h"
 
-#include "dcdatset.h"
-#include "dcxfer.h"
-#include "dcvrus.h"
-#include "dcdebug.h"
-#include "dcpixel.h"
-#include "dcdeftag.h"
-#include "dcostrma.h"    /* for class DcmOutputStream */
-#include "dcostrmf.h"    /* for class DcmOutputFileStream */
-#include "dcistrma.h"    /* for class DcmInputStream */
-#include "dcistrmf.h"    /* for class DcmInputFileStream */
+#include "dcmtk/dcmdata/dcdatset.h"
+#include "dcmtk/dcmdata/dcxfer.h"
+#include "dcmtk/dcmdata/dcvrus.h"
+#include "dcmtk/dcmdata/dcpixel.h"
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcostrma.h"    /* for class DcmOutputStream */
+#include "dcmtk/dcmdata/dcostrmf.h"    /* for class DcmOutputFileStream */
+#include "dcmtk/dcmdata/dcistrma.h"    /* for class DcmInputStream */
+#include "dcmtk/dcmdata/dcistrmf.h"    /* for class DcmInputFileStream */
+#include "dcmtk/dcmdata/dcwcache.h"    /* for class DcmWriteCache */
 
 
 // ********************************
@@ -64,6 +60,19 @@ DcmDataset::DcmDataset()
 }
 
 
+DcmDataset& DcmDataset::operator=(const DcmDataset& obj)
+{
+  if (this != &obj)
+  {
+    // copy parent's member variables
+    DcmItem::operator=(obj);
+    // copy DcmDataset's member variables
+    Xfer = obj.Xfer;
+  }
+  return *this;
+}
+
+
 DcmDataset::DcmDataset(const DcmDataset &old)
   : DcmItem(old),
     Xfer(old.Xfer)
@@ -71,6 +80,17 @@ DcmDataset::DcmDataset(const DcmDataset &old)
 }
 
 
+OFCondition DcmDataset::copyFrom(const DcmObject& rhs)
+{
+  if (this != &rhs)
+  {
+    if (rhs.ident() != ident()) return EC_IllegalCall;
+    *this = OFstatic_cast(const DcmDataset &, rhs);
+  }
+  return EC_Normal;
+}
+
+
 DcmDataset::~DcmDataset()
 {
 }
@@ -79,6 +99,13 @@ DcmDataset::~DcmDataset()
 // ********************************
 
 
+OFCondition DcmDataset::clear()
+{
+    OFCondition result = DcmItem::clear();
+    setLengthField(DCM_UndefinedLength);
+    return result;
+}
+
 DcmEVR DcmDataset::ident() const
 {
     return EVR_dataset;
@@ -91,6 +118,25 @@ E_TransferSyntax DcmDataset::getOriginalXfer() const
 }
 
 
+void DcmDataset::removeInvalidGroups()
+{
+    DcmStack stack;
+    DcmObject *object = NULL;
+    /* iterate over all elements */
+    while (nextObject(stack, OFTrue).good())
+    {
+        object = stack.top();
+        /* delete invalid elements */
+        if ((object->getTag().getGroup() == 0x0002) || !object->getTag().hasValidGroup())
+        {
+            stack.pop();
+            /* remove element from dataset and free memory */
+            delete OFstatic_cast(DcmItem *, stack.top())->remove(object);
+        }
+    }
+}
+
+
 // ********************************
 
 
@@ -125,18 +171,23 @@ OFBool DcmDataset::canWriteXfer(const E_TransferSyntax newXfer,
 // ********************************
 
 
-void DcmDataset::print(ostream &out,
+void DcmDataset::print(STD_NAMESPACE ostream&out,
                        const size_t flags,
                        const int level,
                        const char *pixelFileName,
                        size_t *pixelCounter)
 {
-    out << endl;
+    out << OFendl;
+    if (flags & DCMTypes::PF_useANSIEscapeCodes)
+        out << ANSI_ESCAPE_CODE_COMMENT;
     printNestingLevel(out, flags, level);
-    out << "# Dicom-Data-Set" << endl;
+    out << "# Dicom-Data-Set" << OFendl;
+    if (flags & DCMTypes::PF_useANSIEscapeCodes)
+        out << ANSI_ESCAPE_CODE_COMMENT;
     printNestingLevel(out, flags, level);
-    out << "# Used TransferSyntax: " << DcmXfer(Xfer).getXferName();
-    out << endl;
+    out << "# Used TransferSyntax: " << DcmXfer(Xfer).getXferName() << OFendl;
+    if (flags & DCMTypes::PF_useANSIEscapeCodes)
+        out << ANSI_ESCAPE_CODE_RESET;
     if (!elementList->empty())
     {
         DcmObject *dO;
@@ -152,7 +203,7 @@ void DcmDataset::print(ostream &out,
 // ********************************
 
 
-OFCondition DcmDataset::writeXML(ostream &out,
+OFCondition DcmDataset::writeXML(STD_NAMESPACE ostream&out,
                                  const size_t flags)
 {
     OFString xmlString;
@@ -162,7 +213,7 @@ OFCondition DcmDataset::writeXML(ostream &out,
     out << " name=\"" << OFStandard::convertToMarkupString(xfer.getXferName(), xmlString) << "\"";
     if (flags & DCMTypes::XF_useDcmtkNamespace)
         out << " xmlns=\"" << DCMTK_XML_NAMESPACE_URI << "\"";
-    out << ">" << endl;
+    out << ">" << OFendl;
     if (!elementList->empty())
     {
         /* write content of all children */
@@ -174,7 +225,7 @@ OFCondition DcmDataset::writeXML(ostream &out,
         } while (elementList->seek(ELP_next));
     }
     /* XML end tag for "data-set" */
-    out << "</data-set>" << endl;
+    out << "</data-set>" << OFendl;
     /* always report success */
     return EC_Normal;
 }
@@ -196,18 +247,40 @@ OFCondition DcmDataset::read(DcmInputStream &inStream,
         errorFlag = EC_EndOfStream;
     /* else if the stream did not report an error but the transfer */
     /* state does not equal ERW_ready, go ahead and do something */
-    else if (errorFlag.good() && fTransferState != ERW_ready)
+    else if (errorFlag.good() && getTransferState() != ERW_ready)
     {
         /* if the transfer state is ERW_init, go ahead and check the transfer syntax which was passed */
-        if (fTransferState == ERW_init)
+        if (getTransferState() == ERW_init)
         {
-            /* if the transfer syntax which was passed equals EXS_Unknown we want to */
-            /* determine the transfer syntax from the information in the stream itself. */
-            /* If the transfer syntax is given, we want to use it. */
-            if (xfer == EXS_Unknown)
-                Xfer = checkTransferSyntax(inStream);
-            else
-                Xfer = xfer;
+            if (dcmAutoDetectDatasetXfer.get())
+            {
+                /* To support incorrectly encoded datasets detect the transfer syntax from the stream.  */
+                /* This is possible for given unknown and plain big or little endian transfer syntaxes. */
+                switch( xfer )
+                {
+                    case EXS_Unknown:
+                    case EXS_LittleEndianImplicit:
+                    case EXS_LittleEndianExplicit:
+                    case EXS_BigEndianExplicit:
+                    case EXS_BigEndianImplicit:
+                        Xfer = checkTransferSyntax(inStream);
+                        if ((xfer != EXS_Unknown) && (Xfer != xfer))
+                            DCMDATA_WARN("DcmDataset: Wrong transfer syntax specified, detecting from dataset");
+                        break;
+                    default:
+                        Xfer = xfer;
+                }
+            }
+            else /* default behaviour */
+            {
+                /* If the transfer syntax which was passed equals EXS_Unknown we want to */
+                /* determine the transfer syntax from the information in the stream itself. */
+                /* If the transfer syntax is given, we want to use it. */
+                if (xfer == EXS_Unknown)
+                    Xfer = checkTransferSyntax(inStream);
+                else
+                    Xfer = xfer;
+            }
             /* Check stream compression for this transfer syntax */
             DcmXfer xf(Xfer);
             E_StreamCompression sc = xf.getStreamCompression();
@@ -245,11 +318,11 @@ OFCondition DcmDataset::read(DcmInputStream &inStream,
         computeGroupLengthAndPadding(glenc, EPD_noChange, Xfer);
 
         /* and set the transfer state to ERW_ready to indicate that the data set is complete */
-        fTransferState = ERW_ready;
+        setTransferState(ERW_ready);
     }
 
     /* dump information if required */
-    debug(3, ("DcmDataset::read: At End: errorFlag = %s", errorFlag.text()));
+    DCMDATA_TRACE("DcmDataset::read() returns error = " << errorFlag.text());
 
     /* return result flag */
     return errorFlag;
@@ -259,17 +332,20 @@ OFCondition DcmDataset::read(DcmInputStream &inStream,
 // ********************************
 
 
-OFCondition DcmDataset::write(DcmOutputStream &outStream,
-                              const E_TransferSyntax oxfer,
-                              const E_EncodingType enctype)
+OFCondition DcmDataset::write(
+      DcmOutputStream &outStream,
+      const E_TransferSyntax oxfer,
+      const E_EncodingType enctype /* = EET_UndefinedLength */,
+      DcmWriteCache *wcache)
 {
-    return write(outStream, oxfer, enctype, EGL_recalcGL);
+    return write(outStream, oxfer, enctype, wcache, EGL_recalcGL);
 }
 
 
 OFCondition DcmDataset::write(DcmOutputStream &outStream,
                               const E_TransferSyntax oxfer,
                               const E_EncodingType enctype,
+                              DcmWriteCache *wcache,
                               const E_GrpLenEncoding glenc,
                               const E_PaddingEncoding padenc,
                               const Uint32 padlen,
@@ -277,14 +353,14 @@ OFCondition DcmDataset::write(DcmOutputStream &outStream,
                               Uint32 instanceLength)
 {
   /* if the transfer state of this is not initialized, this is an illegal call */
-  if (fTransferState == ERW_notInitialized)
+  if (getTransferState() == ERW_notInitialized)
     errorFlag = EC_IllegalCall;
   else
   {
     /* check if the stream reported an error so far; if not, we can go ahead and write some data to it */
     errorFlag = outStream.status();
 
-    if (errorFlag.good() && fTransferState != ERW_ready)
+    if (errorFlag.good() && getTransferState() != ERW_ready)
     {
       /* Determine the transfer syntax which shall be used. Either we use the one which was passed, */
       /* or (if it's an unknown tranfer syntax) we use the one which is contained in this->Xfer. */
@@ -297,7 +373,7 @@ OFCondition DcmDataset::write(DcmOutputStream &outStream,
       /* to the strategies which are specified in glenc and padenc. Additionally, we need to set the element */
       /* list pointer of this data set to the fist element and we need to set the transfer state to ERW_inWork */
       /* so that this scenario will only be executed once for this data set object. */
-      if (fTransferState == ERW_init)
+      if (getTransferState() == ERW_init)
       {
 
         /* Check stream compression for this transfer syntax */
@@ -322,12 +398,12 @@ OFCondition DcmDataset::write(DcmOutputStream &outStream,
         /* take care of group length and padding elements, according to what is specified in glenc and padenc */
         computeGroupLengthAndPadding(glenc, padenc, newXfer, enctype, padlen, subPadlen, instanceLength);
         elementList->seek(ELP_first);
-        fTransferState = ERW_inWork;
+        setTransferState(ERW_inWork);
       }
 
       /* if the transfer state is set to ERW_inWork, we need to write the information which */
       /* is included in this data set's element list into the buffer which was passed. */
-      if (fTransferState == ERW_inWork)
+      if (getTransferState() == ERW_inWork)
       {
         // Remember that elementList->get() can be NULL if buffer was full after
         // writing the last item but before writing the sequence delimitation.
@@ -339,14 +415,14 @@ OFCondition DcmDataset::write(DcmOutputStream &outStream,
           do
           {
             dO = elementList->get();
-            errorFlag = dO->write(outStream, newXfer, enctype);
+            errorFlag = dO->write(outStream, newXfer, enctype, wcache);
           } while (errorFlag.good() && elementList->seek(ELP_next));
         }
 
         /* if all the information in this has been written to the */
         /* buffer set this data set's transfer state to ERW_ready */
         if (errorFlag.good())
-          fTransferState = ERW_ready;
+          setTransferState(ERW_ready);
       }
     }
   }
@@ -361,9 +437,10 @@ OFCondition DcmDataset::write(DcmOutputStream &outStream,
 
 OFCondition DcmDataset::writeSignatureFormat(DcmOutputStream &outStream,
                                              const E_TransferSyntax oxfer,
-                                             const E_EncodingType enctype)
+                                             const E_EncodingType enctype,
+                                             DcmWriteCache *wcache)
 {
-  if (fTransferState == ERW_notInitialized)
+  if (getTransferState() == ERW_notInitialized)
     errorFlag = EC_IllegalCall;
   else
   {
@@ -372,15 +449,15 @@ OFCondition DcmDataset::writeSignatureFormat(DcmOutputStream &outStream,
       newXfer = Xfer;
 
     errorFlag = outStream.status();
-    if (errorFlag.good() && fTransferState != ERW_ready)
+    if (errorFlag.good() && getTransferState() != ERW_ready)
     {
-      if (fTransferState == ERW_init)
+      if (getTransferState() == ERW_init)
       {
         computeGroupLengthAndPadding(EGL_recalcGL, EPD_noChange, newXfer, enctype, 0, 0, 0);
         elementList->seek(ELP_first);
-        fTransferState = ERW_inWork;
+        setTransferState(ERW_inWork);
       }
-      if (fTransferState == ERW_inWork)
+      if (getTransferState() == ERW_inWork)
       {
         // elementList->get() can be NULL if buffer was full after
         // writing the last item but before writing the sequence delimitation.
@@ -389,11 +466,11 @@ OFCondition DcmDataset::writeSignatureFormat(DcmOutputStream &outStream,
           DcmObject *dO;
           do {
             dO = elementList->get();
-            errorFlag = dO->writeSignatureFormat(outStream, newXfer, enctype);
+            errorFlag = dO->writeSignatureFormat(outStream, newXfer, enctype, wcache);
           } while (errorFlag.good() && elementList->seek(ELP_next));
         }
         if (errorFlag.good())
-          fTransferState = ERW_ready;
+          setTransferState(ERW_ready);
       }
     }
   }
@@ -421,10 +498,15 @@ OFCondition DcmDataset::loadFile(const char *filename,
 
         if (l_error.good())
         {
-            /* read data from file */
-            transferInit();
-            l_error = read(fileStream, readXfer, groupLength, maxReadLength);
-            transferEnd();
+            /* clear this object */
+            l_error = clear();
+            if (l_error.good())
+            {
+                /* read data from file */
+                transferInit();
+                l_error = read(fileStream, readXfer, groupLength, maxReadLength);
+                transferEnd();
+            }
         }
     }
     return l_error;
@@ -439,6 +521,7 @@ OFCondition DcmDataset::saveFile(const char *fileName,
                                  const Uint32 padLength,
                                  const Uint32 subPadLength)
 {
+    DcmWriteCache wcache;
     OFCondition l_error = EC_IllegalParameter;
     /* check parameters first */
     if ((fileName != NULL) && (strlen(fileName) > 0))
@@ -452,7 +535,7 @@ OFCondition DcmDataset::saveFile(const char *fileName,
         {
             /* write data to file */
             transferInit();
-            l_error = write(fileStream, writeXfer, encodingType, groupLength, padEncoding, padLength, subPadLength);
+            l_error = write(fileStream, writeXfer, encodingType, &wcache, groupLength, padEncoding, padLength, subPadLength);
             transferEnd();
         }
     }
@@ -559,6 +642,74 @@ void DcmDataset::removeAllButOriginalRepresentations()
 /*
 ** CVS/RCS Log:
 ** $Log: dcdatset.cc,v $
+** Revision 1.52  2010-11-12 12:16:11  joergr
+** Output ANSI escape codes at the beginnig of each line in order to make sure
+** that always the correct color is used in case of truncated multi-line output.
+**
+** Revision 1.51  2010-10-29 10:57:21  joergr
+** Added support for colored output to the print() method.
+**
+** Revision 1.50  2010-10-20 16:44:16  joergr
+** Use type cast macros (e.g. OFstatic_cast) where appropriate.
+**
+** Revision 1.49  2010-10-14 13:14:07  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.48  2009-12-04 16:55:33  joergr
+** Sightly modified some log messages.
+**
+** Revision 1.47  2009-11-13 13:11:20  joergr
+** Fixed minor issues in log output.
+**
+** Revision 1.46  2009-11-04 09:58:09  uli
+** Switched to logging mechanism provided by the "new" oflog module
+**
+** Revision 1.45  2009-08-25 12:54:57  joergr
+** Added new methods which remove all data elements with an invalid group number
+** from the meta information header, dataset and/or fileformat.
+**
+** Revision 1.44  2008-07-17 10:31:31  onken
+** Implemented copyFrom() method for complete DcmObject class hierarchy, which
+** permits setting an instance's value from an existing object. Implemented
+** assignment operator where necessary.
+**
+** Revision 1.43  2007-11-29 14:30:20  meichel
+** Write methods now handle large raw data elements (such as pixel data)
+**   without loading everything into memory. This allows very large images to
+**   be sent over a network connection, or to be copied without ever being
+**   fully in memory.
+**
+** Revision 1.42  2007/06/29 14:17:49  meichel
+** Code clean-up: Most member variables in module dcmdata are now private,
+**   not protected anymore.
+**
+** Revision 1.41  2006/08/15 15:49:54  meichel
+** Updated all code in module dcmdata to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.40  2005/12/08 15:40:59  meichel
+** Changed include path schema for all DCMTK header files
+**
+** Revision 1.39  2005/12/02 08:51:44  joergr
+** Changed macro NO_XFER_DETECTION_FOR_DATASETS into a global option that can
+** be enabled and disabled at runtime.
+**
+** Revision 1.38  2005/12/01 09:57:26  joergr
+** Added support for DICOM objects where the dataset is stored with a different
+** transfer syntax than specified in the meta header.  The new behaviour can be
+** disabled by compiling with the macro NO_XFER_DETECTION_FOR_DATASETS defined.
+**
+** Revision 1.37  2005/11/28 15:53:13  meichel
+** Renamed macros in dcdebug.h
+**
+** Revision 1.36  2005/11/11 10:31:58  meichel
+** Added explicit DcmDataset::clear() implementation.
+**
+** Revision 1.35  2005/11/07 17:22:33  meichel
+** Implemented DcmFileFormat::clear(). Now the loadFile methods in class
+**   DcmFileFormat and class DcmDataset both make sure that clear() is called
+**   before new data is read, allowing for a re-use of the object.
+**
 ** Revision 1.34  2004/02/04 16:19:15  joergr
 ** Adapted type casts to new-style typecast operators defined in ofcast.h.
 ** Removed acknowledgements with e-mail addresses from CVS log.
