@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -22,9 +18,9 @@
  *  Purpose: DcmInputBufferStream and related classes,
  *    implements input to blocks of memory as needed in the dcmnet module.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:41:13 $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:08 $
+ *  CVS/RCS Revision: $Revision: 1.9 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -33,7 +29,6 @@
 
 #include "dcmtk/config/osconfig.h"
 #include "dcmtk/dcmdata/dcistrmb.h"
-#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/dcmdata/dcerror.h"
 
 #define DCMBUFFERPRODUCER_BUFSIZE 1024
@@ -69,7 +64,7 @@ OFCondition DcmBufferProducer::status() const
   return status_;
 }
 
-OFBool DcmBufferProducer::eos() const
+OFBool DcmBufferProducer::eos() 
 {
   // end of stream is true if the user has called setEos() before
   // and there is no more data available in the current buffer.
@@ -78,7 +73,7 @@ OFBool DcmBufferProducer::eos() const
 }
 
 
-Uint32 DcmBufferProducer::avail() const
+offile_off_t DcmBufferProducer::avail()
 {
   if (status_.good())
   {
@@ -90,9 +85,9 @@ Uint32 DcmBufferProducer::avail() const
 }
 
 
-Uint32 DcmBufferProducer::read(void *buf, Uint32 buflen)
+offile_off_t DcmBufferProducer::read(void *buf, offile_off_t buflen)
 {
-  Uint32 result = 0;
+  offile_off_t result = 0;
   if (status_.good() && buflen && buf)
   {
     unsigned char *target = OFstatic_cast(unsigned char *, buf);
@@ -110,7 +105,7 @@ Uint32 DcmBufferProducer::read(void *buf, Uint32 buflen)
     if (buflen && bufSize_)
     {
       // read data from user buffer
-      Uint32 numbytes = bufSize_ - bufIndex_;
+      offile_off_t numbytes = bufSize_ - bufIndex_;
       if (numbytes > buflen) numbytes = buflen;
       memcpy(target, buffer_ + bufIndex_, OFstatic_cast(size_t, numbytes));
       bufIndex_ += numbytes;
@@ -121,9 +116,9 @@ Uint32 DcmBufferProducer::read(void *buf, Uint32 buflen)
 }
 
 
-Uint32 DcmBufferProducer::skip(Uint32 skiplen)
+offile_off_t DcmBufferProducer::skip(offile_off_t skiplen)
 {
-  Uint32 result = 0;
+  offile_off_t result = 0;
   if (status_.good() && skiplen)
   {
     if (backupIndex_ < DCMBUFFERPRODUCER_BUFSIZE)
@@ -138,7 +133,7 @@ Uint32 DcmBufferProducer::skip(Uint32 skiplen)
     if (skiplen && bufSize_)
     {
       // skip data from user buffer
-      Uint32 skipbytes = bufSize_ - bufIndex_;
+      offile_off_t skipbytes = bufSize_ - bufIndex_;
       if (skipbytes > skiplen) skipbytes = skiplen;
       bufIndex_ += skipbytes;
       result += skipbytes;
@@ -147,7 +142,7 @@ Uint32 DcmBufferProducer::skip(Uint32 skiplen)
   return result;
 }
 
-void DcmBufferProducer::putback(Uint32 num)
+void DcmBufferProducer::putback(offile_off_t num)
 {
   if (status_.good() && num)
   {
@@ -195,7 +190,7 @@ void DcmBufferProducer::putback(Uint32 num)
   }
 }
 
-void DcmBufferProducer::setBuffer(const void *buf, Uint32 buflen)
+void DcmBufferProducer::setBuffer(const void *buf, offile_off_t buflen)
 {
   if (status_.good())
   {
@@ -220,7 +215,7 @@ void DcmBufferProducer::releaseBuffer()
   if (status_.good() && buffer_)
   {
     // compute the least number of bytes that we have to store in the backup buffer
-    Uint32 numBytes = bufSize_ - bufIndex_;
+    offile_off_t numBytes = bufSize_ - bufIndex_;
 
     if (numBytes > backupIndex_)
     {
@@ -306,8 +301,7 @@ DcmInputBufferStream::~DcmInputBufferStream()
 #ifdef DEBUG
   if ((!eos()) && (avail() > 0))
   {
-    ofConsole.lockCerr() << "Warning: closing unflushed DcmInputBufferStream, loss of data!" << endl;
-    ofConsole.unlockCerr();
+      DCMDATA_WARN("closing unflushed DcmInputBufferStream, loss of data!");
   }
 #endif
 }
@@ -318,7 +312,7 @@ DcmInputStreamFactory *DcmInputBufferStream::newFactory() const
   return NULL;
 }
 
-void DcmInputBufferStream::setBuffer(const void *buf, Uint32 buflen)
+void DcmInputBufferStream::setBuffer(const void *buf, offile_off_t buflen)
 {
   producer_.setBuffer(buf, buflen);
 
@@ -342,6 +336,23 @@ void DcmInputBufferStream::setEos()
 /*
  * CVS/RCS Log:
  * $Log: dcistrmb.cc,v $
+ * Revision 1.9  2010-10-14 13:14:08  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.8  2010-02-22 11:39:54  uli
+ * Remove some unneeded includes.
+ *
+ * Revision 1.7  2009-11-04 09:58:09  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.6  2007-02-19 15:45:31  meichel
+ * Class DcmInputStream and related classes are now safe for use with
+ *   large files (2 GBytes or more) if supported by compiler and operating system.
+ *
+ * Revision 1.5  2006/08/15 15:49:54  meichel
+ * Updated all code in module dcmdata to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.4  2005/12/08 15:41:13  meichel
  * Changed include path schema for all DCMTK header files
  *
