@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -22,9 +18,9 @@
  *  Purpose: DcmOutputBufferStream and related classes,
  *    implements output to blocks of memory as needed in the dcmnet module.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:41:21 $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:08 $
+ *  CVS/RCS Revision: $Revision: 1.10 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -33,11 +29,10 @@
 
 #include "dcmtk/config/osconfig.h"
 #include "dcmtk/dcmdata/dcostrmb.h"
-#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/dcmdata/dcerror.h"
 
 
-DcmBufferConsumer::DcmBufferConsumer(void *buf, Uint32 bufLen)
+DcmBufferConsumer::DcmBufferConsumer(void *buf, offile_off_t bufLen)
 : DcmConsumer()
 , buffer_(OFstatic_cast(unsigned char *, buf))
 , bufSize_(bufLen)
@@ -66,14 +61,14 @@ OFBool DcmBufferConsumer::isFlushed() const
   return (filled_ == 0);
 }
 
-Uint32 DcmBufferConsumer::avail() const
+offile_off_t DcmBufferConsumer::avail() const
 {
   return bufSize_ - filled_;
 }
 
-Uint32 DcmBufferConsumer::write(const void *buf, Uint32 buflen)
+offile_off_t DcmBufferConsumer::write(const void *buf, offile_off_t buflen)
 {
-  Uint32 result = 0;
+  offile_off_t result = 0;
   if (status_.good() && buf && buflen)
   {
     result = bufSize_ - filled_;
@@ -89,7 +84,7 @@ void DcmBufferConsumer::flush()
   // nothing to flush
 }
 
-void DcmBufferConsumer::flushBuffer(void *& buffer, Uint32& length)
+void DcmBufferConsumer::flushBuffer(void *& buffer, offile_off_t& length)
 {
   buffer = buffer_;
   length = filled_;
@@ -98,7 +93,7 @@ void DcmBufferConsumer::flushBuffer(void *& buffer, Uint32& length)
 
 /* ======================================================================= */
 
-DcmOutputBufferStream::DcmOutputBufferStream(void *buf, Uint32 bufLen)
+DcmOutputBufferStream::DcmOutputBufferStream(void *buf, offile_off_t bufLen)
 : DcmOutputStream(&consumer_) // safe because DcmOutputStream only stores pointer
 , consumer_(buf, bufLen)
 {
@@ -109,13 +104,12 @@ DcmOutputBufferStream::~DcmOutputBufferStream()
 #ifdef DEBUG
   if (! isFlushed())
   {
-    ofConsole.lockCerr() << "Warning: closing unflushed DcmOutputBufferStream, loss of data!" << endl;
-    ofConsole.unlockCerr();
+    DCMDATA_WARN("DcmOutputBufferStream: Closing unflushed DcmOutputBufferStream, loss of data!");
   }
 #endif
 }
 
-void DcmOutputBufferStream::flushBuffer(void *& buffer, Uint32& length)
+void DcmOutputBufferStream::flushBuffer(void *& buffer, offile_off_t& length)
 {
   consumer_.flushBuffer(buffer, length);
 }
@@ -124,6 +118,26 @@ void DcmOutputBufferStream::flushBuffer(void *& buffer, Uint32& length)
 /*
  * CVS/RCS Log:
  * $Log: dcostrmb.cc,v $
+ * Revision 1.10  2010-10-14 13:14:08  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.9  2010-02-22 11:39:54  uli
+ * Remove some unneeded includes.
+ *
+ * Revision 1.8  2009-12-04 17:10:00  joergr
+ * Slightly modified some log messages.
+ *
+ * Revision 1.7  2009-11-04 09:58:10  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.6  2007-02-19 16:06:10  meichel
+ * Class DcmOutputStream and related classes are now safe for use with
+ *   large files (2 GBytes or more) if supported by compiler and operating system.
+ *
+ * Revision 1.5  2006/08/15 15:49:54  meichel
+ * Updated all code in module dcmdata to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.4  2005/12/08 15:41:21  meichel
  * Changed include path schema for all DCMTK header files
  *
