@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: encoder codec class for RLE
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:41:30 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmdata/libsrc/dcrlecce.cc,v $
- *  CVS/RCS Revision: $Revision: 1.11 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:09 $
+ *  CVS/RCS Revision: $Revision: 1.16 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -40,6 +35,7 @@
 #include "dcmtk/dcmdata/dcpixseq.h"  /* for class DcmPixelSequence */
 #include "dcmtk/dcmdata/dcpxitem.h"  /* for class DcmPixelItem */
 #include "dcmtk/dcmdata/dcswap.h"    /* for swapIfNecessary */
+#include "dcmtk/dcmdata/dcitem.h"
 #include "dcmtk/ofstd/ofstd.h"
 
 #define INCLUDE_CSTDIO
@@ -89,6 +85,22 @@ OFCondition DcmRLECodecEncoder::decode(
 }
 
 
+OFCondition DcmRLECodecEncoder::decodeFrame(
+    const DcmRepresentationParameter * /* fromParam */ ,
+    DcmPixelSequence * /* fromPixSeq */ ,
+    const DcmCodecParameter * /* cp */ ,
+    DcmItem * /* dataset */ ,
+    Uint32 /* frameNo */ ,
+    Uint32& /* startFragment */ ,
+    void * /* buffer */ ,
+    Uint32 /* bufSize */ ,
+    OFString& /* decompressedColorModel */ ) const
+{
+  // we are an encoder only
+  return EC_IllegalCall;
+}    
+
+
 OFCondition DcmRLECodecEncoder::encode(
     const E_TransferSyntax /* fromRepType */,
     const DcmRepresentationParameter * /* fromRepParam */,
@@ -104,12 +116,12 @@ OFCondition DcmRLECodecEncoder::encode(
 
 
 OFCondition DcmRLECodecEncoder::encode(
-        const Uint16 *pixelData,
-        const Uint32 length,
-        const DcmRepresentationParameter * /* toRepParam */ ,
-        DcmPixelSequence * & pixSeq,
-        const DcmCodecParameter *cp,
-        DcmStack & objStack) const
+    const Uint16 *pixelData,
+    const Uint32 length,
+    const DcmRepresentationParameter * /* toRepParam */ ,
+    DcmPixelSequence * & pixSeq,
+    const DcmCodecParameter *cp,
+    DcmStack & objStack) const
 {
   OFCondition result = EC_Normal;
 
@@ -416,9 +428,41 @@ OFCondition DcmRLECodecEncoder::updateDerivationDescription(
 }
 
 
+OFCondition DcmRLECodecEncoder::determineDecompressedColorModel(
+    const DcmRepresentationParameter * /* fromParam */,
+    DcmPixelSequence * /* fromPixSeq */,
+    const DcmCodecParameter * /* cp */,
+    DcmItem * /* dataset */,
+    OFString & /* decompressedColorModel */) const
+{
+    return EC_IllegalCall;
+}
+
+
 /*
  * CVS/RCS Log
  * $Log: dcrlecce.cc,v $
+ * Revision 1.16  2010-10-14 13:14:09  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.15  2010-03-01 09:08:45  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.14  2009-11-17 16:41:26  joergr
+ * Added new method that allows for determining the color model of the
+ * decompressed image.
+ *
+ * Revision 1.13  2009-11-04 09:58:10  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.12  2008-05-29 10:46:16  meichel
+ * Implemented new method DcmPixelData::getUncompressedFrame
+ *   that permits frame-wise access to compressed and uncompressed
+ *   objects without ever loading the complete object into main memory.
+ *   For this new method to work with compressed images, all classes derived from
+ *   DcmCodec need to implement a new method decodeFrame(). For now, only
+ *   dummy implementations returning an error code have been defined.
+ *
  * Revision 1.11  2005/12/08 15:41:30  meichel
  * Changed include path schema for all DCMTK header files
  *
