@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: singleton class that registers RLE decoder.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:41:33 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmdata/libsrc/dcrledrg.cc,v $
- *  CVS/RCS Revision: $Revision: 1.3 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:09 $
+ *  CVS/RCS Revision: $Revision: 1.5 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -45,13 +40,11 @@ DcmRLECodecDecoder *DcmRLEDecoderRegistration::codec          = NULL;
 
 void DcmRLEDecoderRegistration::registerCodecs(
     OFBool pCreateSOPInstanceUID,
-    OFBool pVerbose,
     OFBool pReverseDecompressionByteOrder)
 {
   if (! registered)
   {
     cp = new DcmRLECodecParameter(
-      pVerbose,
       pCreateSOPInstanceUID,
       0, OFTrue, OFFalse,
       pReverseDecompressionByteOrder);
@@ -85,7 +78,13 @@ void DcmRLEDecoderRegistration::cleanup()
 /*
  * CVS/RCS Log
  * $Log: dcrledrg.cc,v $
- * Revision 1.3  2005/12/08 15:41:33  meichel
+ * Revision 1.5  2010-10-14 13:14:09  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.4  2009-11-04 09:58:10  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.3  2005-12-08 15:41:33  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.2  2005/07/26 17:08:35  meichel
