@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Implementation of class DcmFloatingPointDouble
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:41:52 $
- *  CVS/RCS Revision: $Revision: 1.27 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-20 16:44:17 $
+ *  CVS/RCS Revision: $Revision: 1.34 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -71,6 +67,17 @@ DcmFloatingPointDouble &DcmFloatingPointDouble::operator=(const DcmFloatingPoint
 }
 
 
+OFCondition DcmFloatingPointDouble::copyFrom(const DcmObject& rhs)
+{
+  if (this != &rhs)
+  {
+    if (rhs.ident() != ident()) return EC_IllegalCall;
+    *this = OFstatic_cast(const DcmFloatingPointDouble &, rhs);
+  }
+  return EC_Normal;
+}
+
+
 // ********************************
 
 
@@ -80,16 +87,24 @@ DcmEVR DcmFloatingPointDouble::ident() const
 }
 
 
+OFCondition DcmFloatingPointDouble::checkValue(const OFString &vm,
+                                               const OFBool /*oldFormat*/)
+{
+    /* check VM only, further checks on the floating point values could be added later */
+    return DcmElement::checkVM(getVM(), vm);
+}
+
+
 unsigned long DcmFloatingPointDouble::getVM()
 {
-    return Length / sizeof(Float64);
+    return getLengthField() / sizeof(Float64);
 }
 
 
 // ********************************
 
 
-void DcmFloatingPointDouble::print(ostream &out,
+void DcmFloatingPointDouble::print(STD_NAMESPACE ostream&out,
                                    const size_t flags,
                                    const int level,
                                    const char * /*pixelFileName*/,
@@ -115,11 +130,11 @@ void DcmFloatingPointDouble::print(ostream &out,
             {
                 /* check whether first value is printed (omit delimiter) */
                 if (i == 0)
-                    OFStandard::ftoa(buffer, sizeof(buffer), *doubleVals);
+                    OFStandard::ftoa(buffer, sizeof(buffer), *doubleVals, 0, 0, 17 /* DBL_DIG + 2 for DICOM FD */);
                 else
                 {
                     buffer[0] = '\\';
-                    OFStandard::ftoa(buffer + 1, sizeof(buffer) - 1, *doubleVals);
+                    OFStandard::ftoa(buffer + 1, sizeof(buffer) - 1, *doubleVals, 0, 0, 17 /* DBL_DIG + 2 for DICOM FD */);
                 }
                 /* check whether current value sticks to the length limit */
                 newLength = printedLength + strlen(buffer);
@@ -193,7 +208,7 @@ OFCondition DcmFloatingPointDouble::getOFString(OFString &stringVal,
     {
         /* ... and convert it to a character string */
         char buffer[64];
-        OFStandard::ftoa(buffer, sizeof(buffer), doubleVal);
+        OFStandard::ftoa(buffer, sizeof(buffer), doubleVal, 0, 0, 17 /* DBL_DIG + 2 for DICOM FD */);
         /* assign result */
         stringVal = buffer;
     }
@@ -280,13 +295,13 @@ OFCondition DcmFloatingPointDouble::putString(const char *stringVal)
 OFCondition DcmFloatingPointDouble::verify(const OFBool autocorrect)
 {
     /* check for valid value length */
-    if (Length % (sizeof(Float64)) != 0)
+    if (getLengthField() % (sizeof(Float64)) != 0)
     {
         errorFlag = EC_CorruptedData;
         if (autocorrect)
         {
             /* strip to valid length */
-            Length -= (Length % (sizeof(Float64)));
+            setLengthField(getLengthField() - (getLengthField() % (sizeof(Float64))));
         }
     } else
         errorFlag = EC_Normal;
@@ -297,6 +312,32 @@ OFCondition DcmFloatingPointDouble::verify(const OFBool autocorrect)
 /*
 ** CVS/RCS Log:
 ** $Log: dcvrfd.cc,v $
+** Revision 1.34  2010-10-20 16:44:17  joergr
+** Use type cast macros (e.g. OFstatic_cast) where appropriate.
+**
+** Revision 1.33  2010-10-14 13:14:10  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.32  2010-04-23 14:30:34  joergr
+** Added new method to all VR classes which checks whether the stored value
+** conforms to the VR definition and to the specified VM.
+**
+** Revision 1.31  2008-07-17 10:31:32  onken
+** Implemented copyFrom() method for complete DcmObject class hierarchy, which
+** permits setting an instance's value from an existing object. Implemented
+** assignment operator where necessary.
+**
+** Revision 1.30  2007-06-29 14:17:49  meichel
+** Code clean-up: Most member variables in module dcmdata are now private,
+**   not protected anymore.
+**
+** Revision 1.29  2007/02/21 09:26:19  meichel
+** Increased output precision to 17 (DBL_DIG+2) when converting an FD element to string.
+**
+** Revision 1.28  2006/08/15 15:49:54  meichel
+** Updated all code in module dcmdata to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
 ** Revision 1.27  2005/12/08 15:41:52  meichel
 ** Changed include path schema for all DCMTK header files
 **
