@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2004, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -22,21 +18,20 @@
  *  Purpose: handling of transfer syntaxes
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2004/04/06 18:09:14 $
- *  CVS/RCS Revision: $Revision: 1.23 $
+ *  Update Date:      $Date: 2010-10-14 13:14:11 $
+ *  CVS/RCS Revision: $Revision: 1.33 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
  *
  */
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
-#include "dcxfer.h"
-#include "dcuid.h"
-#include "dcdebug.h"
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/dcmdata/dcxfer.h"
+#include "dcmtk/dcmdata/dcuid.h"
 
 #define INCLUDE_CSTRING
-#include "ofstdinc.h"
+#include "dcmtk/ofstd/ofstdinc.h"
 
 
 typedef struct
@@ -49,46 +44,51 @@ typedef struct
     E_JPEGEncapsulated  encapsulated;
     Uint32              JPEGProcess8;
     Uint32              JPEGProcess12;
+    OFBool              retired;
     E_StreamCompression streamCompression;
 } S_XferNames;
 
 
-#define ERROR_XferName "UnknownTransferSyntax"
+#define ERROR_XferName "Unknown Transfer Syntax"
 
 
 const S_XferNames XferNames[] =
 {
     { UID_LittleEndianImplicitTransferSyntax,
-      "LittleEndianImplicit",
+      "Little Endian Implicit",
       EXS_LittleEndianImplicit,
       EBO_LittleEndian,
       EVT_Implicit,
       EJE_NotEncapsulated,
       0L, 0L,
+      OFFalse,
       ESC_none },
     { "",  // illegal type
-      "VirtualBigEndianImplicit",
+      "Virtual Big Endian Implicit",
       EXS_BigEndianImplicit,
       EBO_BigEndian,
       EVT_Implicit,
       EJE_NotEncapsulated,
       0L, 0L,
+      OFFalse,
       ESC_none },
     { UID_LittleEndianExplicitTransferSyntax,
-      "LittleEndianExplicit",
+      "Little Endian Explicit",
       EXS_LittleEndianExplicit,
       EBO_LittleEndian,
       EVT_Explicit,
       EJE_NotEncapsulated,
       0L, 0L,
+      OFFalse,
       ESC_none },
     { UID_BigEndianExplicitTransferSyntax,  // defined in dctypes.h
-      "BigEndianExplicit",
+      "Big Endian Explicit",
       EXS_BigEndianExplicit,
       EBO_BigEndian,
       EVT_Explicit,
       EJE_NotEncapsulated,
       0L, 0L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess1TransferSyntax,
       "JPEG Baseline",
@@ -97,6 +97,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       1L, 1L,
+      OFFalse,
       ESC_none },
     { UID_JPEGProcess2_4TransferSyntax,
       "JPEG Extended, Process 2+4",
@@ -105,6 +106,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       2L ,4L,
+      OFFalse,
       ESC_none },
     { UID_JPEGProcess3_5TransferSyntax,
       "JPEG Extended, Process 3+5",
@@ -113,6 +115,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       3L ,5L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess6_8TransferSyntax,
       "JPEG Spectral Selection, Non-hierarchical, Process 6+8",
@@ -121,6 +124,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       6L ,8L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess7_9TransferSyntax,
       "JPEG Spectral Selection, Non-hierarchical, Process 7+9",
@@ -129,6 +133,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       7L ,9L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess10_12TransferSyntax,
       "JPEG Full Progression, Non-hierarchical, Process 10+12",
@@ -137,6 +142,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       10L ,12L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess11_13TransferSyntax,
       "JPEG Full Progression, Non-hierarchical, Process 11+13",
@@ -145,6 +151,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       11L ,13L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess14TransferSyntax,
       "JPEG Lossless, Non-hierarchical, Process 14",
@@ -153,6 +160,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       14L ,14L,
+      OFFalse,
       ESC_none },
     { UID_JPEGProcess15TransferSyntax,
       "JPEG Lossless, Non-hierarchical, Process 15",
@@ -161,6 +169,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       15L ,15L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess16_18TransferSyntax,
       "JPEG Extended, Hierarchical, Process 16+18",
@@ -169,6 +178,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       16L ,18L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess17_19TransferSyntax,
       "JPEG Extended, Hierarchical, Process 17+19",
@@ -177,6 +187,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       17L ,19L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess20_22TransferSyntax,
       "JPEG Spectral Selection, Hierarchical, Process 20+22",
@@ -185,6 +196,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       20L ,22L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess21_23TransferSyntax,
       "JPEG Spectral Selection, Hierarchical, Process 21+23",
@@ -193,6 +205,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       21L ,23L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess24_26TransferSyntax,
       "JPEG Full Progression, Hierarchical, Process 24+26",
@@ -201,6 +214,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       24L ,26L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess25_27TransferSyntax,
       "JPEG Full Progression, Hierarchical, Process 25+27",
@@ -209,6 +223,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       25L ,27L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess28TransferSyntax,
       "JPEG Lossless, Hierarchical, Process 28",
@@ -217,6 +232,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       28L ,28L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess29TransferSyntax,
       "JPEG Lossless, Hierarchical, Process 29",
@@ -225,6 +241,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       29L ,29L,
+      OFTrue,
       ESC_none },
     { UID_JPEGProcess14SV1TransferSyntax,
       "JPEG Lossless, Non-hierarchical, 1st Order Prediction",
@@ -233,6 +250,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       14L ,14L,
+      OFFalse,
       ESC_none },
     { UID_RLELosslessTransferSyntax,
       "RLE Lossless",
@@ -241,6 +259,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       0L, 0L,
+      OFFalse,
       ESC_none },
     { UID_JPEGLSLosslessTransferSyntax,
       "JPEG-LS Lossless",
@@ -249,6 +268,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       0L, 0L,
+      OFFalse,
       ESC_none },
     { UID_JPEGLSLossyTransferSyntax,
       "JPEG-LS Lossy (Near-lossless)",
@@ -257,6 +277,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       0L, 0L,
+      OFFalse,
       ESC_none },
     { UID_DeflatedExplicitVRLittleEndianTransferSyntax,
       "Deflated Explicit VR Little Endian",
@@ -265,6 +286,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_NotEncapsulated,
       0L, 0L,
+      OFFalse,
 #ifdef WITH_ZLIB
       ESC_zlib
 #else
@@ -278,6 +300,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       0L, 0L,
+      OFFalse,
       ESC_none },
     { UID_JPEG2000TransferSyntax,
       "JPEG 2000 (Lossless or Lossy)",
@@ -286,6 +309,7 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       0L, 0L,
+      OFFalse,
       ESC_none },
     { UID_MPEG2MainProfileAtMainLevelTransferSyntax,
       "MPEG2 Main Profile @ Main Level",
@@ -294,7 +318,58 @@ const S_XferNames XferNames[] =
       EVT_Explicit,
       EJE_Encapsulated,
       0L, 0L,
-      ESC_none }
+      OFFalse,
+      ESC_none },
+    { UID_MPEG2MainProfileAtHighLevelTransferSyntax,
+      "MPEG2 Main Profile @ High Level",
+      EXS_MPEG2MainProfileAtHighLevel,
+      EBO_LittleEndian,
+      EVT_Explicit,
+      EJE_Encapsulated,
+      0L, 0L,
+      OFFalse,
+      ESC_none },
+   { UID_JPEG2000Part2MulticomponentImageCompressionLosslessOnlyTransferSyntax,
+      "JPEG 2000 Part 2 Multicomponent Image Compression (Lossless only)",
+      EXS_JPEG2000MulticomponentLosslessOnly,
+      EBO_LittleEndian,
+      EVT_Explicit,
+      EJE_Encapsulated,
+      0L, 0L,
+      OFFalse,
+      ESC_none },
+   { UID_JPEG2000Part2MulticomponentImageCompressionTransferSyntax,
+      "JPEG 2000 Part 2 Multicomponent Image Compression (Lossless or Lossy)",
+      EXS_JPEG2000Multicomponent,
+      EBO_LittleEndian,
+      EVT_Explicit,
+      EJE_Encapsulated,
+      0L, 0L,
+      OFFalse,
+      ESC_none },
+   { UID_JPIPReferencedTransferSyntax,
+      "JPIP Referenced",
+      EXS_JPIPReferenced,
+      EBO_LittleEndian,
+      EVT_Explicit,      
+      EJE_NotEncapsulated,  // in fact, pixel data shall be referenced via (0028,7FE0) Pixel Data Provider URL
+      0L, 0L,
+      OFFalse,
+      ESC_none },
+   { UID_JPIPReferencedDeflateTransferSyntax,
+      "JPIP Referenced Deflate",
+      EXS_JPIPReferencedDeflate,
+      EBO_LittleEndian,
+      EVT_Explicit,
+      EJE_NotEncapsulated,  // in fact, pixel data shall be referenced via (0028,7FE0) Pixel Data Provider URL
+      0L, 0L,
+      OFFalse,
+#ifdef WITH_ZLIB
+      ESC_zlib
+#else
+      ESC_unsupported
+#endif
+    }
 
     // enter further transfer syntaxes here ...
 };
@@ -314,6 +389,7 @@ DcmXfer::DcmXfer(E_TransferSyntax xfer)
     encapsulated(EJE_NotEncapsulated),
     JPEGProcess8(0L),
     JPEGProcess12(0L),
+    retired(OFFalse),
     streamCompression(ESC_none)
 {
     int i = 0;
@@ -329,6 +405,7 @@ DcmXfer::DcmXfer(E_TransferSyntax xfer)
         encapsulated      = XferNames[i].encapsulated;
         JPEGProcess8      = XferNames[i].JPEGProcess8;
         JPEGProcess12     = XferNames[i].JPEGProcess12;
+        retired           = XferNames[i].retired;
         streamCompression = XferNames[i].streamCompression;
     }
 }
@@ -346,6 +423,7 @@ DcmXfer::DcmXfer(const char* xferName_xferID)
     encapsulated(EJE_NotEncapsulated),
     JPEGProcess8(0L),
     JPEGProcess12(0L),
+    retired(OFFalse),
     streamCompression(ESC_none)
 {
     const char* xname = xferName_xferID;
@@ -364,6 +442,7 @@ DcmXfer::DcmXfer(const char* xferName_xferID)
             encapsulated      = XferNames[i].encapsulated;
             JPEGProcess8      = XferNames[i].JPEGProcess8;
             JPEGProcess12     = XferNames[i].JPEGProcess12;
+            retired           = XferNames[i].retired;
             streamCompression = XferNames[i].streamCompression;
         }
         else
@@ -381,6 +460,7 @@ DcmXfer::DcmXfer(const char* xferName_xferID)
                 encapsulated      = XferNames[i].encapsulated;
                 JPEGProcess8      = XferNames[i].JPEGProcess8;
                 JPEGProcess12     = XferNames[i].JPEGProcess12;
+                retired           = XferNames[i].retired;
                 streamCompression = XferNames[i].streamCompression;
             }
         }
@@ -400,6 +480,7 @@ DcmXfer::DcmXfer(const DcmXfer &newXfer)
     encapsulated(newXfer.encapsulated),
     JPEGProcess8(newXfer.JPEGProcess8),
     JPEGProcess12(newXfer.JPEGProcess12),
+    retired(newXfer.retired),
     streamCompression(newXfer.streamCompression)
 {
 }
@@ -431,6 +512,7 @@ DcmXfer &DcmXfer::operator=(const E_TransferSyntax xfer)
         encapsulated      = XferNames[i].encapsulated;
         JPEGProcess8      = XferNames[i].JPEGProcess8;
         JPEGProcess12     = XferNames[i].JPEGProcess12;
+        retired           = XferNames[i].retired;
         streamCompression = XferNames[i].streamCompression;
     } else {
         xferSyn           = EXS_Unknown;
@@ -441,6 +523,7 @@ DcmXfer &DcmXfer::operator=(const E_TransferSyntax xfer)
         encapsulated      = EJE_NotEncapsulated;
         JPEGProcess8      = 0L;
         JPEGProcess12     = 0L;
+        retired           = OFFalse;
         streamCompression = ESC_none;
     }
     return *this;
@@ -462,6 +545,7 @@ DcmXfer &DcmXfer::operator=(const DcmXfer &newXfer)
         encapsulated      = newXfer.encapsulated;
         JPEGProcess8      = newXfer.JPEGProcess8;
         JPEGProcess12     = newXfer.JPEGProcess12;
+        retired           = newXfer.retired;
         streamCompression = newXfer.streamCompression;
     }
     return *this;
@@ -470,7 +554,7 @@ DcmXfer &DcmXfer::operator=(const DcmXfer &newXfer)
 
 // ********************************
 
-Uint32 DcmXfer::sizeofTagHeader(DcmEVR evr)
+Uint32 DcmXfer::sizeofTagHeader(DcmEVR evr) const
 {
     Uint32 len = 0;
     if (isExplicitVR())
@@ -526,6 +610,42 @@ const E_ByteOrder gLocalByteOrder = FindMachineTransferSyntax();
 /*
  * CVS/RCS Log:
  * $Log: dcxfer.cc,v $
+ * Revision 1.33  2010-10-14 13:14:11  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.32  2010-10-01 10:21:05  uli
+ * Fixed most compiler warnings from -Wall -Wextra -pedantic in dcmdata.
+ *
+ * Revision 1.31  2010-09-15 08:53:05  joergr
+ * Added definition of XML encoding transfer syntax (Supplement 114) and JPIP
+ * referenced transfer syntaxes (Supplement 106).
+ *
+ * Revision 1.30  2010-09-02 12:12:46  joergr
+ * Added support for "MPEG2 Main Profile @ High Level" transfer syntax.
+ *
+ * Revision 1.29  2009-11-04 09:58:11  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.28  2008-04-23 06:39:34  meichel
+ * Added new method DcmXfer::isRetired that returns true for
+ *   retired transfer syntaxes.
+ *
+ * Revision 1.27  2007/11/29 14:30:21  meichel
+ * Write methods now handle large raw data elements (such as pixel data)
+ *   without loading everything into memory. This allows very large images to
+ *   be sent over a network connection, or to be copied without ever being
+ *   fully in memory.
+ *
+ * Revision 1.26  2007/02/22 12:49:28  joergr
+ * Fixed inconsistent naming of transfer syntaxes (added space characters).
+ *
+ * Revision 1.25  2005/12/08 15:42:11  meichel
+ * Changed include path schema for all DCMTK header files
+ *
+ * Revision 1.24  2005/10/25 08:55:34  meichel
+ * Updated list of UIDs and added support for new transfer syntaxes
+ *   and storage SOP classes.
+ *
  * Revision 1.23  2004/04/06 18:09:14  joergr
  * Updated data dictionary, UIDs and transfer syntaxes for the latest Final Text
  * Supplements (42 and 47) and Correction Proposals (CP 25).
