@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: Generate a C++ header defining symbolic names for DICOM Tags.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/09 15:04:37 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmdata/libsrc/mkdeftag.cc,v $
- *  CVS/RCS Revision: $Revision: 1.24 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-10-20 07:41:35 $
+ *  CVS/RCS Revision: $Revision: 1.31 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -70,10 +65,10 @@ convertToIdentifier(char* s)
     }
     int len = strlen(s);
     int i=0;
-    char c;
+    unsigned char c;
 
     for (i=0; i<len; i++) {
-        c = s[i];
+        c = OFstatic_cast(unsigned char, s[i]);
         if (!(isalnum(c) || (c == '_'))) {
             /* replace char with '_' */
             s[i] = '_';
@@ -103,7 +98,7 @@ printDefined(FILE* fout, const DcmDictEntry* e)
     char buf[DCM_MAXDICTLINESIZE+1];
     const char* tagPrefix;
 
-    if (e == NULL || e->getTagName() == NULL) 
+    if (e == NULL || e->getTagName() == NULL)
         return;
 
     strcpy(buf, e->getTagName());
@@ -126,7 +121,7 @@ printDefined(FILE* fout, const DcmDictEntry* e)
         fprintf(fout, " /* (0x%04x", e->getGroup());
         if (e->isRepeatingGroup()) {
             if (e->getGroupRangeRestriction() != DcmDictRange_Even) {
-                fprintf(fout, "-%c", 
+                fprintf(fout, "-%c",
                         rangeRestriction2char(e->getGroupRangeRestriction()));
             }
             fprintf(fout, "-0x%04x", e->getUpperGroup());
@@ -134,7 +129,7 @@ printDefined(FILE* fout, const DcmDictEntry* e)
         fprintf(fout, ",0x%04x", e->getElement());
         if (e->isRepeatingElement()) {
             if (e->getElementRangeRestriction() != DcmDictRange_Even) {
-                fprintf(fout, "-%c", 
+                fprintf(fout, "-%c",
                         rangeRestriction2char(e->getElementRangeRestriction()));
             }
             fprintf(fout, "-0x%04x", e->getUpperElement());
@@ -156,7 +151,9 @@ getUserName(char* userString, int maxLen)
 {
 #if defined(_REENTRANT) && !defined(_WIN32) && !defined(__CYGWIN__)
     // use getlogin_r instead of getlogin
-    return getlogin_r(userString, int maxLen)
+    if (getlogin_r(userString, maxLen) != 0)
+        strncpy(userString, "<no-utmp-entry>", maxLen);
+    return userString;
 #else
     char* s;
     s = getlogin(); // thread unsafe
@@ -172,13 +169,11 @@ getUserName(char* userString, int maxLen)
 static char*
 getUserName(char* userString, int maxLen)
 {
-    char* s = NULL;
-
     WKSTA_USER_INFO_0 *userinfo;
-    if (NetWkstaUserGetInfo(NULL, 0, (LPBYTE*)&userinfo) == NERR_Success){
-        LPTSTR lptstr = userinfo->wkui0_username;
+    if (NetWkstaUserGetInfo(NULL, 0, (LPBYTE*)&userinfo) == NERR_Success)
+    {
         // Convert the Unicode full name to ANSI.
-        WideCharToMultiByte( CP_ACP, 0, (WCHAR*)lptstr, -1,
+        WideCharToMultiByte( CP_ACP, 0, (WCHAR*)userinfo->wkui0_username, -1,
             userString, maxLen, NULL, NULL );
     } else {
         strncpy(userString, "<no-user-information-available>", maxLen);
@@ -190,8 +185,7 @@ getUserName(char* userString, int maxLen)
 static char*
 getUserName(char* userString, int maxLen)
 {
-    char* s = "<unknown-user>";
-    return strncpy(userString, s, maxLen);
+    return strncpy(userString, "<unknown-user>", maxLen);
 }
 #endif
 
@@ -217,7 +211,7 @@ getHostName(char* hostString, int maxLen)
 {
     return strncpy(hostString, "localhost", maxLen);
 }
-#endif    
+#endif
 
 int main(int argc, char* argv[])
 {
@@ -246,7 +240,7 @@ int main(int argc, char* argv[])
     globalDataDict.clear();
 
     progname = argv[0];
-    for (i=1; i<argc; i++) { 
+    for (i=1; i<argc; i++) {
         globalDataDict.loadDictionary(argv[i]);
     }
 
@@ -258,11 +252,11 @@ int main(int argc, char* argv[])
     fputs("/*\n", fout);
     fputs("** DO NOT EDIT THIS FILE !!!\n", fout);
     fputs("** It was generated automatically by:\n", fout);
-#ifndef SUPRESS_CREATE_STAMP
-    /* 
-     * Putting the date in the file will confuse CVS/RCS 
+#ifndef SUPPRESS_CREATE_STAMP
+    /*
+     * Putting the date in the file will confuse CVS/RCS
      * if nothing has changed except the generation date.
-     * This is only an issue if the header file is continually 
+     * This is only an issue if the header file is continually
      * generated new.
      */
     fputs("**\n", fout);
@@ -276,9 +270,9 @@ int main(int argc, char* argv[])
     fprintf(fout, "**   Prog: %s\n", progname);
     fputs("**\n", fout);
     if (argc > 1) {
-        fprintf(fout, "** From: %s\n", argv[1]);
+        fprintf(fout, "**   From: %s\n", argv[1]);
         for (i=2; i<argc; i++) {
-            fprintf(fout, "**       %s\n", argv[i]);
+            fprintf(fout, "**         %s\n", argv[i]);
         }
     }
     fputs("**\n", fout);
@@ -286,12 +280,12 @@ int main(int argc, char* argv[])
     fputs("#ifndef DCDEFTAG_H\n", fout);
     fputs("#define DCDEFTAG_H\n\n", fout);
     fputs("#include \"dcmtk/dcmdata/dctagkey.h\"\n\n", fout);
-#ifndef SUPRESS_CREATE_STAMP
+#ifndef SUPPRESS_CREATE_STAMP
     fprintf(fout, "#define DCM_DICT_DEFTAG_BUILD_DATE \"%s\"\n", dateString.c_str());
     fputs("\n", fout);
 #endif
 
-    /* 
+    /*
     ** the hash table does not maintain ordering so we must put
     ** all the entries into a sorted list.
     */
@@ -310,8 +304,7 @@ int main(int argc, char* argv[])
     /* generate the entries themselves */
     fputs("\n/*\n", fout);
     fputs("** Fixed Tags in ascending (gggg,eeee) order.\n", fout);
-    fprintf(fout, "** Number of entries: %d\n", 
-           list.size());
+    fprintf(fout, "** Number of entries: %lu\n", OFstatic_cast(unsigned long, list.size()));
     fputs("** Tags with a repeating component (repeating tags) are listed later.\n", fout);
     fputs("*/\n", fout);
 
@@ -333,7 +326,7 @@ int main(int argc, char* argv[])
     }
 
     fputs("\n/*\n", fout);
-    fputs("** Tags where the group/element can vary (repeating tags).\n", 
+    fputs("** Tags where the group/element can vary (repeating tags).\n",
           fout);
     fprintf(fout, "** Number of entries: %d\n", repCount);
     fputs("*/\n", fout);
@@ -355,6 +348,28 @@ int main(int argc, char* argv[])
 /*
 ** CVS/RCS Log:
 ** $Log: mkdeftag.cc,v $
+** Revision 1.31  2010-10-20 07:41:35  uli
+** Made sure isalpha() & friends are only called with valid arguments.
+**
+** Revision 1.30  2010-10-14 13:14:11  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.29  2010-07-02 07:12:29  joergr
+** Fixed typo: Changed "SUPRESS_CREATE_STAMP" to "SUPPRESS_CREATE_STAMP".
+**
+** Revision 1.28  2010-03-03 08:50:30  joergr
+** Fixed compilation issue with call to getlogin_r().
+**
+** Revision 1.27  2009-11-04 09:58:11  uli
+** Switched to logging mechanism provided by the "new" oflog module
+**
+** Revision 1.26  2009-01-15 14:30:12  joergr
+** Added type cast to integer variable in order to avoid compiler warning.
+** Changed formatting of comment header.
+**
+** Revision 1.25  2006/08/02 15:20:42  meichel
+** Fixed bugs that prevented compiling the affected tools under MinGW
+**
 ** Revision 1.24  2005/12/09 15:04:37  meichel
 ** Updated build system for dcdeftag/dcdictzz to reflect new directory structure
 **
