@@ -1,32 +1,27 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmdata
  *
  *  Author:  Andrew Hewett
  *
- *  Purpose: 
+ *  Purpose:
  *  Generate a builtin data dictionary which can be compiled into
- *  the dcmdata library.  
+ *  the dcmdata library.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/09 15:04:37 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmdata/libsrc/mkdictbi.cc,v $
- *  CVS/RCS Revision: $Revision: 1.27 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:11 $
+ *  CVS/RCS Revision: $Revision: 1.34 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -87,7 +82,7 @@ rr2s(DcmDictRangeRestriction rr)
     return s;
 }
 
-static void 
+static void
 printSimpleEntry(FILE* fout, const DcmDictEntry* e, OFBool& isFirst, OFBool& isPrivate)
 {
 
@@ -111,13 +106,13 @@ printSimpleEntry(FILE* fout, const DcmDictEntry* e, OFBool& isFirst, OFBool& isP
     } else fprintf(fout, "  , ");
 
     fprintf(fout, "{ 0x%04x, 0x%04x, 0x%04x, 0x%04x,\n",
-            e->getGroup(), e->getElement(), 
+            e->getGroup(), e->getElement(),
             e->getUpperGroup(), e->getUpperElement());
     fprintf(fout, "      EVR_%s, \"%s\", %d, %d, \"%s\",\n",
             e->getVR().getVRName(),
-            e->getTagName(), 
+            e->getTagName(),
             e->getVMMin(), e->getVMMax(),
-            e->getStandardVersion());
+            OFSTRING_GUARD(e->getStandardVersion()));
     fprintf(fout, "      %s, %s,\n", rr2s(e->getGroupRangeRestriction()),
             rr2s(e->getElementRangeRestriction()));
 
@@ -139,7 +134,9 @@ getUserName(char* userString, int maxLen)
 {
 #if defined(_REENTRANT) && !defined(_WIN32) && !defined(__CYGWIN__)
     // use getlogin_r instead of getlogin
-    return getlogin_r(userString, int maxLen)
+    if (getlogin_r(userString, maxLen) != 0)
+        strncpy(userString, "<no-utmp-entry>", maxLen);
+    return userString;
 #else
     char* s;
     s = getlogin(); // thread unsafe
@@ -154,13 +151,11 @@ getUserName(char* userString, int maxLen)
 static char*
 getUserName(char* userString, int maxLen)
 {
-    char* s = NULL;
-
     WKSTA_USER_INFO_0 *userinfo;
-    if (NetWkstaUserGetInfo(NULL, 0, (LPBYTE*)&userinfo) == NERR_Success){
-        LPTSTR lptstr = userinfo->wkui0_username;
+    if (NetWkstaUserGetInfo(NULL, 0, (LPBYTE*)&userinfo) == NERR_Success)
+    {
         // Convert the Unicode full name to ANSI.
-        WideCharToMultiByte( CP_ACP, 0, (WCHAR*)lptstr, -1,
+        WideCharToMultiByte( CP_ACP, 0, (WCHAR*)userinfo->wkui0_username, -1,
             userString, maxLen, NULL, NULL );
     } else {
         strncpy(userString, "<no-user-information-available>", maxLen);
@@ -171,8 +166,7 @@ getUserName(char* userString, int maxLen)
 static char*
 getUserName(char* userString, int maxLen)
 {
-    char* s = "<unknown-user>";
-    return strncpy(userString, s, maxLen);
+    return strncpy(userString, "<unknown-user>", maxLen);
 }
 #endif
 
@@ -198,9 +192,9 @@ getHostName(char* hostString, int maxLen)
 {
     return strncpy(hostString, "localhost", maxLen);
 }
-#endif    
+#endif
 
-int 
+int
 main(int argc, char* argv[])
 {
     char* progname;
@@ -228,10 +222,10 @@ main(int argc, char* argv[])
 
     progname = argv[0];
     int i;
-    for (i=1; i<argc; i++) { 
+    for (i=1; i<argc; i++) {
         globalDataDict.loadDictionary(argv[i]);
     }
-    
+
     fout = stdout;
 
     OFString dateString;
@@ -242,11 +236,11 @@ main(int argc, char* argv[])
     fprintf(fout, "/*\n");
     fprintf(fout, "** DO NOT EDIT THIS FILE !!!\n");
     fprintf(fout, "** It was generated automatically by:\n");
-#ifndef SUPRESS_CREATE_STAMP
-    /* 
-     * Putting the date in the file will confuse CVS/RCS 
+#ifndef SUPPRESS_CREATE_STAMP
+    /*
+     * Putting the date in the file will confuse CVS/RCS
      * if nothing has changed except the generation date.
-     * This is only an issue if the header file is continually 
+     * This is only an issue if the header file is continually
      * generated new.
      */
     fputs("**\n", fout);
@@ -260,9 +254,9 @@ main(int argc, char* argv[])
     fprintf(fout, "**   Prog: %s\n", progname);
     fputs("**\n", fout);
     if (argc > 1) {
-        fprintf(fout, "** From: %s\n", argv[1]);
+        fprintf(fout, "**   From: %s\n", argv[1]);
         for (i=2; i<argc; i++) {
-            fprintf(fout, "**       %s\n", argv[i]);
+            fprintf(fout, "**         %s\n", argv[i]);
         }
     }
     fputs("**\n", fout);
@@ -289,11 +283,11 @@ main(int argc, char* argv[])
     fprintf(fout, "};\n");
     fprintf(fout, "\n");
     fprintf(fout, "static const DBI_SimpleEntry simpleBuiltinDict[] = {\n");
-    
+
     OFBool isFirst = OFTrue;
     OFBool isPrivate = OFFalse;
 
-    /* 
+    /*
     ** the hash table does not maintain ordering so we must put
     ** all the entries into a sorted list.
     */
@@ -360,6 +354,27 @@ main(int argc, char* argv[])
 /*
 ** CVS/RCS Log:
 ** $Log: mkdictbi.cc,v $
+** Revision 1.34  2010-10-14 13:14:11  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.33  2010-08-10 11:59:31  uli
+** Fixed some cases where dcmFindNameOfUID() returning NULL could cause crashes.
+**
+** Revision 1.32  2010-07-02 07:12:29  joergr
+** Fixed typo: Changed "SUPRESS_CREATE_STAMP" to "SUPPRESS_CREATE_STAMP".
+**
+** Revision 1.31  2010-03-03 08:50:30  joergr
+** Fixed compilation issue with call to getlogin_r().
+**
+** Revision 1.30  2009-11-04 09:58:11  uli
+** Switched to logging mechanism provided by the "new" oflog module
+**
+** Revision 1.29  2009-01-15 14:30:26  joergr
+** Changed formatting of comment header.
+**
+** Revision 1.28  2006/08/02 15:20:42  meichel
+** Fixed bugs that prevented compiling the affected tools under MinGW
+**
 ** Revision 1.27  2005/12/09 15:04:37  meichel
 ** Updated build system for dcdeftag/dcdictzz to reflect new directory structure
 **
