@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2001-2005, OFFIS
+ *  Copyright (C) 2001-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimage
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Convert DICOM color images palette color
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:17 $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:33 $
+ *  CVS/RCS Revision: $Revision: 1.22 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -42,16 +38,15 @@
 #endif
 
 #include "dcmtk/dcmdata/dctk.h"          /* for various dcmdata headers */
-#include "dcmtk/dcmdata/dcdebug.h"       /* for SetDebugLevel */
 #include "dcmtk/dcmdata/cmdlnarg.h"      /* for prepareCmdLineArgs */
 #include "dcmtk/dcmdata/dcuid.h"         /* for dcmtk version name */
-#include "dcmtk/dcmimgle/dcmimage.h"      /* for DicomImage */
+#include "dcmtk/dcmimgle/dcmimage.h"     /* for DicomImage */
 
-#include "dcmtk/ofstd/ofconapp.h"      /* for OFConsoleApplication */
-#include "dcmtk/ofstd/ofcmdln.h"       /* for OFCommandLine */
+#include "dcmtk/ofstd/ofconapp.h"        /* for OFConsoleApplication */
+#include "dcmtk/ofstd/ofcmdln.h"         /* for OFCommandLine */
 
-#include "dcmtk/dcmimage/diregist.h"      /* include to support color images */
-#include "dcmtk/dcmimage/diquant.h"       /* for DcmQuant */
+#include "dcmtk/dcmimage/diregist.h"     /* include to support color images */
+#include "dcmtk/dcmimage/diquant.h"      /* for DcmQuant */
 #include "dcmtk/dcmdata/dccodec.h"       /* for DcmCodec */
 
 #ifdef BUILD_WITH_DCMJPEG_SUPPORT
@@ -71,6 +66,8 @@
 #define OFFIS_CONSOLE_APPLICATION "dcmquant"
 #endif
 
+static OFLogger dcmquantLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -85,9 +82,8 @@ int main(int argc, char *argv[])
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, OFFIS_CONSOLE_DESCRIPTION, rcsid);
     OFCommandLine cmd;
 
-    OFBool opt_verbose = OFFalse;
-    OFBool opt_oDataset = OFFalse;
     E_FileReadMode opt_readMode = ERM_autoDetect;
+    E_FileWriteMode opt_writeMode = EWM_fileformat;
     E_TransferSyntax opt_ixfer = EXS_Unknown;
     E_TransferSyntax opt_oxfer = EXS_Unknown;
     E_GrpLenEncoding opt_oglenc = EGL_recalcGL;
@@ -112,20 +108,18 @@ int main(int argc, char *argv[])
     OFBool              opt_secondarycapture = OFFalse;
     OFBool              opt_uidcreation = OFTrue;
 
-
 #ifdef BUILD_WITH_DCMJPEG_SUPPORT
-    // JPEG parameters
+    // JPEG parameters, currently not used
+# if 0
     OFCmdUnsignedInt    opt_quality = 90;                 /* default: 90% JPEG quality */
     E_SubSampling       opt_sampling = ESS_422;           /* default: 4:2:2 sub-sampling */
+# endif
     E_DecompressionColorSpaceConversion opt_decompCSconversion = EDC_photometricInterpretation;
 #endif
 
     const char *        opt_ifname = NULL;
     const char *        opt_ofname = NULL;
 
-    SetDebugLevel((0));
-    DicomImageClass::setDebugLevel(DicomImageClass::DL_Warnings | DicomImageClass::DL_Errors);
-
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
 
@@ -133,110 +127,111 @@ int main(int argc, char *argv[])
     cmd.addParam("dcmfile-out", "DICOM output filename to be written");
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-     cmd.addOption("--help",                "-h",      "print this help text and exit" /*, OFTrue is set implicitly */);
-     cmd.addOption("--version",                        "print version information and exit", OFTrue /* exclusive */);
-     cmd.addOption("--verbose",             "-v",      "verbose mode, print processing details");
+     cmd.addOption("--help",                 "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+     cmd.addOption("--version",                        "print version information and exit", OFCommandLine::AF_Exclusive);
+     OFLog::addOptions(cmd);
 
     cmd.addGroup("input options:");
 
      cmd.addSubGroup("input file format:");
-      cmd.addOption("--read-file",          "+f",      "read file format or data set (default)");
-      cmd.addOption("--read-file-only",     "+fo",     "read file format only");
-      cmd.addOption("--read-dataset",       "-f",      "read data set without file meta information");
+      cmd.addOption("--read-file",           "+f",     "read file format or data set (default)");
+      cmd.addOption("--read-file-only",      "+fo",    "read file format only");
+      cmd.addOption("--read-dataset",        "-f",     "read data set without file meta information");
 
      cmd.addSubGroup("input transfer syntax:");
-      cmd.addOption("--read-xfer-auto",     "-t=",     "use TS recognition (default)");
-      cmd.addOption("--read-xfer-detect",   "-td",     "ignore TS specified in the file meta header");
-      cmd.addOption("--read-xfer-little",   "-te",     "read with explicit VR little endian TS");
-      cmd.addOption("--read-xfer-big",      "-tb",     "read with explicit VR big endian TS");
-      cmd.addOption("--read-xfer-implicit", "-ti",     "read with implicit VR little endian TS");
+      cmd.addOption("--read-xfer-auto",      "-t=",    "use TS recognition (default)");
+      cmd.addOption("--read-xfer-detect",    "-td",    "ignore TS specified in the file meta header");
+      cmd.addOption("--read-xfer-little",    "-te",    "read with explicit VR little endian TS");
+      cmd.addOption("--read-xfer-big",       "-tb",    "read with explicit VR big endian TS");
+      cmd.addOption("--read-xfer-implicit",  "-ti",    "read with implicit VR little endian TS");
 
     cmd.addGroup("image processing and encoding options:");
      cmd.addSubGroup("frame selection:");
-      cmd.addOption("--frame",              "+fr",  1, "[n]umber : integer",
+      cmd.addOption("--frame",               "+fr", 1, "[n]umber: integer",
                                                        "select specified frame");
-      cmd.addOption("--all-frames",         "+fa",     "select all frames (default)");
+      cmd.addOption("--all-frames",          "+fa",    "select all frames (default)");
 
 #ifdef BUILD_WITH_DCMJPEG_SUPPORT
      cmd.addSubGroup("color space conversion options (compressed images only):");
-      cmd.addOption("--conv-photometric",   "+cp",     "convert if YCbCr photom. interpr. (default)");
-      cmd.addOption("--conv-lossy",         "+cl",     "convert YCbCr to RGB if lossy JPEG");
-      cmd.addOption("--conv-always",        "+ca",     "always convert YCbCr to RGB");
-      cmd.addOption("--conv-never",         "+cn",     "never convert color space");
+      cmd.addOption("--conv-photometric",    "+cp",    "convert if YCbCr photometric interpr. (default)");
+      cmd.addOption("--conv-lossy",          "+cl",    "convert YCbCr to RGB if lossy JPEG");
+      cmd.addOption("--conv-guess",          "+cg",    "convert to RGB if YCbCr is guessed by library");
+      cmd.addOption("--conv-guess-lossy",    "+cgl",   "convert to RGB if lossy JPEG and YCbCr is\nguessed by the underlying JPEG library");
+      cmd.addOption("--conv-always",         "+ca",    "always convert YCbCr to RGB");
+      cmd.addOption("--conv-never",          "+cn",    "never convert color space");
 #endif
 
-     cmd.addSubGroup("compatibility options:");
-      cmd.addOption("--accept-palettes",    "+Mp",     "accept incorrect palette attribute tags\n(0028,111x) and (0028,121x)");
+     cmd.addSubGroup("compatibility:");
+      cmd.addOption("--accept-palettes",     "+Mp",    "accept incorrect palette attribute tags\n(0028,111x) and (0028,121x)");
 
-     cmd.addSubGroup("median cut dimension selection options:");
-      cmd.addOption("--mc-dimension-rgb",   "+Dr",     "max dimension from RGB range (default)");
-      cmd.addOption("--mc-dimension-lum",   "+Dl",     "max dimension from luminance");
+     cmd.addSubGroup("median cut dimension selection:");
+      cmd.addOption("--mc-dimension-rgb",    "+Dr",    "max dimension from RGB range (default)");
+      cmd.addOption("--mc-dimension-lum",    "+Dl",    "max dimension from luminance");
 
-     cmd.addSubGroup("median cut representative color selection options:");
-      cmd.addOption("--mc-color-avgbox",   "+Cb",     "average colors in box (default)");
-      cmd.addOption("--mc-color-avgpixel", "+Cp",     "average pixels in box");
-      cmd.addOption("--mc-color-center",   "+Cc",     "select center of box");
+     cmd.addSubGroup("median cut representative color selection:");
+      cmd.addOption("--mc-color-avgbox",     "+Cb",    "average colors in box (default)");
+      cmd.addOption("--mc-color-avgpixel",   "+Cp",    "average pixels in box");
+      cmd.addOption("--mc-color-center",     "+Cc",    "select center of box");
 
-     cmd.addSubGroup("color palette creation options:");
-      cmd.addOption("--write-ow",           "+pw",     "write Palette LUT as OW instead of US");
-      cmd.addOption("--lut-entries-word",   "+pe",     "write Palette LUT with 16-bit entries");
-      cmd.addOption("--floyd-steinberg",    "+pf",     "use Floyd-Steinberg error diffusion");
-      cmd.addOption("--colors",             "+pc",  1, "number of colors: 2..65536 (default 256)",
+     cmd.addSubGroup("color palette creation:");
+      cmd.addOption("--write-ow",            "+pw",    "write Palette LUT as OW instead of US");
+      cmd.addOption("--lut-entries-word",    "+pe",    "write Palette LUT with 16-bit entries");
+      cmd.addOption("--floyd-steinberg",     "+pf",    "use Floyd-Steinberg error diffusion");
+      cmd.addOption("--colors",              "+pc", 1, "number of colors: 2..65536 (default 256)",
                                                        "number of colors to quantize to");
 
-    cmd.addSubGroup("SOP Class UID options:");
-     cmd.addOption("--class-default",      "+cd",     "keep SOP Class UID (default)");
-     cmd.addOption("--class-sc",           "+cs",     "convert to Secondary Capture Image\n(implies --uid-always)");
+     cmd.addSubGroup("SOP Class UID:");
+      cmd.addOption("--class-default",       "+cd",    "keep SOP Class UID (default)");
+      cmd.addOption("--class-sc",            "+cs",    "convert to Secondary Capture Image\n(implies --uid-always)");
 
-    cmd.addSubGroup("SOP Instance UID options:");
-     cmd.addOption("--uid-always",         "+ua",     "always assign new UID (default)");
-     cmd.addOption("--uid-never",          "+un",     "never assign new UID");
+     cmd.addSubGroup("SOP Instance UID:");
+      cmd.addOption("--uid-always",          "+ua",    "always assign new UID (default)");
+      cmd.addOption("--uid-never",           "+un",    "never assign new UID");
 
-  cmd.addGroup("output options:");
-    cmd.addSubGroup("output file format:");
-      cmd.addOption("--write-file",             "+F",        "write file format (default)");
-      cmd.addOption("--write-dataset",          "-F",        "write data set without file meta information");
-    cmd.addSubGroup("output transfer syntax:");
-      cmd.addOption("--write-xfer-same",        "+t=",       "write with same TS as input (default)");
-      cmd.addOption("--write-xfer-little",      "+te",       "write with explicit VR little endian TS");
-      cmd.addOption("--write-xfer-big",         "+tb",       "write with explicit VR big endian TS");
-      cmd.addOption("--write-xfer-implicit",    "+ti",       "write with implicit VR little endian TS");
-    cmd.addSubGroup("post-1993 value representations:");
-      cmd.addOption("--enable-new-vr",          "+u",        "enable support for new VRs (UN/UT) (default)");
-      cmd.addOption("--disable-new-vr",         "-u",        "disable support for new VRs, convert to OB");
-    cmd.addSubGroup("group length encoding:");
-      cmd.addOption("--group-length-recalc",    "+g=",       "recalculate group lengths if present (default)");
-      cmd.addOption("--group-length-create",    "+g",        "always write with group length elements");
-      cmd.addOption("--group-length-remove",    "-g",        "always write without group length elements");
-    cmd.addSubGroup("length encoding in sequences and items:");
-      cmd.addOption("--length-explicit",        "+e",        "write with explicit lengths (default)");
-      cmd.addOption("--length-undefined",       "-e",        "write with undefined lengths");
-    cmd.addSubGroup("data set trailing padding (not with --write-dataset):");
-      cmd.addOption("--padding-retain",         "-p=",       "do not change padding\n(default if not --write-dataset)");
-      cmd.addOption("--padding-off",            "-p",        "no padding (implicit if --write-dataset)");
-      cmd.addOption("--padding-create",         "+p",    2,  "[f]ile-pad [i]tem-pad: integer",
-                                                             "align file on multiple of f bytes\nand items on multiple of i bytes");
+    cmd.addGroup("output options:");
+     cmd.addSubGroup("output file format:");
+      cmd.addOption("--write-file",          "+F",     "write file format (default)");
+      cmd.addOption("--write-dataset",       "-F",     "write data set without file meta information");
+     cmd.addSubGroup("output transfer syntax:");
+      cmd.addOption("--write-xfer-same",     "+t=",    "write with same TS as input (default)");
+      cmd.addOption("--write-xfer-little",   "+te",    "write with explicit VR little endian TS");
+      cmd.addOption("--write-xfer-big",      "+tb",    "write with explicit VR big endian TS");
+      cmd.addOption("--write-xfer-implicit", "+ti",    "write with implicit VR little endian TS");
+     cmd.addSubGroup("post-1993 value representations:");
+      cmd.addOption("--enable-new-vr",       "+u",     "enable support for new VRs (UN/UT) (default)");
+      cmd.addOption("--disable-new-vr",      "-u",     "disable support for new VRs, convert to OB");
+     cmd.addSubGroup("group length encoding:");
+      cmd.addOption("--group-length-recalc", "+g=",    "recalculate group lengths if present (default)");
+      cmd.addOption("--group-length-create", "+g",     "always write with group length elements");
+      cmd.addOption("--group-length-remove", "-g",     "always write without group length elements");
+     cmd.addSubGroup("length encoding in sequences and items:");
+      cmd.addOption("--length-explicit",     "+e",     "write with explicit lengths (default)");
+      cmd.addOption("--length-undefined",    "-e",     "write with undefined lengths");
+     cmd.addSubGroup("data set trailing padding (not with --write-dataset):");
+      cmd.addOption("--padding-retain",      "-p=",    "do not change padding\n(default if not --write-dataset)");
+      cmd.addOption("--padding-off",         "-p",     "no padding (implicit if --write-dataset)");
+      cmd.addOption("--padding-create",      "+p",  2, "[f]ile-pad [i]tem-pad: integer",
+                                                       "align file on multiple of f bytes\nand items on multiple of i bytes");
 
     if (app.parseCommandLine(cmd, argc, argv))
     {
       /* check exclusive options first */
-
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
           if (cmd.findOption("--version"))
           {
-              app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-              CERR << endl << "External libraries used:";
+              app.printHeader(OFTrue /*print host identifier*/);
+              COUT << OFendl << "External libraries used:";
 #if !defined(WITH_ZLIB) && !defined(BUILD_WITH_DCMJPEG_SUPPORT)
-              CERR << " none" << endl;
+              COUT << " none" << OFendl;
 #else
-              CERR << endl;
+              COUT << OFendl;
 #endif
 #ifdef WITH_ZLIB
-              CERR << "- ZLIB, Version " << zlibVersion() << endl;
+              COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
 #ifdef BUILD_WITH_DCMJPEG_SUPPORT
-              CERR << "- " << DiJPEGPlugin::getLibraryVersionString() << endl;
+              COUT << "- " << DiJPEGPlugin::getLibraryVersionString() << OFendl;
 #endif
               return 0;
           }
@@ -247,7 +242,7 @@ int main(int argc, char *argv[])
       cmd.getParam(1, opt_ifname);
       cmd.getParam(2, opt_ofname);
 
-      if (cmd.findOption("--verbose")) opt_verbose = OFTrue;
+      OFLog::configureFromCommandLine(cmd, app);
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--read-file")) opt_readMode = ERM_autoDetect;
@@ -293,6 +288,23 @@ int main(int argc, char *argv[])
       }
       cmd.endOptionBlock();
 
+#ifdef BUILD_WITH_DCMJPEG_SUPPORT
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--conv-photometric"))
+          opt_decompCSconversion = EDC_photometricInterpretation;
+      if (cmd.findOption("--conv-lossy"))
+          opt_decompCSconversion = EDC_lossyOnly;
+      if (cmd.findOption("--conv-guess"))
+          opt_decompCSconversion = EDC_guess;
+      if (cmd.findOption("--conv-guess-lossy"))
+          opt_decompCSconversion = EDC_guessLossyOnly;
+      if (cmd.findOption("--conv-always"))
+          opt_decompCSconversion = EDC_always;
+      if (cmd.findOption("--conv-never"))
+          opt_decompCSconversion = EDC_never;
+      cmd.endOptionBlock();
+#endif
+
       if (cmd.findOption("--write-ow")) opt_palette_ow = OFTrue;
       if (cmd.findOption("--lut-entries-word")) opt_entries_word = OFTrue;
       if (cmd.findOption("--floyd-steinberg")) opt_palette_fs = OFTrue;
@@ -320,8 +332,8 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--write-file")) opt_oDataset = OFFalse;
-      if (cmd.findOption("--write-dataset")) opt_oDataset = OFTrue;
+      if (cmd.findOption("--write-file")) opt_writeMode = EWM_fileformat;
+      if (cmd.findOption("--write-dataset")) opt_writeMode = EWM_dataset;
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
@@ -358,13 +370,13 @@ int main(int argc, char *argv[])
       cmd.beginOptionBlock();
       if (cmd.findOption("--padding-retain"))
       {
-          if (opt_oDataset) app.printError("--padding-retain not allowed with --write-dataset");
+          app.checkConflict("--padding-retain", "--write-dataset", opt_writeMode == EWM_dataset);
           opt_opadenc = EPD_noChange;
       }
       if (cmd.findOption("--padding-off")) opt_opadenc = EPD_withoutPadding;
       if (cmd.findOption("--padding-create"))
       {
-          if (opt_oDataset) app.printError("--padding-create not allowed with --write-dataset");
+          app.checkConflict("--padding-create", "--write-dataset", opt_writeMode == EWM_dataset);
           app.checkValue(cmd.getValueAndCheckMin(opt_filepad, 0));
           app.checkValue(cmd.getValueAndCheckMin(opt_itempad, 0));
           opt_opadenc = EPD_withPadding;
@@ -372,17 +384,19 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
     }
 
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmquantLogger, rcsid << OFendl);
+
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dcmquantLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
 #ifdef BUILD_WITH_DCMJPEG_SUPPORT
     // register global decompression codecs
-    DJDecoderRegistration::registerCodecs(opt_decompCSconversion, EUC_default, EPC_default, OFFalse);
+    DJDecoderRegistration::registerCodecs(opt_decompCSconversion);
 #endif
 
     // ======================================================================
@@ -390,7 +404,7 @@ int main(int argc, char *argv[])
 
     if ((opt_ifname == NULL) || (strlen(opt_ifname) == 0))
     {
-        CERR << "Error: invalid filename: <empty string>" << endl;
+        OFLOG_FATAL(dcmquantLogger, "invalid filename: <empty string>");
         return 1;
     }
 
@@ -400,13 +414,11 @@ int main(int argc, char *argv[])
     OFCondition error = fileformat.loadFile(opt_ifname, opt_ixfer, EGL_noChange, DCM_MaxReadLength, opt_readMode);
     if (error.bad())
     {
-        CERR << "Error: " << error.text()
-             << ": reading file: " <<  opt_ifname << endl;
+        OFLOG_FATAL(dcmquantLogger, error.text() << ": reading file: " <<  opt_ifname);
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "load all data into memory" << endl;
+    OFLOG_INFO(dcmquantLogger, "load all data into memory");
 
     /* make sure that pixel data is loaded before output file is created */
     dataset->loadAllDataIntoMemory();
@@ -416,41 +428,42 @@ int main(int argc, char *argv[])
 
     if (opt_oxfer == EXS_Unknown)
     {
-        if (opt_verbose)
-            COUT << "set output transfer syntax to input transfer syntax" << endl;
+        OFLOG_INFO(dcmquantLogger, "set output transfer syntax to input transfer syntax");
         opt_oxfer = dataset->getOriginalXfer();
     }
 
-    if (opt_verbose)
-        COUT << "check if new output transfer syntax is possible" << endl;
+    OFLOG_INFO(dcmquantLogger, "check if new output transfer syntax is possible");
 
     DcmXfer opt_oxferSyn(opt_oxfer);
     dataset->chooseRepresentation(opt_oxfer, NULL);
 
     if (dataset->canWriteXfer(opt_oxfer))
     {
-        if (opt_verbose)
-            COUT << "output transfer syntax " << opt_oxferSyn.getXferName()
-                 << " can be written" << endl;
+        OFLOG_INFO(dcmquantLogger, "output transfer syntax " << opt_oxferSyn.getXferName()
+            << " can be written");
     } else {
-        CERR << "Error: no conversion to transfer syntax " << opt_oxferSyn.getXferName()
-             << " possible!" << endl;
+        OFLOG_FATAL(dcmquantLogger, "no conversion to transfer syntax " << opt_oxferSyn.getXferName()
+            << " possible");
         return 1;
     }
 
     // ======================================================================
     // image processing starts here
 
-    if (opt_verbose)
-        CERR << "preparing pixel data." << endl;
+    OFLOG_INFO(dcmquantLogger, "preparing pixel data.");
 
     // create DicomImage object
     DicomImage di(dataset, opt_oxfer, opt_compatibilityMode, opt_frame - 1, opt_frameCount);
-    if (di.getStatus() != EIS_Normal) app.printError(DicomImage::getString(di.getStatus()));
+    if (di.getStatus() != EIS_Normal)
+    {
+        OFLOG_FATAL(dcmquantLogger, DicomImage::getString(di.getStatus()));
+        return 1;
+    }
 
     if (di.isMonochrome())
     {
-      app.printError("cannot convert monochrome image to palette color");
+      OFLOG_FATAL(dcmquantLogger, "cannot convert monochrome image to palette color");
+      return 1;
     }
 
     OFString derivationDescription;
@@ -458,7 +471,7 @@ int main(int argc, char *argv[])
     // create palette color image
     error = DcmQuant::createPaletteColorImage(
       di, *dataset, opt_palette_ow, opt_entries_word, opt_palette_fs, opt_palette_col,
-      derivationDescription, opt_verbose, opt_largeType, opt_repType);
+      derivationDescription, opt_largeType, opt_repType);
 
     // update image type
     if (error.good()) error = DcmCodec::updateImageType(dataset);
@@ -477,29 +490,29 @@ int main(int argc, char *argv[])
 
     if (error.bad())
     {
-        CERR << "Error: " << error.text()
-             << ": converting image: " <<  opt_ifname << endl;
+        OFLOG_FATAL(dcmquantLogger, error.text() << ": converting image: " <<  opt_ifname);
         return 1;
     }
 
     // ======================================================================
     // write back output file
 
-    if (opt_verbose)
-        COUT << "write converted DICOM file" << endl;
+    OFLOG_INFO(dcmquantLogger, "write converted DICOM file");
+
+    // update file meta information with new SOP Instance UID
+    if ((opt_uidcreation || opt_secondarycapture) && (opt_writeMode == EWM_fileformat))
+        opt_writeMode = EWM_updateMeta;
 
     error = fileformat.saveFile(opt_ofname, opt_oxfer, opt_oenctype, opt_oglenc, opt_opadenc,
-        OFstatic_cast(Uint32, opt_filepad), OFstatic_cast(Uint32, opt_itempad), opt_oDataset);
+        OFstatic_cast(Uint32, opt_filepad), OFstatic_cast(Uint32, opt_itempad), opt_writeMode);
 
     if (error.bad())
     {
-        CERR << "Error: " << error.text()
-             << ": writing file: " <<  opt_ofname << endl;
+        OFLOG_FATAL(dcmquantLogger, error.text() << ": writing file: " <<  opt_ofname);
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "conversion successful" << endl;
+    OFLOG_INFO(dcmquantLogger, "conversion successful");
 
 #ifdef BUILD_WITH_DCMJPEG_SUPPORT
     // deregister global decompression codecs
@@ -513,6 +526,40 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcmquant.cc,v $
+ * Revision 1.22  2010-10-14 13:13:33  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.21  2010-03-24 15:07:25  joergr
+ * Added missing command line options for the color space conversion.
+ *
+ * Revision 1.20  2009-10-14 10:26:37  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.19  2009-10-13 14:08:33  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.18  2009-08-21 09:28:02  joergr
+ * Added parameter 'writeMode' to save/write methods which allows for specifying
+ * whether to write a dataset or fileformat as well as whether to update the
+ * file meta information or to create a new file meta information header.
+ * Use helper function checkConflict() where appropriate.
+ *
+ * Revision 1.17  2009-04-21 14:04:12  joergr
+ * Fixed minor inconsistencies in manpage / syntax usage.
+ *
+ * Revision 1.16  2008-09-25 12:47:58  joergr
+ * Added support for printing the expanded command line arguments.
+ * iAlways output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.15  2006/08/15 16:35:00  meichel
+ * Updated the code in module dcmimage to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.14  2006/07/27 13:59:24  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Option "--help" is no longer an exclusive option
+ * by default.
+ *
  * Revision 1.13  2005/12/08 15:42:17  meichel
  * Changed include path schema for all DCMTK header files
  *
