@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimage
  *
@@ -22,8 +18,8 @@
  *  Purpose: Scale DICOM images
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2005/12/15 17:42:10 $
- *  CVS/RCS Revision: $Revision: 1.14 $
+ *  Update Date:      $Date: 2010-10-14 13:13:34 $
+ *  CVS/RCS Revision: $Revision: 1.26 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -42,15 +38,16 @@
 #endif
 
 #include "dcmtk/dcmdata/dctk.h"          /* for various dcmdata headers */
-#include "dcmtk/dcmdata/dcdebug.h"       /* for SetDebugLevel */
 #include "dcmtk/dcmdata/cmdlnarg.h"      /* for prepareCmdLineArgs */
 #include "dcmtk/dcmdata/dcuid.h"         /* for dcmtk version name */
 
-#include "dcmtk/ofstd/ofconapp.h"      /* for OFConsoleApplication */
-#include "dcmtk/ofstd/ofcmdln.h"       /* for OFCommandLine */
+#include "dcmtk/ofstd/ofconapp.h"        /* for OFConsoleApplication */
+#include "dcmtk/ofstd/ofcmdln.h"         /* for OFCommandLine */
 
-#include "dcmtk/dcmimgle/dcmimage.h"      /* for DicomImage */
-#include "dcmtk/dcmimage/diregist.h"      /* include to support color images */
+#include "dcmtk/oflog/oflog.h"           /* for OFLogger */
+
+#include "dcmtk/dcmimgle/dcmimage.h"     /* for DicomImage */
+#include "dcmtk/dcmimage/diregist.h"     /* include to support color images */
 #include "dcmtk/dcmdata/dcrledrg.h"      /* for DcmRLEDecoderRegistration */
 
 #ifdef BUILD_DCMSCALE_AS_DCMJSCAL
@@ -70,6 +67,8 @@
 #define OFFIS_CONSOLE_APPLICATION "dcmscale"
 #endif
 
+static OFLogger dcmscaleLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -84,11 +83,9 @@ int main(int argc, char *argv[])
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, OFFIS_CONSOLE_DESCRIPTION, rcsid);
     OFCommandLine cmd;
 
-    OFBool opt_debug = OFFalse;
-    OFBool opt_verbose = OFFalse;
-    OFBool opt_oDataset = OFFalse;
     OFBool opt_uidCreation = OFTrue;
     E_FileReadMode opt_readMode = ERM_autoDetect;
+    E_FileWriteMode opt_writeMode = EWM_fileformat;
     E_TransferSyntax opt_ixfer = EXS_Unknown;
     E_TransferSyntax opt_oxfer = EXS_Unknown;
     E_GrpLenEncoding opt_oglenc = EGL_recalcGL;
@@ -120,9 +117,6 @@ int main(int argc, char *argv[])
     const char *opt_ifname = NULL;
     const char *opt_ofname = NULL;
 
-    SetDebugLevel((0));
-    DicomImageClass::setDebugLevel(DicomImageClass::DL_Warnings | DicomImageClass::DL_Errors);
-
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
 
@@ -130,18 +124,15 @@ int main(int argc, char *argv[])
     cmd.addParam("dcmfile-out", "DICOM output filename to be written");
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-     cmd.addOption("--help",                "-h",       "print this help text and exit" /*, OFTrue is set implicitly */);
-     cmd.addOption("--version",                         "print version information and exit", OFTrue /* exclusive */);
-     cmd.addOption("--verbose",             "-v",       "verbose mode, print processing details");
-     cmd.addOption("--debug",               "-d",       "debug mode, print debug information");
+     cmd.addOption("--help",                "-h",       "print this help text and exit", OFCommandLine::AF_Exclusive);
+     cmd.addOption("--version",                         "print version information and exit", OFCommandLine::AF_Exclusive);
+     OFLog::addOptions(cmd);
 
     cmd.addGroup("input options:");
-
      cmd.addSubGroup("input file format:");
       cmd.addOption("--read-file",          "+f",       "read file format or data set (default)");
       cmd.addOption("--read-file-only",     "+fo",      "read file format only");
       cmd.addOption("--read-dataset",       "-f",       "read data set without file meta information");
-
      cmd.addSubGroup("input transfer syntax:");
       cmd.addOption("--read-xfer-auto",     "-t=",      "use TS recognition (default)");
       cmd.addOption("--read-xfer-detect",   "-td",      "ignore TS specified in the file meta header");
@@ -152,30 +143,32 @@ int main(int argc, char *argv[])
     cmd.addGroup("image processing and encoding options:");
 #ifdef BUILD_DCMSCALE_AS_DCMJSCAL
      cmd.addSubGroup("color space conversion options (compressed images only):");
-      cmd.addOption("--conv-photometric",   "+cp",      "convert if YCbCr photom. interpr. (default)");
+      cmd.addOption("--conv-photometric",   "+cp",      "convert if YCbCr photometric interpr. (default)");
       cmd.addOption("--conv-lossy",         "+cl",      "convert YCbCr to RGB if lossy JPEG");
+      cmd.addOption("--conv-guess",         "+cg",      "convert to RGB if YCbCr is guessed by library");
+      cmd.addOption("--conv-guess-lossy",   "+cgl",     "convert to RGB if lossy JPEG and YCbCr is\nguessed by the underlying JPEG library");
       cmd.addOption("--conv-always",        "+ca",      "always convert YCbCr to RGB");
       cmd.addOption("--conv-never",         "+cn",      "never convert color space");
 #endif
      cmd.addSubGroup("scaling:");
       cmd.addOption("--recognize-aspect",    "+a",      "recognize pixel aspect ratio (default)");
       cmd.addOption("--ignore-aspect",       "-a",      "ignore pixel aspect ratio when scaling");
-      cmd.addOption("--interpolate",         "+i",   1, "[n]umber of algorithm : integer",
-                                                        "use interpolation when scaling (1..2, def: 1)");
+      cmd.addOption("--interpolate",         "+i",   1, "[n]umber of algorithm: integer",
+                                                        "use interpolation when scaling (1..4, def: 1)");
       cmd.addOption("--no-interpolation",    "-i",      "no interpolation when scaling");
       cmd.addOption("--no-scaling",          "-S",      "no scaling, ignore pixel aspect ratio (default)");
-      cmd.addOption("--scale-x-factor",      "+Sxf", 1, "[f]actor : float",
+      cmd.addOption("--scale-x-factor",      "+Sxf", 1, "[f]actor: float",
                                                         "scale x axis by factor, auto-compute y axis");
-      cmd.addOption("--scale-y-factor",      "+Syf", 1, "[f]actor : float",
+      cmd.addOption("--scale-y-factor",      "+Syf", 1, "[f]actor: float",
                                                         "scale y axis by factor, auto-compute x axis");
-      cmd.addOption("--scale-x-size",        "+Sxv", 1, "[n]umber : integer",
+      cmd.addOption("--scale-x-size",        "+Sxv", 1, "[n]umber: integer",
                                                         "scale x axis to n pixels, auto-compute y axis");
-      cmd.addOption("--scale-y-size",        "+Syv", 1, "[n]umber : integer",
+      cmd.addOption("--scale-y-size",        "+Syv", 1, "[n]umber: integer",
                                                         "scale y axis to n pixels, auto-compute x axis");
      cmd.addSubGroup("other transformations:");
-      cmd.addOption("--clip-region",         "+C",   4, "[l]eft [t]op [w]idth [h]eight : integer",
+      cmd.addOption("--clip-region",         "+C",   4, "[l]eft [t]op [w]idth [h]eight: integer",
                                                         "clip rectangular image region (l, t, w, h)");
-     cmd.addSubGroup("SOP Instance UID options:");
+     cmd.addSubGroup("SOP Instance UID:");
       cmd.addOption("--uid-always",          "+ua",     "always assign new SOP Instance UID (default)");
       cmd.addOption("--uid-never",           "+un",     "never assign new SOP Instance UID");
 
@@ -201,29 +194,28 @@ int main(int argc, char *argv[])
     cmd.addSubGroup("data set trailing padding (not with --write-dataset):");
       cmd.addOption("--padding-retain",      "-p=",     "do not change padding\n(default if not --write-dataset)");
       cmd.addOption("--padding-off",         "-p",      "no padding (implicit if --write-dataset)");
-      cmd.addOption("--padding-create",      "+p",   2, "[f]ile-pad [i]tem-pad : integer",
+      cmd.addOption("--padding-create",      "+p",   2, "[f]ile-pad [i]tem-pad: integer",
                                                         "align file on multiple of f bytes\nand items on multiple of i bytes");
 
     if (app.parseCommandLine(cmd, argc, argv))
     {
       /* check exclusive options first */
-
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
           if (cmd.findOption("--version"))
           {
-              app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-              CERR << endl << "External libraries used:";
+              app.printHeader(OFTrue /*print host identifier*/);
+              COUT << OFendl << "External libraries used:";
 #if !defined(WITH_ZLIB) && !defined(BUILD_DCMSCALE_AS_DCMJSCAL)
-              CERR << " none" << endl;
+              COUT << " none" << OFendl;
 #else
-              CERR << endl;
+              COUT << OFendl;
 #endif
 #ifdef WITH_ZLIB
-              CERR << "- ZLIB, Version " << zlibVersion() << endl;
+              COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
 #ifdef BUILD_DCMSCALE_AS_DCMJSCAL
-              CERR << "- " << DiJPEGPlugin::getLibraryVersionString() << endl;
+              COUT << "- " << DiJPEGPlugin::getLibraryVersionString() << OFendl;
 #endif
               return 0;
           }
@@ -236,10 +228,7 @@ int main(int argc, char *argv[])
 
       /* general options */
 
-      if (cmd.findOption("--debug"))
-          opt_debug = OFTrue;
-      if (cmd.findOption("--verbose"))
-          opt_verbose = OFTrue;
+      OFLog::configureFromCommandLine(cmd, app);
 
       /* input options */
 
@@ -271,6 +260,25 @@ int main(int argc, char *argv[])
       }
       cmd.endOptionBlock();
 
+      /* image processing options: color space conversion */
+
+#ifdef BUILD_DCMSCALE_AS_DCMJSCAL
+      cmd.beginOptionBlock();
+      if (cmd.findOption("--conv-photometric"))
+          opt_decompCSconversion = EDC_photometricInterpretation;
+      if (cmd.findOption("--conv-lossy"))
+          opt_decompCSconversion = EDC_lossyOnly;
+      if (cmd.findOption("--conv-guess"))
+          opt_decompCSconversion = EDC_guess;
+      if (cmd.findOption("--conv-guess-lossy"))
+          opt_decompCSconversion = EDC_guessLossyOnly;
+      if (cmd.findOption("--conv-always"))
+          opt_decompCSconversion = EDC_always;
+      if (cmd.findOption("--conv-never"))
+          opt_decompCSconversion = EDC_never;
+      cmd.endOptionBlock();
+#endif
+
       /* image processing options: scaling */
 
       cmd.beginOptionBlock();
@@ -282,7 +290,7 @@ int main(int argc, char *argv[])
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--interpolate"))
-          app.checkValue(cmd.getValueAndCheckMinMax(opt_useInterpolation, 1, 2));
+          app.checkValue(cmd.getValueAndCheckMinMax(opt_useInterpolation, 1, 4));
       if (cmd.findOption("--no-interpolation"))
           opt_useInterpolation = 0;
       cmd.endOptionBlock();
@@ -318,8 +326,8 @@ int main(int argc, char *argv[])
       {
           app.checkValue(cmd.getValue(opt_left));
           app.checkValue(cmd.getValue(opt_top));
-          app.checkValue(cmd.getValueAndCheckMin(opt_width, 1));
-          app.checkValue(cmd.getValueAndCheckMin(opt_height, 1));
+          app.checkValue(cmd.getValue(opt_width));
+          app.checkValue(cmd.getValue(opt_height));
           opt_useClip = OFTrue;
       }
 
@@ -333,8 +341,8 @@ int main(int argc, char *argv[])
       /* output options */
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--write-file")) opt_oDataset = OFFalse;
-      if (cmd.findOption("--write-dataset")) opt_oDataset = OFTrue;
+      if (cmd.findOption("--write-file")) opt_writeMode = EWM_fileformat;
+      if (cmd.findOption("--write-dataset")) opt_writeMode = EWM_dataset;
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
@@ -371,13 +379,13 @@ int main(int argc, char *argv[])
       cmd.beginOptionBlock();
       if (cmd.findOption("--padding-retain"))
       {
-          app.checkConflict("--padding-retain", "--write-dataset", opt_oDataset);
+          app.checkConflict("--padding-retain", "--write-dataset", opt_writeMode == EWM_dataset);
           opt_opadenc = EPD_noChange;
       }
       if (cmd.findOption("--padding-off")) opt_opadenc = EPD_withoutPadding;
       if (cmd.findOption("--padding-create"))
       {
-          app.checkConflict("--padding-create", "--write-dataset", opt_oDataset);
+          app.checkConflict("--padding-create", "--write-dataset", opt_writeMode == EWM_dataset);
           app.checkValue(cmd.getValueAndCheckMin(opt_filepad, 0));
           app.checkValue(cmd.getValueAndCheckMin(opt_itempad, 0));
           opt_opadenc = EPD_withPadding;
@@ -385,37 +393,40 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
     }
 
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmscaleLogger, rcsid << OFendl);
+
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dcmscaleLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     // register RLE decompression codec
-    DcmRLEDecoderRegistration::registerCodecs(OFFalse /*pCreateSOPInstanceUID*/, opt_debug);
+    DcmRLEDecoderRegistration::registerCodecs();
 #ifdef BUILD_DCMSCALE_AS_DCMJSCAL
     // register global decompression codecs
-    DJDecoderRegistration::registerCodecs(opt_decompCSconversion, EUC_default, EPC_default, opt_debug);
+    DJDecoderRegistration::registerCodecs(opt_decompCSconversion);
 #endif
 
-    if (opt_debug)
-        DicomImageClass::setDebugLevel(DicomImageClass::getDebugLevel() | DicomImageClass::DL_DebugMessages);
-    if (opt_verbose)
-        DicomImageClass::setDebugLevel(DicomImageClass::getDebugLevel() | DicomImageClass::DL_Informationals);
-
     // ======================================================================
     // read input file
 
     if ((opt_ifname == NULL) || (strlen(opt_ifname) == 0))
     {
-        CERR << "Error: invalid filename: <empty string>" << endl;
+        OFLOG_FATAL(dcmscaleLogger, "invalid input filename: <empty string>");
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "open input file " << opt_ifname << endl;
+    /* no clipping/scaling */
+    if (!opt_scaleType && !opt_useClip)
+    {
+        OFLOG_FATAL(dcmscaleLogger, "nothing to do");
+        return 1;
+    }
+
+    OFLOG_INFO(dcmscaleLogger, "open input file " << opt_ifname);
 
     DcmFileFormat fileformat;
     DcmDataset *dataset = fileformat.getDataset();
@@ -423,13 +434,11 @@ int main(int argc, char *argv[])
     OFCondition error = fileformat.loadFile(opt_ifname, opt_ixfer, EGL_noChange, DCM_MaxReadLength, opt_readMode);
     if (error.bad())
     {
-        CERR << "Error: " << error.text()
-             << ": reading file: " <<  opt_ifname << endl;
+        OFLOG_FATAL(dcmscaleLogger, error.text() << ": reading file: " <<  opt_ifname);
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "load all data into memory" << endl;
+    OFLOG_INFO(dcmscaleLogger, "load all data into memory");
 
     /* make sure that pixel data is loaded before output file is created */
     dataset->loadAllDataIntoMemory();
@@ -439,48 +448,50 @@ int main(int argc, char *argv[])
 
     if (opt_oxfer == EXS_Unknown)
     {
-        if (opt_verbose)
-            COUT << "set output transfer syntax to input transfer syntax" << endl;
+        OFLOG_INFO(dcmscaleLogger, "set output transfer syntax to input transfer syntax");
         opt_oxfer = dataset->getOriginalXfer();
     }
 
-    if (opt_verbose)
-        COUT << "check if new output transfer syntax is possible" << endl;
+    OFLOG_INFO(dcmscaleLogger, "check if new output transfer syntax is possible");
 
     DcmXfer opt_oxferSyn(opt_oxfer);
     dataset->chooseRepresentation(opt_oxfer, NULL);
 
     if (dataset->canWriteXfer(opt_oxfer))
     {
-        if (opt_verbose)
-            COUT << "output transfer syntax " << opt_oxferSyn.getXferName()
-                 << " can be written" << endl;
+        OFLOG_INFO(dcmscaleLogger, "output transfer syntax " << opt_oxferSyn.getXferName()
+            << " can be written");
     } else {
-        CERR << "Error: no conversion to transfer syntax " << opt_oxferSyn.getXferName()
-             << " possible!" << endl;
+        OFLOG_FATAL(dcmscaleLogger, "no conversion to transfer syntax " << opt_oxferSyn.getXferName()
+            << " possible");
         return 1;
     }
 
     // ======================================================================
     // image processing starts here
 
-    if (opt_verbose)
-        COUT << "preparing pixel data" << endl;
+    OFLOG_INFO(dcmscaleLogger, "preparing pixel data");
 
     const unsigned long flags = (opt_scaleType > 0) ? CIF_MayDetachPixelData : 0;
     // create DicomImage object
     DicomImage *di = new DicomImage(dataset, opt_oxfer, flags);
     if (di == NULL)
-        app.printError("memory exhausted");
+    {
+        OFLOG_FATAL(dcmscaleLogger, "memory exhausted");
+        return 1;
+    }
     if (di->getStatus() != EIS_Normal)
-        app.printError(DicomImage::getString(di->getStatus()));
+    {
+        OFLOG_FATAL(dcmscaleLogger, DicomImage::getString(di->getStatus()));
+        return 1;
+    }
 
     DicomImage *newimage = NULL;
     OFString derivationDescription;
 
-    if (opt_verbose && opt_useClip)
-        COUT << "clipping image to (" << opt_left << "," << opt_top
-             << "," << opt_width << "," << opt_height << ")" << endl;
+    if (opt_useClip)
+        OFLOG_INFO(dcmscaleLogger, "clipping image to (" << opt_left << "," << opt_top
+            << "," << opt_width << "," << opt_height << ")");
     // perform clipping (without scaling)
     if (opt_scaleType <= 0)
     {
@@ -496,10 +507,9 @@ int main(int argc, char *argv[])
         switch (opt_scaleType)
         {
             case 1:
-                if (opt_verbose)
-                    COUT << "scaling image, X factor=" << opt_scale_factor
-                         << ", Interpolation=" << OFstatic_cast(int, opt_useInterpolation)
-                         << ", Aspect Ratio=" << (opt_useAspectRatio ? "yes" : "no") << endl;
+                OFLOG_INFO(dcmscaleLogger, "scaling image, X factor=" << opt_scale_factor
+                    << ", Interpolation=" << OFstatic_cast(int, opt_useInterpolation)
+                    << ", Aspect Ratio=" << (opt_useAspectRatio ? "yes" : "no"));
                 if (opt_useClip)
                     newimage = di->createScaledImage(opt_left, opt_top, opt_width, opt_height, opt_scale_factor, 0.0,
                         OFstatic_cast(int, opt_useInterpolation), opt_useAspectRatio);
@@ -508,10 +518,9 @@ int main(int argc, char *argv[])
                         opt_useAspectRatio);
                 break;
             case 2:
-                if (opt_verbose)
-                    COUT << "scaling image, Y factor=" << opt_scale_factor
-                         << ", Interpolation=" << OFstatic_cast(int, opt_useInterpolation)
-                         << ", Aspect Ratio=" << (opt_useAspectRatio ? "yes" : "no") << endl;
+                OFLOG_INFO(dcmscaleLogger, "scaling image, Y factor=" << opt_scale_factor
+                    << ", Interpolation=" << OFstatic_cast(int, opt_useInterpolation)
+                    << ", Aspect Ratio=" << (opt_useAspectRatio ? "yes" : "no"));
                 if (opt_useClip)
                     newimage = di->createScaledImage(opt_left, opt_top, opt_width, opt_height, 0.0, opt_scale_factor,
                         OFstatic_cast(int, opt_useInterpolation), opt_useAspectRatio);
@@ -520,10 +529,9 @@ int main(int argc, char *argv[])
                         opt_useAspectRatio);
                 break;
             case 3:
-                if (opt_verbose)
-                    COUT << "scaling image, X size=" << opt_scale_size
-                         << ", Interpolation=" << OFstatic_cast(int, opt_useInterpolation)
-                         << ", Aspect Ratio=" << (opt_useAspectRatio ? "yes" : "no") << endl;
+                OFLOG_INFO(dcmscaleLogger, "scaling image, X size=" << opt_scale_size
+                    << ", Interpolation=" << OFstatic_cast(int, opt_useInterpolation)
+                    << ", Aspect Ratio=" << (opt_useAspectRatio ? "yes" : "no"));
                 if (opt_useClip)
                     newimage = di->createScaledImage(opt_left, opt_top, opt_width, opt_height, opt_scale_size, 0,
                         OFstatic_cast(int, opt_useInterpolation), opt_useAspectRatio);
@@ -532,10 +540,9 @@ int main(int argc, char *argv[])
                         opt_useAspectRatio);
                 break;
             case 4:
-                if (opt_verbose)
-                    COUT << "scaling image, Y size=" << opt_scale_size
-                         << ", Interpolation=" << OFstatic_cast(int, opt_useInterpolation)
-                         << ", Aspect Ratio=" << (opt_useAspectRatio ? "yes" : "no") << endl;
+                OFLOG_INFO(dcmscaleLogger, "scaling image, Y size=" << opt_scale_size
+                    << ", Interpolation=" << OFstatic_cast(int, opt_useInterpolation)
+                    << ", Aspect Ratio=" << (opt_useAspectRatio ? "yes" : "no"));
                 if (opt_useClip)
                     newimage = di->createScaledImage(opt_left, opt_top, opt_width, opt_height, 0, opt_scale_size,
                         OFstatic_cast(int, opt_useInterpolation), opt_useAspectRatio);
@@ -552,14 +559,23 @@ int main(int argc, char *argv[])
             derivationDescription = "Scaled image";
     }
     if (opt_scaleType > 4)
-        CERR << "internal error: unknown scaling type" << endl;
+        OFLOG_ERROR(dcmscaleLogger, "internal error: unknown scaling type");
     else if (newimage == NULL)
-        app.printError("cannot create new image");
+    {
+        OFLOG_FATAL(dcmscaleLogger, "cannot create new image");
+        return 1;
+    }
     else if (newimage->getStatus() != EIS_Normal)
-        app.printError(DicomImage::getString(newimage->getStatus()));
+    {
+        OFLOG_FATAL(dcmscaleLogger, DicomImage::getString(newimage->getStatus()));
+        return 1;
+    }
     /* write scaled image to dataset (update attributes of Image Pixel Module) */
     else if (!newimage->writeImageToDataset(*dataset))
-        app.printError("cannot write new image to dataset");
+    {
+        OFLOG_FATAL(dcmscaleLogger, "cannot write new image to dataset");
+        return 1;
+    }
     delete newimage;
 
     /* cleanup original image */
@@ -621,27 +637,25 @@ int main(int argc, char *argv[])
         char new_uid[100];
         dataset->putAndInsertString(DCM_SOPInstanceUID, dcmGenerateUniqueIdentifier(new_uid));
         // force meta-header to refresh SOP Instance UID
-        DcmItem *metaInfo = fileformat.getMetaInfo();
-        if (metaInfo != NULL)
-            delete metaInfo->remove(DCM_MediaStorageSOPInstanceUID);
+        if (opt_writeMode == EWM_fileformat)
+            opt_writeMode = EWM_updateMeta;
     }
 
     // ======================================================================
     // write back output file
 
-    if (opt_verbose)
-        COUT << "create output file " << opt_ofname << endl;
+    OFLOG_INFO(dcmscaleLogger, "create output file " << opt_ofname);
+
+    error = fileformat.saveFile(opt_ofname, opt_oxfer, opt_oenctype, opt_oglenc, opt_opadenc,
+        OFstatic_cast(Uint32, opt_filepad), OFstatic_cast(Uint32, opt_itempad), opt_writeMode);
 
-    error = fileformat.saveFile(opt_ofname, opt_oxfer, opt_oenctype, opt_oglenc, opt_opadenc, opt_filepad, opt_itempad, opt_oDataset);
     if (error.bad())
     {
-        CERR << "Error: " << error.text()
-             << ": writing file: " <<  opt_ofname << endl;
+        OFLOG_FATAL(dcmscaleLogger, error.text() << ": writing file: " <<  opt_ofname);
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "conversion successful" << endl;
+    OFLOG_INFO(dcmscaleLogger, "conversion successful");
 
     // deregister RLE decompression codec
     DcmRLEDecoderRegistration::cleanup();
@@ -657,6 +671,50 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcmscale.cc,v $
+ * Revision 1.26  2010-10-14 13:13:34  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.25  2010-03-24 15:07:25  joergr
+ * Added missing command line options for the color space conversion.
+ *
+ * Revision 1.24  2009-10-14 10:26:37  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.23  2009-10-13 14:08:33  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.22  2009-08-21 09:28:12  joergr
+ * Added parameter 'writeMode' to save/write methods which allows for specifying
+ * whether to write a dataset or fileformat as well as whether to update the
+ * file meta information or to create a new file meta information header.
+ *
+ * Revision 1.21  2009-04-21 14:04:12  joergr
+ * Fixed minor inconsistencies in manpage / syntax usage.
+ *
+ * Revision 1.20  2009-04-03 11:45:02  joergr
+ * Added check whether neither scaling nor clipping is required.
+ *
+ * Revision 1.19  2008-09-25 14:43:22  joergr
+ * Moved output of resource identifier in order to avoid printing the same
+ * information twice.
+ *
+ * Revision 1.18  2008-09-25 12:47:58  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.17  2008-05-20 09:58:22  joergr
+ * Added new bilinear and bicubic scaling algorithms for image magnification.
+ * Allow width and height of the clipping area to be 0 (compute automatically).
+ *
+ * Revision 1.16  2006/08/15 16:35:00  meichel
+ * Updated the code in module dcmimage to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.15  2006/07/27 13:59:24  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Option "--help" is no longer an exclusive option
+ * by default.
+ *
  * Revision 1.14  2005/12/15 17:42:10  joergr
  * Changed type of local variable, reported by Sun CC 2.0.1 on Solaris.
  *
