@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomColorOutputPixelTemplate (Header)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 16:01:33 $
- *  CVS/RCS Revision: $Revision: 1.24 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:16:29 $
+ *  CVS/RCS Revision: $Revision: 1.28 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,12 +31,12 @@
 #define DICOOPXT_H
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/dcmdata/dctypes.h"
 
 #include "dcmtk/dcmimage/dicoopx.h"
 #include "dcmtk/dcmimage/dicopx.h"
 #include "dcmtk/dcmimgle/dipxrept.h"
-#include "dcmtk/dcmimgle/diutils.h"
+
+#include "dcmtk/ofstd/ofbmanip.h"
 
 
 /*---------------------*
@@ -94,7 +90,7 @@ class DiColorOutputPixelTemplate
      *  @param  pixel   pointer to intermediate pixel representation
      *  @param  count   number of pixels per frame
      *  @param  frame   frame to be rendered
-     *  #param  frames  (total number of frames present in intermediate representation)
+     * (#)param frames  (total number of frames present in intermediate representation)
      *  @param  planar  flag indicating whether data shall be stored color-by-pixel or color-by-plane
      */
     DiColorOutputPixelTemplate(void *buffer,
@@ -186,7 +182,7 @@ class DiColorOutputPixelTemplate
      *
      ** @return status, true if successful, false otherwise
      */
-    int writePPM(ostream &stream) const
+    int writePPM(STD_NAMESPACE ostream& stream) const
     {
         if (Data != NULL)
         {
@@ -253,6 +249,7 @@ class DiColorOutputPixelTemplate
                 Data = new T2[FrameSize * 3];
             if (Data != NULL)
             {
+                DCMIMAGE_DEBUG("converting color pixel data to output format");
                 register T2 *q = Data;
                 register unsigned long i;
                 const T2 max2 = OFstatic_cast(T2, DicomImageClass::maxval(bits2));
@@ -431,6 +428,20 @@ class DiColorOutputPixelTemplate
  *
  * CVS/RCS Log:
  * $Log: dicoopxt.h,v $
+ * Revision 1.28  2010-10-14 13:16:29  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.27  2010-10-05 15:34:41  joergr
+ * Output information on conversion process to the logger (debug mode).
+ * Fixed various Doxygen API documentation issues.
+ *
+ * Revision 1.26  2010-03-01 09:08:46  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.25  2006-08-15 16:35:01  meichel
+ * Updated the code in module dcmimage to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.24  2005/12/08 16:01:33  meichel
  * Changed include path schema for all DCMTK header files
  *
