@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimage
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomColorImage (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:21 $
- *  CVS/RCS Revision: $Revision: 1.35 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:14 $
+ *  CVS/RCS Revision: $Revision: 1.45 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,6 +28,7 @@
 
 
 #include "dcmtk/config/osconfig.h"
+
 #include "dcmtk/dcmdata/dctypes.h"
 #include "dcmtk/dcmdata/dcdeftag.h"
 #include "dcmtk/dcmdata/dcpixel.h"
@@ -44,6 +41,7 @@
 #include "dcmtk/dcmimage/dicoflt.h"
 #include "dcmtk/dcmimage/dicorot.h"
 #include "dcmtk/dcmimage/dicoopxt.h"
+#include "dcmtk/dcmimage/dilogger.h"
 #include "dcmtk/dcmimgle/diutils.h"
 
 
@@ -132,11 +130,7 @@ DiColorImage::DiColorImage(const DiColorImage *image,
                     src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames, image->BitsPerSample, interpolate);
                 break;
             default:
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid value for inter-representation !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMAGE_WARN("invalid value for inter-representation");
         }
         checkInterData(0);
     }
@@ -165,11 +159,7 @@ DiColorImage::DiColorImage(const DiColorImage *image,
                 InterData = new DiColorFlipTemplate<Uint32>(image->InterData, Columns, Rows, NumberOfFrames, horz, vert);
                 break;
             default:
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid value for inter-representation !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMAGE_WARN("invalid value for inter-representation");
         }
         checkInterData(0);
     }
@@ -200,11 +190,7 @@ DiColorImage::DiColorImage(const DiColorImage *image,
                     NumberOfFrames, degree);
                 break;
             default:
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid value for inter-representation !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMAGE_WARN("invalid value for inter-representation");
         }
         checkInterData(0);
     }
@@ -232,28 +218,19 @@ int DiColorImage::checkInterData(const int mode)
         if (ImageStatus == EIS_Normal)
         {
             ImageStatus = EIS_MemoryFailure;
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: can't allocate memory for inter-representation !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMAGE_ERROR("can't allocate memory for inter-representation");
         } else
             ImageStatus = EIS_InvalidImage;
     }
     else if (InterData->getData() == NULL)
         ImageStatus = EIS_InvalidImage;
-    else if (mode && (ImageStatus == EIS_Normal))
+    else if (mode && (ImageStatus == EIS_Normal) && isOriginal /* do not check derived images */)
     {
-        const unsigned long count = OFstatic_cast(unsigned long, Columns) * OFstatic_cast(unsigned long, Rows) * TotalNumberOfFrames;
+        const unsigned long count = OFstatic_cast(unsigned long, Columns) * OFstatic_cast(unsigned long, Rows) * NumberOfFrames;
         if ((InterData->getInputCount() != count) && ((InterData->getInputCount() >> 1) != ((count + 1) >> 1)))
         {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-            {
-                ofConsole.lockCerr() << "WARNING: computed (" << count
-                                     << ") and stored (" << InterData->getInputCount() << ") "
-                                     << "pixel count differ !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMAGE_WARN("computed (" << count << ") and stored (" << InterData->getInputCount()
+                << ") " << "pixel count differ");
         }
     }
     return (ImageStatus == EIS_Normal);
@@ -351,29 +328,17 @@ const void *DiColorImage::getData(void *buffer,
                             getBits(), bits, planar, inverse);
                     break;
                 default:
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                    {
-                        ofConsole.lockCerr() << "WARNING: invalid value for inter-representation !" << endl;
-                        ofConsole.unlockCerr();
-                    }
+                    DCMIMAGE_WARN("invalid value for inter-representation");
             }
             if (OutputData == NULL)
             {
                 ImageStatus = EIS_MemoryFailure;
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                {
-                    ofConsole.lockCerr() << "ERROR: can't allocate memory for inter-representation !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMAGE_ERROR("can't allocate memory for inter-representation");
             }
             else
                 return OutputData->getData();
         } else {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: given output buffer is too small (only " << size << " bytes) !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMAGE_ERROR("given output buffer is too small (only " << size << " bytes)");
         }
     }
     return NULL;
@@ -433,11 +398,7 @@ int DiColorImage::flip(const int horz,
             }
             break;
         default:
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-            {
-                ofConsole.lockCerr() << "WARNING: invalid value for inter-representation !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMAGE_WARN("invalid value for inter-representation");
     }
     return 1;
 }
@@ -479,11 +440,7 @@ int DiColorImage::rotate(const int degree)
                 }
                 break;
             default:
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid value for inter-representation !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMAGE_WARN("invalid value for inter-representation");
         }
     }
     return 1;
@@ -556,7 +513,8 @@ void DiColorImage::updateImagePixelModuleAttributes(DcmItem &dataset)
 // --- write current image to DICOM dataset
 
 int DiColorImage::writeImageToDataset(DcmItem &dataset,
-                                      const int /*mode*/)
+                                      const int /*mode*/,
+                                      const int planar)
 {
     int result = 0;
     if ((InterData != NULL) && (InterData->getCount() > 0) && (BitsPerSample > 0))
@@ -568,15 +526,19 @@ int DiColorImage::writeImageToDataset(DcmItem &dataset,
             OFBool ok = OFFalse;
             /* number of samples */
             const unsigned long count = InterData->getCount() * 3 /*planes*/;
+            /* number of pixels per frame */
+            const unsigned long fcount = OFstatic_cast(unsigned long, Columns) * OFstatic_cast(unsigned long, Rows);
+            /* determine planar configuration */
+            const int planarConfig = (planar == 2) ? InterData->getPlanarConfiguration() : ((planar == 0) ? 0 : 1);
             switch (InterData->getRepresentation())
             {
                 case EPR_Uint8:
                 case EPR_Sint8:
                 {
-                    /* write 8 bit pixel data (OB, color by plane) */
+                    /* write 8 bit pixel data (OB) */
                     Uint8 *data = NULL;
                     if (pixel->createUint8Array(count, data).good() &&
-                        InterData->getPixelData(OFstatic_cast(void *, data), OFstatic_cast(size_t, count)))
+                        InterData->getPixelData(OFstatic_cast(void *, data), OFstatic_cast(size_t, count), fcount, NumberOfFrames, planarConfig))
                     {
                         ok = OFTrue;
                     }
@@ -585,10 +547,10 @@ int DiColorImage::writeImageToDataset(DcmItem &dataset,
                 case EPR_Uint16:
                 case EPR_Sint16:
                 {
-                    /* write 16 bit pixel data (OW, color by plane) */
+                    /* write 16 bit pixel data (OW) */
                     Uint16 *data = NULL;
                     if (pixel->createUint16Array(count, data).good() &&
-                        InterData->getPixelData(OFstatic_cast(void *, data), OFstatic_cast(size_t, count)))
+                        InterData->getPixelData(OFstatic_cast(void *, data), OFstatic_cast(size_t, count), fcount, NumberOfFrames, planarConfig))
                     {
                         ok = OFTrue;
                     }
@@ -597,10 +559,10 @@ int DiColorImage::writeImageToDataset(DcmItem &dataset,
                 case EPR_Uint32:
                 case EPR_Sint32:
                 {
-                    /* write 32 bit pixel data (OW, color by plane) */
+                    /* write 32 bit pixel data (OW) */
                     Uint16 *data = NULL;
                     if (pixel->createUint16Array(count * 2 /*double-words*/, data).good() &&
-                        InterData->getPixelData(OFstatic_cast(void *, data), OFstatic_cast(size_t, count)))
+                        InterData->getPixelData(OFstatic_cast(void *, data), OFstatic_cast(size_t, count), fcount, NumberOfFrames, planarConfig))
                     {
                         ok = OFTrue;
                     }
@@ -610,6 +572,7 @@ int DiColorImage::writeImageToDataset(DcmItem &dataset,
             /* check whether pixel data has been written and insert element into the dataset */
             if (ok && dataset.insert(pixel, OFTrue /*replaceOld*/).good())
             {
+                char numBuf[20];
                 /* set color model */
                 if (getInternalColorModel() == EPI_YBR_Full)
                     dataset.putAndInsertString(DCM_PhotometricInterpretation, "YBR_FULL");
@@ -618,9 +581,14 @@ int DiColorImage::writeImageToDataset(DcmItem &dataset,
                 /* set image resolution */
                 dataset.putAndInsertUint16(DCM_Columns, Columns);
                 dataset.putAndInsertUint16(DCM_Rows, Rows);
-                dataset.putAndInsertSint32(DCM_NumberOfFrames, NumberOfFrames);
+#if SIZEOF_LONG == 8
+                sprintf(numBuf, "%d", NumberOfFrames);
+#else
+                sprintf(numBuf, "%ld", NumberOfFrames);
+#endif
+                dataset.putAndInsertString(DCM_NumberOfFrames, numBuf);
                 dataset.putAndInsertUint16(DCM_SamplesPerPixel, 3);
-                dataset.putAndInsertUint16(DCM_PlanarConfiguration, 1);
+                dataset.putAndInsertUint16(DCM_PlanarConfiguration, planarConfig);
                 /* set pixel encoding and data */
                 switch (InterData->getRepresentation())
                 {
@@ -664,7 +632,7 @@ int DiColorImage::writeImageToDataset(DcmItem &dataset,
 }
 
 
-int DiColorImage::writePPM(ostream &stream,
+int DiColorImage::writePPM(STD_NAMESPACE ostream& stream,
                            const unsigned long frame,
                            const int bits)
 {
@@ -673,9 +641,9 @@ int DiColorImage::writePPM(ostream &stream,
         getOutputData(frame, bits);
         if (OutputData != NULL)
         {
-            stream << "P3" << endl;
-            stream << Columns << " " << Rows << endl;
-            stream << DicomImageClass::maxval(bits) << endl;
+            stream << "P3" << OFendl;
+            stream << Columns << " " << Rows << OFendl;
+            stream << DicomImageClass::maxval(bits) << OFendl;
             int ok = OutputData->writePPM(stream);
             deleteOutputData();
             return ok;
@@ -732,7 +700,7 @@ int DiColorImage::writeBMP(FILE *stream,
                            const unsigned long frame,
                            const int bits)
 {
-    if (RGBColorModel && ((bits == 0) || (bits == 24)))
+    if (RGBColorModel && ((bits == 0) || (bits == 24) || (bits == 32)))
         return DiImage::writeBMP(stream, frame, (bits == 0) ? 24 : bits);
     return 0;
 }
@@ -742,6 +710,44 @@ int DiColorImage::writeBMP(FILE *stream,
  *
  * CVS/RCS Log:
  * $Log: dicoimg.cc,v $
+ * Revision 1.45  2010-10-14 13:14:14  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.44  2010-08-13 13:24:48  joergr
+ * Fixed wrong call to DcmItem::putAndInsertSint32() for setting the value of
+ * NumberOfFrames (0028,0008) which has a value representation of IS (not SL).
+ *
+ * Revision 1.43  2009-11-25 14:43:36  joergr
+ * Added new source and header file for the module logger.
+ *
+ * Revision 1.42  2009-10-14 10:23:56  joergr
+ * Fixed minor issues in log output. Also updated copyright date (if required).
+ *
+ * Revision 1.41  2009-10-13 14:08:33  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.40  2008-05-13 10:05:37  joergr
+ * Fixed issue with multi-frame color images: writeImageToDataset() used wrong
+ * format for color-by-plane output.
+ * Added new parameter to writeImageToDataset() in order to affect the planar
+ * configuration of the output image/dataset. Changed behaviour: By default,
+ * the output now uses the same planar configuration as the "original" image
+ * (previously: always color-by-plane).
+ *
+ * Revision 1.39  2006/11/17 15:10:59  joergr
+ * Only compare stored and computed pixel count for "original" images that are
+ * directly loaded from DICOM files or datasets.
+ *
+ * Revision 1.38  2006/10/27 15:00:49  joergr
+ * Fixed wrong warning message about length of pixel data.
+ *
+ * Revision 1.37  2006/08/15 16:35:01  meichel
+ * Updated the code in module dcmimage to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.36  2006/07/10 10:56:51  joergr
+ * Added support for 32-bit BMP images.
+ *
  * Revision 1.35  2005/12/08 15:42:21  meichel
  * Changed include path schema for all DCMTK header files
  *
