@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimage
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomColorPixel (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:23 $
- *  CVS/RCS Revision: $Revision: 1.15 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:14 $
+ *  CVS/RCS Revision: $Revision: 1.19 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -36,6 +32,7 @@
 #include "dcmtk/dcmdata/dcdeftag.h"
 
 #include "dcmtk/dcmimage/dicopx.h"
+#include "dcmtk/dcmimage/diqttype.h"
 #include "dcmtk/dcmimgle/dimopx.h"
 #include "dcmtk/dcmimgle/diinpx.h"
 #include "dcmtk/dcmimgle/didocu.h"
@@ -60,12 +57,8 @@ DiColorPixel::DiColorPixel(const DiDocument *docu,
         {
             if (us != samples)
             {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid value for 'SamplesPerPixel' (" << us
-                                         << ") ... assuming " << samples << " !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMAGE_WARN("invalid value for 'SamplesPerPixel' (" << us
+                    << ") ... assuming " << samples);
             }
             if (docu->getValue(DCM_PlanarConfiguration, us))
             {
@@ -75,30 +68,18 @@ DiColorPixel::DiColorPixel(const DiDocument *docu,
                     PlanarConfiguration = (us == 1);
                     if ((us != 0) && (us != 1))
                     {
-                        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                        {
-                            ofConsole.lockCerr() << "WARNING: invalid value for 'PlanarConfiguration' (" << us
-                                                 << ") ... assuming 'color-by-pixel' (0) !" << endl;
-                            ofConsole.unlockCerr();
-                        }
+                        DCMIMAGE_WARN("invalid value for 'PlanarConfiguration' (" << us
+                            << ") ... assuming 'color-by-pixel' (0)");
                     }
                 } else {
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                    {
-                        ofConsole.lockCerr() << "WARNING: unexpected attribute 'PlanarConfiguration' (" << us
-                                             << ") ... ignoring !" << endl;
-                        ofConsole.unlockCerr();
-                    }
+                    DCMIMAGE_WARN("unexpected attribute 'PlanarConfiguration' (" << us
+                        << ") ... ignoring");
                 }
             }
             else if (samples > 1)
             {
                 status = EIS_MissingAttribute;
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                {
-                    ofConsole.lockCerr() << "ERROR: mandatory attribute 'PlanarConfiguration' is missing !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMAGE_ERROR("mandatory attribute 'PlanarConfiguration' is missing");
                 return;
             }
             if (pixel != NULL)
@@ -110,11 +91,7 @@ DiColorPixel::DiColorPixel(const DiDocument *docu,
             }
         } else {
             status = EIS_MissingAttribute;
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: mandatory attribute 'SamplesPerPixel' is missing !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMAGE_ERROR("mandatory attribute 'SamplesPerPixel' is missing");
         }
     }
 }
@@ -140,6 +117,19 @@ DiColorPixel::~DiColorPixel()
  *
  * CVS/RCS Log:
  * $Log: dicopx.cc,v $
+ * Revision 1.19  2010-10-14 13:14:14  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.18  2009-10-14 10:23:56  joergr
+ * Fixed minor issues in log output. Also updated copyright date (if required).
+ *
+ * Revision 1.17  2009-10-13 14:08:33  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.16  2006-08-15 16:35:01  meichel
+ * Updated the code in module dcmimage to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.15  2005/12/08 15:42:23  meichel
  * Changed include path schema for all DCMTK header files
  *
