@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2003-2005, OFFIS
+ *  Copyright (C) 2003-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimage
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Implements PNG interface for plugable image formats
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:26 $
- *  CVS/RCS Revision: $Revision: 1.6 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:14 $
+ *  CVS/RCS Revision: $Revision: 1.8 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -214,7 +210,10 @@ OFString DiPNGPlugin::getLibraryVersionString()
     char cver[10];
     png_uint_32 ver = png_access_version_number();
     if( ver < 999999 ) {
-        sprintf( cver, "%li.%li.%li", (ver/10000)%100, (ver/100)%100, ver%100 );
+        sprintf( cver, "%li.%li.%li",
+                        OFstatic_cast(long int, (ver/10000)%100),
+                        OFstatic_cast(long int, (ver/100)%100),
+                        OFstatic_cast(long int, ver%100) );
     }else{
         sprintf( cver, "unknown" );
     }
@@ -232,7 +231,13 @@ int dipipng_cc_dummy_to_keep_linker_from_moaning = 0;
 /*
  * CVS/RCS Log:
  * $Log: dipipng.cc,v $
- * Revision 1.6  2005/12/08 15:42:26  meichel
+ * Revision 1.8  2010-10-14 13:14:14  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.7  2010-08-06 08:41:36  uli
+ * Fixed some more compiler warnings.
+ *
+ * Revision 1.6  2005-12-08 15:42:26  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.5  2004/04/07 12:07:52  joergr
