@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2001-2005, OFFIS
+ *  Copyright (C) 2001-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmjpeg
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Implements TIFF interface for plugable image formats
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:27 $
- *  CVS/RCS Revision: $Revision: 1.8 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-12-08 13:26:43 $
+ *  CVS/RCS Revision: $Revision: 1.12 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -72,18 +68,27 @@ int DiTIFFPlugin::write(
   {
     int stream_fd = fileno(stream);
 
+
 #ifdef HAVE_WINDOWS_H
-    /* The Win32 version of libtiff expects a Win32 HANDLE (casted to int)
-     * instead of a file descriptor. Therefore, we use _get_osfhandle()
-     * which takes a Unix-style file descriptor and derives the corresponding
-     * Win32 API file handle (HANDLE). This function may not be available on all
-     * compilers for Win32, sorry.
-     */
-#ifdef __CYGWIN__
-    stream_fd = OFstatic_cast(int, get_osfhandle(stream_fd));
-#else
-    stream_fd =OFstatic_cast(int, _get_osfhandle(stream_fd));
+
+#if TIFFLIB_VERSION < 20050912
+#error TIFF library versions prior to 3.7.4 are not supported by DCMTK on Win32 - critical API change!
 #endif
+
+/* Older versions of libtiff expected a Win32 HANDLE when compiled on Windows
+ * instead of a file descriptor. The code below was needed to make that work.
+ * Libtiff version 3.7.4 and newer are known to use a file descriptor instead,
+ * but it is not completely clear at which libtiff release the API change happened.
+ *
+ * #ifdef __CYGWIN__
+ *   stream_fd = OFstatic_cast(int, get_osfhandle(stream_fd));
+ * #else
+ *   stream_fd =OFstatic_cast(int, _get_osfhandle(stream_fd));
+ * #endif
+ */
+
+#elif TIFFLIB_VERSION < 20041016
+#error TIFF library versions prior to 3.7.0 are not supported by DCMTK - TIFFCleanup is missing!
 #endif
 
     /* create bitmap with 8 bits per sample */
@@ -161,7 +166,11 @@ int DiTIFFPlugin::write(
             offset += bytesperrow;
           }
           TIFFFlushData(tif);
-          TIFFClose(tif);
+          /* Clean up internal structures and free memory.
+           * However, the file will be closed by the caller, therefore
+           * TIFFClose(tif) is not called.
+           */
+          TIFFCleanup(tif);
         }
         if (OK) result = 1;
       }
@@ -210,7 +219,21 @@ int dipitiff_cc_dummy_to_keep_linker_from_moaning = 0;
  *
  * CVS/RCS Log:
  * $Log: dipitiff.cc,v $
- * Revision 1.8  2005/12/08 15:42:27  meichel
+ * Revision 1.12  2010-12-08 13:26:43  uli
+ * Explicitely check for libtiff 3.7.0 or newer.
+ *
+ * Revision 1.11  2010-10-14 13:14:14  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.10  2010-06-07 12:49:51  onken
+ * Fixed crash in dcmimage's TIFF plugin on some windows systems
+ * that was caused by closing the output file more than once.
+ *
+ * Revision 1.9  2009-08-06 12:33:56  meichel
+ * Fixed bug that caused TIFF export in dcm2pnm to fail on Win32
+ *   for newer releases of libtiff (3.7.4 and newer)
+ *
+ * Revision 1.8  2005-12-08 15:42:27  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.7  2004/02/06 11:20:00  joergr
