@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimage
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: class DcmQuantColorTable
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:28 $
- *  CVS/RCS Revision: $Revision: 1.8 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:14 $
+ *  CVS/RCS Revision: $Revision: 1.10 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -31,9 +27,8 @@
  */
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/dcmimage/diqtctab.h"
 
-#include "dcmtk/ofstd/ofconsol.h"
+#include "dcmtk/dcmimage/diqtctab.h"
 #include "dcmtk/dcmimage/diqtpbox.h"
 #include "dcmtk/dcmdata/dcerror.h"   /* for EC_IllegalCall */
 #include "dcmtk/dcmdata/dcelem.h"    /* for DcmElement */
@@ -562,6 +557,12 @@ void DcmQuantColorTable::setDescriptionString(OFString& str) const
  *
  * CVS/RCS Log:
  * $Log: diqtctab.cc,v $
+ * Revision 1.10  2010-10-14 13:14:14  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.9  2009-11-25 14:44:52  joergr
+ * Removed inclusion of header file "ofconsol.h".
+ *
  * Revision 1.8  2005/12/08 15:42:28  meichel
  * Changed include path schema for all DCMTK header files
  *
