@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimage
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: class DcmQuantPixelBoxArray
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:32 $
- *  CVS/RCS Revision: $Revision: 1.5 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:15 $
+ *  CVS/RCS Revision: $Revision: 1.7 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,6 +31,12 @@
 #include "dcmtk/ofstd/ofcast.h"
 #include "dcmtk/dcmimage/diqtpbox.h"   /* for DcmQuantPixelBoxArray */
 
+#ifdef USE_STD_CXX_INCLUDES
+// Solaris defines qsort() in namespace std, other compilers don't...
+namespace std { }
+using namespace std;
+#endif
+
 
 BEGIN_EXTERN_C
 static int sumcompare(const void *x1, const void *x2)
@@ -74,7 +76,14 @@ DcmQuantPixelBoxArray::~DcmQuantPixelBoxArray()
  *
  * CVS/RCS Log:
  * $Log: diqtpbox.cc,v $
- * Revision 1.5  2005/12/08 15:42:32  meichel
+ * Revision 1.7  2010-10-14 13:14:15  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.6  2009-08-19 14:48:54  meichel
+ * Unlike some other compilers, Sun Studio 11 on Solaris declares longjmp()
+ *   and qsort() in namespace std. Added code to handle this case.
+ *
+ * Revision 1.5  2005-12-08 15:42:32  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.4  2003/12/17 16:34:57  joergr
