@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimage
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DcmQuant
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:33 $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:15 $
+ *  CVS/RCS Revision: $Revision: 1.9 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,22 +28,22 @@
 
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/dcmimage/diquant.h"
 
-#include "dcmtk/ofstd/ofconsol.h"  /* for ofConsole */
+#include "dcmtk/dcmimage/diquant.h"
 #include "dcmtk/dcmimage/diqtid.h"    /* for DcmQuantIdent */
 #include "dcmtk/dcmimage/diqtcmap.h"  /* for DcmQuantColorMapping */
 #include "dcmtk/dcmimage/diqtpix.h"   /* for DcmQuantPixel */
 #include "dcmtk/dcmimage/diqthash.h"  /* for DcmQuantColorHashTable */
 #include "dcmtk/dcmimage/diqtctab.h"  /* for DcmQuantColorTable */
 #include "dcmtk/dcmimage/diqtfs.h"    /* for DcmQuantFloydSteinberg */
-#include "dcmtk/dcmdata/dcswap.h"    /* for swapIfNecessary() */
-#include "dcmtk/dcmdata/dcitem.h"    /* for DcmItem */
+#include "dcmtk/dcmimage/dilogger.h"  /* for logging macros */
+#include "dcmtk/dcmdata/dcswap.h"     /* for swapIfNecessary() */
+#include "dcmtk/dcmdata/dcitem.h"     /* for DcmItem */
 #include "dcmtk/dcmimgle/dcmimage.h"  /* for DicomImage */
-#include "dcmtk/dcmdata/dcdeftag.h"  /* for tag constants */
-#include "dcmtk/dcmdata/dcpixel.h"   /* for DcmPixelData */
-#include "dcmtk/dcmdata/dcsequen.h"  /* for DcmSequenceOfItems */
-#include "dcmtk/dcmdata/dcuid.h"     /* for dcmGenerateUniqueIdentifier() */
+#include "dcmtk/dcmdata/dcdeftag.h"   /* for tag constants */
+#include "dcmtk/dcmdata/dcpixel.h"    /* for DcmPixelData */
+#include "dcmtk/dcmdata/dcsequen.h"   /* for DcmSequenceOfItems */
+#include "dcmtk/dcmdata/dcuid.h"      /* for dcmGenerateUniqueIdentifier() */
 
 
 OFCondition DcmQuant::createPaletteColorImage(
@@ -58,11 +54,10 @@ OFCondition DcmQuant::createPaletteColorImage(
     OFBool floydSteinberg,
     Uint32 numberOfColors,
     OFString& description,
-    OFBool verbose,
     DcmLargestDimensionType largeType,
     DcmRepresentativeColorType repType)
 {
-	// make sure we're operating on a color image
+    // make sure we're operating on a color image
     if (sourceImage.isMonochrome()) return EC_IllegalCall;
 
     // make sure numberOfColors is in range
@@ -71,33 +66,21 @@ OFCondition DcmQuant::createPaletteColorImage(
     OFCondition result = EC_Normal;
 
     // Create histogram of the colors, clustered if necessary
-    if (verbose)
-    {
-      ofConsole.lockCerr() << "computing image histogram" << endl;
-      ofConsole.unlockCerr();
-    }
+    DCMIMAGE_DEBUG("computing image histogram");
 
     DcmQuantColorTable chv;
     result = chv.computeHistogram(sourceImage, DcmQuantMaxColors);
     if (result.bad()) return result;
 
     unsigned long maxval = chv.getMaxVal();
-    if (verbose)
-    {
-      ofConsole.lockCerr() << "image histogram: found " << chv.getColors() << " colors (at maxval=" << maxval << ")" << endl;
-      ofConsole.unlockCerr();
-    }
+    DCMIMAGE_DEBUG("image histogram: found " << chv.getColors() << " colors (at maxval=" << maxval << ")");
 
     // apply median-cut to histogram, making the new colormap.
     unsigned long cols = sourceImage.getWidth();
     unsigned long rows = sourceImage.getHeight();
     unsigned long frames = sourceImage.getFrameCount();
 
-    if (verbose)
-    {
-      ofConsole.lockCerr() << "computing color map using Heckbert's median cut algorithm" << endl;
-      ofConsole.unlockCerr();
-    }
+    DCMIMAGE_DEBUG("computing color map using Heckbert's median cut algorithm");
 
     DcmQuantColorTable colormap;
     result = colormap.medianCut(chv, cols * rows * frames, maxval, numberOfColors, largeType, repType);
@@ -107,11 +90,7 @@ OFCondition DcmQuant::createPaletteColorImage(
     // map the colors in the image to their closest match in the
     // new colormap, and write 'em out.
     DcmQuantColorHashTable cht;
-    if (verbose)
-    {
-      ofConsole.lockCerr() << "mapping image data to color table" << endl;
-      ofConsole.unlockCerr();
-    }
+    DCMIMAGE_DEBUG("mapping image data to color table");
 
     DcmQuantFloydSteinberg fs;
     if (floydSteinberg)
@@ -136,7 +115,7 @@ OFCondition DcmQuant::createPaletteColorImage(
        result = pixelData->createUint16Array(totalSize/sizeof(Uint16), imageData16);
        if (result.good())
        {
-       	 imageData16[(totalSize/sizeof(Uint16)) -1] = 0; // make sure pad byte is zero
+         imageData16[(totalSize/sizeof(Uint16)) -1] = 0; // make sure pad byte is zero
          imageData8 = OFreinterpret_cast(Uint8 *, imageData16);
          result = target.insert(pixelData, OFTrue);
          if (result.good())
@@ -167,11 +146,7 @@ OFCondition DcmQuant::createPaletteColorImage(
        }
     }
 
-    if (verbose)
-    {
-      ofConsole.lockCerr() << "creating DICOM image pixel module" << endl;
-      ofConsole.unlockCerr();
-    }
+    DCMIMAGE_DEBUG("creating DICOM image pixel module");
 
     // create target image pixel module
     if (result.good()) result = target.putAndInsertUint16(DCM_SamplesPerPixel, 1);
@@ -199,6 +174,7 @@ OFCondition DcmQuant::createPaletteColorImage(
     delete target.remove(DCM_SmallestImagePixelValue);
     delete target.remove(DCM_LargestImagePixelValue);
     delete target.remove(DCM_PixelPaddingValue);
+    delete target.remove(DCM_PixelPaddingRangeLimit);
     delete target.remove(DCM_SmallestPixelValueInSeries);
     delete target.remove(DCM_LargestPixelValueInSeries);
     delete target.remove(DCM_PaletteColorLookupTableUID);
@@ -256,6 +232,23 @@ OFCondition DcmQuant::updateDerivationDescription(DcmItem *dataset, const char *
  *
  * CVS/RCS Log:
  * $Log: diquant.cc,v $
+ * Revision 1.9  2010-10-14 13:14:15  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.8  2010-10-05 14:55:26  joergr
+ * Also remove PixelPaddingRangeLimit element from the dataset (if required).
+ *
+ * Revision 1.7  2009-11-25 14:44:03  joergr
+ * Added new source and header file for the module logger.
+ * Removed inclusion of header file "ofconsol.h".
+ *
+ * Revision 1.6  2009-10-13 14:08:33  uli
+ * Switched to logging mechanism provided by the "new" oflog module
+ *
+ * Revision 1.5  2006-08-15 16:35:01  meichel
+ * Updated the code in module dcmimage to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.4  2005/12/08 15:42:33  meichel
  * Changed include path schema for all DCMTK header files
  *
