@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: convert hardcopy characteristic curve file to softcopy format
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:40 $
- *  CVS/RCS Revision: $Revision: 1.5 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-10-20 07:41:35 $
+ *  CVS/RCS Revision: $Revision: 1.10 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,6 +31,7 @@
 
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CCTYPE
+#define INCLUDE_CSTRING
 #include "dcmtk/ofstd/ofstdinc.h"
 
 #include "dcmtk/ofstd/ofstream.h"
@@ -56,13 +53,13 @@ int main(int argc, char *argv[])
     if (argc == 3)
     {
 #ifdef HAVE_IOS_NOCREATE
-        ifstream input(argv[1], ios::in|ios::nocreate);
+        STD_NAMESPACE ifstream input(argv[1], STD_NAMESPACE ios::in | STD_NAMESPACE ios::nocreate);
 #else
-        ifstream input(argv[1], ios::in);
+        STD_NAMESPACE ifstream input(argv[1], STD_NAMESPACE ios::in);
 #endif
         if (input)
         {
-            ofstream output(argv[2]);
+            STD_NAMESPACE ofstream output(argv[2]);
             if (output)
             {
                 char c;
@@ -71,14 +68,14 @@ int main(int argc, char *argv[])
                 int order = -1;
                 double amb = 0;
                 double lum = 0;
-                output << "# Softcopy characteristic curve file (converted from hardcopy format)" << endl;
+                output << "# Softcopy characteristic curve file (converted from hardcopy format)" << OFendl;
                 while (input.get(c) && !error)
                 {
                     if (c == '#')                                               // comment character
                     {
                         while (input.get(c) && (c != '\n') && (c != '\r'));     // skip comments
                     }
-                    else if (!isspace(c))                                       // skip whitespaces
+                    else if (!isspace(OFstatic_cast(unsigned char, c)))         // skip whitespaces
                     {
                         input.putback(c);
                         if (maxddl == 0)                                        // read maxvalue
@@ -90,8 +87,8 @@ int main(int argc, char *argv[])
                                 input >> maxddl;
                                 if (maxddl > 0)
                                 {
-                                    output << endl << "# maximum DDL value" << endl;
-                                    output << "max " << maxddl << endl;
+                                    output << OFendl << "# maximum DDL value" << OFendl;
+                                    output << "max " << maxddl << OFendl;
                                 } else
                                     error = 1;
                             } else
@@ -106,8 +103,8 @@ int main(int argc, char *argv[])
                                 input >> amb;
                                 if (amb >= 0)
                                 {
-                                    output << endl << "# reflected ambient light (already included)" << endl;
-                                    output << "# amb " << amb << endl;
+                                    output << OFendl << "# reflected ambient light (already included)" << OFendl;
+                                    output << "# amb " << amb << OFendl;
                                 } else
                                     error = 1;
                             } else
@@ -122,8 +119,8 @@ int main(int argc, char *argv[])
                                 input >> lum;
                                 if (lum >= 0)
                                 {
-                                    output << endl << "# illumination (already included)" << endl;
-                                    output << "# lum " << lum << endl;
+                                    output << OFendl << "# illumination (already included)" << OFendl;
+                                    output << "# lum " << lum << OFendl;
                                 } else
                                     error = 1;
                             } else
@@ -138,8 +135,8 @@ int main(int argc, char *argv[])
                                 input >> order;
                                 if (order >= 0)
                                 {
-                                    output << endl << "# order of the polynomial curve fitting algorithm (optional)" << endl;
-                                    output << "ord " << order << endl;
+                                    output << OFendl << "# order of the polynomial curve fitting algorithm (optional)" << OFendl;
+                                    output << "ord " << order << OFendl;
                                 } else
                                     error = 1;
                             } else
@@ -152,10 +149,10 @@ int main(int argc, char *argv[])
                             if (input.good() && (ddlval <= maxddl))
                             {
                                 if (i == 0)
-                                    output << endl << "# DDL   LumVal" << endl;
+                                    output << OFendl << "# DDL   LumVal" << OFendl;
                                 output << ddlval << "\t";
-                                output.setf(ios::fixed, ios::floatfield);
-                                output << DiDisplayFunction::convertODtoLum(odval, amb, lum) << endl;
+                                output.setf(STD_NAMESPACE ios::fixed, STD_NAMESPACE ios::floatfield);
+                                output << DiDisplayFunction::convertODtoLum(odval, amb, lum) << OFendl;
                                 ++i;
                             } else
                                 error = 1;
@@ -164,22 +161,22 @@ int main(int argc, char *argv[])
                 }
                 if (error)
                 {
-                    output << endl << "# error: corrupted input file" << endl;
-                    CERR << "ERROR: corrupted input file !" << endl;
+                    output << OFendl << "# error: corrupted input file" << OFendl;
+                    CERR << "ERROR: corrupted input file !" << OFendl;
                 } else
-                    output << endl << "# end of file" << endl;
+                    output << OFendl << "# end of file" << OFendl;
              } else
-                CERR << "ERROR: can't create output file !" << endl;
+                CERR << "ERROR: can't create output file !" << OFendl;
         } else
-            CERR << "ERROR: can't open input file !" << endl;
+            CERR << "ERROR: can't open input file !" << OFendl;
     } else {
         /* print usage */
-        CERR << rcsid << endl << endl;
-        CERR << OFFIS_CONSOLE_APPLICATION << ": Convert hardcopy characteristic curve file to softcopy format" << endl;
-        CERR << "usage: " << OFFIS_CONSOLE_APPLICATION << " in-file out-file" << endl << endl;
-        CERR << "parameters:" << endl;
-        CERR << "  in-file   hardcopy characteristic curve file to be converted" << endl;
-        CERR << "  out-file  softcopy characteristic curve file to be written" << endl;
+        CERR << rcsid << OFendl << OFendl;
+        CERR << OFFIS_CONSOLE_APPLICATION << ": Convert hardcopy characteristic curve file to softcopy format" << OFendl;
+        CERR << "usage: " << OFFIS_CONSOLE_APPLICATION << " in-file out-file" << OFendl << OFendl;
+        CERR << "parameters:" << OFendl;
+        CERR << "  in-file   hardcopy characteristic curve file to be converted" << OFendl;
+        CERR << "  out-file  softcopy characteristic curve file to be written" << OFendl;
     }
     return error;
 }
@@ -188,6 +185,22 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcod2lum.cc,v $
+ * Revision 1.10  2010-10-20 07:41:35  uli
+ * Made sure isalpha() & friends are only called with valid arguments.
+ *
+ * Revision 1.9  2010-10-14 13:13:36  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.8  2010-06-25 09:15:19  uli
+ * Fixed issues with compiling with HAVE_STD_STRING.
+ *
+ * Revision 1.7  2006-08-15 16:30:09  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.6  2006/07/27 14:01:23  joergr
+ * Updated copyright date.
+ *
  * Revision 1.5  2005/12/08 15:42:40  meichel
  * Changed include path schema for all DCMTK header files
  *
