@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: convert VeriLUM CCx_xx.dat files to DCMTK display files
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:41 $
- *  CVS/RCS Revision: $Revision: 1.20 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-10-20 07:41:35 $
+ *  CVS/RCS Revision: $Revision: 1.27 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -38,8 +34,8 @@
 #include "dcmtk/ofstd/ofstdinc.h"
 
 #include "dcmtk/ofstd/ofstream.h"
-#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/ofstd/ofstd.h"
+#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/dcmdata/dcuid.h"    /* for dcmtk version name */
 
 
@@ -55,67 +51,67 @@ int main(int argc, char *argv[])
     if ((argc >= 3) && (argc <= 4))
     {
 #ifdef HAVE_IOS_NOCREATE
-        ifstream input(argv[1], ios::in|ios::nocreate);
+        STD_NAMESPACE ifstream input(argv[1], STD_NAMESPACE ios::in | STD_NAMESPACE ios::nocreate);
 #else
-        ifstream input(argv[1], ios::in);
+        STD_NAMESPACE ifstream input(argv[1], STD_NAMESPACE ios::in);
 #endif
         if (input)
         {
-            ofstream output(argv[2]);
+            STD_NAMESPACE ofstream output(argv[2]);
             if (output)
             {
                 const unsigned int maxddl = 255;                                    // maximum DDL value (8 bits)
-                output << "# Monitor characteristic file (converted from VeriLUM to DCMTK)" << endl << "# ";
+                output << "# Monitor characteristic file (converted from VeriLUM to DCMTK)" << OFendl << "# ";
                 char c;
                 while (input.get(c) && (c != '\n') && (c != '\r'))                  // read description
                     output << c;                                                    // ... and write it to output file
-                output << endl << endl;
-                output << "# maximum DDL value" << endl << endl;
-                output << "  max   " << maxddl << endl << endl;
+                output << OFendl << OFendl;
+                output << "# maximum DDL value" << OFendl << OFendl;
+                output << "  max   " << maxddl << OFendl << OFendl;
                 if (argc == 4)
                 {
                     double ambient = OFStandard::atof(argv[3]);
-                    output << "# ambient light value" << endl << endl;
-                    output << "  amb   " << ambient << endl << endl;
+                    output << "# ambient light value" << OFendl << OFendl;
+                    output << "  amb   " << ambient << OFendl << OFendl;
                 }
-                output << "# DDL   LumVal" << endl << endl;
+                output << "# DDL   LumVal" << OFendl << OFendl;
                 double lum;
                 unsigned int ddl;
                 unsigned int i = 0;
                 while ((i <= maxddl) && input.good() && output.good())
                 {
-                    while (input.get(c) && !isdigit(c));                            // skip non-numeric chars
+                    while (input.get(c) && !isdigit(OFstatic_cast(unsigned char, c))); // skip non-numeric chars
                     input.putback(c);
                     input >> ddl;                                                   // read DDL value
-                    while (input.get(c) && !isdigit(c));                            // skip non-numeric chars
+                    while (input.get(c) && !isdigit(OFstatic_cast(unsigned char, c))); // skip non-numeric chars
                     input.putback(c);
                     input >> lum;                                                   // read luminance value
                     output.width(5);
                     output << ddl;                                                  // write DDL value
                     output.width(12);
-                    output.setf(ios::fixed, ios::floatfield);
-                    output << lum << endl;                                          // write luminance value
+                    output.setf(STD_NAMESPACE ios::fixed, STD_NAMESPACE ios::floatfield);
+                    output << lum << OFendl;                                          // write luminance value
                     ++i;
                 }
                 if (i <= maxddl)
-                    CERR << "ERROR: can't convert input file ... error in line #" << i << " !" << endl;
+                    CERR << "ERROR: can't convert input file ... error in line #" << i << OFendl;
                 else {
-                    output << endl << "# eof of file";
+                    output << OFendl << "# eof of file";
                     return 0;                                                       // everything is OK
                 }
              } else
-                CERR << "ERROR: can't create output file !" << endl;
+                CERR << "ERROR: can't create output file" << OFendl;
         } else
-            CERR << "ERROR: can't open input file !" << endl;
+            CERR << "ERROR: can't open input file" << OFendl;
     } else {
         /* print usage */
-        CERR << rcsid << endl << endl;
-        CERR << OFFIS_CONSOLE_APPLICATION << ": Convert VeriLUM \"CCx_xx.dat\" files to DCMTK display files" << endl;
-        CERR << "usage: " << OFFIS_CONSOLE_APPLICATION << " in-file out-file [ambient]" << endl << endl;
-        CERR << "parameters:" << endl;
-        CERR << "  in-file   VeriLUM characteristic curve file to be converted" << endl;
-        CERR << "  out-file  DCMTK display file to be written" << endl;
-        CERR << "  ambient   ambient light (cd/m^2, floating point value)" << endl;
+        CERR << rcsid << OFendl << OFendl;
+        CERR << OFFIS_CONSOLE_APPLICATION << ": Convert VeriLUM \"CCx_xx.dat\" files to DCMTK display files" << OFendl;
+        CERR << "usage: " << OFFIS_CONSOLE_APPLICATION << " in-file out-file [ambient]" << OFendl << OFendl;
+        CERR << "parameters:" << OFendl;
+        CERR << "  in-file   VeriLUM characteristic curve file to be converted" << OFendl;
+        CERR << "  out-file  DCMTK display file to be written" << OFendl;
+        CERR << "  ambient   ambient light (cd/m^2, floating point value)" << OFendl;
     }
     return 1;                                                                       // an error has happened
 }
@@ -124,6 +120,28 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dconvlum.cc,v $
+ * Revision 1.27  2010-10-20 07:41:35  uli
+ * Made sure isalpha() & friends are only called with valid arguments.
+ *
+ * Revision 1.26  2010-10-14 13:13:36  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.25  2010-03-01 09:08:46  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.24  2009-11-25 16:22:36  joergr
+ * Removed inclusion of header file "ofconsol.h".
+ *
+ * Revision 1.23  2009-10-28 14:24:10  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.22  2006/08/15 16:30:09  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.21  2006/07/27 14:01:23  joergr
+ * Updated copyright date.
+ *
  * Revision 1.20  2005/12/08 15:42:41  meichel
  * Changed include path schema for all DCMTK header files
  *
