@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomMonochromeImage (Header)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 16:47:50 $
- *  CVS/RCS Revision: $Revision: 1.46 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:16:26 $
+ *  CVS/RCS Revision: $Revision: 1.57 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,14 +31,12 @@
 #define DIMOIMG_H
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/dcmdata/dctypes.h"
+
 #include "dcmtk/ofstd/ofcast.h"
 
 #include "dcmtk/dcmimgle/diimage.h"
 #include "dcmtk/dcmimgle/dimopx.h"
 #include "dcmtk/dcmimgle/dimoopx.h"
-#include "dcmtk/dcmimgle/diovlay.h"
-#include "dcmtk/dcmimgle/diluptab.h"
 #include "dcmtk/dcmimgle/didispfn.h"
 
 
@@ -103,6 +97,14 @@ class DiMonoImage
      */
     virtual ~DiMonoImage();
 
+    /** process next couple of frames
+     *
+     ** @param  fcount  number of frames to be processed (0 = same number as before)
+     *
+     ** @return status, true if successful, false otherwise
+     */
+    virtual int processNextFrames(const unsigned long fcount);
+
     /** get minimum and maximum pixel values.
      *  the resulting pixel values are stored in 'double' variables to avoid problems
      *  with different number ranges, limited to monochrome images
@@ -273,33 +275,49 @@ class DiMonoImage
         return WindowCount;
     }
 
+    /** get VOI LUT function.
+     *  possible values are: EFV_Default, EFV_Linear, EFV_Sigmoid.
+     *
+     ** @return currently active VOI LUT function
+     */
+    EF_VoiLutFunction getVoiLutFunction() const;
+
+    /** set VOI LUT function
+     *
+     ** @param  function  type of VOI LUT function (default, linear or sigmoid).
+     *                    'default' basically means the same as 'linear'.
+     *
+     ** @return true if successful (1 = function has changed,
+     *                              2 = function has not changed)
+     *          false otherwise
+     */
+    int setVoiLutFunction(const EF_VoiLutFunction function);
+
     /** set VOI LUT (given by dcmdata elements).
      *  possibly active window/center is implicitly disabled.
      *
      ** @param  data         contains LUT data
      *  @param  descriptor   describes LUT structure
      *  @param  explanation  free form description of VOI LUT (optional)
-     *  @param  ignoreDepth  ignore third value of LUT descriptor if OFTrue.
-     *                       Determine bits per table entry automatically from max value.
+     *  @param  descripMode  mode specifying the use of the bits per table entry value
      *
      ** @return true if successful, false otherwise
      */
     int setVoiLut(const DcmUnsignedShort &data,
                   const DcmUnsignedShort &descriptor,
                   const DcmLongString *explanation,
-                  const OFBool ignoreDepth = OFFalse);
+                  const EL_BitsPerTableEntry descripMode = ELM_UseValue);
 
     /** set VOI LUT (given by index to VOI LUT sequence stored in image file).
      *  possibly active window/center is implicitly disabled.
      *
      ** @param  pos          index to VOI LUT sequence
-     *  @param  ignoreDepth  ignore third value of LUT descriptor if OFTrue.
-     *                       Determine bits per table entry automatically from max value.
+     *  @param  descripMode  mode specifying the use of the bits per table entry value
      *
      ** @return true if successful, false otherwise
      */
     int setVoiLut(const unsigned long pos,
-                  const OFBool ignoreDepth = OFFalse);
+                  const EL_BitsPerTableEntry descripMode = ELM_UseValue);
 
     /** get number of VOI LUTs (stored in image file)
      *
@@ -391,15 +409,14 @@ class DiMonoImage
      ** @param  data         contains LUT data
      *  @param  descriptor   describes LUT structure
      *  @param  explanation  free form description of presentation LUT (optional)
-     *  @param  ignoreDepth  ignore third value of LUT descriptor if OFTrue.
-     *                       Determine bits per table entry automatically from max value.
+     *  @param  descripMode  mode specifying the use of the bits per table entry value
      *
      ** @return true if successful, false otherwise
      */
     int setPresentationLut(const DcmUnsignedShort &data,
                            const DcmUnsignedShort &descriptor,
                            const DcmLongString *explanation = NULL,
-                           const OFBool ignoreDepth = OFFalse);
+                           const EL_BitsPerTableEntry descripMode = ELM_UseValue);
 
     /** set inverse LUT for presentation transformation.
      *  this LUT transform is e.g. used for DICOM print (12->8, 8->12 bit)
@@ -407,14 +424,13 @@ class DiMonoImage
      *
      ** @param  data         contains LUT data
      *  @param  descriptor   describes LUT structure
-     *  @param  ignoreDepth  ignore third value of LUT descriptor if OFTrue.
-     *                       Determine bits per table entry automatically from max value.
+     *  @param  descripMode  mode specifying the use of the bits per table entry value
      *
      ** @return true if successful, false otherwise
      */
     int setInversePresentationLut(const DcmUnsignedShort &data,
                                   const DcmUnsignedShort &descriptor,
-                                  const OFBool ignoreDepth = OFFalse);
+                                  const EL_BitsPerTableEntry descripMode = ELM_UseValue);
 
     /** get description of active presentation LUT
      *
@@ -584,16 +600,16 @@ class DiMonoImage
      ** @return pointer to overlay plane data (internal memory buffer)
      */
     const void *getOverlayData(const unsigned long frame,
-                                const unsigned int plane,
-                                unsigned int &left_pos,
-                                unsigned int &top_pos,
-                                unsigned int &width,
-                                unsigned int &height,
-                                EM_Overlay &mode,
-                                const unsigned int idx,
-                                const int bits = 8,
-                                const Uint16 fore = 0xff,
-                                const Uint16 back = 0x0);
+                               const unsigned int plane,
+                               unsigned int &left_pos,
+                               unsigned int &top_pos,
+                               unsigned int &width,
+                               unsigned int &height,
+                               EM_Overlay &mode,
+                               const unsigned int idx,
+                               const int bits = 8,
+                               const Uint16 fore = 0xff,
+                               const Uint16 back = 0x0);
 
     /** create bitmap for specified overlay plane.
      *  (up to 16 bits per pixel with two values: fore and back)
@@ -729,11 +745,13 @@ class DiMonoImage
      ** @param  dataset  reference to DICOM dataset where the image attributes are stored
      *  @param  mode     0 = determine value of BitsStored from 'used' pixel values,
      *                   1 = determine value of BitsStored from 'possible' pixel values
+     *  @param  planar   dummy parameter (only used for color images)
      *
      ** @return true if successful, false otherwise
      */
     int writeImageToDataset(DcmItem &dataset,
-                            const int mode);
+                            const int mode,
+                            const int planar);
 
     /** write pixel data to PPM file.
      *  pixel data is written in ASCII format.
@@ -744,7 +762,7 @@ class DiMonoImage
      *
      ** @return true if successful, false otherwise
      */
-    int writePPM(ostream &stream,
+    int writePPM(STD_NAMESPACE ostream& stream,
                  const unsigned long frame,
                  const int bits);
 
@@ -777,7 +795,7 @@ class DiMonoImage
      *
      ** @param  stream  open C output stream
      *  @param  frame   index of frame used for output (default: first frame = 0)
-     *  @param  bits    number of bits used for output of pixel data (8 or 24, 0=default means 8)
+     *  @param  bits    number of bits used for output of pixel data (8, 24 or 32, default (0) = 8)
      *
      ** @return true if successful, false otherwise
      */
@@ -832,8 +850,10 @@ class DiMonoImage
      *  @param  src_rows      height of area to be scaled
      *  @param  dest_cols     width of scaled image (in pixels)
      *  @param  dest_rows     height of scaled image (in pixels)
-     *  @param  interpolate   specifies whether scaling algorithm should use interpolation (if necessary)
-     *                        default: no interpolation (0), 1 = pbmplus algorithm, 2 = c't algorithm
+     *  @param  interpolate   specifies whether scaling algorithm should use interpolation (if necessary).
+     *                        default: no interpolation (0), preferred interpolation algorithm (if applicable):
+     *                          1 = pbmplus algorithm, 2 = c't algorithm, 3 = bilinear magnification,
+     *                          4 = bicubic magnification
      *  @param  aspect        specifies whether pixel aspect ratio should be taken into consideration
      *                        (if true, width OR height should be 0, i.e. this component will be calculated
      *                         automatically)
@@ -885,8 +905,10 @@ class DiMonoImage
     /** initialize internal data structures and member variables
      *
      ** @param  modality  pointer to object handling the modality transform
+     *  @param  reuse     reuse particular information determined in a previous call
      */
-    void Init(DiMonoModality *modality);
+    void Init(DiMonoModality *modality,
+              const OFBool reuse = OFFalse);
 
     /** initialize internal data structures (for Uint8)
      *
@@ -1096,8 +1118,9 @@ class DiMonoImage
 
     /// free text explanation of current VOI transformation
     OFString VoiExplanation;
-
-    /// presentation LUT shape (identity or inverse)
+    /// VOI LUT function (linear or sigmoid)
+    EF_VoiLutFunction VoiLutFunction;
+    /// presentation LUT shape (identity, inverse or lin od)
     ES_PresentationLut PresLutShape;
 
     /// minimum density of a print-out (in hundreds of Optical Density)
@@ -1143,6 +1166,47 @@ class DiMonoImage
  *
  * CVS/RCS Log:
  * $Log: dimoimg.h,v $
+ * Revision 1.57  2010-10-14 13:16:26  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.56  2010-10-05 15:24:02  joergr
+ * Added preliminary support for VOI LUT function. Please note, however, that
+ * the sigmoid transformation is not yet implemented.
+ *
+ * Revision 1.55  2010-07-21 13:08:56  joergr
+ * Fixed memory leak when using processNextFrames(): DiOverlay object was
+ * created multiple times.
+ *
+ * Revision 1.54  2010-03-01 09:08:47  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.53  2009-11-25 16:06:14  joergr
+ * Adapted code for new approach to access individual frames of a DICOM image.
+ *
+ * Revision 1.52  2008-11-18 11:01:28  joergr
+ * Fixed issue with incorrectly encoded overlay planes (wrong values for
+ * OverlayBitsAllocated and OverlayBitPosition).
+ *
+ * Revision 1.51  2008-05-20 10:03:53  joergr
+ * Added new bilinear and bicubic scaling algorithms for image magnification.
+ *
+ * Revision 1.50  2008-05-13 09:54:40  joergr
+ * Added new parameter to writeImageToDataset() in order to affect the planar
+ * configuration of the output image/dataset. Changed behaviour: By default,
+ * the output now uses the same planar configuration as the "original" image
+ * (previously: always color-by-plane).
+ *
+ * Revision 1.49  2007/03/16 11:56:06  joergr
+ * Introduced new flag that allows to select how to handle the BitsPerTableEntry
+ * value in the LUT descriptor (use, ignore or check).
+ *
+ * Revision 1.48  2006/08/15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.47  2006/07/10 10:52:27  joergr
+ * Added support for 32-bit BMP images.
+ *
  * Revision 1.46  2005/12/08 16:47:50  meichel
  * Changed include path schema for all DCMTK header files
  *
