@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomMonochromeInputPixelTemplate (Header)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 16:47:51 $
- *  CVS/RCS Revision: $Revision: 1.33 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:16:26 $
+ *  CVS/RCS Revision: $Revision: 1.40 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,11 +31,12 @@
 #define DIMOIPXT_H
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/ofstd/ofconsol.h"
+
 #include "dcmtk/ofstd/ofbmanip.h"
 #include "dcmtk/ofstd/ofcast.h"
 
 #include "dcmtk/dcmimgle/dimopxt.h"
+#include "dcmtk/dcmimgle/diinpx.h"
 
 
 /*---------------------*
@@ -107,18 +104,12 @@ class DiMonoInputPixelTemplate
                                    const unsigned long ocnt)
     {
         int result = 0;
-        if ((sizeof(T1) <= 2) && (this->InputCount > 3 * ocnt))                     // optimization criteria
+        if ((sizeof(T1) <= 2) && (this->InputCount > 3 * ocnt))               // optimization criteria
         {                                                                     // use LUT for optimization
             lut = new T3[ocnt];
             if (lut != NULL)
             {
-#ifdef DEBUG
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Informationals))
-                {
-                    ofConsole.lockCerr() << "INFO: using optimized routine with additional LUT" << endl;
-                    ofConsole.unlockCerr();
-                }
-#endif
+                DCMIMGLE_DEBUG("using optimized routine with additional LUT");
                 result = 1;
             }
         }
@@ -140,19 +131,14 @@ class DiMonoInputPixelTemplate
                 const int useInputBuffer = (sizeof(T1) == sizeof(T3)) && (this->Count <= input->getCount());
                 if (useInputBuffer)                            // do not copy pixel data, reference them!
                 {
+                    DCMIMGLE_DEBUG("re-using input buffer, do not copy pixel data");
                     this->Data = OFstatic_cast(T3 *, input->getDataPtr());
                     input->removeDataReference();              // avoid double deletion
                 } else
                     this->Data = new T3[this->Count];
                 if (this->Data != NULL)
                 {
-#ifdef DEBUG
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Informationals))
-                    {
-                        ofConsole.lockCerr() << "INFO: using modality routine 'modlut()'" << endl;
-                        ofConsole.unlockCerr();
-                    }
-#endif
+                    DCMIMGLE_DEBUG("applying modality tranformation with LUT (" << mlut->getCount() << " entries)");
                     register T2 value = 0;
                     const T2 firstentry = mlut->getFirstEntry(value);                     // choose signed/unsigned method
                     const T2 lastentry = mlut->getLastEntry(value);
@@ -179,7 +165,7 @@ class DiMonoInputPixelTemplate
                         }
                         const T3 *lut0 = lut - OFstatic_cast(T2, absmin);                 // points to 'zero' entry
                         q = this->Data;
-                        for (i = this->InputCount; i != 0; --i)                                 // apply LUT
+                        for (i = this->InputCount; i != 0; --i)                           // apply LUT
                             *(q++) = *(lut0 + (*(p++)));
                     }
                     if (lut == NULL)                                                      // use "normal" transformation
@@ -217,6 +203,7 @@ class DiMonoInputPixelTemplate
             const int useInputBuffer = (sizeof(T1) == sizeof(T3)) && (this->Count <= input->getCount()) && (input->getPixelStart() == 0);
             if (useInputBuffer)
             {                                              // do not copy pixel data, reference them!
+                DCMIMGLE_DEBUG("re-using input buffer, do not copy pixel data");
                 this->Data = OFstatic_cast(T3 *, input->getDataPtr());
                 input->removeDataReference();              // avoid double deletion
             } else
@@ -234,13 +221,7 @@ class DiMonoInputPixelTemplate
                             *(q++) = OFstatic_cast(T3, *(p++));
                     }
                 } else {
-#ifdef DEBUG
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Informationals))
-                    {
-                        ofConsole.lockCerr() << "INFO: using modality routine 'rescale()'" << endl;
-                        ofConsole.unlockCerr();
-                    }
-#endif
+                    DCMIMGLE_DEBUG("applying modality transformation with rescale slope = " << slope << ", intercept = " << intercept);
                     T3 *lut = NULL;
                     register const T1 *p = pixel + input->getPixelStart();
                     const unsigned long ocnt = OFstatic_cast(unsigned long, input->getAbsMaxRange());  // number of LUT entries
@@ -264,14 +245,14 @@ class DiMonoInputPixelTemplate
                         }
                         const T3 *lut0 = lut - OFstatic_cast(T2, absmin);                 // points to 'zero' entry
                         q = this->Data;
-                        for (i = this->InputCount; i != 0; --i)                                 // apply LUT
+                        for (i = this->InputCount; i != 0; --i)                           // apply LUT
                             *(q++) = *(lut0 + (*(p++)));
                     }
                     if (lut == NULL)                                                      // use "normal" transformation
                     {
                         if (slope == 1.0)
                         {
-                            for (i = this->Count; i != 0; --i)
+                            for (i = this->InputCount; i != 0; --i)
                                 *(q++) = OFstatic_cast(T3, OFstatic_cast(double, *(p++)) + intercept);
                         } else {
                             if (intercept == 0.0)
@@ -299,6 +280,28 @@ class DiMonoInputPixelTemplate
  *
  * CVS/RCS Log:
  * $Log: dimoipxt.h,v $
+ * Revision 1.40  2010-10-14 13:16:26  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.39  2010-03-01 09:08:47  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.38  2009-11-25 16:07:12  joergr
+ * Removed inclusion of header file "ofconsol.h". Revised logging messages.
+ *
+ * Revision 1.37  2009-10-28 14:38:16  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.36  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.35  2008-04-09 11:02:08  joergr
+ * Fixed wrong use of variable in "for" loop which might cause a crash.
+ *
+ * Revision 1.34  2006/08/15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.33  2005/12/08 16:47:51  meichel
  * Changed include path schema for all DCMTK header files
  *
