@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomMonochromePixelTemplate (Header)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 16:47:56 $
- *  CVS/RCS Revision: $Revision: 1.27 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:16:26 $
+ *  CVS/RCS Revision: $Revision: 1.34 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,17 +31,12 @@
 #define DIMOPXT_H
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/ofstd/ofconsol.h"
+
 #include "dcmtk/ofstd/ofbmanip.h"
 #include "dcmtk/ofstd/ofcast.h"
 
-#include "dcmtk/dcmdata/dctypes.h"
-#include "dcmtk/dcmdata/dcdefine.h"
-
-#include "dcmtk/dcmimgle/dimopx.h"
 #include "dcmtk/dcmimgle/dipxrept.h"
-#include "dcmtk/dcmimgle/dimomod.h"
-#include "dcmtk/dcmimgle/diinpx.h"
+#include "dcmtk/dcmimgle/dimopx.h"
 #include "dcmtk/dcmimgle/dimoopx.h"
 
 
@@ -281,12 +272,8 @@ class DiMonoPixelTemplate
                     if ((Data[i] >= MinValue[0]) && (Data[i] <= MaxValue[0]))       // only for stability !
                         ++quant[OFstatic_cast(Uint32, Data[i] - MinValue[0])];      // count values
 #ifdef DEBUG
-                    else if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                    {
-                        ofConsole.lockCerr() << "WARNING: invalid value (" << Data[i] << ") in "
-                                             << "int DiMonoPixelTemplate<T>::getHistogramWindow() ! " << endl;
-                        ofConsole.unlockCerr();
-                    }
+                    else
+                        DCMIMGLE_WARN("invalid value (" << Data[i] << ") in DiMonoPixelTemplate<T>::getHistogramWindow()");
 #endif
                 }
                 const Uint32 threshvalue = OFstatic_cast(Uint32, thresh * OFstatic_cast(double, Count));
@@ -350,7 +337,7 @@ class DiMonoPixelTemplate
         MaxValue[1] = 0;
     }
 
-    /** determine minimum and maximum pixelvalues
+    /** determine minimum and maximum pixel values
      *
      ** @param  minvalue  starting global minimum value (0 = invalid)
      *  @param  maxvalue  starting global maximum value (0 = invalid)
@@ -367,6 +354,7 @@ class DiMonoPixelTemplate
             {
                 if ((minvalue == 0) && (maxvalue == 0))
                 {
+                    DCMIMGLE_DEBUG("determining global minimum and maximum pixel values for monochrome image");
                     register T *p = Data;
                     register T value = *p;
                     register unsigned long i;
@@ -391,6 +379,7 @@ class DiMonoPixelTemplate
             }
             if (mode & 0x2)
             {
+                DCMIMGLE_DEBUG("determining next minimum and maximum pixel values for monochrome image");
                 register T *p = Data;
                 register T value;
                 register int firstmin = 1;
@@ -439,6 +428,29 @@ class DiMonoPixelTemplate
  *
  * CVS/RCS Log:
  * $Log: dimopxt.h,v $
+ * Revision 1.34  2010-10-14 13:16:26  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.33  2010-03-01 09:08:47  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.32  2009-11-25 16:09:22  joergr
+ * Removed inclusion of header file "ofconsol.h". Added more logging messages.
+ *
+ * Revision 1.31  2009-10-28 14:38:17  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.30  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.29  2009-09-28 13:27:30  joergr
+ * Moved general purpose definition file from module dcmdata to ofstd, and
+ * added new defines in order to make the usage easier.
+ *
+ * Revision 1.28  2006/08/15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.27  2005/12/08 16:47:56  meichel
  * Changed include path schema for all DCMTK header files
  *
