@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomImage-Interface (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:42 $
- *  CVS/RCS Revision: $Revision: 1.26 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-11-01 08:55:56 $
+ *  CVS/RCS Revision: $Revision: 1.37 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,6 +28,7 @@
 
 
 #include "dcmtk/config/osconfig.h"
+
 #include "dcmtk/dcmdata/dctypes.h"
 #include "dcmtk/dcmdata/dcdeftag.h"
 #include "dcmtk/dcmdata/dcobject.h"
@@ -189,7 +186,6 @@ DicomImage::~DicomImage()
 
 /*********************************************************************/
 
-
 // --- initialize 'DicomImage' object (same procedure for every 'real' constructor)
 
 void DicomImage::Init()
@@ -197,7 +193,7 @@ void DicomImage::Init()
     if ((Document != NULL) && (Document->good()))
     {
         const char *str;
-        if (hasSOPclassUID(UID_StandaloneOverlayStorage))
+        if (hasSOPclassUID(UID_RETIRED_StandaloneOverlayStorage))
         {
             PhotometricInterpretation = EPI_Monochrome2;            // standalone overlays are handled like monochrome
             Image = new DiOverlayImage(Document, ImageStatus);      // images without pixel data
@@ -207,28 +203,32 @@ void DicomImage::Init()
             PhotometricInterpretation = EPI_Monochrome2;            // default for presentation states
             Image = new DiMono2Image(Document, ImageStatus);
         }
-        else if (Document->getValue(DCM_PhotometricInterpretation, str))
+        else if (strlen(str = Document->getPhotometricInterpretation()) > 0)
         {
+            const SP_Interpretation *pin = PhotometricInterpretationNames;
             char *cstr = new char[strlen(str) + 1];
             if (cstr != NULL)
             {
                 char *q = cstr;
-                for (const char *p = str; *p != 0; p++)             // remove invalid chars
+                unsigned char c;
+                for (const char *p = str; *p != 0; p++)    // remove invalid chars
                 {
-                    if (isalpha(*p))
-                        *(q++) = toupper(*p);
-                    else if (isdigit(*p))
-                        *(q++) = *p;
+                    c = OFstatic_cast(unsigned char, *p);
+                    if (isalpha(c))
+                        *(q++) = toupper(c);
+                    else if (isdigit(c))
+                        *(q++) = c;
                 }
-                *q = '\0';                                          // end of c-string
-            }
-            else
-                cstr = OFconst_cast(char *, str);
-            const SP_Interpretation *pin = PhotometricInterpretationNames;
-            while ((pin->Name != NULL) && (strcmp(pin->Name, cstr) != 0))
-                ++pin;
-            if (cstr != str)
+                *q = '\0';                                          // end of C string
+                while ((pin->Name != NULL) && (strcmp(pin->Name, cstr) != 0))
+                    ++pin;
                 delete[] cstr;
+            } else {
+                DCMIMGLE_WARN("can't create filtered version of 'PhotometricInterpretation' (" << str << ")");
+                cstr = OFconst_cast(char *, str);                   // just reference the original string
+                while ((pin->DefinedTerm != NULL) && (strcmp(pin->DefinedTerm, cstr) != 0))
+                    ++pin;
+            }
             PhotometricInterpretation = pin->Type;                  // unknown if last entry
             switch (PhotometricInterpretation)
             {
@@ -246,36 +246,23 @@ void DicomImage::Init()
                         if (PhotometricInterpretation == EPI_Unknown)
                         {
                             ImageStatus = EIS_InvalidValue;
-                            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                            {
-                                ofConsole.lockCerr() << "ERROR: invalid value for 'PhotometricInterpretation' (" << str << ") !" << endl;
-                                ofConsole.unlockCerr();
-                            }
+                            DCMIMGLE_ERROR("invalid value for 'PhotometricInterpretation' (" << str << ")");
                         } else {
                             ImageStatus = EIS_NotSupportedValue;
-                            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                            {
-                                ofConsole.lockCerr() << "ERROR: unsupported value for 'PhotometricInterpretation' (" << str << ") !" << endl
-                                                     << "       library 'dcmimage' required to handle color images !" << endl;
-                                ofConsole.unlockCerr();
-                            }
+                            DCMIMGLE_ERROR("unsupported value for 'PhotometricInterpretation' (" << str << ")");
                         }
                     }
             }
         }
-        else if (Document->getFlags() & CIF_AcrNemaCompatibility)    // ACR-NEMA has no 'photometric interpretation'
+        else if (Document->getFlags() & CIF_AcrNemaCompatibility)   // ACR-NEMA has no 'photometric interpretation'
         {
             PhotometricInterpretation = EPI_Monochrome2;
             Image = new DiMono2Image(Document, ImageStatus);
-        }
-        else
-        {
+        } else {
             ImageStatus = EIS_MissingAttribute;
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: mandatory attribute 'PhotometricInterpretation' is missing !" << endl;
-                ofConsole.unlockCerr();
-            }
+            PhotometricInterpretation = EPI_Missing;
+            if (Document->getPixelData() != NULL)
+                DCMIMGLE_ERROR("mandatory attribute 'PhotometricInterpretation' is missing or can't be determined");
         }
     }
     else
@@ -290,11 +277,7 @@ int DicomImage::checkDataDictionary()
     if (!dcmDataDict.isDictionaryLoaded())
     {
         ImageStatus = EIS_NoDataDictionary;
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: can't load data dictionary !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("can't load data dictionary");
     }
     return ImageStatus == EIS_Normal;
 }
@@ -316,9 +299,9 @@ const char *DicomImage::getString(const EI_Status status)
       case EIS_MissingAttribute:
         return "Missing attribute";
       case EIS_InvalidValue:
-        return "Invalid data value";
+        return "Invalid element value";
       case EIS_NotSupportedValue:
-        return "Unsupported data value";
+        return "Unsupported element value";
       case EIS_MemoryFailure:
         return "Out of memory";
       case EIS_InvalidImage:
@@ -333,9 +316,9 @@ const char *DicomImage::getString(const EI_Status status)
 const char *DicomImage::getString(const EP_Interpretation interpret)
 {
     const SP_Interpretation *pin = PhotometricInterpretationNames;
-    while ((pin->Name != NULL) && (pin->Type != interpret))
+    while ((pin->DefinedTerm != NULL) && (pin->Type != interpret))
         ++pin;
-    return pin->Name;
+    return pin->DefinedTerm;
 }
 
 
@@ -422,48 +405,47 @@ DicomImage *DicomImage::createScaledImage(const signed long left_pos,
     const unsigned long gh = getHeight();
     if ((Image != NULL) && (gw > 0) && (gh > 0))
     {
-        if (clip_width == 0)                                         // set 'width' if parameter is missing
+        if ((clip_width == 0) && (left_pos < OFstatic_cast(signed long, gw)))  // set 'width' if parameter is missing
             clip_width = gw - left_pos;
-        if (clip_height == 0)                                        // same for 'height'
+        if ((clip_height == 0) && (top_pos < OFstatic_cast(signed long, gh)))  // same for 'height'
             clip_height = gh - top_pos;
         if ((scale_width == 0) && (scale_height == 0))
         {
             scale_width = clip_width;                                // auto-set width/height
             scale_height = clip_height;
         }
-        if (aspect)                                                  // maintain pixel aspect ratio
+        else if ((clip_width > 0) && (clip_height > 0))
         {
-            if (scale_width == 0)
-                scale_width = OFstatic_cast(unsigned long, getWidthHeightRatio() * OFstatic_cast(double, scale_height * gw) / gh);
-            else if (scale_height == 0)
-                scale_height = OFstatic_cast(unsigned long, getHeightWidthRatio() * OFstatic_cast(double, scale_width * gh) / gw);
-            else
-                aspect = 0;                                           // ignore pixel aspect ratio
-        }
-        else                                                          // ignore pixel aspect ratio
-        {
-            if (scale_width == 0)
-                scale_width = OFstatic_cast(unsigned long, OFstatic_cast(double, scale_height * gw) / gh);
-            else if (scale_height == 0)
-                scale_height = OFstatic_cast(unsigned long, OFstatic_cast(double, scale_width * gh) / gw);
+            if (aspect)                                              // maintain pixel aspect ratio
+            {
+                if (scale_width == 0)
+                    scale_width = OFstatic_cast(unsigned long, getWidthHeightRatio() * OFstatic_cast(double, scale_height * clip_width) / clip_height);
+                else if (scale_height == 0)
+                    scale_height = OFstatic_cast(unsigned long, getHeightWidthRatio() * OFstatic_cast(double, scale_width * clip_height) / clip_width);
+                else
+                    aspect = 0;                                      // ignore pixel aspect ratio
+            }
+            else                                                     // ignore pixel aspect ratio
+            {
+                if (scale_width == 0)
+                    scale_width = OFstatic_cast(unsigned long, OFstatic_cast(double, scale_height * clip_width) / clip_height);
+                else if (scale_height == 0)
+                    scale_height = OFstatic_cast(unsigned long, OFstatic_cast(double, scale_width * clip_height) / clip_width);
+            }
         }
         const unsigned long maxvalue = DicomImageClass::maxval(bitsof(Uint16));
         if (scale_width > maxvalue)
-            scale_width = maxvalue;                                   // limit 'width' to maximum value (65535)
+            scale_width = maxvalue;                                  // limit 'width' to maximum value (65535)
         if (scale_height > maxvalue)
-            scale_height = maxvalue;                                  // same for 'height'
+            scale_height = maxvalue;                                 // same for 'height'
 
         /* need to limit clipping region ... !? */
 
-        if (((left_pos < 0) || (top_pos < 0) || (OFstatic_cast(unsigned long, left_pos + clip_width) > gw) ||
-            (OFstatic_cast(unsigned long, top_pos + clip_height) > gh)) &&
+        if (((left_pos < 0) || (OFstatic_cast(unsigned long, left_pos + clip_width) > gw) ||
+            (top_pos < 0) || (OFstatic_cast(unsigned long, top_pos + clip_height) > gh)) &&
             ((clip_width != scale_width) || (clip_height != scale_height)))
         {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: combined clipping & scaling outside image boundaries not yet supported !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("combined clipping & scaling outside image boundaries not yet supported");
         }
         else if ((scale_width > 0) && (scale_height > 0))
         {
@@ -496,9 +478,9 @@ DicomImage *DicomImage::createScaledImage(const signed long left_pos,
     {
         const unsigned long gw = getWidth();
         const unsigned long gh = getHeight();
-        if (width == 0)                                     // set 'width' if parameter is missing (0)
+        if ((width == 0) && (left_pos < OFstatic_cast(signed long, gw)))  // set 'width' if parameter is missing (0)
             width = gw - left_pos;
-        if (height == 0)                                    // same for 'height'
+        if ((height == 0) && (top_pos < OFstatic_cast(signed long, gh)))  // same for 'height'
             height = gh - top_pos;
         return createScaledImage(left_pos, top_pos, width, height, OFstatic_cast(unsigned long, xfactor * width),
             OFstatic_cast(unsigned long, yfactor * height), interpolate, aspect, pvalue);
@@ -690,7 +672,7 @@ int DicomImage::writePPM(const char *filename,
 
 // --- same for C++ 'ostream'
 
-int DicomImage::writePPM(ostream &stream,
+int DicomImage::writePPM(STD_NAMESPACE ostream& stream,
                          const int bits,
                          const unsigned long frame)
 {
@@ -752,7 +734,8 @@ int DicomImage::writeBMP(const char *filename,
                          const int bits,
                          const unsigned long frame)
 {
-    if ((filename != NULL) && (Image != NULL) && ((bits == 0) || ((bits == 8) && isMonochrome()) || (bits == 24)))
+    if ((filename != NULL) && (Image != NULL) &&
+        ((bits == 0) || ((bits == 8) && isMonochrome()) || (bits == 24) || (bits == 32)))
     {
         char fname[FILENAME_MAX + 1];
         if (sprintf(fname, filename, frame) >= 0)           // replace '%d' etc. with frame number
@@ -775,8 +758,11 @@ int DicomImage::writeBMP(FILE *stream,
                          const int bits,
                          const unsigned long frame)
 {
-    if ((stream != NULL) && (Image != NULL) && ((bits == 0) || ((bits == 8) && isMonochrome()) || (bits == 24)))
+    if ((stream != NULL) && (Image != NULL) &&
+        ((bits == 0) || ((bits == 8) && isMonochrome()) || (bits == 24) || (bits == 32)))
+    {
         return Image->writeBMP(stream, frame, bits);
+    }
     return 0;
 }
 
@@ -820,6 +806,44 @@ int DicomImage::writePluginFormat(const DiPluginFormat *plugin,
  *
  * CVS/RCS Log:
  * $Log: dcmimage.cc,v $
+ * Revision 1.37  2010-11-01 08:55:56  uli
+ * Moved variable declarations in front of their loop.
+ *
+ * Revision 1.36  2010-10-20 07:41:35  uli
+ * Made sure isalpha() & friends are only called with valid arguments.
+ *
+ * Revision 1.35  2010-10-14 13:14:17  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.34  2010-09-24 13:25:41  joergr
+ * Compared names of SOP Class UIDs with 2009 edition of the DICOM standard. The
+ * resulting name changes are mainly caused by the fact that the corresponding
+ * SOP Class is now retired.
+ *
+ * Revision 1.33  2009-11-25 16:33:23  joergr
+ * Adapted code for new approach to access individual frames of a DICOM image.
+ * The getString() method now returns the Defined Term of the attribute
+ * PhotometricInterpretation.
+ *
+ * Revision 1.32  2009-10-28 14:26:01  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.31  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.30  2008-05-20 15:27:51  joergr
+ * Added more checks on parameters for combined scaling and clipping.
+ *
+ * Revision 1.29  2008-05-20 10:01:33  joergr
+ * Fixed issue with wrong image aspect ratio in combined scaling/clipping mode.
+ *
+ * Revision 1.28  2006/08/15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.27  2006/07/10 10:54:26  joergr
+ * Added support for 32-bit BMP images.
+ *
  * Revision 1.26  2005/12/08 15:42:42  meichel
  * Changed include path schema for all DCMTK header files
  *
