@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomCIELABFunction (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:44 $
- *  CVS/RCS Revision: $Revision: 1.21 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:17 $
+ *  CVS/RCS Revision: $Revision: 1.27 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,11 +28,12 @@
 
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/ofstd/ofconsol.h"
+
 #include "dcmtk/dcmimgle/diciefn.h"
 #include "dcmtk/ofstd/ofstream.h"
 
 #define INCLUDE_CMATH
+#define INCLUDE_CSTRING
 #include "dcmtk/ofstd/ofstdinc.h"
 
 
@@ -51,11 +48,7 @@ DiCIELABFunction::DiCIELABFunction(const char *filename,
 {
     if (!Valid)
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: invalid DISPLAY file ... ignoring !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("invalid DISPLAY file ... ignoring");
     }
 }
 
@@ -69,11 +62,7 @@ DiCIELABFunction::DiCIELABFunction(const double *val_tab,             // UNTESTE
 {
     if (!Valid)
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: invalid DISPLAY values ... ignoring !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("invalid DISPLAY values ... ignoring");
     }
 }
 
@@ -88,11 +77,7 @@ DiCIELABFunction::DiCIELABFunction(const Uint16 *ddl_tab,             // UNTESTE
 {
     if (!Valid)
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: invalid DISPLAY values ... ignoring !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("invalid DISPLAY values ... ignoring");
     }
 }
 
@@ -106,11 +91,7 @@ DiCIELABFunction::DiCIELABFunction(const double val_min,
 {
     if (!Valid)
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: invalid DISPLAY values ... ignoring !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("invalid DISPLAY values ... ignoring");
     }
 }
 
@@ -161,24 +142,24 @@ int DiCIELABFunction::writeCurveData(const char *filename,
 {
     if ((filename != NULL) && (strlen(filename) > 0))
     {
-        ofstream file(filename);
+        STD_NAMESPACE ofstream file(filename);
         if (file)
         {
             const OFBool inverseLUT = (DeviceType == EDT_Scanner) || (DeviceType == EDT_Camera);
             /* comment header */
-            file << "# Display function       : CIELAB" << endl;
+            file << "# Display function       : CIELAB" << OFendl;
             if (DeviceType == EDT_Printer)
-                file << "# Type of output device  : Printer (hardcopy)" << endl;
+                file << "# Type of output device  : Printer (hardcopy)" << OFendl;
             else if (DeviceType == EDT_Scanner)
-                file << "# Type of output device  : Scanner (hardcopy)" << endl;
+                file << "# Type of output device  : Scanner (hardcopy)" << OFendl;
             else if (DeviceType == EDT_Camera)
-                file << "# Type of output device  : Camera (softcopy)" << endl;
+                file << "# Type of output device  : Camera (softcopy)" << OFendl;
             else
-                file << "# Type of output device  : Monitor (softcopy)" << endl;
-            file << "# Device driving levels  : " << ValueCount << endl;
+                file << "# Type of output device  : Monitor (softcopy)" << OFendl;
+            file << "# Device driving levels  : " << ValueCount << OFendl;
             if ((DeviceType == EDT_Printer) || (DeviceType == EDT_Scanner))
-                file << "# Illumination  [cd/m^2] : " << Illumination << endl;
-            file << "# Ambient light [cd/m^2] : " << AmbientLight << endl;
+                file << "# Illumination  [cd/m^2] : " << Illumination << OFendl;
+            file << "# Ambient light [cd/m^2] : " << AmbientLight << OFendl;
             if ((DeviceType == EDT_Printer) || (DeviceType == EDT_Scanner))
             {
                 const double min_lum = getMinLuminanceValue();
@@ -199,7 +180,7 @@ int DiCIELABFunction::writeCurveData(const char *filename,
                         file << "n/s";
                     file << ")";
                 }
-                file << endl;
+                file << OFendl;
                 file << "# Optical density   [OD] : " << MinValue << " - " << MaxValue;
                 if ((MinDensity >= 0) || (MaxDensity >= 0))
                 {
@@ -215,28 +196,28 @@ int DiCIELABFunction::writeCurveData(const char *filename,
                         file << "n/s";
                     file << ")";
                 }
-                file << endl;
+                file << OFendl;
             } else
-                file << "# Luminance w/o [cd/m^2] : " << MinValue << " - " << MaxValue << endl;
+                file << "# Luminance w/o [cd/m^2] : " << MinValue << " - " << MaxValue << OFendl;
             file << "# Interpolation method   : ";
             if (getPolynomialOrder() > 0)
-                file << "Curve fitting algorithm with order " << getPolynomialOrder() << endl << endl;
+                file << "Curve fitting algorithm with order " << getPolynomialOrder() << OFendl << OFendl;
             else
-                file << "Cubic spline interpolation" << endl << endl;
+                file << "Cubic spline interpolation" << OFendl << OFendl;
             /* print headings of the table */
             if (mode)
             {
                 file << "# NB: values for CC, CIELAB and PSC";
                 if (inverseLUT)
                     file << "'";                // add ' to PSC
-                file << " are specified in cd/m^2" << endl << endl;
+                file << " are specified in cd/m^2" << OFendl << OFendl;
                 file << "DDL\tCC\tCIELAB\tPSC";
                 if (inverseLUT)
                     file << "'";                // add ' to PSC
-                file << endl;
+                file << OFendl;
             } else {
-                file << "# NB: values for CC and CIELAB are specified in cd/m^2" << endl << endl;
-                file << "DDL\tCIELAB" << endl;
+                file << "# NB: values for CC and CIELAB are specified in cd/m^2" << OFendl << OFendl;
+                file << "DDL\tCIELAB" << OFendl;
             }
             /* create CIELAB LUT and write curve data to file */
             DiCIELABLUT *lut = NULL;
@@ -271,6 +252,25 @@ int DiCIELABFunction::writeCurveData(const char *filename,
  *
  * CVS/RCS Log:
  * $Log: diciefn.cc,v $
+ * Revision 1.27  2010-10-14 13:14:17  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.26  2010-06-25 09:15:19  uli
+ * Fixed issues with compiling with HAVE_STD_STRING.
+ *
+ * Revision 1.25  2009-11-25 16:11:03  joergr
+ * Removed inclusion of header file "ofconsol.h".
+ *
+ * Revision 1.24  2009-10-28 14:26:01  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.23  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.22  2006-08-15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.21  2005/12/08 15:42:44  meichel
  * Changed include path schema for all DCMTK header files
  *
