@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomCIELABLUT (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:45 $
- *  CVS/RCS Revision: $Revision: 1.22 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:17 $
+ *  CVS/RCS Revision: $Revision: 1.27 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -33,7 +29,6 @@
 
 #include "dcmtk/config/osconfig.h"
 
-#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/dcmimgle/dicielut.h"
 
 #define INCLUDE_CMATH
@@ -55,28 +50,16 @@ DiCIELABLUT::DiCIELABLUT(const unsigned long count,
                          const double lum_max,
                          const double amb,
                          const OFBool inverse,
-                         ostream *stream,
+                         STD_NAMESPACE ostream *stream,
                          const OFBool printMode)
   : DiDisplayLUT(count, max, amb /*, 'illum' not used*/)
 {
     if ((Count > 0) && (Bits > 0))
     {
-#ifdef DEBUG
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Informationals))
-        {
-            ofConsole.lockCerr() << "INFO: new CIELAB LUT with " << Bits << " bits output and "
-                                 << Count << " entries created !" << endl;
-            ofConsole.unlockCerr();
-        }
-#endif
+        DCMIMGLE_DEBUG("new CIELAB LUT with " << Bits << " bits output and " << Count << " entries created");
         if (val_min >= val_max)
         {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: invalid value range for CIELAB LUT creation ("
-                                     << val_min << " - " << val_max << ") !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("invalid value range for CIELAB LUT creation (" << val_min << " - " << val_max << ")");
         }
         /* create the lookup table */
         Valid = createLUT(ddl_tab, val_tab, ddl_cnt, val_min, val_max, lum_min, lum_max,
@@ -105,7 +88,7 @@ int DiCIELABLUT::createLUT(const Uint16 *ddl_tab,
                            const double lum_min,
                            const double lum_max,
                            const OFBool inverse,
-                           ostream *stream,
+                           STD_NAMESPACE ostream *stream,
                            const OFBool printMode)
 {
     int status = 0;
@@ -196,7 +179,7 @@ int DiCIELABLUT::createLUT(const Uint16 *ddl_tab,
                         for (i = 0; i < ddl_cnt; ++i)
                         {
                             (*stream) << ddl_tab[i];                               // DDL
-                            stream->setf(ios::fixed, ios::floatfield);
+                            stream->setf(STD_NAMESPACE ios::fixed, STD_NAMESPACE ios::floatfield);
                             if (printMode)
                                 (*stream) << "\t" << val_tab[i] + amb;             // CC
                             (*stream) << "\t" << cielab[i];                        // CIELAB
@@ -207,14 +190,10 @@ int DiCIELABLUT::createLUT(const Uint16 *ddl_tab,
                                 else
                                     (*stream) << "\t" << val_tab[Data[i]] + amb;   // PSC
                             }
-                            (*stream) << endl;
+                            (*stream) << OFendl;
                         }
                     } else {
-                        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                        {
-                            ofConsole.lockCerr() << "WARNING: can't write curve data, wrong DISPLAY file or CIELAB LUT !" << endl;
-                            ofConsole.unlockCerr();
-                        }
+                        DCMIMGLE_WARN("can't write curve data, wrong DISPLAY file or CIELAB LUT");
                     }
                 }
                 status = 1;
@@ -230,6 +209,22 @@ int DiCIELABLUT::createLUT(const Uint16 *ddl_tab,
  *
  * CVS/RCS Log:
  * $Log: dicielut.cc,v $
+ * Revision 1.27  2010-10-14 13:14:17  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.26  2009-11-25 16:11:03  joergr
+ * Removed inclusion of header file "ofconsol.h".
+ *
+ * Revision 1.25  2009-10-28 14:26:01  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.24  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.23  2006-08-15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.22  2005/12/08 15:42:45  meichel
  * Changed include path schema for all DCMTK header files
  *
