@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomDisplayFunction (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:47 $
- *  CVS/RCS Revision: $Revision: 1.44 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-10-20 07:41:35 $
+ *  CVS/RCS Revision: $Revision: 1.51 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,11 +28,12 @@
 
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/ofstd/ofconsol.h"
+
 #include "dcmtk/ofstd/ofbmanip.h"
 #include "dcmtk/dcmimgle/didispfn.h"
 #include "dcmtk/dcmimgle/displint.h"
 #include "dcmtk/dcmimgle/dicrvfit.h"
+#include "dcmtk/dcmimgle/didislut.h"
 #include "dcmtk/ofstd/ofstream.h"
 
 #define INCLUDE_CCTYPE
@@ -347,9 +344,9 @@ int DiDisplayFunction::readConfigFile(const char *filename)
     if ((filename != NULL) && (strlen(filename) > 0))
     {
 #ifdef HAVE_IOS_NOCREATE
-        ifstream file(filename, ios::in|ios::nocreate);
+        STD_NAMESPACE ifstream file(filename, STD_NAMESPACE ios::in | STD_NAMESPACE ios::nocreate);
 #else
-        ifstream file(filename, ios::in);
+        STD_NAMESPACE ifstream file(filename, STD_NAMESPACE ios::in);
 #endif
         if (file)
         {
@@ -360,7 +357,7 @@ int DiDisplayFunction::readConfigFile(const char *filename)
                 {
                     while (file.get(c) && (c != '\n') && (c != '\r'));      // skip comments
                 }
-                else if (!isspace(c))                                       // skip whitespaces
+                else if (!isspace(OFstatic_cast(unsigned char, c)))         // skip whitespaces
                 {
                     file.putback(c);
                     if (MaxDDLValue == 0)                                   // read maxvalue
@@ -377,19 +374,11 @@ int DiDisplayFunction::readConfigFile(const char *filename)
                                 if ((DDLValue == NULL) || (LODValue == NULL))
                                     return 0;
                             } else {
-                                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                                {
-                                    ofConsole.lockCerr() << "ERROR: invalid or missing value for maximum DDL value in DISPLAY file !" << endl;
-                                    ofConsole.unlockCerr();
-                                }
+                                DCMIMGLE_ERROR("invalid or missing value for maximum DDL value in DISPLAY file");
                                 return 0;                                   // abort
                             }
                         } else {
-                            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                            {
-                                ofConsole.lockCerr() << "ERROR: missing keyword 'max' for maximum DDL value in DISPLAY file !" << endl;
-                                ofConsole.unlockCerr();
-                            }
+                            DCMIMGLE_ERROR("missing keyword 'max' for maximum DDL value in DISPLAY file");
                             return 0;                                       // abort
                         }
                     }
@@ -402,19 +391,11 @@ int DiDisplayFunction::readConfigFile(const char *filename)
                             file >> AmbientLight;
                             if (AmbientLight < 0)
                             {
-                                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                                {
-                                    ofConsole.lockCerr() << "WARNING: invalid value for ambient light in DISPLAY file ... ignoring !" << endl;
-                                    ofConsole.unlockCerr();
-                                }
+                                DCMIMGLE_WARN("invalid value for ambient light in DISPLAY file ... ignoring");
                                 AmbientLight = 0;
                             }
                         } else {
-                            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                            {
-                                ofConsole.lockCerr() << "ERROR: invalid DISPLAY file ... ignoring !" << endl;
-                                ofConsole.unlockCerr();
-                            }
+                            DCMIMGLE_ERROR("invalid DISPLAY file ... ignoring");
                             return 0;                                       // abort
                         }
                     }
@@ -427,19 +408,11 @@ int DiDisplayFunction::readConfigFile(const char *filename)
                             file >> Illumination;
                             if (Illumination < 0)
                             {
-                                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                                {
-                                    ofConsole.lockCerr() << "WARNING: invalid value for illumination in DISPLAY file ... ignoring !" << endl;
-                                    ofConsole.unlockCerr();
-                                }
+                                DCMIMGLE_WARN("invalid value for illumination in DISPLAY file ... ignoring");
                                 Illumination = 0;
                             }
                         } else {
-                            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                            {
-                                ofConsole.lockCerr() << "ERROR: invalid DISPLAY file ... ignoring !" << endl;
-                                ofConsole.unlockCerr();
-                            }
+                            DCMIMGLE_ERROR("invalid DISPLAY file ... ignoring");
                             return 0;                                       // abort
                         }
                     }
@@ -452,19 +425,11 @@ int DiDisplayFunction::readConfigFile(const char *filename)
                             file >> Order;
                             if (Order < 0)
                             {
-                                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                                {
-                                    ofConsole.lockCerr() << "WARNING: invalid value for polynomial order in DISPLAY file ... ignoring !" << endl;
-                                    ofConsole.unlockCerr();
-                                }
+                                DCMIMGLE_WARN("invalid value for polynomial order in DISPLAY file ... ignoring");
                                 Order = 0;
                             }
                         } else {
-                            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                            {
-                                ofConsole.lockCerr() << "ERROR: invalid DISPLAY file ... ignoring !" << endl;
-                                ofConsole.unlockCerr();
-                            }
+                            DCMIMGLE_ERROR("invalid DISPLAY file ... ignoring");
                             return 0;                                       // abort
                         }
                     } else {
@@ -474,32 +439,16 @@ int DiDisplayFunction::readConfigFile(const char *filename)
                             file >> LODValue[ValueCount];                   // read luminance/OD value
                             if (file.fail())
                             {
-                                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                                {
-                                    ofConsole.lockCerr() << "WARNING: missing luminance/OD value in DISPLAY file ... "
-                                                         << "ignoring last entry !" << endl;
-                                    ofConsole.unlockCerr();
-                                }
+                                DCMIMGLE_WARN("missing luminance/OD value in DISPLAY file ... ignoring last entry");
                             }
                             else if (DDLValue[ValueCount] > MaxDDLValue)
                             {
-                                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                                {
-                                    ofConsole.lockCerr() << "WARNING: DDL value (" << DDLValue[ValueCount]
-                                                         << ") exceeds maximum value ("
-                                                         << MaxDDLValue << ") in DISPLAY file ..." << endl
-                                                         << "         ... ignoring value !" << endl;
-                                    ofConsole.unlockCerr();
-                                }
+                                DCMIMGLE_WARN("DDL value (" << DDLValue[ValueCount] << ") exceeds maximum value ("
+                                    << MaxDDLValue << ") in DISPLAY file ... ignoring value");
                             } else
                                 ++ValueCount;
                         } else {
-                            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                            {
-                                ofConsole.lockCerr() << "WARNING: too many values in DISPLAY file ... "
-                                                     << "ignoring last line(s) !" << endl;
-                                ofConsole.unlockCerr();
-                            }
+                            DCMIMGLE_WARN("too many values in DISPLAY file ... ignoring last line(s)");
                             return 2;
                         }
                     }
@@ -508,18 +457,10 @@ int DiDisplayFunction::readConfigFile(const char *filename)
             if ((MaxDDLValue > 0) && (ValueCount > 0))
                 return ((DDLValue != NULL) && (LODValue != NULL));
             else {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid DISPLAY file ... ignoring !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_WARN("invalid DISPLAY file ... ignoring");
             }
         } else {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-            {
-                ofConsole.lockCerr() << "WARNING: can't open DISPLAY file ... ignoring !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_WARN("can't open DISPLAY file ... ignoring");
         }
     }
     return 0;
@@ -565,11 +506,7 @@ int DiDisplayFunction::createSortedTable(const Uint16 *ddl_tab,
                     ++i;
                 if (i < ValueCount)
                 {
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                    {
-                        ofConsole.lockCerr() << "WARNING: OD values (ordered by DDLs) don't descend monotonously !" << endl;
-                        ofConsole.unlockCerr();
-                    }
+                    DCMIMGLE_WARN("OD values (ordered by DDLs) don't descend monotonously");
                 }
             } else {
                 /* softcopy device: check for monotonous ascending luminance values */
@@ -577,11 +514,7 @@ int DiDisplayFunction::createSortedTable(const Uint16 *ddl_tab,
                     ++i;
                 if (i < ValueCount)
                 {
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                    {
-                        ofConsole.lockCerr() << "WARNING: luminance values (ordered by DDLs) don't ascend monotonously !" << endl;
-                        ofConsole.unlockCerr();
-                    }
+                    DCMIMGLE_WARN("luminance values (ordered by DDLs) don't ascend monotonously");
                 }
             }
             status = (ValueCount > 0);
@@ -686,12 +619,7 @@ int DiDisplayFunction::checkMinMaxDensity() const
 {
     if ((MinDensity >= 0) && (MaxDensity >= 0) && (MinDensity >= MaxDensity))
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-        {
-            ofConsole.lockCerr() << "WARNING: invalid optical density range (Dmin = " << MinDensity
-                                 << ", Dmax = " << MaxDensity << ") !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_WARN("invalid optical density range (Dmin = " << MinDensity << ", Dmax = " << MaxDensity << ")");
         return 0;
     }
     return 1;
@@ -762,6 +690,28 @@ double DiDisplayFunction::convertODtoLum(const double value,
  *
  * CVS/RCS Log:
  * $Log: didispfn.cc,v $
+ * Revision 1.51  2010-10-20 07:41:35  uli
+ * Made sure isalpha() & friends are only called with valid arguments.
+ *
+ * Revision 1.50  2010-10-14 13:14:17  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.49  2010-03-01 09:08:47  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.48  2009-11-25 16:11:03  joergr
+ * Removed inclusion of header file "ofconsol.h".
+ *
+ * Revision 1.47  2009-10-28 14:26:01  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.46  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.45  2006-08-15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.44  2005/12/08 15:42:47  meichel
  * Changed include path schema for all DCMTK header files
  *
