@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomGSDFunction (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:49 $
- *  CVS/RCS Revision: $Revision: 1.30 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:18 $
+ *  CVS/RCS Revision: $Revision: 1.38 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -33,13 +29,14 @@
 
 #include "dcmtk/config/osconfig.h"
 
-#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/dcmimgle/digsdfn.h"
 #include "dcmtk/dcmimgle/displint.h"
+#include "dcmtk/dcmimgle/digsdlut.h"
 
 #include "dcmtk/ofstd/ofstream.h"
 
 #define INCLUDE_CMATH
+#define INCLUDE_CSTRING
 #include "dcmtk/ofstd/ofstdinc.h"
 
 
@@ -67,11 +64,7 @@ DiGSDFunction::DiGSDFunction(const char *filename,
         Valid = calculateGSDF() && calculateGSDFSpline() && calculateJNDBoundaries();
     if (!Valid)
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: invalid DISPLAY file ... ignoring !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("invalid DISPLAY file ... ignoring");
     }
 }
 
@@ -91,11 +84,7 @@ DiGSDFunction::DiGSDFunction(const double *val_tab,             // UNTESTED !!
         Valid = calculateGSDF() && calculateGSDFSpline() && calculateJNDBoundaries();
     if (!Valid)
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: invalid DISPLAY values ... ignoring !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("invalid DISPLAY values ... ignoring");
     }
 }
 
@@ -116,11 +105,7 @@ DiGSDFunction::DiGSDFunction(const Uint16 *ddl_tab,             // UNTESTED !!
         Valid = calculateGSDF() && calculateGSDFSpline() && calculateJNDBoundaries();
     if (!Valid)
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: invalid DISPLAY values ... ignoring !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("invalid DISPLAY values ... ignoring");
     }
 }
 
@@ -140,11 +125,7 @@ DiGSDFunction::DiGSDFunction(const double val_min,
         Valid = calculateGSDF() && calculateGSDFSpline() && calculateJNDBoundaries();
     if (!Valid)
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: invalid DISPLAY values ... ignoring !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("invalid DISPLAY values ... ignoring");
     }
 }
 
@@ -198,24 +179,24 @@ int DiGSDFunction::writeCurveData(const char *filename,
 {
     if ((filename != NULL) && (strlen(filename) > 0))
     {
-        ofstream file(filename);
+        STD_NAMESPACE ofstream file(filename);
         if (file)
         {
             const OFBool inverseLUT = (DeviceType == EDT_Scanner) || (DeviceType == EDT_Camera);
             /* comment header */
-            file << "# Display function       : GSDF (DICOM Part 14)" << endl;
+            file << "# Display function       : GSDF (DICOM Part 14)" << OFendl;
             if (DeviceType == EDT_Printer)
-                file << "# Type of output device  : Printer (hardcopy)" << endl;
+                file << "# Type of output device  : Printer (hardcopy)" << OFendl;
             else if (DeviceType == EDT_Scanner)
-                file << "# Type of output device  : Scanner (hardcopy)" << endl;
+                file << "# Type of output device  : Scanner (hardcopy)" << OFendl;
             else if (DeviceType == EDT_Camera)
-                file << "# Type of output device  : Camera (softcopy)" << endl;
+                file << "# Type of output device  : Camera (softcopy)" << OFendl;
             else
-                file << "# Type of output device  : Monitor (softcopy)" << endl;
-            file << "# Device driving levels  : " << ValueCount << endl;
+                file << "# Type of output device  : Monitor (softcopy)" << OFendl;
+            file << "# Device driving levels  : " << ValueCount << OFendl;
             if ((DeviceType == EDT_Printer) || (DeviceType == EDT_Scanner))
-                file << "# Illumination  [cd/m^2] : " << Illumination << endl;
-            file << "# Ambient light [cd/m^2] : " << AmbientLight << endl;
+                file << "# Illumination  [cd/m^2] : " << Illumination << OFendl;
+            file << "# Ambient light [cd/m^2] : " << AmbientLight << OFendl;
             if ((DeviceType == EDT_Printer) || (DeviceType == EDT_Scanner))
             {
                 const double min_lum = getMinLuminanceValue();
@@ -236,7 +217,7 @@ int DiGSDFunction::writeCurveData(const char *filename,
                         file << "n/s";
                     file << ")";
                 }
-                file << endl;
+                file << OFendl;
                 file << "# Optical density   [OD] : " << MinValue << " - " << MaxValue;
                 if ((MinDensity >= 0) || (MaxDensity >= 0))
                 {
@@ -252,29 +233,29 @@ int DiGSDFunction::writeCurveData(const char *filename,
                         file << "n/s";
                     file << ")";
                 }
-                file << endl;
+                file << OFendl;
             } else
-                file << "# Luminance w/o [cd/m^2] : " << MinValue << " - " << MaxValue << endl;
-            file << "# Barten JND index range : " << JNDMin << " - " << JNDMax << " (" << (JNDMax - JNDMin) << ")" << endl;
+                file << "# Luminance w/o [cd/m^2] : " << MinValue << " - " << MaxValue << OFendl;
+            file << "# Barten JND index range : " << JNDMin << " - " << JNDMax << " (" << (JNDMax - JNDMin) << ")" << OFendl;
             file << "# Interpolation method   : ";
             if (getPolynomialOrder() > 0)
-                file << "Curve fitting algorithm with order " << getPolynomialOrder() << endl << endl;
+                file << "Curve fitting algorithm with order " << getPolynomialOrder() << OFendl << OFendl;
             else
-                file << "Cubic spline interpolation" << endl << endl;
+                file << "Cubic spline interpolation" << OFendl << OFendl;
             /* print headings of the table */
             if (mode)
             {
                 file << "# NB: values for CC, GSDF and PSC";
                 if (inverseLUT)
                     file << "'";            // add ' to PSC
-                file << " are specified in cd/m^2" << endl << endl;
+                file << " are specified in cd/m^2" << OFendl << OFendl;
                 file << "DDL\tCC\tGSDF\tPSC";
                 if (inverseLUT)
                     file << "'";            // add ' to PSC
-                file << endl;
+                file << OFendl;
             } else {
-                file << "# NB: values for CC and GSDF are specified in cd/m^2" << endl << endl;
-                file << "DDL\tGSDF" << endl;
+                file << "# NB: values for CC and GSDF are specified in cd/m^2" << OFendl << OFendl;
+                file << "DDL\tGSDF" << OFendl;
             }
             /* create GSDF LUT and write curve data to file */
             DiGSDFLUT *lut = NULL;
@@ -460,6 +441,31 @@ double DiGSDFunction::getJNDIndex(const double lum)
  *
  * CVS/RCS Log:
  * $Log: digsdfn.cc,v $
+ * Revision 1.38  2010-10-14 13:14:18  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.37  2010-06-25 09:15:19  uli
+ * Fixed issues with compiling with HAVE_STD_STRING.
+ *
+ * Revision 1.36  2010-03-01 09:08:47  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.35  2009-11-25 16:31:48  joergr
+ * Removed inclusion of header file "ofconsol.h".
+ *
+ * Revision 1.34  2009-10-28 14:26:02  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.33  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.32  2006-08-15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.31  2006/02/03 16:53:14  joergr
+ * Fixed inconsistent source code layout.
+ *
  * Revision 1.30  2005/12/08 15:42:49  meichel
  * Changed include path schema for all DCMTK header files
  *
@@ -562,4 +568,3 @@ double DiGSDFunction::getJNDIndex(const double lum)
  *
  *
  */
-
