@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomGSDFLUT (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:50 $
- *  CVS/RCS Revision: $Revision: 1.21 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:18 $
+ *  CVS/RCS Revision: $Revision: 1.26 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -33,7 +29,6 @@
 
 #include "dcmtk/config/osconfig.h"
 
-#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/dcmimgle/digsdlut.h"
 #include "dcmtk/dcmimgle/displint.h"
 
@@ -60,28 +55,16 @@ DiGSDFLUT::DiGSDFLUT(const unsigned long count,
                      const double amb,
                      const double illum,
                      const OFBool inverse,
-                     ostream *stream,
+                     STD_NAMESPACE ostream *stream,
                      const OFBool printMode)
   : DiDisplayLUT(count, max, amb, illum)
 {
     if ((Count > 0) && (Bits > 0))
     {
-#ifdef DEBUG
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Informationals))
-        {
-            ofConsole.lockCerr() << "INFO: new GSDF LUT with " << Bits << " bits output and "
-                                 << Count << " entries created !" << endl;
-            ofConsole.unlockCerr();
-        }
-#endif
+        DCMIMGLE_DEBUG("new GSDF LUT with " << Bits << " bits output and " << Count << " entries created");
         if (jnd_min >= jnd_max)
         {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: invalid JND range for GSDF LUT creation ("
-                                     << jnd_min << " - " << jnd_max << ") !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("invalid JND range for GSDF LUT creation (" << jnd_min << " - " << jnd_max << ")");
         }
         /* create the lookup table */
         Valid = createLUT(ddl_tab, val_tab, ddl_cnt, gsdf_tab, gsdf_spl, gsdf_cnt,
@@ -113,7 +96,7 @@ int DiGSDFLUT::createLUT(const Uint16 *ddl_tab,
                          const double lum_min,
                          const double lum_max,
                          const OFBool inverse,
-                         ostream *stream,
+                         STD_NAMESPACE ostream *stream,
                          const OFBool printMode)
 {
     /* check for valid parameters */
@@ -210,7 +193,7 @@ int DiGSDFLUT::createLUT(const Uint16 *ddl_tab,
                                     for (i = 0; i < ddl_cnt; ++i)
                                     {
                                         (*stream) << ddl_tab[i];                               // DDL
-                                        stream->setf(ios::fixed, ios::floatfield);
+                                        stream->setf(STD_NAMESPACE ios::fixed, STD_NAMESPACE ios::floatfield);
                                         if (printMode)
                                             (*stream) << "\t" << val_tab[i] + amb;             // CC
                                         (*stream) << "\t" << gsdf[i];                          // GSDF
@@ -221,15 +204,10 @@ int DiGSDFLUT::createLUT(const Uint16 *ddl_tab,
                                             else
                                                 (*stream) << "\t" << val_tab[Data[i]] + amb;   // PSC
                                         }
-                                        (*stream) << endl;
+                                        (*stream) << OFendl;
                                     }
                                 } else {
-                                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                                    {
-                                        ofConsole.lockCerr() << "WARNING: can't write curve data, "
-                                                             << "wrong DISPLAY file or GSDF LUT !" << endl;
-                                        ofConsole.unlockCerr();
-                                    }
+                                    DCMIMGLE_WARN("can't write curve data, wrong DISPLAY file or GSDF LUT");
                                 }
                             }
                             status = 1;
@@ -251,6 +229,22 @@ int DiGSDFLUT::createLUT(const Uint16 *ddl_tab,
  *
  * CVS/RCS Log:
  * $Log: digsdlut.cc,v $
+ * Revision 1.26  2010-10-14 13:14:18  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.25  2009-11-25 16:31:48  joergr
+ * Removed inclusion of header file "ofconsol.h".
+ *
+ * Revision 1.24  2009-10-28 14:26:02  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.23  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.22  2006-08-15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.21  2005/12/08 15:42:50  meichel
  * Changed include path schema for all DCMTK header files
  *
