@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomInputPixel (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:52 $
- *  CVS/RCS Revision: $Revision: 1.8 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:18 $
+ *  CVS/RCS Revision: $Revision: 1.10 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -41,13 +37,17 @@
  *----------------*/
 
 DiInputPixel::DiInputPixel(const unsigned int bits,
-                           const unsigned long start,
-                           const unsigned long count)
+                           const unsigned long first,
+                           const unsigned long number,
+                           const unsigned long fsize)
   : Count(0),
     Bits(bits),
-    PixelStart(start),
-    PixelCount(count),
-    ComputedCount(count),
+    FirstFrame(first),
+    NumberOfFrames(number),
+    FrameSize(fsize),
+    PixelStart(first * fsize),
+    PixelCount(number * fsize),
+    ComputedCount(number * fsize),
     AbsMinimum(0),
     AbsMaximum(0)
 {
@@ -67,6 +67,12 @@ DiInputPixel::~DiInputPixel()
  *
  * CVS/RCS Log:
  * $Log: diinpx.cc,v $
+ * Revision 1.10  2010-10-14 13:14:18  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.9  2009-11-25 16:31:18  joergr
+ * Adapted code for new approach to access individual frames of a DICOM image.
+ *
  * Revision 1.8  2005/12/08 15:42:52  meichel
  * Changed include path schema for all DCMTK header files
  *
