@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2003, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -22,8 +18,8 @@
  *  Purpose: DicomLookupTable (Source)
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2003/12/23 16:03:18 $
- *  CVS/RCS Revision: $Revision: 1.30 $
+ *  Update Date:      $Date: 2010-10-14 13:14:18 $
+ *  CVS/RCS Revision: $Revision: 1.40 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -31,16 +27,17 @@
  */
 
 
-#include "osconfig.h"
-#include "dcdeftag.h"
-#include "dcsequen.h"
-#include "dcitem.h"
+#include "dcmtk/config/osconfig.h"
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcsequen.h"
+#include "dcmtk/dcmdata/dcitem.h"
+#include "dcmtk/dcmdata/dcvrus.h"
 
-#include "ofbmanip.h"
-#include "ofcast.h"
+#include "dcmtk/ofstd/ofbmanip.h"
+#include "dcmtk/ofstd/ofcast.h"
 
-#include "diluptab.h"
-#include "didocu.h"
+#include "dcmtk/dcmimgle/diluptab.h"
+#include "dcmtk/dcmimgle/didocu.h"
 
 
 /*----------------*
@@ -51,14 +48,14 @@ DiLookupTable::DiLookupTable(const DiDocument *docu,
                              const DcmTagKey &descriptor,
                              const DcmTagKey &data,
                              const DcmTagKey &explanation,
-                             const OFBool ignoreDepth,
+                             const EL_BitsPerTableEntry descripMode,
                              EI_Status *status)
   : DiBaseLUT(),
     OriginalBitsAllocated(16),
     OriginalData(NULL)
 {
     if (docu != NULL)
-        Init(docu, NULL, descriptor, data, explanation, ignoreDepth, status);
+        Init(docu, NULL, descriptor, data, explanation, descripMode, status);
 }
 
 
@@ -67,7 +64,7 @@ DiLookupTable::DiLookupTable(const DiDocument *docu,
                              const DcmTagKey &descriptor,
                              const DcmTagKey &data,
                              const DcmTagKey &explanation,
-                             const OFBool ignoreDepth,
+                             const EL_BitsPerTableEntry descripMode,
                              const unsigned long pos,
                              unsigned long *card)
   : DiBaseLUT(),
@@ -78,13 +75,13 @@ DiLookupTable::DiLookupTable(const DiDocument *docu,
     {
         DcmSequenceOfItems *seq = NULL;
         const unsigned long count = docu->getSequence(sequence, seq);
-        /* store number of items in the option return variable */
+        /* store number of items in the optional return variable */
         if (card != NULL)
             *card = count;
         if ((seq != NULL) && (pos < count))
         {
             DcmItem *item = seq->getItem(pos);
-            Init(docu, item, descriptor, data, explanation, ignoreDepth);
+            Init(docu, item, descriptor, data, explanation, descripMode);
         }
     }
 }
@@ -93,7 +90,7 @@ DiLookupTable::DiLookupTable(const DiDocument *docu,
 DiLookupTable::DiLookupTable(const DcmUnsignedShort &data,
                              const DcmUnsignedShort &descriptor,
                              const DcmLongString *explanation,
-                             const OFBool ignoreDepth,
+                             const EL_BitsPerTableEntry descripMode,
                              const signed long first,
                              EI_Status *status)
   : DiBaseLUT(),
@@ -101,41 +98,31 @@ DiLookupTable::DiLookupTable(const DcmUnsignedShort &data,
     OriginalData(NULL)
 {
     Uint16 us = 0;
-    if (DiDocument::getElemValue(OFreinterpret_cast(const DcmElement *, &descriptor), us, 0) >= 3)     // number of LUT entries
+    const DcmElement *descElem = OFreinterpret_cast(const DcmElement *, &descriptor);
+    if (DiDocument::getElemValue(descElem, us, 0, OFTrue /*allowSigned*/) >= 3)         // number of LUT entries
     {
-        Count = (us == 0) ? MAX_TABLE_ENTRY_COUNT : us;                                                // see DICOM supplement 5: "0" => 65536
-        DiDocument::getElemValue(OFreinterpret_cast(const DcmElement *, &descriptor), FirstEntry, 1);  // can be SS or US (will be type casted later)
+        Count = (us == 0) ? MAX_TABLE_ENTRY_COUNT : us;                                 // see DICOM supplement 5: "0" => 65536
+        DiDocument::getElemValue(descElem, FirstEntry, 1, OFTrue /*allowSigned*/);      // can be SS or US (will be type casted later)
         if ((first >= 0) && (FirstEntry != OFstatic_cast(Uint16, first)))
         {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-            {
-                ofConsole.lockCerr() << "WARNING: invalid value for 'First input value mapped' (" << FirstEntry
-                                     << ") ... assuming " << first << " !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_WARN("invalid value for 'FirstInputValueMapped' in lookup table ("
+                << FirstEntry << ") ... assuming " << first);
             FirstEntry = OFstatic_cast(Uint16, first);
         }
-        DiDocument::getElemValue(OFreinterpret_cast(const DcmElement *, &descriptor), us, 2);           // bits per entry (only informational)
+        DiDocument::getElemValue(descElem, us, 2, OFTrue /*allowSigned*/);              // bits per entry (only informational)
         unsigned long count = DiDocument::getElemValue(OFreinterpret_cast(const DcmElement *, &data), Data);
-        OriginalData = OFstatic_cast(void *, OFconst_cast(Uint16 *, Data));                             // store pointer to original data
+        OriginalData = OFstatic_cast(void *, OFconst_cast(Uint16 *, Data));             // store pointer to original data
         if (explanation != NULL)
-            DiDocument::getElemValue(OFreinterpret_cast(const DcmElement *, explanation), Explanation); // explanation (free form text)
-        checkTable(count, us, ignoreDepth, status);
+            DiDocument::getElemValue(OFreinterpret_cast(const DcmElement *, explanation), Explanation);   // explanation (free form text)
+        checkTable(count, us, descripMode, status);
      } else {
         if (status != NULL)
         {
             *status = EIS_MissingAttribute;
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: incomplete or missing 'LookupTableDescriptor' !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("incomplete or missing 'LookupTableDescriptor' " << descriptor.getTag());
         } else {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-            {
-                ofConsole.lockCerr() << "WARNING: incomplete or missing  'LookupTableDescriptor' ... ignoring LUT !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_WARN("incomplete or missing 'LookupTableDescriptor' " << descriptor.getTag()
+                << " ... ignoring LUT");
         }
      }
 }
@@ -169,35 +156,28 @@ void DiLookupTable::Init(const DiDocument *docu,
                          const DcmTagKey &descriptor,
                          const DcmTagKey &data,
                          const DcmTagKey &explanation,
-                         const OFBool ignoreDepth,
+                         const EL_BitsPerTableEntry descripMode,
                          EI_Status *status)
 {
     Uint16 us = 0;
-    if (docu->getValue(descriptor, us, 0, obj) >= 3)                         // number of LUT entries
+    if (docu->getValue(descriptor, us, 0, obj, OFTrue /*allowSigned*/) >= 3)    // number of LUT entries
     {
-        Count = (us == 0) ? MAX_TABLE_ENTRY_COUNT : us;                      // see DICOM supplement 5: "0" => 65536
-        docu->getValue(descriptor, FirstEntry, 1, obj);                      // can be SS or US (will be type casted later)
-        docu->getValue(descriptor, us, 2, obj);                              // bits per entry (only informational)
+        Count = (us == 0) ? MAX_TABLE_ENTRY_COUNT : us;                         // see DICOM supplement 5: "0" => 65536
+        docu->getValue(descriptor, FirstEntry, 1, obj, OFTrue /*allowSigned*/); // can be SS or US (will be type casted later)
+        docu->getValue(descriptor, us, 2, obj, OFTrue /*allowSigned*/);         // bits per entry (only informational)
         unsigned long count = docu->getValue(data, Data, obj);
-        OriginalData = OFstatic_cast(void *, OFconst_cast(Uint16 *, Data));  // store pointer to original data
-        if (explanation != DcmTagKey(0, 0))
-            docu->getValue(explanation, Explanation, 0 /*vm pos*/, obj);     // explanation (free form text)
-        checkTable(count, us, ignoreDepth, status);
+        OriginalData = OFstatic_cast(void *, OFconst_cast(Uint16 *, Data));     // store pointer to original data
+        if (explanation != DCM_UndefinedTagKey)
+            docu->getValue(explanation, Explanation, 0 /*vm pos*/, obj);        // explanation (free form text)
+        checkTable(count, us, descripMode, status);
     } else {
         if (status != NULL)
         {
             *status = EIS_MissingAttribute;
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: incomplete or missing 'LookupTableDescriptor' !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("incomplete or missing 'LookupTableDescriptor' " << descriptor);
         } else {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-            {
-                ofConsole.lockCerr() << "WARNING: incomplete or missing  'LookupTableDescriptor' ... ignoring LUT !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_WARN("incomplete or missing 'LookupTableDescriptor' " << descriptor
+                << " ... ignoring LUT");
         }
     }
 }
@@ -205,7 +185,7 @@ void DiLookupTable::Init(const DiDocument *docu,
 
 void DiLookupTable::checkTable(unsigned long count,
                                Uint16 bits,
-                               const OFBool ignoreDepth,
+                               const EL_BitsPerTableEntry descripMode,
                                EI_Status *status)
 {
     if (count > 0)                                                            // valid LUT
@@ -218,13 +198,7 @@ void DiLookupTable::checkTable(unsigned long count,
             if (count == ((Count + 1) >> 1))                                  // bits allocated 8, ignore padding
             {
                 OriginalBitsAllocated = 8;
-#ifdef DEBUG
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Informationals))
-                {
-                    ofConsole.lockCerr() << "INFO: lookup table uses 8 bits allocated ... converting to 16 bits." << endl;
-                    ofConsole.unlockCerr();
-                }
-#endif
+                DCMIMGLE_DEBUG("lookup table uses 8 bits allocated ... converting to 16 bits");
                 DataBuffer = new Uint16[Count];                               // create new LUT
                 if ((DataBuffer != NULL) && (Data != NULL))
                 {
@@ -232,14 +206,7 @@ void DiLookupTable::checkTable(unsigned long count,
                     register Uint16 *q = DataBuffer;
                     if (gLocalByteOrder == EBO_BigEndian)                     // local machine has big endian byte ordering
                     {
-#ifdef DEBUG
-                        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Informationals))
-                        {
-                            ofConsole.lockCerr() << "INFO: local machine has big endian byte ordering"
-                                                 << " ... swapping 8 bit LUT entries." << endl;
-                            ofConsole.unlockCerr();
-                        }
-#endif
+                        DCMIMGLE_DEBUG("local machine has big endian byte ordering ... swapping 8 bit LUT entries");
                         for (i = count; i != 0; --i)                          // copy 8 bit entries to new 16 bit LUT (swap hi/lo byte)
                         {
                             *(q++) = *(p + 1);                                // copy low byte ...
@@ -253,12 +220,7 @@ void DiLookupTable::checkTable(unsigned long count,
                 }
                 Data = DataBuffer;
             } else {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid value for 'NumberOfTableEntries' (" << Count << ") "
-                                         << "... assuming " << count << " !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_WARN("invalid value for 'NumberOfTableEntries' (" << Count << ") ... assuming " << count);
                 Count = count;
             }
         }
@@ -275,7 +237,7 @@ void DiLookupTable::checkTable(unsigned long count,
                 if (value > MaxValue)                                         // get global maximum
                     MaxValue = value;
             }
-            checkBits(bits, 8, 0, ignoreDepth);                               // set 'Bits'
+            checkBits(bits, 8, 0, descripMode);                               // set 'Bits'
         } else {
             int cmp = 0;
             for (i = Count; i != 0; --i)
@@ -289,9 +251,9 @@ void DiLookupTable::checkTable(unsigned long count,
                     MaxValue = value;
             }
             if (cmp == 0)                                                     // lo-byte is always equal to hi-byte
-                checkBits(bits, MIN_TABLE_ENTRY_SIZE, MAX_TABLE_ENTRY_SIZE, ignoreDepth);  // set 'Bits'
+                checkBits(bits, MIN_TABLE_ENTRY_SIZE, MAX_TABLE_ENTRY_SIZE, descripMode);  // set 'Bits'
             else
-                checkBits(bits, MAX_TABLE_ENTRY_SIZE, MIN_TABLE_ENTRY_SIZE, ignoreDepth);
+                checkBits(bits, MAX_TABLE_ENTRY_SIZE, MIN_TABLE_ENTRY_SIZE, descripMode);
         }
         Uint16 mask = OFstatic_cast(Uint16, DicomImageClass::maxval(Bits));   // mask lo-byte (8) or full word (16)
         if (((MinValue & mask) != MinValue) || ((MaxValue & mask) != MaxValue))
@@ -314,17 +276,9 @@ void DiLookupTable::checkTable(unsigned long count,
         if (status != NULL)
         {
             *status = EIS_InvalidValue;
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: empty 'LookupTableData' attribute !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("empty 'LookupTableData' attribute");
         } else {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-            {
-                ofConsole.lockCerr() << "WARNING: empty 'LookupTableData' attribute ... ignoring LUT !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_WARN("empty 'LookupTableData' attribute ... ignoring LUT");
         }
     }
 }
@@ -336,10 +290,10 @@ void DiLookupTable::checkTable(unsigned long count,
 void DiLookupTable::checkBits(const Uint16 bits,
                               const Uint16 rightBits,
                               const Uint16 wrongBits,
-                              const OFBool ignoreDepth)
+                              const EL_BitsPerTableEntry descripMode)
 {
     /* is stored bit depth out of range? */
-    if (ignoreDepth || (bits < MIN_TABLE_ENTRY_SIZE) || (bits > MAX_TABLE_ENTRY_SIZE))
+    if ((descripMode == ELM_IgnoreValue) || (bits < MIN_TABLE_ENTRY_SIZE) || (bits > MAX_TABLE_ENTRY_SIZE))
     {
         /* check whether correct bit depth can be determined automatically */
         Bits = (MaxValue > 0) ? DicomImageClass::tobits(MaxValue, 0) : bits;
@@ -351,33 +305,18 @@ void DiLookupTable::checkBits(const Uint16 bits,
         /* check whether value has changed? */
         if (bits != Bits)
         {
-            if (ignoreDepth)
+            if (descripMode == ELM_IgnoreValue)
             {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Informationals))
-                {
-                    ofConsole.lockCerr() << "INFO: ignoring value for 'BitsPerTableEntry' (" << bits
-                                         << ") ... using " << Bits << " instead !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_INFO("ignoring value for 'BitsPerTableEntry' (" << bits << ") ... using " << Bits << " instead");
             } else {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: unsuitable value for 'BitsPerTableEntry' (" << bits
-                                         << ") ... valid range " << MIN_TABLE_ENTRY_SIZE << "-"
-                                         << MAX_TABLE_ENTRY_SIZE << ", using " << Bits << " !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_WARN("unsuitable value for 'BitsPerTableEntry' (" << bits << ") ... valid range "
+                    << MIN_TABLE_ENTRY_SIZE << "-" << MAX_TABLE_ENTRY_SIZE << ", using " << Bits);
             }
         }
     }
-    else if (bits == wrongBits)
+    else if ((descripMode == ELM_CheckValue) && (bits == wrongBits))
     {
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-        {
-            ofConsole.lockCerr() << "WARNING: unsuitable value for 'BitsPerTableEntry' (" << bits << ") "
-                                 << "... assuming " << rightBits << " !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_WARN("unsuitable value for 'BitsPerTableEntry' (" << bits << ") ... assuming " << rightBits);
         Bits = rightBits;
     } else {
         /* assuming that the descriptor value is correct! */
@@ -617,6 +556,42 @@ OFBool DiLookupTable::operator==(const DiLookupTable &lut)
  *
  * CVS/RCS Log:
  * $Log: diluptab.cc,v $
+ * Revision 1.40  2010-10-14 13:14:18  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.39  2010-10-06 14:48:47  joergr
+ * Use DCM_UndefinedTagKey if no explanation tag can be specified for a LUT.
+ *
+ * Revision 1.38  2009-11-25 16:38:19  joergr
+ * Fixed issue with LUT Descriptor elements using the value representation SS.
+ * Revised logging messages.
+ *
+ * Revision 1.37  2009-10-28 14:26:02  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.36  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.35  2009-02-26 10:08:10  joergr
+ * Enhanced warning message text.
+ *
+ * Revision 1.34  2007/07/25 15:10:08  joergr
+ * Fixed typo.
+ *
+ * Revision 1.33  2007/03/16 11:52:34  joergr
+ * Introduced new flag that allows to select how to handle the BitsPerTableEntry
+ * value in the LUT descriptor (use, ignore or check).
+ * Fixed problem with wrong interpretation of the palette descriptor in certain
+ * cases. Now the BitsPerTableEntry stored in the LUT descriptor is used by
+ * default. The previous behavior can be enabled using the ELM_CheckValue mode.
+ *
+ * Revision 1.32  2006/08/15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.31  2005/12/08 15:42:53  meichel
+ * Changed include path schema for all DCMTK header files
+ *
  * Revision 1.30  2003/12/23 16:03:18  joergr
  * Replaced post-increment/decrement operators by pre-increment/decrement
  * operators where appropriate (e.g. 'i++' by '++i').
