@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomMonochromeImage (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:42:56 $
- *  CVS/RCS Revision: $Revision: 1.62 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:18 $
+ *  CVS/RCS Revision: $Revision: 1.84 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -79,6 +75,7 @@ DiMonoImage::DiMonoImage(const DiDocument *docu,
     VoiLutCount(0),
     ValidWindow(0),
     VoiExplanation(),
+    VoiLutFunction(EFV_Default),
     PresLutShape(ESP_Default),
     MinDensity(Default_MinDensity),
     MaxDensity(Default_MaxDensity),
@@ -114,6 +111,7 @@ DiMonoImage::DiMonoImage(const DiDocument *docu,
     VoiLutCount(0),
     ValidWindow(0),
     VoiExplanation(),
+    VoiLutFunction(EFV_Default),
     PresLutShape(ESP_Default),
     MinDensity(Default_MinDensity),
     MaxDensity(Default_MaxDensity),
@@ -150,6 +148,7 @@ DiMonoImage::DiMonoImage(const DiDocument *docu,
     VoiLutCount(0),
     ValidWindow(0),
     VoiExplanation(),
+    VoiLutFunction(EFV_Default),
     PresLutShape(ESP_Default),
     MinDensity(Default_MinDensity),
     MaxDensity(Default_MaxDensity),
@@ -188,6 +187,7 @@ DiMonoImage::DiMonoImage(const DiDocument *docu,
     VoiLutCount(0),
     ValidWindow(0),
     VoiExplanation(),
+    VoiLutFunction(EFV_Default),
     PresLutShape(ESP_Default),
     MinDensity(Default_MinDensity),
     MaxDensity(Default_MaxDensity),
@@ -219,6 +219,7 @@ DiMonoImage::DiMonoImage(const DiMonoImage *image,
     VoiLutCount(image->VoiLutCount),
     ValidWindow(image->ValidWindow),
     VoiExplanation(image->VoiExplanation),
+    VoiLutFunction(image->VoiLutFunction),
     PresLutShape(image->PresLutShape),
     MinDensity(image->MinDensity),
     MaxDensity(image->MaxDensity),
@@ -286,6 +287,7 @@ DiMonoImage::DiMonoImage(const DiColorImage *image,
     VoiLutCount(0),
     ValidWindow(0),
     VoiExplanation(),
+    VoiLutFunction(EFV_Default),
     PresLutShape(ESP_Default),
     MinDensity(Default_MinDensity),
     MaxDensity(Default_MaxDensity),
@@ -330,6 +332,7 @@ DiMonoImage::DiMonoImage(const DiMonoImage *image,
     VoiLutCount(image->VoiLutCount),
     ValidWindow(image->ValidWindow),
     VoiExplanation(image->VoiExplanation),
+    VoiLutFunction(image->VoiLutFunction),
     PresLutShape(image->PresLutShape),
     MinDensity(image->MinDensity),
     MaxDensity(image->MaxDensity),
@@ -346,31 +349,38 @@ DiMonoImage::DiMonoImage(const DiMonoImage *image,
     Overlays[1] = NULL;
     if (image->InterData != NULL)
     {
+        const unsigned int bits = image->InterData->getBits();
         switch (image->InterData->getRepresentation())
         {
             case EPR_Uint8:
                 InterData = new DiMonoScaleTemplate<Uint8>(image->InterData, image->Columns, image->Rows,
-                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames, interpolate, pvalue);
+                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames,
+                    bits, interpolate, pvalue);
                 break;
             case EPR_Sint8:
                 InterData = new DiMonoScaleTemplate<Sint8>(image->InterData, image->Columns, image->Rows,
-                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames, interpolate, pvalue);
+                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames,
+                    bits, interpolate, pvalue);
                 break;
             case EPR_Uint16:
                 InterData = new DiMonoScaleTemplate<Uint16>(image->InterData, image->Columns, image->Rows,
-                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames, interpolate, pvalue);
+                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames,
+                    bits, interpolate, pvalue);
                 break;
             case EPR_Sint16:
                 InterData = new DiMonoScaleTemplate<Sint16>(image->InterData, image->Columns, image->Rows,
-                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames, interpolate, pvalue);
+                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames,
+                    bits, interpolate, pvalue);
                 break;
             case EPR_Uint32:
                 InterData = new DiMonoScaleTemplate<Uint32>(image->InterData, image->Columns, image->Rows,
-                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames, interpolate, pvalue);
+                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames,
+                    bits, interpolate, pvalue);
                 break;
             case EPR_Sint32:
                 InterData = new DiMonoScaleTemplate<Sint32>(image->InterData, image->Columns, image->Rows,
-                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames, interpolate, pvalue);
+                    left_pos, top_pos, src_cols, src_rows, dest_cols, dest_rows, NumberOfFrames,
+                    bits, interpolate, pvalue);
                 break;
         }
     }
@@ -407,6 +417,7 @@ DiMonoImage::DiMonoImage(const DiMonoImage *image,
     VoiLutCount(image->VoiLutCount),
     ValidWindow(image->ValidWindow),
     VoiExplanation(image->VoiExplanation),
+    VoiLutFunction(image->VoiLutFunction),
     PresLutShape(image->PresLutShape),
     MinDensity(image->MinDensity),
     MaxDensity(image->MaxDensity),
@@ -473,6 +484,7 @@ DiMonoImage::DiMonoImage(const DiMonoImage *image,
     VoiLutCount(image->VoiLutCount),
     ValidWindow(image->ValidWindow),
     VoiExplanation(image->VoiExplanation),
+    VoiLutFunction(image->VoiLutFunction),
     PresLutShape(image->PresLutShape),
     MinDensity(image->MinDensity),
     MaxDensity(image->MaxDensity),
@@ -544,6 +556,7 @@ DiMonoImage::DiMonoImage(const DiMonoImage &)
     VoiLutCount(0),
     ValidWindow(0),
     VoiExplanation(),
+    VoiLutFunction(EFV_Default),
     PresLutShape(ESP_Default),
     MinDensity(Default_MinDensity),
     MaxDensity(Default_MaxDensity),
@@ -556,11 +569,7 @@ DiMonoImage::DiMonoImage(const DiMonoImage &)
     OutputData(NULL),
     OverlayData(NULL)
 {
-    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-    {
-        ofConsole.lockCerr() << "ERROR in DiMonoImage copy-constructor !!!" << endl;
-        ofConsole.unlockCerr();
-    }
+    DCMIMGLE_FATAL("using unimplemented copy constructor in class DiMonoImage ... aborting");
     abort();
 }
 
@@ -581,6 +590,7 @@ DiMonoImage::DiMonoImage(const DiMonoImage *image,
     VoiLutCount(0),
     ValidWindow(0),
     VoiExplanation(),
+    VoiLutFunction(EFV_Default),
     PresLutShape(ESP_Default),
     MinDensity(Default_MinDensity),
     MaxDensity(Default_MaxDensity),
@@ -643,15 +653,36 @@ DiMonoImage::~DiMonoImage()
 /*********************************************************************/
 
 
-void DiMonoImage::Init(DiMonoModality *modality)
+int DiMonoImage::processNextFrames(const unsigned long fcount)
+{
+    if (DiImage::processNextFrames(fcount))
+    {
+        delete InterData;
+        InterData = NULL;
+        DiMonoModality *modality = new DiMonoModality(Document, InputData);
+        Init(modality, OFTrue /* reuse */);
+        return (ImageStatus == EIS_Normal);
+    }
+    return 0;
+}
+
+/*********************************************************************/
+
+
+void DiMonoImage::Init(DiMonoModality *modality,
+                       const OFBool reuse)
 {
     if (modality != NULL)
     {
-        Overlays[0] = new DiOverlay(Document, BitsAllocated);
-        if ((Overlays[0] != NULL) && !(Document->getFlags() & CIF_UsePresentationState))
-            Overlays[0]->showAllPlanes();                       // default: show all overlays with stored modes
-        if ((Overlays[0] == NULL) || (Overlays[0]->getCount() == 0) || (!Overlays[0]->hasEmbeddedData()))
-            detachPixelData();                                  // no longer needed, save memory
+        /* only create new overlay object if none exists */
+        if (Overlays[0] == NULL)
+        {
+            Overlays[0] = new DiOverlay(Document, BitsAllocated, BitsStored, HighBit);
+            if ((Overlays[0] != NULL) && !(Document->getFlags() & CIF_UsePresentationState))
+                Overlays[0]->showAllPlanes();               // default: show all overlays with stored modes
+            if ((Overlays[0] == NULL) || (Overlays[0]->getCount() == 0) || (!Overlays[0]->hasEmbeddedData()))
+                detachPixelData();                          // no longer needed, save memory
+        }
         switch (InputData->getRepresentation())
         {
             case EPR_Uint8:
@@ -676,33 +707,39 @@ void DiMonoImage::Init(DiMonoModality *modality)
         deleteInputData();                                  // no longer needed, save memory
         if (modality->getBits() > 0)
             BitsPerSample = modality->getBits();            // get bit depth of internal representation
-        /* get grayscale related attributes */
-        if (checkInterData() && !(Document->getFlags() & CIF_UsePresentationState))
+        if (checkInterData())
         {
-            /* VOI windows */
-            WindowCount = Document->getVM(DCM_WindowCenter);
-            const unsigned long count = Document->getVM(DCM_WindowWidth);
-            if (count < WindowCount)                        // determine number of VOI windows
-                WindowCount = count;
-            /* VOI LUT */
-            DcmSequenceOfItems *seq = NULL;
-            VoiLutCount = Document->getSequence(DCM_VOILUTSequence, seq);
-            /* Presentation LUT Shape */
-            OFString str;
-            if (Document->getValue(DCM_PresentationLUTShape, str))
+            /* get grayscale related attributes (if desired) */
+            if (!reuse && !(Document->getFlags() & CIF_UsePresentationState))
             {
-                if (str == "IDENTITY")
-                    PresLutShape = ESP_Identity;
-                else if (str == "INVERSE")
-                    PresLutShape = ESP_Inverse;
-                else
+                /* VOI windows */
+                WindowCount = Document->getVM(DCM_WindowCenter);
+                const unsigned long count = Document->getVM(DCM_WindowWidth);
+                if (count < WindowCount)                    // determine number of VOI windows
+                    WindowCount = count;
+                /* VOI LUT */
+                DcmSequenceOfItems *seq = NULL;
+                VoiLutCount = Document->getSequence(DCM_VOILUTSequence, seq);
+                /* VOI LUT Function */
+                OFString str;
+                if (Document->getValue(DCM_VOILUTFunction, str))
                 {
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                    {
-                        ofConsole.lockCerr() << "WARNING: unknown value for 'PresentationLUTShape' ("
-                                             << str << ") ... ignoring !" << endl;
-                        ofConsole.unlockCerr();
-                    }
+                    if (str == "LINEAR")
+                        VoiLutFunction = EFV_Linear;
+                    else if (str == "SIGMOID")
+                        VoiLutFunction = EFV_Sigmoid;
+                    else
+                        DCMIMGLE_WARN("unknown value for 'VOILUTFunction' (" << str << ") ... ignoring");
+                }
+                /* Presentation LUT Shape */
+                if (Document->getValue(DCM_PresentationLUTShape, str))
+                {
+                    if (str == "IDENTITY")
+                        PresLutShape = ESP_Identity;
+                    else if (str == "INVERSE")
+                        PresLutShape = ESP_Inverse;
+                    else
+                        DCMIMGLE_WARN("unknown value for 'PresentationLUTShape' (" << str << ") ... ignoring");
                 }
             }
         }
@@ -893,28 +930,18 @@ int DiMonoImage::checkInterData(const int mode)
         if (ImageStatus == EIS_Normal)
         {
             ImageStatus = EIS_MemoryFailure;
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: can't allocate memory for inter-representation !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("can't allocate memory for inter-representation");
         } else
             ImageStatus = EIS_InvalidImage;
     }
     else if (InterData->getData() == NULL)
         ImageStatus = EIS_InvalidImage;
-    else if (mode && (ImageStatus == EIS_Normal))
+    else if (mode && (ImageStatus == EIS_Normal) && isOriginal /* do not check derived images */)
     {
-        const unsigned long count = OFstatic_cast(unsigned long, Columns) * OFstatic_cast(unsigned long, Rows) * TotalNumberOfFrames;
+        const unsigned long count = OFstatic_cast(unsigned long, Columns) * OFstatic_cast(unsigned long, Rows) * NumberOfFrames;
         if ((InterData->getInputCount() != count) && ((InterData->getInputCount() >> 1) != ((count + 1) >> 1)))
         {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-            {
-                ofConsole.lockCerr() << "WARNING: computed (" << count
-                                     << ") and stored (" << InterData->getInputCount() << ") "
-                                     << "pixel count differ !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_WARN("computed (" << count << ") and stored (" << InterData->getInputCount() << ") pixel count differ");
         }
     }
     return (ImageStatus == EIS_Normal);
@@ -1145,17 +1172,34 @@ int DiMonoImage::getWindow(double &center, double &width)
 }
 
 
+EF_VoiLutFunction DiMonoImage::getVoiLutFunction() const
+{
+    return VoiLutFunction;
+}
+
+
+int DiMonoImage::setVoiLutFunction(const EF_VoiLutFunction function)
+{
+    if (function != VoiLutFunction)
+    {
+        VoiLutFunction = function;
+        return 1;
+    }
+    return 2;
+}
+
+
 int DiMonoImage::setVoiLut(const DcmUnsignedShort &data,
                            const DcmUnsignedShort &descriptor,
                            const DcmLongString *explanation,
-                           const OFBool ignoreDepth)
+                           const EL_BitsPerTableEntry descripMode)
 {
     if (VoiLutData != NULL)
         VoiLutData->removeReference();
-    VoiLutData = new DiLookupTable(data, descriptor, explanation, ignoreDepth);
+    VoiLutData = new DiLookupTable(data, descriptor, explanation, descripMode);
     if (VoiLutData != NULL)
     {
-        VoiExplanation = VoiLutData->getExplanation();
+        VoiExplanation = OFSTRING_GUARD(VoiLutData->getExplanation());
         return VoiLutData->isValid();
     }
     VoiExplanation = "";
@@ -1164,17 +1208,17 @@ int DiMonoImage::setVoiLut(const DcmUnsignedShort &data,
 
 
 int DiMonoImage::setVoiLut(const unsigned long pos,
-                           const OFBool ignoreDepth)
+                           const EL_BitsPerTableEntry descripMode)
 {
     if (!(Document->getFlags() & CIF_UsePresentationState))
     {
         if (VoiLutData != NULL)
             VoiLutData->removeReference();
         VoiLutData = new DiLookupTable(Document, DCM_VOILUTSequence, DCM_LUTDescriptor, DCM_LUTData,
-            DCM_LUTExplanation, ignoreDepth, pos, &VoiLutCount);
+            DCM_LUTExplanation, descripMode, pos, &VoiLutCount);
         if (VoiLutData != NULL)
         {
-            VoiExplanation = VoiLutData->getExplanation();
+            VoiExplanation = OFSTRING_GUARD(VoiLutData->getExplanation());
             return VoiLutData->isValid();
         }
         VoiExplanation = "";
@@ -1272,11 +1316,11 @@ int DiMonoImage::setPresentationLutShape(const ES_PresentationLut shape)
 int DiMonoImage::setPresentationLut(const DcmUnsignedShort &data,
                                     const DcmUnsignedShort &descriptor,
                                     const DcmLongString *explanation,
-                                    const OFBool ignoreDepth)
+                                    const EL_BitsPerTableEntry descripMode)
 {
     if (PresLutData != NULL)
         PresLutData->removeReference();
-    PresLutData = new DiLookupTable(data, descriptor, explanation, ignoreDepth, 0);
+    PresLutData = new DiLookupTable(data, descriptor, explanation, descripMode, 0);
     if (PresLutData != NULL)
     {
         PresLutShape = ESP_Default;
@@ -1288,13 +1332,13 @@ int DiMonoImage::setPresentationLut(const DcmUnsignedShort &data,
 
 int DiMonoImage::setInversePresentationLut(const DcmUnsignedShort &data,
                                            const DcmUnsignedShort &descriptor,
-                                           const OFBool ignoreDepth)
+                                           const EL_BitsPerTableEntry descripMode)
 {
     int status = 0;
     if (PresLutData != NULL)
         PresLutData->removeReference();
     PresLutData = NULL;
-    DiLookupTable *lut = new DiLookupTable(data, descriptor, NULL, ignoreDepth, 0);
+    DiLookupTable *lut = new DiLookupTable(data, descriptor, NULL, descripMode, 0);
     if ((lut != NULL) && (lut->isValid()))
     {
         PresLutData = lut->createInverseLUT();
@@ -1476,12 +1520,7 @@ const void *DiMonoImage::getData(void *buffer,
             {
                 if (!createLinODPresentationLut(4096, 16))  // create presentation LUT converting linOD data (on demand)
                 {
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                    {
-                       ofConsole.lockCerr() << "WARNING: could not create presentation LUT for LinOD conversion" << endl
-                                            << "         ... ignoring presentation LUT shape LinOD !" << endl;
-                       ofConsole.unlockCerr();
-                    }
+                    DCMIMGLE_WARN("could not create presentation LUT for LinOD conversion ... ignoring presentation LUT shape LinOD");
                 }
             }
             if (Polarity == EPP_Reverse)                    // swap high and low value
@@ -1493,12 +1532,8 @@ const void *DiMonoImage::getData(void *buffer,
             DiDisplayFunction *disp = DisplayFunction;
             if ((disp != NULL) && (disp->isValid()) && (disp->getMaxDDLValue() != DicomImageClass::maxval(bits)))
             {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                   ofConsole.lockCerr() << "WARNING: selected display function doesn't fit to requested output depth ("
-                                        << bits << ")" << endl << "         ... ignoring display transformation !" << endl;
-                   ofConsole.unlockCerr();
-                }
+                DCMIMGLE_WARN("selected display function doesn't fit to requested output depth (" << bits
+                    << ") ... ignoring display transformation");
                 disp = NULL;
             }
             const int samples = (bits == MI_PastelColor) ? 3 : 1;
@@ -1526,20 +1561,12 @@ const void *DiMonoImage::getData(void *buffer,
             if (OutputData == NULL)
             {
                 ImageStatus = EIS_MemoryFailure;
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                {
-                    ofConsole.lockCerr() << "ERROR: can't allocate memory for output-representation !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_ERROR("can't allocate memory for output-representation");
             }
             else
                 return OutputData->getData();           // points to beginning of output data
         } else {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: given output buffer is too small (only " << size << " bytes) !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("given output buffer is too small (only " << size << " bytes)");
         }
     }
     return NULL;
@@ -1655,7 +1682,7 @@ unsigned long DiMonoImage::createDIB(void *&data,
             if (bits == 8)                                  // -- for idx color model (byte)
             {
                 // each line has to start at 32-bit-address, if 'padding' is true
-                const int gap = (padding) ? (4 - Columns & 0x3) & 0x3 : 0;
+                const int gap = (padding) ? (4 - (Columns & 0x3)) & 0x3 : 0;
                 const unsigned long count = OFstatic_cast(unsigned long, Columns + gap) * OFstatic_cast(unsigned long, Rows);
                 if ((gap > 0) || (nextRow != 0) || (data != NULL))
                 {
@@ -1688,7 +1715,7 @@ unsigned long DiMonoImage::createDIB(void *&data,
             {
                 const unsigned long col3 = OFstatic_cast(unsigned long, Columns) * 3;
                 // each line has to start at 32-bit-address, if 'padding' is true
-                const int gap = (padding) ? OFstatic_cast(int, (4 - col3 & 0x3) & 0x3) : 0;
+                const int gap = (padding) ? OFstatic_cast(int, (4 - (col3 & 0x3)) & 0x3) : 0;
                 const unsigned long count = (col3 + gap) * OFstatic_cast(unsigned long, Rows);
                 if ((data == NULL) || (size >= count))
                 {
@@ -1734,9 +1761,9 @@ unsigned long DiMonoImage::createDIB(void *&data,
                             for (x = Columns; x != 0; --x)
                             {
                                 value = *(p++);                 // store gray value
-                                *(q++) = (value << 24) |
-                                         (value << 16) |
-                                         (value << 8);          // copy to the three RGB-planes
+                                *(q++) = (value << 16) |
+                                         (value << 8) |
+                                         value;                 // copy to the three RGB-planes
                             }
                             p += nextRow;                       // jump (backwards) to next row
                         }
@@ -1812,50 +1839,57 @@ void *DiMonoImage::createPackedBitmap(const void *buffer,
 {
     if ((buffer != NULL) && (size > 0) && (alloc > 0) && (stored > 0) && (stored < alloc))
     {
-        if ((alloc == 16) && (stored == 12) && ((size * 8 + alloc - 1) / alloc == count))
+        if ((alloc == 16) && (stored == 12))
         {
-            Uint16 *data = NULL;
-            data = new Uint16[((count + 1) * stored - 1) / 16];     // create new memory buffer
-            if (data != NULL)
+            /* need to split 'size' in order to avoid integer overflow for large pixel data */
+            const unsigned long size_1 = size / alloc;
+            const unsigned long size_2 = size % alloc;
+//          # old code: if ((size * 8 + alloc - 1) / alloc == count)
+            if (8 * size_1 + (8 * size_2 + alloc - 1) / alloc == count)
             {
-                register const Uint16 *p = OFstatic_cast(const Uint16 *, buffer);
-                register Uint16 *q = data;
-                register unsigned long i;
-                register Uint16 value1;
-                register Uint16 value2;
-                for (i = 0; i < count - 3; i += 4)                  // make 3 items out of 4
+                Uint16 *data = NULL;
+                data = new Uint16[((count + 1) * stored - 1) / 16];     // create new memory buffer
+                if (data != NULL)
                 {
-                    value1 = *(p++);
-                    value2 = *(p++);
-                    *(q++) = OFstatic_cast(Uint16, (value1 & 0x0fff) | (value2 << 12));
-                    value1 = *(p++);
-                    *(q++) = OFstatic_cast(Uint16, ((value2 >> 4) & 0x00ff) | (value1 << 8));
-                    value2 = *(p++);
-                    *(q++) = OFstatic_cast(Uint16, ((value1 >> 8) & 0x000f) | (value2 << 4));
-                }
-                switch (count - i)                                  // add remaining pixels
-                {
-                    case 1:                                         // add 1 pixel
-                        *(q++) = OFstatic_cast(Uint16, *(p++) & 0x0fff);
-                        break;
-                    case 2:                                         // add 2 pixels
-                        value1 = *(p++);
-                        value2 = *(p++);
-                        *(q++) = OFstatic_cast(Uint16, (value1 & 0x0fff) | (value2 << 12));
-                        *(q++) = OFstatic_cast(Uint16, (value2 >> 4) & 0x00ff);
-                        break;
-                    case 3:                                         // add 3 pixels
+                    register const Uint16 *p = OFstatic_cast(const Uint16 *, buffer);
+                    register Uint16 *q = data;
+                    register unsigned long i;
+                    register Uint16 value1;
+                    register Uint16 value2;
+                    for (i = 0; i < count - 3; i += 4)                  // make 3 items out of 4
+                    {
                         value1 = *(p++);
                         value2 = *(p++);
                         *(q++) = OFstatic_cast(Uint16, (value1 & 0x0fff) | (value2 << 12));
                         value1 = *(p++);
                         *(q++) = OFstatic_cast(Uint16, ((value2 >> 4) & 0x00ff) | (value1 << 8));
-                        *(q++) = OFstatic_cast(Uint16, (value1 >> 8) & 0x000f);
-                        break;
-                    default:                                        // add no pixel
-                        ;
+                        value2 = *(p++);
+                        *(q++) = OFstatic_cast(Uint16, ((value1 >> 8) & 0x000f) | (value2 << 4));
+                    }
+                    switch (count - i)                                  // add remaining pixels
+                    {
+                        case 1:                                         // add 1 pixel
+                            *(q++) = OFstatic_cast(Uint16, *(p++) & 0x0fff);
+                            break;
+                        case 2:                                         // add 2 pixels
+                            value1 = *(p++);
+                            value2 = *(p++);
+                            *(q++) = OFstatic_cast(Uint16, (value1 & 0x0fff) | (value2 << 12));
+                            *(q++) = OFstatic_cast(Uint16, (value2 >> 4) & 0x00ff);
+                            break;
+                        case 3:                                         // add 3 pixels
+                            value1 = *(p++);
+                            value2 = *(p++);
+                            *(q++) = OFstatic_cast(Uint16, (value1 & 0x0fff) | (value2 << 12));
+                            value1 = *(p++);
+                            *(q++) = OFstatic_cast(Uint16, ((value2 >> 4) & 0x00ff) | (value1 << 8));
+                            *(q++) = OFstatic_cast(Uint16, (value1 >> 8) & 0x000f);
+                            break;
+                        default:                                        // add no pixel
+                            ;
+                    }
+                    return OFstatic_cast(void *, data);
                 }
-                return OFstatic_cast(void *, data);
             }
         }
     }
@@ -1931,17 +1965,17 @@ void DiMonoImage::updateImagePixelModuleAttributes(DcmItem &dataset)
     {
         if (!dataset.tagExists(DcmTagKey(grp, DCM_OverlayData.getElement())))
         {
-            delete dataset.remove(DcmTagKey(grp, DCM_OverlayGroupLength.getElement()));
+            delete dataset.remove(DcmTagKey(grp, 0x0000)); // group length
             delete dataset.remove(DcmTagKey(grp, DCM_OverlayRows.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_OverlayColumns.getElement()));
-            delete dataset.remove(DcmTagKey(grp, DCM_OverlayPlanes.getElement()));
+            delete dataset.remove(DcmTagKey(grp, DCM_RETIRED_OverlayPlanes.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_NumberOfFramesInOverlay.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_OverlayDescription.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_OverlayType.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_OverlaySubtype.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_OverlayOrigin.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_ImageFrameOrigin.getElement()));
-            delete dataset.remove(DcmTagKey(grp, DCM_OverlayPlaneOrigin.getElement()));
+            delete dataset.remove(DcmTagKey(grp, DCM_RETIRED_OverlayPlaneOrigin.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_OverlayBitsAllocated.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_OverlayBitPosition.getElement()));
             delete dataset.remove(DcmTagKey(grp, DCM_OverlayLabel.getElement()));
@@ -1953,23 +1987,33 @@ void DiMonoImage::updateImagePixelModuleAttributes(DcmItem &dataset)
 // --- write current image to DICOM dataset
 
 int DiMonoImage::writeImageToDataset(DcmItem &dataset,
-                                     const int mode)
+                                     const int mode,
+                                     const int /*planar*/)
 {
     int result = 0;
     if (InterData != NULL)
     {
         const void *pixel = InterData->getData();
         const unsigned long count = InterData->getCount();
+        const EP_Representation repres = InterData->getRepresentation();
         if ((BitsPerSample > 0) && (pixel != NULL) && (count > 0))
         {
+            char numBuf[20];
             unsigned int bits = BitsPerSample;
             /* only 'used' pixel data */
             if (!mode)
             {
                 double minValue, maxValue;
                 InterData->getMinMaxValues(minValue, maxValue);
-                bits = DicomImageClass::rangeToBits(minValue, maxValue);
+                if (minValue < maxValue)
+                    bits = DicomImageClass::rangeToBits(minValue, maxValue);
+                else
+                    bits = 1;
             }
+            /* check determined bits stored value */
+            const unsigned int repBits = DicomImageClass::getRepresentationBits(repres);
+            if (bits > repBits)
+                bits = repBits;
             /* set color model */
             if (getInternalColorModel() == EPI_Monochrome1)
                 dataset.putAndInsertString(DCM_PhotometricInterpretation, "MONOCHROME1");
@@ -1978,10 +2022,15 @@ int DiMonoImage::writeImageToDataset(DcmItem &dataset,
             /* set image resolution */
             dataset.putAndInsertUint16(DCM_Columns, Columns);
             dataset.putAndInsertUint16(DCM_Rows, Rows);
-            dataset.putAndInsertSint32(DCM_NumberOfFrames, NumberOfFrames);
+#if SIZEOF_LONG == 8
+            sprintf(numBuf, "%d", NumberOfFrames);
+#else
+            sprintf(numBuf, "%ld", NumberOfFrames);
+#endif
+            dataset.putAndInsertString(DCM_NumberOfFrames, numBuf);
             dataset.putAndInsertUint16(DCM_SamplesPerPixel, 1);
             /* set pixel encoding and data */
-            switch (InterData->getRepresentation())
+            switch (repres)
             {
                 case EPR_Uint8:
                     dataset.putAndInsertUint16(DCM_BitsAllocated, 8);
@@ -2006,12 +2055,12 @@ int DiMonoImage::writeImageToDataset(DcmItem &dataset,
                 case EPR_Uint32:
                     dataset.putAndInsertUint16(DCM_BitsAllocated, 32);
                     dataset.putAndInsertUint16(DCM_PixelRepresentation, 0);
-                    dataset.putAndInsertUint16Array(DCM_PixelData, OFstatic_cast(const Uint16 *, pixel), count);
+                    dataset.putAndInsertUint16Array(DCM_PixelData, OFstatic_cast(const Uint16 *, pixel), count * 2 /*double-words*/);
                     break;
                 case EPR_Sint32:
                     dataset.putAndInsertUint16(DCM_BitsAllocated, 32);
                     dataset.putAndInsertUint16(DCM_PixelRepresentation, 1);
-                    dataset.putAndInsertUint16Array(DCM_PixelData, OFstatic_cast(const Uint16 *, pixel), count);
+                    dataset.putAndInsertUint16Array(DCM_PixelData, OFstatic_cast(const Uint16 *, pixel), count * 2 /*double-words*/);
                     break;
             }
             dataset.putAndInsertUint16(DCM_BitsStored, bits);
@@ -2029,7 +2078,7 @@ int DiMonoImage::writeImageToDataset(DcmItem &dataset,
  *   write output data of 'frame' with depth of 'bits' to C++-output 'stream' (format is PGM - portable gray map)
  */
 
-int DiMonoImage::writePPM(ostream &stream,
+int DiMonoImage::writePPM(STD_NAMESPACE ostream& stream,
                           const unsigned long frame,
                           const int bits)
 {
@@ -2038,13 +2087,13 @@ int DiMonoImage::writePPM(ostream &stream,
     {
         if (bits == MI_PastelColor)
         {
-            stream << "P3" << endl;
-            stream << Columns << " " << Rows << endl;
-            stream << "255" << endl;
+            stream << "P3" << OFendl;
+            stream << Columns << " " << Rows << OFendl;
+            stream << "255" << OFendl;
         } else {
-            stream << "P2" << endl;
-            stream << Columns << " " << Rows << endl;
-            stream << DicomImageClass::maxval(bits) << endl;
+            stream << "P2" << OFendl;
+            stream << Columns << " " << Rows << OFendl;
+            stream << DicomImageClass::maxval(bits) << OFendl;
         }
         int ok = OutputData->writePPM(stream);
         deleteOutputData();
@@ -2107,14 +2156,14 @@ int DiMonoImage::writeRawPPM(FILE *stream,
 
 
 /*
- *   write output data of 'frame' with depth of 'bits' (8 or 24) to C-file 'stream' (format is BMP)
+ *   write output data of 'frame' with depth of 'bits' (8, 24 or 32) to C-file 'stream' (format is BMP)
  */
 
 int DiMonoImage::writeBMP(FILE *stream,
                           const unsigned long frame,
                           const int bits)
 {
-    if ((bits == 0) || (bits == 8) || (bits == 24))
+    if ((bits == 0) || (bits == 8) || (bits == 24) || (bits == 32))
         return DiImage::writeBMP(stream, frame, (bits == 0) ? 8 : bits);
     return 0;
 }
@@ -2124,6 +2173,84 @@ int DiMonoImage::writeBMP(FILE *stream,
  *
  * CVS/RCS Log:
  * $Log: dimoimg.cc,v $
+ * Revision 1.84  2010-10-14 13:14:18  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.83  2010-10-05 15:24:06  joergr
+ * Added preliminary support for VOI LUT function. Please note, however, that
+ * the sigmoid transformation is not yet implemented.
+ *
+ * Revision 1.82  2010-07-26 07:24:08  joergr
+ * Made sure that no NULL pointer is passed to the OFString constructor.
+ *
+ * Revision 1.81  2010-07-21 13:10:43  joergr
+ * Fixed CVS log entry and updated copyright date.
+ *
+ * Revision 1.80  2010-07-21 13:08:00  joergr
+ * Fixed memory leak when using processNextFrames(): DiOverlay object was
+ * created multiple times.
+ *
+ * Revision 1.79  2009-11-25 16:30:54  joergr
+ * Adapted code for new approach to access individual frames of a DICOM image.
+ *
+ * Revision 1.78  2009-10-28 14:26:02  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.77  2009-10-28 09:53:40  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.76  2009-08-26 07:48:48  joergr
+ * Added parentheses around + or - in operand of & in order to avoid warnings
+ * reported by gcc 4.3.2.
+ *
+ * Revision 1.75  2009-04-20 12:22:42  joergr
+ * Fixed issue with wrong BitsStored value in writeImageToDataset().
+ *
+ * Revision 1.74  2008-11-18 10:57:09  joergr
+ * Fixed issue with incorrectly encoded overlay planes (wrong values for
+ * OverlayBitsAllocated and OverlayBitPosition).
+ *
+ * Revision 1.73  2008-08-08 14:17:50  joergr
+ * Fixed issue with NumberOfFrames element in writeImageToDataset().
+ *
+ * Revision 1.72  2008-05-20 13:12:02  joergr
+ * Fixed issue with signed pixel data in bicubic interpolation algorithm.
+ *
+ * Revision 1.71  2008-05-13 09:54:45  joergr
+ * Added new parameter to writeImageToDataset() in order to affect the planar
+ * configuration of the output image/dataset. Changed behaviour: By default,
+ * the output now uses the same planar configuration as the "original" image
+ * (previously: always color-by-plane).
+ *
+ * Revision 1.70  2008-04-30 12:38:42  meichel
+ * Fixed compile errors due to changes in attribute tag names
+ *
+ * Revision 1.69  2007/10/23 16:52:29  joergr
+ * Fixed bug in writeImageToDataset() for images with BitsAllocated = 32.
+ *
+ * Revision 1.68  2007/03/16 11:51:43  joergr
+ * Introduced new flag that allows to select how to handle the BitsPerTableEntry
+ * value in the LUT descriptor (use, ignore or check).
+ *
+ * Revision 1.67  2007/02/08 17:08:21  joergr
+ * Added lower limit check in DiMonoImage::writeImageToDataset() calculating
+ * the value for bits stored.
+ *
+ * Revision 1.66  2006/11/17 15:09:54  joergr
+ * Only compare stored and computed pixel count for "original" images that are
+ * directly loaded from DICOM files or datasets.
+ *
+ * Revision 1.65  2006/10/27 15:00:16  joergr
+ * Fixed possible integer overflow for images with very large pixel data.
+ * Fixed wrong warning message about length of pixel data.
+ *
+ * Revision 1.64  2006/08/15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.63  2006/07/10 10:54:26  joergr
+ * Added support for 32-bit BMP images.
+ *
  * Revision 1.62  2005/12/08 15:42:56  meichel
  * Changed include path schema for all DCMTK header files
  *
