@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomOverlay (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:43:04 $
- *  CVS/RCS Revision: $Revision: 1.25 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:18 $
+ *  CVS/RCS Revision: $Revision: 1.30 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -56,7 +52,9 @@ const unsigned int DiOverlay::FirstOverlayGroup = 0x6000;
  *----------------*/
 
 DiOverlay::DiOverlay(const DiDocument *docu,
-                     const Uint16 alloc)
+                     const Uint16 alloc,
+                     const Uint16 stored,
+                     const Uint16 high)
   : Left(0),
     Top(0),
     Width(0),
@@ -71,7 +69,7 @@ DiOverlay::DiOverlay(const DiDocument *docu,
         register unsigned int i;
         for (i = 0; i < MaxOverlayCount; ++i)
         {
-            Data->Planes[Data->Count] = new DiOverlayPlane(docu, convertToGroupNumber(i), alloc);
+            Data->Planes[Data->Count] = new DiOverlayPlane(docu, convertToGroupNumber(i), alloc, stored, high);
             if (Data->Planes[Data->Count] != NULL)
             {
                 if (checkPlane(Data->Count))
@@ -232,11 +230,7 @@ Uint16 *DiOverlay::Init(const DiOverlay *overlay)
                 }
                 if (Data->Count != overlay->Data->Count)            // assertion!
                 {
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                    {
-                        ofConsole.lockCerr() << "WARNING: different number of overlay planes for scaled and unscaled image !" << endl;
-                        ofConsole.unlockCerr();
-                    }
+                    DCMIMGLE_WARN("different number of overlay planes for scaled and unscaled image");
                 }
                 if (overlay->Data->DataBuffer != NULL)              // existing data buffer
                     temp = overlay->Data->DataBuffer;               // point to input buffer
@@ -609,6 +603,23 @@ unsigned long DiOverlay::create6xxx3000PlaneData(Uint8 *&buffer,
  *
  * CVS/RCS Log:
  * $Log: diovlay.cc,v $
+ * Revision 1.30  2010-10-14 13:14:18  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.29  2009-10-28 14:26:02  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.28  2009-10-28 09:53:41  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.27  2008-11-18 10:57:10  joergr
+ * Fixed issue with incorrectly encoded overlay planes (wrong values for
+ * OverlayBitsAllocated and OverlayBitPosition).
+ *
+ * Revision 1.26  2006/08/15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.25  2005/12/08 15:43:04  meichel
  * Changed include path schema for all DCMTK header files
  *
