@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DicomOverlayImage (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:43:05 $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:18 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -76,11 +72,7 @@ DiOverlayImage::DiOverlayImage(const DiDocument *docu,
                 if (InterData == NULL)
                 {
                     ImageStatus = EIS_MemoryFailure;
-                    if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                    {
-                        ofConsole.lockCerr() << "ERROR: can't allocate memory for inter-representation !" << endl;
-                        ofConsole.unlockCerr();
-                    }
+                    DCMIMGLE_ERROR("can't allocate memory for inter-representation");
                 }
                 else if (InterData->getData() == NULL)
                     ImageStatus = EIS_InvalidImage;
@@ -88,23 +80,14 @@ DiOverlayImage::DiOverlayImage(const DiDocument *docu,
             else
             {
                 ImageStatus = EIS_InvalidValue;
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                {
-                    ofConsole.lockCerr() << "ERROR: invalid value for 'Rows' (" << Rows << ") and/or "
-                                         << "'Columns' (" << Columns << ") !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_ERROR("invalid value for 'Rows' (" << Rows << ") and/or 'Columns' (" << Columns << ")");
             }
         }
     }
     else
     {
         ImageStatus = EIS_InvalidDocument;
-        if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-        {
-            ofConsole.lockCerr() << "ERROR: this DICOM document is invalid !" << endl;
-            ofConsole.unlockCerr();
-        }
+        DCMIMGLE_ERROR("this DICOM document is invalid");
     }
 }
 
@@ -122,6 +105,19 @@ DiOverlayImage::~DiOverlayImage()
  *
  * CVS/RCS Log:
  * $Log: diovlimg.cc,v $
+ * Revision 1.17  2010-10-14 13:14:18  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.16  2009-10-28 14:26:02  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.15  2009-10-28 09:53:41  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.14  2006-08-15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.13  2005/12/08 15:43:05  meichel
  * Changed include path schema for all DCMTK header files
  *
