@@ -1,29 +1,25 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmimgle
  *
  *  Author:  Joerg Riesmeier
  *
- *  Purpose: DicomOverlayPlane (Source) - Multiframe Overlays UNTESTED !
+ *  Purpose: DicomOverlayPlane (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:43:06 $
- *  CVS/RCS Revision: $Revision: 1.29 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:18 $
+ *  CVS/RCS Revision: $Revision: 1.37 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,10 +28,11 @@
 
 
 #include "dcmtk/config/osconfig.h"
-#include "dcmtk/ofstd/ofconsol.h"
+
 #include "dcmtk/dcmdata/dctypes.h"
 #include "dcmtk/dcmdata/dcdeftag.h"
 #include "dcmtk/dcmdata/dctagkey.h"
+#include "dcmtk/dcmdata/dcpixel.h"
 #include "dcmtk/ofstd/ofbmanip.h"
 
 #include "dcmtk/dcmimgle/diovpln.h"
@@ -48,7 +45,9 @@
 
 DiOverlayPlane::DiOverlayPlane(const DiDocument *docu,
                                const unsigned int group,
-                               Uint16 alloc)
+                               Uint16 alloc,
+                               const Uint16 stored,
+                               const Uint16 high)
   : NumberOfFrames(0),
     ImageFrameOrigin(0),
     Top(0),
@@ -90,7 +89,7 @@ DiOverlayPlane::DiOverlayPlane(const DiDocument *docu,
         /* get overlay type */
         tag.setElement(DCM_OverlayType.getElement());
         const char *str;
-        if ((docu->getValue(tag, str) > 0) && (strcmp(str, "R") == 0))
+        if ((docu->getValue(tag, str) > 0) && (str != NULL) && (strcmp(str, "R") == 0))
             DefaultMode = Mode = EMO_RegionOfInterest;
         Sint32 sl = 0;
         /* multi-frame overlays */
@@ -106,23 +105,17 @@ DiOverlayPlane::DiOverlayPlane(const DiDocument *docu,
         Valid = (docu->getValue(tag, Left, 0) > 0);
         if (Valid)
         {
+            DCMIMGLE_DEBUG("processing overlay plane in group 0x" << STD_NAMESPACE hex << group);
             if (docu->getValue(tag, Top, 1) < 2)
-            {
-                ofConsole.lockCerr() << "WARNING: missing second value for 'OverlayOrigin' ... "
-                                     << "assuming 'Top' = " << Top << " !" << endl;
-                ofConsole.unlockCerr();
-            }
+                DCMIMGLE_WARN("missing second value for 'OverlayOrigin' ... assuming 'Top' = " << Top);
         }
 #else
         Valid = (docu->getValue(tag, Top, 0) > 0);
         if (Valid)
         {
+            DCMIMGLE_DEBUG("processing overlay plane in group 0x" << STD_NAMESPACE hex << group);
             if (docu->getValue(tag, Left, 1) < 2)
-            {
-                ofConsole.lockCerr() << "WARNING: missing second value for 'OverlayOrigin' ... "
-                                     << "assuming 'Left' = " << Left << " !" << endl;
-                ofConsole.unlockCerr();
-            }
+                DCMIMGLE_WARN("missing second value for 'OverlayOrigin' ... assuming 'Left' = " << Left);
         }
 #endif
         /* overlay origin is numbered from 1 */
@@ -144,46 +137,57 @@ DiOverlayPlane::DiOverlayPlane(const DiDocument *docu,
         /* final validity checks */
         if (Valid)
         {
+            /* separate overlay data? */
             unsigned long length = docu->getValue(tag, Data) * 2 /* bytes */;
             if (length == 0)
             {
-                ImageFrameOrigin = 0;                               // see supplement 4
-                length = docu->getValue(DCM_PixelData, Data) * 2 /* bytes */;
-                EmbeddedData = (Data != NULL);
+                if (!(docu->getFlags() & CIF_NeverAccessEmbeddedOverlays))
+                {
+                    if (!docu->isCompressed())
+                    {
+                        /* if not, check for embedded overlay data */
+                        DcmPixelData *pixelData = docu->getPixelData();
+                        if (pixelData != NULL)
+                        {
+                            ImageFrameOrigin = 0;                           // see supplement 4
+                            const OFBool loaded = pixelData->valueLoaded();
+                            if (pixelData->getUint16Array(OFconst_cast(Uint16 *&, Data)).good())
+                            {
+                                length = pixelData->getLength(docu->getTransferSyntax());
+                                EmbeddedData = (Data != NULL);
+                                if (!loaded)
+                                    DCMIMGLE_DEBUG("loaded complete pixel data into memory for embedded overlay data: " << length << " bytes");
+                            }
+                        }
+                    } else
+                        DCMIMGLE_ERROR("embedded overlay data cannot be accessed since pixel data is still compressed");
+                } else
+                    DCMIMGLE_WARN("ignoring possibly embedded overlay data by configuration");
             } else
                 alloc = 1;                                          // separately stored overlay data
             /* check for correct value of BitsAllocated */
             if (BitsAllocated != alloc)                             // see correction proposal 87
             {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid value for 'OverlayBitsAllocated' (" << BitsAllocated
-                                         << ") ... assuming " << alloc << " !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_WARN("invalid value for 'OverlayBitsAllocated' (" << BitsAllocated << ") ... assuming " << alloc);
                 BitsAllocated = alloc;
             }
             /* check for correct value of BitPosition */
-            if (BitPosition > BitsAllocated)
+            if (BitPosition >= BitsAllocated)
             {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Warnings))
-                {
-                    ofConsole.lockCerr() << "WARNING: invalid value for 'OverlayBitPosition' (" << BitPosition
-                                         << ") ... assuming " << (BitsAllocated - 1) << " !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_WARN("invalid value for 'OverlayBitPosition' (" << BitPosition << ") ... assuming " << (BitsAllocated - 1));
                 BitPosition = BitsAllocated - 1;
             }
+            if (EmbeddedData && (BitPosition <= high) && (BitPosition + stored > high))
+            {
+                DCMIMGLE_WARN("invalid value for 'OverlayBitPosition' (" << BitPosition << "), refers to bit position within stored pixel value");
+                Data = NULL;    // invalid plane
+            }
             /* expected length of overlay data */
             const unsigned long expLen = (OFstatic_cast(unsigned long, NumberOfFrames) * OFstatic_cast(unsigned long, Rows) *
                                           OFstatic_cast(unsigned long, Columns) * OFstatic_cast(unsigned long, BitsAllocated) + 7) / 8;
-            if ((length == 0) || (length < expLen))
+            if ((Data != NULL) && ((length == 0) || (length < expLen)))
             {
-                if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-                {
-                    ofConsole.lockCerr() << "ERROR: overlay data length is too short !" << endl;
-                    ofConsole.unlockCerr();
-                }
+                DCMIMGLE_ERROR("overlay data length is too short, " << expLen << " bytes expected but " << length << " bytes found");
                 Valid = 0;
                 Data = NULL;
             } else
@@ -240,11 +244,7 @@ DiOverlayPlane::DiOverlayPlane(const unsigned int group,
         const unsigned long expLen = (OFstatic_cast(unsigned long, Rows) * OFstatic_cast(unsigned long, Columns) + 7) / 8;
         if ((length == 0) || (length < expLen))
         {
-            if (DicomImageClass::checkDebugLevel(DicomImageClass::DL_Errors))
-            {
-                ofConsole.lockCerr() << "ERROR: overlay data length is too short !" << endl;
-                ofConsole.unlockCerr();
-            }
+            DCMIMGLE_ERROR("overlay data length is too short, " << expLen << " bytes expected but " << length << " bytes found");
             /* Valid = 0;  =>  This is the default. */
             Data = NULL;
         } else
@@ -533,6 +533,14 @@ int DiOverlayPlane::show(const Uint16 pvalue)
 }
 
 
+void DiOverlayPlane::place(const signed int left_pos,
+                           const signed int top_pos)
+{
+    Left = OFstatic_cast(Sint16, left_pos);
+    Top = OFstatic_cast(Sint16, top_pos);
+}
+
+
 void DiOverlayPlane::setScaling(const double xfactor,
                                 const double yfactor)
 {
@@ -603,6 +611,35 @@ void DiOverlayPlane::setRotation(const int degree,
  *
  * CVS/RCS Log:
  * $Log: diovpln.cc,v $
+ * Revision 1.37  2010-10-14 13:14:18  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.36  2010-06-16 07:08:12  joergr
+ * Added type cast to integer variables in order to avoid compiler warnings
+ * reported by VisualStudio 2008 with warning level 4 (highest).
+ *
+ * Revision 1.35  2009-11-25 16:30:21  joergr
+ * Adapted code for new approach to access individual frames of a DICOM image.
+ * Removed inclusion of header file "ofconsol.h".
+ * Revised logging messages. Added more logging messages.
+ *
+ * Revision 1.34  2009-10-28 14:26:02  joergr
+ * Fixed minor issues in log output.
+ *
+ * Revision 1.33  2009-10-28 09:53:41  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.32  2008-11-18 10:57:10  joergr
+ * Fixed issue with incorrectly encoded overlay planes (wrong values for
+ * OverlayBitsAllocated and OverlayBitPosition).
+ *
+ * Revision 1.31  2007-08-27 09:57:31  joergr
+ * Added further check on Overlay Type variable.
+ *
+ * Revision 1.30  2006/08/15 16:30:11  meichel
+ * Updated the code in module dcmimgle to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.29  2005/12/08 15:43:06  meichel
  * Changed include path schema for all DCMTK header files
  *
