@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2001-2005, OFFIS
+ *  Copyright (C) 2001-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmjpeg
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Decompress DICOM file
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:43:21 $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:38 $
+ *  CVS/RCS Revision: $Revision: 1.26 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -42,7 +38,6 @@
 #endif
 
 #include "dcmtk/dcmdata/dctk.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/ofstd/ofconapp.h"
 #include "dcmtk/dcmdata/dcuid.h"       /* for dcmtk version name */
@@ -55,6 +50,8 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dcmdjpeg"
 
+static OFLogger dcmdjpegLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -72,15 +69,11 @@ int main(int argc, char *argv[])
   GUSISetup(GUSIwithInternetSockets);
 #endif
 
-  SetDebugLevel(( 0 ));
-
   const char *opt_ifname = NULL;
   const char *opt_ofname = NULL;
 
-  int opt_debugMode = 0;
-  OFBool opt_verbose = OFFalse;
-  OFBool opt_oDataset = OFFalse;
   E_FileReadMode opt_readMode = ERM_autoDetect;
+  E_FileWriteMode opt_writeMode = EWM_fileformat;
   E_TransferSyntax opt_oxfer = EXS_LittleEndianExplicit;
   E_GrpLenEncoding opt_oglenc = EGL_recalcGL;
   E_EncodingType opt_oenctype = EET_ExplicitLength;
@@ -93,8 +86,9 @@ int main(int argc, char *argv[])
   E_DecompressionColorSpaceConversion opt_decompCSconversion = EDC_photometricInterpretation;
   E_UIDCreation opt_uidcreation = EUC_default;
   E_PlanarConfiguration opt_planarconfig = EPC_default;
+  OFBool opt_predictor6WorkaroundEnable = OFFalse;
 
-  OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "Decode JPEG-compressed DICOM file", rcsid);
+  OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, "Decode JPEG-compressed DICOM file", rcsid);
   OFCommandLine cmd;
   cmd.setOptionColumns(LONGCOL, SHORTCOL);
   cmd.setParamColumn(LONGCOL + SHORTCOL + 4);
@@ -103,73 +97,76 @@ int main(int argc, char *argv[])
   cmd.addParam("dcmfile-out", "DICOM output filename");
 
   cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-   cmd.addOption("--help",                      "-h",        "print this help text and exit");
-   cmd.addOption("--version",                                "print version information and exit", OFTrue /* exclusive */);
-   cmd.addOption("--verbose",                   "-v",        "verbose mode, print processing details");
-   cmd.addOption("--debug",                     "-d",        "debug mode, print debug information");
+    cmd.addOption("--help",                  "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+    cmd.addOption("--version",                         "print version information and exit", OFCommandLine::AF_Exclusive);
+    OFLog::addOptions(cmd);
 
    cmd.addGroup("input options:");
     cmd.addSubGroup("input file format:");
-     cmd.addOption("--read-file",              "+f",        "read file format or data set (default)");
-     cmd.addOption("--read-file-only",         "+fo",       "read file format only");
-     cmd.addOption("--read-dataset",           "-f",        "read data set without file meta information");
+     cmd.addOption("--read-file",            "+f",     "read file format or data set (default)");
+     cmd.addOption("--read-file-only",       "+fo",    "read file format only");
+     cmd.addOption("--read-dataset",         "-f",     "read data set without file meta information");
 
   cmd.addGroup("processing options:");
-    cmd.addSubGroup("color space conversion options:");
-      cmd.addOption("--conv-photometric",       "+cp",       "convert if YCbCr photom. interpr. (default)");
-      cmd.addOption("--conv-lossy",             "+cl",       "convert YCbCr to RGB if lossy JPEG");
-      cmd.addOption("--conv-always",            "+ca",       "always convert YCbCr to RGB");
-      cmd.addOption("--conv-never",             "+cn",       "never convert color space");
+    cmd.addSubGroup("color space conversion:");
+      cmd.addOption("--conv-photometric",    "+cp",    "convert if YCbCr photometric interpr. (default)");
+      cmd.addOption("--conv-lossy",          "+cl",    "convert YCbCr to RGB if lossy JPEG");
+      cmd.addOption("--conv-guess",          "+cg",    "convert to RGB if YCbCr is guessed by library");
+      cmd.addOption("--conv-guess-lossy",    "+cgl",   "convert to RGB if lossy JPEG and YCbCr is\nguessed by the underlying JPEG library");
+      cmd.addOption("--conv-always",         "+ca",    "always convert YCbCr to RGB");
+      cmd.addOption("--conv-never",          "+cn",    "never convert color space");
 
-    cmd.addSubGroup("planar configuration options:");
-      cmd.addOption("--planar-auto",            "+pa",       "automatically determine planar configuration\nfrom SOP class and color space (default)");
-      cmd.addOption("--color-by-pixel",         "+px",       "always store color-by-pixel");
-      cmd.addOption("--color-by-plane",         "+pl",       "always store color-by-plane");
+    cmd.addSubGroup("planar configuration:");
+      cmd.addOption("--planar-auto",         "+pa",    "automatically determine planar configuration\nfrom SOP class and color space (default)");
+      cmd.addOption("--color-by-pixel",      "+px",    "always store color-by-pixel");
+      cmd.addOption("--color-by-plane",      "+pl",    "always store color-by-plane");
 
-    cmd.addSubGroup("SOP Instance UID options:");
-     cmd.addOption("--uid-default",        "+ud",     "keep same SOP Instance UID (default)");
-     cmd.addOption("--uid-always",         "+ua",     "always assign new UID");
+    cmd.addSubGroup("SOP Instance UID:");
+      cmd.addOption("--uid-default",         "+ud",    "keep same SOP Instance UID (default)");
+      cmd.addOption("--uid-always",          "+ua",    "always assign new UID");
+
+    cmd.addSubGroup("workaround options for incorrect JPEG encodings:");
+      cmd.addOption("--workaround-pred6",    "+w6",    "enable workaround for JPEG lossless images\nwith overflow in predictor 6");
 
   cmd.addGroup("output options:");
     cmd.addSubGroup("output file format:");
-      cmd.addOption("--write-file",             "+F",        "write file format (default)");
-      cmd.addOption("--write-dataset",          "-F",        "write data set without file meta information");
+      cmd.addOption("--write-file",          "+F",     "write file format (default)");
+      cmd.addOption("--write-dataset",       "-F",     "write data set without file meta information");
     cmd.addSubGroup("output transfer syntax:");
-      cmd.addOption("--write-xfer-little",      "+te",       "write with explicit VR little endian (default)");
-      cmd.addOption("--write-xfer-big",         "+tb",       "write with explicit VR big endian TS");
-      cmd.addOption("--write-xfer-implicit",    "+ti",       "write with implicit VR little endian TS");
+      cmd.addOption("--write-xfer-little",   "+te",    "write with explicit VR little endian (default)");
+      cmd.addOption("--write-xfer-big",      "+tb",    "write with explicit VR big endian TS");
+      cmd.addOption("--write-xfer-implicit", "+ti",    "write with implicit VR little endian TS");
     cmd.addSubGroup("post-1993 value representations:");
-      cmd.addOption("--enable-new-vr",          "+u",        "enable support for new VRs (UN/UT) (default)");
-      cmd.addOption("--disable-new-vr",         "-u",        "disable support for new VRs, convert to OB");
+      cmd.addOption("--enable-new-vr",       "+u",     "enable support for new VRs (UN/UT) (default)");
+      cmd.addOption("--disable-new-vr",      "-u",     "disable support for new VRs, convert to OB");
     cmd.addSubGroup("group length encoding:");
-      cmd.addOption("--group-length-recalc",    "+g=",       "recalculate group lengths if present (default)");
-      cmd.addOption("--group-length-create",    "+g",        "always write with group length elements");
-      cmd.addOption("--group-length-remove",    "-g",        "always write without group length elements");
+      cmd.addOption("--group-length-recalc", "+g=",    "recalculate group lengths if present (default)");
+      cmd.addOption("--group-length-create", "+g",     "always write with group length elements");
+      cmd.addOption("--group-length-remove", "-g",     "always write without group length elements");
     cmd.addSubGroup("length encoding in sequences and items:");
-      cmd.addOption("--length-explicit",        "+e",        "write with explicit lengths (default)");
-      cmd.addOption("--length-undefined",       "-e",        "write with undefined lengths");
+      cmd.addOption("--length-explicit",     "+e",     "write with explicit lengths (default)");
+      cmd.addOption("--length-undefined",    "-e",     "write with undefined lengths");
     cmd.addSubGroup("data set trailing padding (not with --write-dataset):");
-      cmd.addOption("--padding-retain",         "-p=",       "do not change padding\n(default if not --write-dataset)");
-      cmd.addOption("--padding-off",            "-p",        "no padding (implicit if --write-dataset)");
-      cmd.addOption("--padding-create",         "+p",    2,  "[f]ile-pad [i]tem-pad: integer",
-                                                             "align file on multiple of f bytes\nand items on multiple of i bytes");
+      cmd.addOption("--padding-retain",      "-p=",    "do not change padding\n(default if not --write-dataset)");
+      cmd.addOption("--padding-off",         "-p",     "no padding (implicit if --write-dataset)");
+      cmd.addOption("--padding-create",      "+p",  2, "[f]ile-pad [i]tem-pad: integer",
+                                                       "align file on multiple of f bytes\nand items on multiple of i bytes");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
           if (cmd.findOption("--version"))
           {
-              app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-              CERR << endl << "External libraries used:" << endl;
+              app.printHeader(OFTrue /*print host identifier*/);
+              COUT << OFendl << "External libraries used:" << OFendl;
 #ifdef WITH_ZLIB
-              CERR << "- ZLIB, Version " << zlibVersion() << endl;
+              COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
-              CERR << "- " << DiJPEGPlugin::getLibraryVersionString() << endl;
+              COUT << "- " << DiJPEGPlugin::getLibraryVersionString() << OFendl;
               return 0;
           }
       }
@@ -181,8 +178,7 @@ int main(int argc, char *argv[])
 
       /* options */
 
-      if (cmd.findOption("--verbose")) opt_verbose = OFTrue;
-      if (cmd.findOption("--debug")) opt_debugMode = 5;
+      OFLog::configureFromCommandLine(cmd, app);
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--planar-auto")) opt_planarconfig = EPC_default;
@@ -191,10 +187,12 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--conv-photometric"))  opt_decompCSconversion = EDC_photometricInterpretation;
-      if (cmd.findOption("--conv-lossy"))        opt_decompCSconversion = EDC_lossyOnly;
-      if (cmd.findOption("--conv-always"))       opt_decompCSconversion = EDC_always;
-      if (cmd.findOption("--conv-never"))        opt_decompCSconversion = EDC_never;
+      if (cmd.findOption("--conv-photometric")) opt_decompCSconversion = EDC_photometricInterpretation;
+      if (cmd.findOption("--conv-lossy")) opt_decompCSconversion = EDC_lossyOnly;
+      if (cmd.findOption("--conv-guess")) opt_decompCSconversion = EDC_guess;
+      if (cmd.findOption("--conv-guess-lossy")) opt_decompCSconversion = EDC_guessLossyOnly;
+      if (cmd.findOption("--conv-always")) opt_decompCSconversion = EDC_always;
+      if (cmd.findOption("--conv-never")) opt_decompCSconversion = EDC_never;
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
@@ -202,6 +200,8 @@ int main(int argc, char *argv[])
       if (cmd.findOption("--uid-always")) opt_uidcreation = EUC_always;
       cmd.endOptionBlock();
 
+      if (cmd.findOption("--workaround-pred6")) opt_predictor6WorkaroundEnable = OFTrue;
+
       cmd.beginOptionBlock();
       if (cmd.findOption("--read-file"))
       {
@@ -227,8 +227,8 @@ int main(int argc, char *argv[])
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
-      if (cmd.findOption("--write-file")) opt_oDataset = OFFalse;
-      if (cmd.findOption("--write-dataset")) opt_oDataset = OFTrue;
+      if (cmd.findOption("--write-file")) opt_writeMode = EWM_fileformat;
+      if (cmd.findOption("--write-dataset")) opt_writeMode = EWM_dataset;
       cmd.endOptionBlock();
 
       cmd.beginOptionBlock();
@@ -264,42 +264,42 @@ int main(int argc, char *argv[])
       cmd.beginOptionBlock();
       if (cmd.findOption("--padding-retain"))
       {
-        if (opt_oDataset) app.printError("--padding-retain not allowed with --write-dataset");
+        app.checkConflict("--padding-retain", "--write-dataset", opt_writeMode == EWM_dataset);
         opt_opadenc = EPD_noChange;
       }
       if (cmd.findOption("--padding-off")) opt_opadenc = EPD_withoutPadding;
       if (cmd.findOption("--padding-create"))
       {
-          if (opt_oDataset) app.printError("--padding-create not allowed with --write-dataset");
-          app.checkValue(cmd.getValueAndCheckMin(opt_filepad, 0));
-          app.checkValue(cmd.getValueAndCheckMin(opt_itempad, 0));
-          opt_opadenc = EPD_withPadding;
+        app.checkConflict("--padding-create", "--write-dataset", opt_writeMode == EWM_dataset);
+        app.checkValue(cmd.getValueAndCheckMin(opt_filepad, 0));
+        app.checkValue(cmd.getValueAndCheckMin(opt_itempad, 0));
+        opt_opadenc = EPD_withPadding;
       }
       cmd.endOptionBlock();
 
     }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmdjpegLogger, rcsid << OFendl);
 
     // register global decompression codecs
     DJDecoderRegistration::registerCodecs(
       opt_decompCSconversion,
       opt_uidcreation,
       opt_planarconfig,
-      opt_verbose);
+      opt_predictor6WorkaroundEnable);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dcmdjpegLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     // open inputfile
     if ((opt_ifname == NULL) || (strlen(opt_ifname) == 0))
     {
-        CERR << "Error: invalid filename: <empty string>" << endl;
+        OFLOG_FATAL(dcmdjpegLogger, "invalid filename: <empty string>");
         return 1;
     }
 
@@ -307,59 +307,55 @@ int main(int argc, char *argv[])
 
     DcmFileFormat fileformat;
 
-    if (opt_verbose)
-        COUT << "reading input file " << opt_ifname << endl;
+    OFLOG_INFO(dcmdjpegLogger, "reading input file " << opt_ifname);
 
     error = fileformat.loadFile(opt_ifname, opt_ixfer, EGL_noChange, DCM_MaxReadLength, opt_readMode);
     if (error.bad())
     {
-        CERR << "Error: "
-             << error.text()
-             << ": reading file: " <<  opt_ifname << endl;
+        OFLOG_FATAL(dcmdjpegLogger, error.text() << ": reading file: " <<  opt_ifname);
         return 1;
     }
 
     DcmDataset *dataset = fileformat.getDataset();
 
-    if (opt_verbose)
-        COUT << "decompressing file" << endl;
+    OFLOG_INFO(dcmdjpegLogger, "decompressing file");
 
     DcmXfer opt_oxferSyn(opt_oxfer);
+    DcmXfer original_xfer(dataset->getOriginalXfer());
 
     error = dataset->chooseRepresentation(opt_oxfer, NULL);
     if (error.bad())
     {
-        CERR << "Error: "
-             << error.text()
-             << ": decompressing file: " <<  opt_ifname << endl;
-       if (error == EJ_UnsupportedColorConversion)
-           CERR << "Try --conv-never to disable color space conversion" << endl;
+        OFLOG_FATAL(dcmdjpegLogger, error.text() << ": decompressing file: " <<  opt_ifname);
+        if (error == EJ_UnsupportedColorConversion)
+            OFLOG_FATAL(dcmdjpegLogger, "Try --conv-never to disable color space conversion");
+        else if (error == EC_CannotChangeRepresentation)
+            OFLOG_FATAL(dcmdjpegLogger, "Input transfer syntax " << original_xfer.getXferName() << " not supported");
         return 1;
     }
 
     if (! dataset->canWriteXfer(opt_oxfer))
     {
-        CERR << "Error: no conversion to transfer syntax " << opt_oxferSyn.getXferName()
-             << " possible" << endl;
+        OFLOG_FATAL(dcmdjpegLogger, "no conversion to transfer syntax " << opt_oxferSyn.getXferName() << " possible");
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "creating output file " << opt_ofname << endl;
+    OFLOG_INFO(dcmdjpegLogger, "creating output file " << opt_ofname);
+
+    // update file meta information with new SOP Instance UID
+    if ((opt_uidcreation == EUC_always) && (opt_writeMode == EWM_fileformat))
+        opt_writeMode = EWM_updateMeta;
 
     fileformat.loadAllDataIntoMemory();
     error = fileformat.saveFile(opt_ofname, opt_oxfer, opt_oenctype, opt_oglenc,
-              opt_opadenc, (Uint32) opt_filepad, (Uint32) opt_itempad, opt_oDataset);
+        opt_opadenc, (Uint32) opt_filepad, (Uint32) opt_itempad, opt_writeMode);
     if (error != EC_Normal)
     {
-        CERR << "Error: "
-             << error.text()
-             << ": writing file: " <<  opt_ofname << endl;
+        OFLOG_FATAL(dcmdjpegLogger, error.text() << ": writing file: " <<  opt_ofname);
         return 1;
     }
 
-    if (opt_verbose)
-        COUT << "conversion successful" << endl;
+    OFLOG_INFO(dcmdjpegLogger, "conversion successful");
 
     // deregister global decompression codecs
     DJDecoderRegistration::cleanup();
@@ -371,6 +367,55 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcmdjpeg.cc,v $
+ * Revision 1.26  2010-10-14 13:13:38  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.25  2010-03-24 15:05:32  joergr
+ * Added new options for the color space conversion during decompression based
+ * on the color model that is "guessed" by the underlying JPEG library (IJG).
+ *
+ * Revision 1.24  2009-10-07 12:44:33  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.23  2009-08-21 09:37:16  joergr
+ * Only update file meta information if required (use new file write mode).
+ *
+ * Revision 1.22  2009-08-21 09:33:03  joergr
+ * Added parameter 'writeMode' to save/write methods which allows for specifying
+ * whether to write a dataset or fileformat as well as whether to update the
+ * file meta information or to create a new file meta information header.
+ * Use helper function checkDependence() and checkConflict() where appropriate.
+ *
+ * Revision 1.21  2009-08-05 10:30:00  joergr
+ * Fixed various issues with syntax usage (e.g. layout and formatting).
+ *
+ * Revision 1.20  2009-04-21 14:07:14  joergr
+ * Fixed minor inconsistencies in manpage / syntax usage.
+ *
+ * Revision 1.19  2009-03-19 12:11:24  joergr
+ * Added more explicit message in case input transfer syntax is not supported.
+ *
+ * Revision 1.18  2008-09-25 14:49:45  joergr
+ * Moved output of resource identifier in order to avoid printing the same
+ * information twice.
+ *
+ * Revision 1.17  2008-09-25 13:58:28  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.16  2006/08/16 16:30:20  meichel
+ * Updated all code in module dcmjpeg to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.15  2006/07/27 14:05:02  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
+ * Revision 1.14  2006/03/29 15:58:52  meichel
+ * Added support for decompressing images with 16 bits/pixel compressed with
+ *   a faulty lossless JPEG encoder that produces integer overflows in predictor 6.
+ *
  * Revision 1.13  2005/12/08 15:43:21  meichel
  * Changed include path schema for all DCMTK header files
  *
