@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1997-2005, OFFIS
+ *  Copyright (C) 2001-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmjpeg
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: abstract codec class for JPEG encoders.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/16 13:04:30 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmjpeg/libsrc/djcodece.cc,v $
- *  CVS/RCS Revision: $Revision: 1.22 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-11-03 11:22:38 $
+ *  CVS/RCS Revision: $Revision: 1.36 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -39,22 +34,22 @@
 #include "dcmtk/ofstd/ofstd.h"
 
 // dcmdata includes
-#include "dcmtk/dcmdata/dcdatset.h"  /* for class DcmDataset */
-#include "dcmtk/dcmdata/dcdeftag.h"  /* for tag constants */
-#include "dcmtk/dcmdata/dcovlay.h"   /* for class DcmOverlayData */
-#include "dcmtk/dcmdata/dcpixseq.h"  /* for class DcmPixelSequence */
-#include "dcmtk/dcmdata/dcpxitem.h"  /* for class DcmPixelItem */
-#include "dcmtk/dcmdata/dcuid.h"     /* for dcmGenerateUniqueIdentifer()*/
-#include "dcmtk/dcmdata/dcvrcs.h"    /* for class DcmCodeString */
-#include "dcmtk/dcmdata/dcvrds.h"    /* for class DcmDecimalString */
-#include "dcmtk/dcmdata/dcvrlt.h"    /* for class DcmLongText */
-#include "dcmtk/dcmdata/dcvrst.h"    /* for class DcmShortText */
-#include "dcmtk/dcmdata/dcvrus.h"    /* for class DcmUnsignedShort */
-#include "dcmtk/dcmdata/dcswap.h"    /* for swapIfNecessary */
+#include "dcmtk/dcmdata/dcdatset.h"   /* for class DcmDataset */
+#include "dcmtk/dcmdata/dcdeftag.h"   /* for tag constants */
+#include "dcmtk/dcmdata/dcovlay.h"    /* for class DcmOverlayData */
+#include "dcmtk/dcmdata/dcpixseq.h"   /* for class DcmPixelSequence */
+#include "dcmtk/dcmdata/dcpxitem.h"   /* for class DcmPixelItem */
+#include "dcmtk/dcmdata/dcuid.h"      /* for dcmGenerateUniqueIdentifer()*/
+#include "dcmtk/dcmdata/dcvrcs.h"     /* for class DcmCodeString */
+#include "dcmtk/dcmdata/dcvrds.h"     /* for class DcmDecimalString */
+#include "dcmtk/dcmdata/dcvrlt.h"     /* for class DcmLongText */
+#include "dcmtk/dcmdata/dcvrst.h"     /* for class DcmShortText */
+#include "dcmtk/dcmdata/dcvrus.h"     /* for class DcmUnsignedShort */
+#include "dcmtk/dcmdata/dcswap.h"     /* for swapIfNecessary */
 
 // dcmjpeg includes
-#include "dcmtk/dcmjpeg/djcparam.h"  /* for class DJCodecParameter */
-#include "dcmtk/dcmjpeg/djencabs.h"  /* for class DJEncoder */
+#include "dcmtk/dcmjpeg/djcparam.h"   /* for class DJCodecParameter */
+#include "dcmtk/dcmjpeg/djencabs.h"   /* for class DJEncoder */
 
 // dcmimgle includes
 #include "dcmtk/dcmimgle/dcmimage.h"  /* for class DicomImage */
@@ -75,50 +70,68 @@ DJCodecEncoder::~DJCodecEncoder()
 
 
 OFBool DJCodecEncoder::canChangeCoding(
-    const E_TransferSyntax oldRepType,
-    const E_TransferSyntax newRepType) const
+  const E_TransferSyntax oldRepType,
+  const E_TransferSyntax newRepType) const
 {
   E_TransferSyntax myXfer = supportedTransferSyntax();
   DcmXfer newRep(newRepType);
   DcmXfer oldRep(oldRepType);
   if (oldRep.isNotEncapsulated() && (newRepType == myXfer)) return OFTrue; // compress requested
 
-  // we don't support re-coding for now.
+  // we don't support re-coding for now
   return OFFalse;
 }
 
 
 OFCondition DJCodecEncoder::decode(
-    const DcmRepresentationParameter * /* fromRepParam */,
-    DcmPixelSequence * /* pixSeq */,
-    DcmPolymorphOBOW& /* uncompressedPixelData */,
-    const DcmCodecParameter * /* cp */,
-    const DcmStack& /* objStack */) const
+  const DcmRepresentationParameter * /* fromRepParam */,
+  DcmPixelSequence * /* pixSeq */,
+  DcmPolymorphOBOW& /* uncompressedPixelData */,
+  const DcmCodecParameter * /* cp */,
+  const DcmStack& /* objStack */) const
 {
   // we are an encoder only
   return EC_IllegalCall;
 }
 
-OFCondition DJCodecEncoder::encode(
-    const E_TransferSyntax /* fromRepType */,
-    const DcmRepresentationParameter * /* fromRepParam */,
-    DcmPixelSequence * /* fromPixSeq */,
-    const DcmRepresentationParameter * /* toRepParam */,
-    DcmPixelSequence * & /* toPixSeq */,
-    const DcmCodecParameter * /* cp */,
-    DcmStack & /* objStack */) const
+
+OFCondition DJCodecEncoder::decodeFrame(
+  const DcmRepresentationParameter * /* fromParam */ ,
+  DcmPixelSequence * /* fromPixSeq */ ,
+  const DcmCodecParameter * /* cp */ ,
+  DcmItem * /* dataset */ ,
+  Uint32 /* frameNo */ ,
+  Uint32& /* startFragment */ ,
+  void * /* buffer */ ,
+  Uint32 /* bufSize */ ,
+  OFString& /* decompressedColorModel */ ) const
 {
-  // we don't support re-coding for now.
+  // we are an encoder only
   return EC_IllegalCall;
 }
 
+
 OFCondition DJCodecEncoder::encode(
-        const Uint16 * /* pixelData */,
-        const Uint32 /* length */,
-        const DcmRepresentationParameter * toRepParam,
-        DcmPixelSequence * & pixSeq,
-        const DcmCodecParameter *cp,
-        DcmStack & objStack) const
+  const E_TransferSyntax /* fromRepType */,
+  const DcmRepresentationParameter * /* fromRepParam */,
+  DcmPixelSequence * /* fromPixSeq */,
+  const DcmRepresentationParameter * /* toRepParam */,
+  DcmPixelSequence * & /* toPixSeq */,
+  const DcmCodecParameter * /* cp */,
+  DcmStack & /* objStack */) const
+{
+  // we don't support re-coding for now
+  return EC_IllegalCall;
+}
+
+
+OFCondition DJCodecEncoder::encode(
+  const Uint16 * /* pixelData */,
+  const Uint32 /* length */,
+  const DcmRepresentationParameter * toRepParam,
+  DcmPixelSequence * & pixSeq,
+  const DcmCodecParameter *cp,
+  DcmStack & objStack) const
 {
   OFCondition result = EC_Normal;
   // assume we can cast the codec parameter to what we need
@@ -130,7 +143,7 @@ OFCondition DJCodecEncoder::encode(
     return encodeTrueLossless(toRepParam, pixSeq, cp, objStack);
 
   DcmStack localStack(objStack);
-  (void)localStack.pop();             // pop pixel data element from stack
+  (void)localStack.pop();                // pop pixel data element from stack
   DcmObject *dataset = localStack.pop(); // this is the item in which the pixel data is located
 
   if ((!dataset)||((dataset->ident()!= EVR_dataset) && (dataset->ident()!= EVR_item))) result = EC_InvalidTag;
@@ -160,6 +173,7 @@ OFCondition DJCodecEncoder::encode(
         result = encodeColorImage(OFTrue, (DcmItem *)dataset, toRepParam, pixSeq, djcp, compressionRatio);
         break;
       case EPI_Unknown:
+      case EPI_Missing:
         // unknown color model - bail out
         result = EJ_UnsupportedPhotometricInterpretation;
         break;
@@ -191,21 +205,13 @@ OFCondition DJCodecEncoder::encode(
 
       if (result.good())
       {
-        if (isLosslessProcess())
-        {
-          // lossless process - create new UID if mode is EUC_always or if we're converting to Secondary Capture
-          if (djcp->getConvertToSC() || (djcp->getUIDCreation() == EUC_always)) result =
-            DcmCodec::newInstance((DcmItem *)dataset, "DCM", "121320", "Uncompressed predecessor");
-        }
-        else
-        {
-          // lossy process - create new UID unless mode is EUC_never and we're not converting to Secondary Capture
-          if (djcp->getConvertToSC() || (djcp->getUIDCreation() != EUC_never))
-            result = DcmCodec::newInstance((DcmItem *)dataset, "DCM", "121320", "Uncompressed predecessor");
+        // lossy process - create new UID unless mode is EUC_never and we're not converting to Secondary Capture
+        // (pseudo-lossless mode may also result in lossy compression, so treat it the same way)
+        if (djcp->getConvertToSC() || (djcp->getUIDCreation() != EUC_never))
+          result = DcmCodec::newInstance((DcmItem *)dataset, "DCM", "121320", "Uncompressed predecessor");
 
-          // update lossy compression ratio
-          if (result.good()) result = updateLossyCompressionRatio((DcmItem *)dataset, compressionRatio);
-        }
+        // update lossy compression ratio
+        if (result.good()) result = updateLossyCompressionRatio((DcmItem *)dataset, compressionRatio);
       }
 
       // convert to Secondary Capture if requested by user.
@@ -218,13 +224,24 @@ OFCondition DJCodecEncoder::encode(
 }
 
 
+OFCondition DJCodecEncoder::determineDecompressedColorModel(
+    const DcmRepresentationParameter * /* fromParam */,
+    DcmPixelSequence * /* fromPixSeq */,
+    const DcmCodecParameter * /* cp */,
+    DcmItem * /* dataset */,
+    OFString & /* decompressedColorModel */) const
+{
+    return EC_IllegalCall;
+}
+
+
 OFCondition DJCodecEncoder::encodeColorImage(
-        OFBool YBRmode,
-        DcmItem *dataset,
-        const DcmRepresentationParameter * toRepParam,
-        DcmPixelSequence * & pixSeq,
-        const DJCodecParameter *cp,
-        double& compressionRatio) const
+  OFBool YBRmode,
+  DcmItem *dataset,
+  const DcmRepresentationParameter * toRepParam,
+  DcmPixelSequence * & pixSeq,
+  const DJCodecParameter *cp,
+  double& compressionRatio) const
 {
   OFCondition result = EC_Normal;
   DcmOffsetList offsetList;
@@ -424,10 +441,10 @@ OFCondition DJCodecEncoder::encodeColorImage(
 
 
 OFCondition DJCodecEncoder::encodeTrueLossless(
-        const DcmRepresentationParameter * toRepParam,
-        DcmPixelSequence * & pixSeq,
-        const DcmCodecParameter *cp,
-        DcmStack & objStack) const
+  const DcmRepresentationParameter * toRepParam,
+  DcmPixelSequence * & pixSeq,
+  const DcmCodecParameter *cp,
+  DcmStack & objStack) const
 {
   OFCondition result = EC_Normal;
   // assume we can cast the codec parameter to what we need
@@ -457,14 +474,14 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
     EP_Interpretation interpr = EPI_Unknown;
     Uint8 *jpegData = NULL;
     Uint32 jpegLen  = 0;
-    OFBool byteSwapped = OFFalse;  // true if we have byte-swapped the original pixel data
+    OFBool byteSwapped = OFFalse;      // true if we have byte-swapped the original pixel data
     OFBool planConfSwitched = OFFalse; // true if planar configuration was toggled
     DcmOffsetList offsetList;
     OFString photometricInterpretation;
     DcmElement *dummyElem;
 
     // get relevant attributes for encoding from dataset
-    OFCondition result = datsetItem->findAndGetUint16(DCM_BitsStored, bitsStored);
+    result = datsetItem->findAndGetUint16(DCM_BitsStored, bitsStored);
     if (result.good()) result = datsetItem->findAndGetUint16(DCM_BitsAllocated, bitsAllocated);
     if (result.good()) result = datsetItem->findAndGetUint16(DCM_SamplesPerPixel, samplesPerPixel);
     if (result.good()) result = datsetItem->findAndGetUint16(DCM_Columns, columns);
@@ -481,7 +498,7 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
     }
     if (result.bad())
     {
-      CERR << "True Lossless Encoder: Unable to get relevant attributes from dataset" << endl;
+      DCMJPEG_ERROR("True lossless encoder: Unable to get relevant attributes from dataset");
       return result;
     }
 
@@ -492,14 +509,14 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
       bytesAllocated = 2;
     else
     {
-      CERR << "True lossless encoder: only 8 or 16 bits allocated supported" << endl;
+      DCMJPEG_ERROR("True lossless encoder: Only 8 or 16 bits allocated supported");
       return EC_IllegalParameter;
     }
 
     // make sure that all the descriptive attributes have sensible values
     if ((columns < 1)||(rows < 1)||(samplesPerPixel < 1))
     {
-      CERR << "Invalid attribute values in pixel module" << endl;
+      DCMJPEG_ERROR("True lossless encoder: Invalid attribute values in pixel module");
       return EC_CannotChangeRepresentation;
     }
 
@@ -520,7 +537,7 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
               (photometricInterpretation == "YBR_ICT")         ||
               (photometricInterpretation == "YBR_RCT") )
     {
-      CERR << "True lossless encoder: photometric interpretation not supported: " << photometricInterpretation << endl;
+      DCMJPEG_ERROR("True lossless encoder: Photometric interpretation not supported: " << photometricInterpretation);
       return EC_IllegalParameter;
     }
     else    // Palette, HSV, ARGB, CMYK
@@ -541,21 +558,26 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
     }
     if (result.bad())
     {
-        CERR << "True Lossless Encoder: Unable to change Planar Configuration for encoding" << endl;
+        DCMJPEG_ERROR("True lossless encoder: Unable to change Planar Configuration from 'by plane' to 'by pixel' for encoding");
         return result;
     }
 
-    //check whether enough raw data is available for encoding
+    // check whether enough raw data is available for encoding
     if (bytesAllocated * samplesPerPixel * columns * rows * OFstatic_cast(unsigned long,numberOfFrames) > length)
     {
-      CERR << "True lossless encoder: Can not change representation, not enough data" << endl;
-      result = EC_CannotChangeRepresentation;
+      DCMJPEG_ERROR("True lossless encoder: Cannot change representation, not enough data");
+      return EC_CannotChangeRepresentation;
     }
 
     // byte swap pixel data to little endian if bits allocated is 8
     if ((gLocalByteOrder == EBO_BigEndian) && (bitsAllocated == 8))
     {
-      swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, OFstatic_cast(void *, OFconst_cast(Uint16 *, pixelData)), length, sizeof(Uint16));
+      result = swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, OFstatic_cast(void *, OFconst_cast(Uint16 *, pixelData)), length, sizeof(Uint16));
+      if ( result.bad() )
+      {
+        DCMJPEG_ERROR("True lossless encoder: Unable to swap bytes to respect local byte ordering");
+        return EC_CannotChangeRepresentation;
+      }
       byteSwapped = OFTrue;
     }
 
@@ -601,7 +623,7 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
         framePointer+=frameSize;
         if (jpegLen == 0)
         {
-          CERR << "True lossless encoder: Error encoding frame" << endl;
+          DCMJPEG_ERROR("True lossless encoder: Error encoding frame");
           result = EC_CannotChangeRepresentation;
         }
         else
@@ -614,7 +636,7 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
     }
     else
     {
-      CERR << "True lossless Encoder: Cannot allocate encoder instance" << endl;
+      DCMJPEG_ERROR("True lossless encoder: Cannot allocate encoder instance");
       result = EC_IllegalCall;
     }
     if (result.good())
@@ -625,25 +647,37 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
     else
       delete pixelSequence;
     delete jpeg; // encoder no longer in use
+
+    if ((result.good()) && (djcp->getCreateOffsetTable()))
+    {
+      // create offset table
+      result = offsetTable->createOffsetTable(offsetList);
+    }
+
     // the following operations do not affect the Image Pixel Module
     // but other modules such as SOP Common.  We only perform these
     // changes if we're on the main level of the datsetItem,
     // which should always identify itself as datsetItem, not as item.
-    if (result.good())
-      result = updateDerivationDescription(datsetItem, toRepParam, djcp, OFstatic_cast(Uint8, bitsAllocated), compressionRatio);
 
-    if ( (datsetItem->ident() == EVR_item) && result.good() )
+    // update derivation description reflecting the JPEG compression applied
+    result = updateDerivationDescription(datsetItem, toRepParam, djcp, OFstatic_cast(Uint8, bitsAllocated), compressionRatio);
+
+    if ( (datsetItem->ident() == EVR_dataset) && result.good() )
     {
       // convert to Secondary Capture if requested by user.
       // This method creates a new SOP class UID, so it should be executed
       // after the call to newInstance() which creates a Source Image Sequence.
       if ( djcp->getConvertToSC() || (djcp->getUIDCreation() == EUC_always) )
       {
-        result = DcmCodec::convertToSecondaryCapture(datsetItem);
+        if (djcp->getConvertToSC())
+        {
+          result = DcmCodec::convertToSecondaryCapture(datsetItem);
+        }
         // update image type (set to DERIVED)
         if (result.good())
           result = DcmCodec::updateImageType(datsetItem);
-        result = DcmCodec::newInstance((DcmItem *)datsetItem, "DCM", "121320", "Uncompressed predecessor");
+        if (result.good())
+          result = DcmCodec::newInstance((DcmItem *)datsetItem, "DCM", "121320", "Uncompressed predecessor");
       }
     }
     // switch _original_ pixel data back to "color by plane", if required
@@ -658,6 +692,11 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
         // update Planar Configuration in dataset
         result = updatePlanarConfiguration(datsetItem, 0 /* update to "by pixel" */);
       }
+      else
+      {
+        DCMJPEG_ERROR("True lossless encoder: Cannot switch back to original planar configuration of the pixel data");
+        result = EC_CannotChangeRepresentation;
+      }
     }
     // byte swap pixel data back to local endian if necessary
     if (byteSwapped)
@@ -666,13 +705,17 @@ OFCondition DJCodecEncoder::encodeTrueLossless(
   return result;
 }
 
-void DJCodecEncoder::appendCompressionRatio(OFString& arg, double ratio)
+
+void DJCodecEncoder::appendCompressionRatio(
+  OFString& arg,
+  double ratio)
 {
   char buf[64];
   OFStandard::ftoa(buf, sizeof(buf), ratio, OFStandard::ftoa_uppercase, 0, 5);
   arg += buf;
 }
 
+
 OFCondition DJCodecEncoder::updateLossyCompressionRatio(
   DcmItem *dataset,
   double ratio) const
@@ -725,6 +768,7 @@ OFCondition DJCodecEncoder::updateLossyCompressionRatio(
   return dataset->putAndInsertString(DCM_LossyImageCompressionMethod, m.c_str());
 }
 
+
 OFCondition DJCodecEncoder::updateDerivationDescription(
   DcmItem *dataset,
   const DcmRepresentationParameter * toRepParam,
@@ -759,8 +803,8 @@ OFCondition DJCodecEncoder::updateDerivationDescription(
     DJCodecParameter *djcp = (DJCodecParameter *)cp;
 
     if (djcp->getTrueLosslessMode())
-      result = DcmCodec::insertCodeSequence(dataset, DCM_DerivationCodeSequence, "DCM", "121327", "Full fidelity image, uncompressed or lossless compressed");
-    else
+      result = DcmCodec::insertCodeSequence(dataset, DCM_DerivationCodeSequence, "DCM", "121327", "Full fidelity image");
+    else // pseudo-lossless mode may also result in lossy compression
       result = DcmCodec::insertCodeSequence(dataset, DCM_DerivationCodeSequence, "DCM", "113040", "Lossy Compression");
   }
   return result;
@@ -832,11 +876,11 @@ OFCondition DJCodecEncoder::adjustOverlays(
 
 
 OFCondition DJCodecEncoder::encodeMonochromeImage(
-        DcmItem *dataset,
-        const DcmRepresentationParameter * toRepParam,
-        DcmPixelSequence * & pixSeq,
-        const DJCodecParameter *cp,
-        double& compressionRatio) const
+  DcmItem *dataset,
+  const DcmRepresentationParameter * toRepParam,
+  DcmPixelSequence * & pixSeq,
+  const DJCodecParameter *cp,
+  double& compressionRatio) const
 {
   OFCondition result = EC_Normal;
   DcmOffsetList offsetList;
@@ -881,7 +925,10 @@ OFCondition DJCodecEncoder::encodeMonochromeImage(
   // don't render overlays
   dimage.hideAllOverlays();
 
-  // original pixel depth of source image
+  // actual pixel depth of source image which can be different from Bits Stored
+  // e. g. when Modality LUT (if enabled) shifts pixel values to a smaller
+  // range or if the pixel values itself do not make use of the "Bits Stored"
+  // full range available.
   int pixelDepth = dimage.getDepth();
 
   // create overlay data for embedded overlays
@@ -921,7 +968,7 @@ OFCondition DJCodecEncoder::encodeMonochromeImage(
             // needs special handling.  This is not an issue if we're converting to
             // secondary capture anyway.
             if ((0 == strcmp(classUID, UID_XRayAngiographicImageStorage)) ||
-                (0 == strcmp(classUID, UID_XRayFluoroscopyImageStorage)) ||
+                (0 == strcmp(classUID, UID_XRayRadiofluoroscopicImageStorage)) ||
                 (0 == strcmp(classUID, UID_RETIRED_XRayAngiographicBiPlaneImageStorage)))
             {
               mode_XA = OFTrue;
@@ -941,12 +988,14 @@ OFCondition DJCodecEncoder::encodeMonochromeImage(
           // query image range and extreme values
           if (result.good())
           {
+            // technically possible min/max values
             if (! dimage.getMinMaxValues(minRange, maxRange, 1)) result = EC_IllegalCall;
             if (maxRange <= minRange) result = EC_IllegalCall;
           }
 
           if (result.good())
           {
+            // actually present min/max values in pixel data
             if (! dimage.getMinMaxValues(minUsed, maxUsed, 0)) result = EC_IllegalCall;
             if (maxUsed < minUsed) result = EC_IllegalCall;
           }
@@ -1191,11 +1240,14 @@ OFCondition DJCodecEncoder::encodeMonochromeImage(
     // update Modality LUT Module and Pixel Intensity Relationship
     if (windowType == 0)
     {
-      if (mode_XA)
+      if (mode_XA) // XA needs special handling
       {
         // XA Mode: set Pixel Intensity Relationship to "DISP", no Modality LUT
         if (result.good()) result = dataset->putAndInsertString(DCM_PixelIntensityRelationship, "DISP");
       }
+      /* else if we had a modality LUT before, a LUT is inserted again.
+         or if specific rescale slope/intercept has been computed, use that in image
+       */
       else if (foundModalityLUT || rescaleSlope != 1.0 || rescaleIntercept != 0.0)
       {
         char buf[64];
@@ -1212,7 +1264,7 @@ OFCondition DJCodecEncoder::encodeMonochromeImage(
     }
     else
     {
-      // if we had found a Modality LUT Transformation, create a new identity transformation
+      // if we had found a Modality LUT Transformation, create a identity LUT transformation
       if (foundModalityLUT)
       {
         if (result.good()) result = dataset->putAndInsertString(DCM_RescaleIntercept, "0");
@@ -1266,15 +1318,17 @@ OFCondition DJCodecEncoder::encodeMonochromeImage(
       }
     }
   }
+
+  // determine compression ratio
   if (compressedSize > 0) compressionRatio = uncompressedSize / compressedSize;
   return result;
 }
 
 
 OFCondition DJCodecEncoder::correctVOIWindows(
-        DcmItem *dataset,
-        double voiOffset,
-        double voiFactor)
+  DcmItem *dataset,
+  double voiOffset,
+  double voiFactor)
 {
   if (voiOffset == 0.0 && voiFactor == 1.0) return EC_Normal;
 
@@ -1312,13 +1366,15 @@ OFCondition DJCodecEncoder::correctVOIWindows(
   if (center && width)
   {
     unsigned long numWindows = center->getVM();
+    // iterate over all defined VOI windows
     for (unsigned long i=0; i<numWindows; i++)
     {
       if (((center->getFloat64(currentCenter,i)).good()) && ((width->getFloat64(currentWidth,i)).good()))
       {
-        // found one pair of values
+        // found one pair of values, adapt them to value range shifted pixel data
         tempCenter = (currentCenter+voiOffset)*voiFactor;
         tempWidth = currentWidth * voiFactor;
+        // add this window to the attribute values that are later replacing old windows
         OFStandard::ftoa(buf, sizeof(buf), tempCenter, OFStandard::ftoa_uppercase, 0, 6);
         if (newCenter.length() > 0) newCenter += "\\";
         newCenter += buf;
@@ -1342,10 +1398,12 @@ OFCondition DJCodecEncoder::correctVOIWindows(
     }
   }
 
+  // remove old windows
   delete dataset->remove(DCM_WindowCenter);
   delete dataset->remove(DCM_WindowWidth);
   delete dataset->remove(DCM_WindowCenterWidthExplanation);
 
+  // and insert newly computed ones if necessary
   if (newCenter.length() > 0)
   {
     if (result.good()) result = dataset->putAndInsertString(DCM_WindowCenter, newCenter.c_str());
@@ -1356,11 +1414,12 @@ OFCondition DJCodecEncoder::correctVOIWindows(
   return result;
 }
 
+
 OFCondition DJCodecEncoder::togglePlanarConfiguration8(
-    Uint8 *pixelData,
-    const unsigned long numValues,
-    const Uint16 samplesPerPixel,
-    const Uint16 oldPlanarConfig)
+  Uint8 *pixelData,
+  const unsigned long numValues,
+  const Uint16 samplesPerPixel,
+  const Uint16 oldPlanarConfig)
 {
   if ( (pixelData == NULL) || (numValues%samplesPerPixel != 0) )
     return EC_IllegalParameter;
@@ -1393,10 +1452,10 @@ OFCondition DJCodecEncoder::togglePlanarConfiguration8(
 
 
 OFCondition DJCodecEncoder::togglePlanarConfiguration16(
-    Uint16 *pixelData,
-    const unsigned long numValues, //number of 16-bit components
-    const Uint16 samplesPerPixel,
-    const Uint16 oldPlanarConfig)
+  Uint16 *pixelData,
+  const unsigned long numValues, //number of 16-bit components
+  const Uint16 samplesPerPixel,
+  const Uint16 oldPlanarConfig)
 {
   if ( (pixelData == NULL) || (numValues%samplesPerPixel != 0) )
     return EC_IllegalParameter;
@@ -1429,17 +1488,76 @@ OFCondition DJCodecEncoder::togglePlanarConfiguration16(
 
 
 OFCondition DJCodecEncoder::updatePlanarConfiguration(
-    DcmItem *item,
-    const Uint16 newPlanConf) const
+  DcmItem *item,
+  const Uint16 newPlanConf) const
 {
   if ( (item == NULL) || (newPlanConf) > 1)
     return EC_IllegalParameter;
   return item->putAndInsertUint16(DCM_PlanarConfiguration, newPlanConf);
 }
 
+
 /*
  * CVS/RCS Log
  * $Log: djcodece.cc,v $
+ * Revision 1.36  2010-11-03 11:22:38  joergr
+ * Since the pseudo-lossless encoder is not guaranteed to result in lossless
+ * compression, the modifications to the DICOM header are treated in the same
+ * way as for lossy compression (e.g Lossy Compression Flag is set to "01").
+ *
+ * Revision 1.35  2010-10-14 13:14:21  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.34  2010-09-24 13:26:22  joergr
+ * Compared names of SOP Class UIDs with 2009 edition of the DICOM standard. The
+ * resulting name changes are mainly caused by the fact that the corresponding
+ * SOP Class is now retired.
+ *
+ * Revision 1.33  2010-06-01 16:17:57  onken
+ * Added some comments and line breaks (improved code readability).
+ *
+ * Revision 1.32  2010-05-27 17:00:18  joergr
+ * Added missing basic offset table to "true lossless" mode (if enabled).
+ * Revised wording of log message.
+ *
+ * Revision 1.31  2009-11-20 16:52:39  onken
+ * Fixed bug in JPEG true lossless encoder which prohibited the generation
+ * of a new SOP Instance UID if desired by the user or if image is
+ * converted to Secondary Capture.
+ *
+ * Revision 1.30  2009-11-17 16:45:22  joergr
+ * Added new method that allows for determining the color model of the
+ * decompressed image.
+ *
+ * Revision 1.29  2009-10-07 12:44:33  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.28  2009-09-28 09:12:46  joergr
+ * Fixed typo in error message. Reformatted source code.
+ *
+ * Revision 1.27  2009-08-04 06:54:47  meichel
+ * Fixed incorrect code meaning string.
+ *
+ * Revision 1.26  2009-03-24 09:22:07  onken
+ * Removed doubled result variable declaration in true lossless encoder
+ * which may have lad the function to return success even in case of errors.
+ *
+ * Revision 1.25  2008-05-29 10:48:46  meichel
+ * Implemented new method DcmPixelData::getUncompressedFrame
+ *   that permits frame-wise access to compressed and uncompressed
+ *   objects without ever loading the complete object into main memory.
+ *   For this new method to work with compressed images, all classes derived from
+ *   DcmCodec need to implement a new method decodeFrame(). For now, only
+ *   dummy implementations returning an error code have been defined.
+ *
+ * Revision 1.24  2006/08/16 16:30:21  meichel
+ * Updated all code in module dcmjpeg to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.23  2006/08/02 10:17:42  onken
+ * Fixed segfault in true lossless encoder in case of not enough pixel data.
+ * Minor corrections and enhancements regarding error handling and messages.
+ *
  * Revision 1.22  2005/12/16 13:04:30  meichel
  * Added typecasts to avoid warnings on VS2005
  *
@@ -1523,4 +1641,3 @@ OFCondition DJCodecEncoder::updatePlanarConfiguration(
  *
  *
  */
-
