@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2001-2005, OFFIS
+ *  Copyright (C) 2001-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmjpeg
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: decompression routines of the IJG JPEG library configured for 16 bits/sample.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:43:37 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmjpeg/libsrc/djdijg16.cc,v $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:21 $
+ *  CVS/RCS Revision: $Revision: 1.23 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -34,10 +29,11 @@
 #include "dcmtk/config/osconfig.h"
 #include "dcmtk/dcmjpeg/djdijg16.h"
 #include "dcmtk/dcmjpeg/djcparam.h"
-#include "dcmtk/ofstd/ofconsol.h"
+#include "dcmtk/dcmdata/dcerror.h"
 
 #define INCLUDE_CSTDIO
 #define INCLUDE_CSETJMP
+#define INCLUDE_CSTRING
 #include "dcmtk/ofstd/ofstdinc.h"
 
 // These two macros are re-defined in the IJG header files.
@@ -61,6 +57,12 @@ BEGIN_EXTERN_C
 #undef const
 #endif
 
+#ifdef USE_STD_CXX_INCLUDES
+// Solaris defines longjmp() in namespace std, other compilers don't...
+namespace std { }
+using namespace std;
+#endif
+
 // private error handler struct
 struct DJDIJG16ErrorStruct
 {
@@ -92,7 +94,7 @@ struct DJDIJG16SourceManagerStruct
 
 // callback forward declarations
 void DJDIJG16ErrorExit(j_common_ptr);
-void DJDIJG16OutputMessage(j_common_ptr cinfo);
+void DJDIJG16EmitMessage(j_common_ptr cinfo, int msg_level);
 void DJDIJG16initSource(j_decompress_ptr);
 ijg_boolean DJDIJG16fillInputBuffer(j_decompress_ptr);
 void DJDIJG16skipInputData(j_decompress_ptr, long);
@@ -109,10 +111,10 @@ void DJDIJG16ErrorExit(j_common_ptr cinfo)
 }
 
 // message handler for warning messages and the like
-void DJDIJG16OutputMessage(j_common_ptr cinfo)
+void DJDIJG16EmitMessage(j_common_ptr cinfo, int msg_level)
 {
   DJDIJG16ErrorStruct *myerr = (DJDIJG16ErrorStruct *)cinfo->err;
-  myerr->instance->outputMessage();
+  myerr->instance->emitMessage(msg_level);
 }
 
 
@@ -240,7 +242,7 @@ OFCondition DJDecompressIJG16Bit::init()
       cinfo->err = jpeg_std_error(& OFconst_cast(DJDIJG16ErrorStruct *, jerr)->pub);
       jerr->instance = this;
       jerr->pub.error_exit = DJDIJG16ErrorExit;
-      jerr->pub.output_message = DJDIJG16OutputMessage;
+      jerr->pub.emit_message = DJDIJG16EmitMessage;
       if (setjmp(OFconst_cast(DJDIJG16ErrorStruct *, jerr)->setjmp_buffer))
       {
         // the IJG error handler will cause the following code to be executed
@@ -258,6 +260,8 @@ OFCondition DJDecompressIJG16Bit::init()
     }
     jpeg_create_decompress(cinfo);
     cinfo->src = &OFconst_cast(DJDIJG16SourceManagerStruct *, src)->pub;
+    cinfo->workaround_options = 0;
+    if (cparam->predictor6WorkaroundEnabled()) cinfo->workaround_options |= WORKAROUND_PREDICTOR6OVERFLOW;
   } else return EC_MemoryExhausted;
 
   // everything OK
@@ -290,18 +294,18 @@ OFCondition DJDecompressIJG16Bit::decode(
 
   if (setjmp(((DJDIJG16ErrorStruct *)(cinfo->err))->setjmp_buffer))
   {
-     // the IJG error handler will cause the following code to be executed
-     char buffer[JMSG_LENGTH_MAX];
-     (*cinfo->err->format_message)((jpeg_common_struct *)cinfo, buffer); /* Create the message */
-     cleanup();
-     return makeOFCondition(OFM_dcmjpeg, EJCode_IJG16_Decompression, OF_error, buffer);
+    // the IJG error handler will cause the following code to be executed
+    char buffer[JMSG_LENGTH_MAX];
+    (*cinfo->err->format_message)((jpeg_common_struct *)cinfo, buffer); /* Create the message */
+    cleanup();
+    return makeOFCondition(OFM_dcmjpeg, EJCode_IJG16_Decompression, OF_error, buffer);
   }
 
   // feed compressed buffer into cinfo structure.
   // The buffer will be activated by the next call to DJDIJG16fillInputBuffer.
   DJDIJG16SourceManagerStruct *src = (DJDIJG16SourceManagerStruct *)(cinfo->src);
-  src->next_buffer            = compressedFrameBuffer;
-  src->next_buffer_size       = compressedFrameBufferSize;
+  src->next_buffer = compressedFrameBuffer;
+  src->next_buffer_size = compressedFrameBufferSize;
 
   // Obtain image info
   if (suspension < 2)
@@ -314,26 +318,65 @@ OFCondition DJDecompressIJG16Bit::decode(
 
     // check if color space conversion is enabled
     OFBool colorSpaceConversion = OFFalse;
-    switch(cparam->getDecompressionColorSpaceConversion())
+    // check whether to use the IJG library guess for the JPEG color space
+    OFBool colorSpaceGuess = OFFalse;
+    switch (cparam->getDecompressionColorSpaceConversion())
     {
-        case EDC_photometricInterpretation: // color space conversion if DICOM photometric interpretation is YCbCr
-          colorSpaceConversion = dicomPhotometricInterpretationIsYCbCr;
-          break;
-        case EDC_lossyOnly: // color space conversion if lossy JPEG
-          if (cinfo->process != JPROC_LOSSLESS) colorSpaceConversion = OFTrue;
-          break;
-        case EDC_always: // always do color space conversion
+      case EDC_photometricInterpretation: // color space conversion if DICOM photometric interpretation is YCbCr
+        colorSpaceConversion = dicomPhotometricInterpretationIsYCbCr;
+        break;
+      case EDC_lossyOnly: // color space conversion if lossy JPEG
+        if (cinfo->process != JPROC_LOSSLESS)
           colorSpaceConversion = OFTrue;
-          break;
-        case EDC_never: // never do color space conversion
-          break;
+        break;
+      case EDC_always: // always do color space conversion
+        colorSpaceConversion = OFTrue;
+        break;
+      case EDC_never: // never do color space conversion
+        break;
+      case EDC_guessLossyOnly: // use color space guess by IJG library if lossy JPEG
+        if (cinfo->process != JPROC_LOSSLESS)
+        {
+          colorSpaceGuess = OFTrue;
+          if (cinfo->jpeg_color_space == JCS_YCbCr)
+            colorSpaceConversion = OFTrue;
+        }
+        break;
+      case EDC_guess: // always use color space guess by IJG library
+        colorSpaceGuess = OFTrue;
+        if (cinfo->jpeg_color_space == JCS_YCbCr)
+          colorSpaceConversion = OFTrue;
+        break;
     }
-    //  Decline color space conversion to RGB for signed pixel data, because IJG can handle only unsigned
-    if ( colorSpaceConversion && isSigned )
+    // decline color space conversion to RGB for signed pixel data,
+    // because IJG can handle only unsigned
+    if (colorSpaceConversion && isSigned)
       return EJ_UnsupportedColorConversion;
 
-    // Set color space for decompression
-    if (colorSpaceConversion)
+    // let the IJG library guess the JPEG color space
+    if (colorSpaceGuess)
+    {
+      switch (cinfo->jpeg_color_space)
+      {
+        case JCS_GRAYSCALE:
+          // cinfo->out_color_space = JCS_GRAYSCALE;
+          decompressedColorModel = EPI_Monochrome2;
+          break;
+        case JCS_YCbCr: // enforce conversion YCbCr to RGB
+          cinfo->out_color_space = JCS_RGB;
+          decompressedColorModel = EPI_RGB;
+          break;
+        case JCS_RGB:
+          // cinfo->out_color_space = JCS_RGB;
+          decompressedColorModel = EPI_RGB;
+          break;
+        default:
+          decompressedColorModel = EPI_Unknown;
+          break;
+      }
+    }
+    // set color space for decompression
+    else if (colorSpaceConversion)
     {
       switch (cinfo->out_color_space)
       {
@@ -356,28 +399,7 @@ OFCondition DJDecompressIJG16Bit::decode(
     }
     else
     {
-#ifdef DETERMINE_OUTPUT_COLOR_SPACE_FROM_IJG_GUESS
-      // let the IJG library guess the JPEG color space
-      // and use it as the value for decompressedColorModel.
-      switch (cinfo->jpeg_color_space)
-      {
-        case JCS_GRAYSCALE:
-          decompressedColorModel = EPI_Monochrome2;
-          break;
-        case JCS_YCbCr:
-          decompressedColorModel = EPI_YBR_Full;
-          break;
-        case JCS_RGB:
-          decompressedColorModel = EPI_RGB;
-          break;
-        default:
-          decompressedColorModel = EPI_Unknown;
-          break;
-      }
-#else
       decompressedColorModel = EPI_Unknown;
-#endif
-
       // prevent the library from performing any color space conversion
       cinfo->jpeg_color_space = JCS_UNKNOWN;
       cinfo->out_color_space = JCS_UNKNOWN;
@@ -429,20 +451,73 @@ OFCondition DJDecompressIJG16Bit::decode(
   return EC_Normal;
 }
 
-void DJDecompressIJG16Bit::outputMessage() const
+void DJDecompressIJG16Bit::emitMessage(int msg_level) const
 {
-  if (cinfo && cparam->isVerbose())
+  // This is how we map the message levels:
+  // -1 - 0: Warning (could also be errors, but no way to find out)
+  //  1    : Debug
+  // Everything else: Trace (No point in splitting this further up)
+  OFLogger::LogLevel level;
+
+  switch (msg_level)
+  {
+  case -1:
+  case 0:
+    level = OFLogger::WARN_LOG_LEVEL;
+    break;
+  case 1:
+    level = OFLogger::DEBUG_LOG_LEVEL;
+    break;
+  default:
+    level = OFLogger::TRACE_LOG_LEVEL;
+    break;
+  }
+
+  if (cinfo && DCM_dcmjpegGetLogger().isEnabledFor(level))
   {
     char buffer[JMSG_LENGTH_MAX];
     (*cinfo->err->format_message)((jpeg_common_struct *)cinfo, buffer); /* Create the message */
-    ofConsole.lockCerr() << buffer << endl;
-    ofConsole.unlockCerr();
+    DCM_dcmjpegGetLogger().forcedLog(level, buffer, __FILE__, __LINE__);
   }
 }
 
 /*
  * CVS/RCS Log
  * $Log: djdijg16.cc,v $
+ * Revision 1.23  2010-10-14 13:14:21  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.22  2010-06-25 09:15:19  uli
+ * Fixed issues with compiling with HAVE_STD_STRING.
+ *
+ * Revision 1.21  2010-03-24 14:57:40  joergr
+ * Added new options for the color space conversion during decompression based
+ * on the color model that is "guessed" by the underlying JPEG library (IJG).
+ *
+ * Revision 1.20  2010-03-01 09:08:48  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.19  2010-02-22 11:39:54  uli
+ * Remove some unneeded includes.
+ *
+ * Revision 1.18  2009-11-18 16:17:54  uli
+ * Use more than just the INFO log level.
+ *
+ * Revision 1.17  2009-10-07 12:44:33  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.16  2009-08-19 12:19:19  meichel
+ * Unlike some other compilers, Sun Studio 11 on Solaris
+ *   declares longjmp() in namespace std. Added code to handle this case.
+ *
+ * Revision 1.15  2006-08-16 16:30:21  meichel
+ * Updated all code in module dcmjpeg to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.14  2006/03/29 15:58:52  meichel
+ * Added support for decompressing images with 16 bits/pixel compressed with
+ *   a faulty lossless JPEG encoder that produces integer overflows in predictor 6.
+ *
  * Revision 1.13  2005/12/08 15:43:37  meichel
  * Changed include path schema for all DCMTK header files
  *
