@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1997-2005, OFFIS
+ *  Copyright (C) 1997-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmjpeg
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: compression routines of the IJG JPEG library configured for 8 bits/sample. 
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:43:41 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmjpeg/libsrc/djeijg8.cc,v $
- *  CVS/RCS Revision: $Revision: 1.7 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:22 $
+ *  CVS/RCS Revision: $Revision: 1.15 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -34,10 +29,11 @@
 #include "dcmtk/config/osconfig.h"
 #include "dcmtk/dcmjpeg/djeijg8.h"
 #include "dcmtk/dcmjpeg/djcparam.h"
-#include "dcmtk/ofstd/ofconsol.h"
+#include "dcmtk/dcmdata/dcerror.h"
 
 #define INCLUDE_CSTDIO
 #define INCLUDE_CSETJMP
+#define INCLUDE_CSTRING
 #include "dcmtk/ofstd/ofstdinc.h"
 
 // These two macros are re-defined in the IJG header files.
@@ -65,6 +61,12 @@ BEGIN_EXTERN_C
 #undef const
 #endif
 
+#ifdef USE_STD_CXX_INCLUDES
+// Solaris defines longjmp() in namespace std, other compilers don't...
+namespace std { }
+using namespace std;
+#endif
+
 // private error handler struct
 struct DJEIJG8ErrorStruct
 {
@@ -80,7 +82,7 @@ struct DJEIJG8ErrorStruct
 
 // callback forward declarations
 void DJEIJG8ErrorExit(j_common_ptr);
-void DJEIJG8OutputMessage(j_common_ptr cinfo);
+void DJEIJG8EmitMessage(j_common_ptr cinfo, int msg_level);
 void DJEIJG8initDestination(j_compress_ptr cinfo);
 ijg_boolean DJEIJG8emptyOutputBuffer(j_compress_ptr cinfo);
 void DJEIJG8termDestination(j_compress_ptr cinfo);
@@ -97,10 +99,10 @@ void DJEIJG8ErrorExit(j_common_ptr cinfo)
 }
 
 // message handler for warning messages and the like
-void DJEIJG8OutputMessage(j_common_ptr cinfo)
+void DJEIJG8EmitMessage(j_common_ptr cinfo, int msg_level)
 {
   DJEIJG8ErrorStruct *myerr = (DJEIJG8ErrorStruct *)cinfo->err;
-  myerr->instance->outputMessage(cinfo);
+  myerr->instance->emitMessage(cinfo, msg_level);
 }
 
 
@@ -343,7 +345,7 @@ OFCondition DJCompressIJG8Bit::encode(
   cinfo.err = jpeg_std_error(&jerr.pub);
   jerr.instance = this;
   jerr.pub.error_exit = DJEIJG8ErrorExit;
-  jerr.pub.output_message = DJEIJG8OutputMessage;
+  jerr.pub.emit_message = DJEIJG8EmitMessage;
   if (setjmp(jerr.setjmp_buffer))
   {
     // the IJG error handler will cause the following code to be executed
@@ -534,15 +536,35 @@ void DJCompressIJG8Bit::cleanup()
   bytesInLastBlock = 0;
 }
 
-void DJCompressIJG8Bit::outputMessage(void *arg) const
+void DJCompressIJG8Bit::emitMessage(void *arg, int msg_level) const
 {
   jpeg_common_struct *cinfo = (jpeg_common_struct *)arg;
-  if (cinfo && cparam->isVerbose())
+
+  // This is how we map the message levels:
+  // -1 - 0: Warning (could also be errors, but no way to find out)
+  //  1    : Debug
+  // Everything else: Trace (No point in splitting this further up)
+  OFLogger::LogLevel level;
+
+  switch (msg_level)
   {
-    char buffer[JMSG_LENGTH_MAX];    
+  case -1:
+  case 0:
+    level = OFLogger::WARN_LOG_LEVEL;
+    break;
+  case 1:
+    level = OFLogger::DEBUG_LOG_LEVEL;
+    break;
+  default:
+    level = OFLogger::TRACE_LOG_LEVEL;
+    break;
+  }
+
+  if (cinfo && DCM_dcmjpegGetLogger().isEnabledFor(level))
+  {
+    char buffer[JMSG_LENGTH_MAX];
     (*cinfo->err->format_message)(cinfo, buffer); /* Create the message */
-    ofConsole.lockCerr() << buffer << endl;
-    ofConsole.unlockCerr();
+    DCM_dcmjpegGetLogger().forcedLog(level, buffer, __FILE__, __LINE__);
   }
 }
 
@@ -550,6 +572,32 @@ void DJCompressIJG8Bit::outputMessage(void *arg) const
 /*
  * CVS/RCS Log
  * $Log: djeijg8.cc,v $
+ * Revision 1.15  2010-10-14 13:14:22  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.14  2010-06-25 09:15:19  uli
+ * Fixed issues with compiling with HAVE_STD_STRING.
+ *
+ * Revision 1.13  2010-03-01 09:08:48  uli
+ * Removed some unnecessary include directives in the headers.
+ *
+ * Revision 1.12  2010-02-22 11:39:54  uli
+ * Remove some unneeded includes.
+ *
+ * Revision 1.11  2009-11-18 16:17:54  uli
+ * Use more than just the INFO log level.
+ *
+ * Revision 1.10  2009-10-07 12:44:34  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.9  2009-08-19 12:19:20  meichel
+ * Unlike some other compilers, Sun Studio 11 on Solaris
+ *   declares longjmp() in namespace std. Added code to handle this case.
+ *
+ * Revision 1.8  2006-08-16 16:30:21  meichel
+ * Updated all code in module dcmjpeg to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.7  2005/12/08 15:43:41  meichel
  * Changed include path schema for all DCMTK header files
  *
