@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1997-2005, OFFIS
+ *  Copyright (C) 1997-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmjpeg
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: Codec class for encoding JPEG Lossless (8/12/16-bit)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:43:44 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmjpeg/libsrc/djenclol.cc,v $
- *  CVS/RCS Revision: $Revision: 1.2 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-11-03 11:22:38 $
+ *  CVS/RCS Revision: $Revision: 1.4 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -65,7 +60,7 @@ OFBool DJEncoderLossless::isLosslessProcess() const
 
 void DJEncoderLossless::createDerivationDescription(
   const DcmRepresentationParameter * toRepParam,
-  const DJCodecParameter * /* cp */ ,
+  const DJCodecParameter *cp,
   Uint8 /* bitsPerSample */ ,
   double ratio,
   OFString& derivationDescription) const
@@ -73,8 +68,11 @@ void DJEncoderLossless::createDerivationDescription(
   DJ_RPLossless defaultRP;
   const DJ_RPLossless *rp = toRepParam ? (const DJ_RPLossless *)toRepParam : &defaultRP ;
   char buf[64];
- 
-  derivationDescription =  "Lossless JPEG compression, selection value ";
+
+  if (cp->getTrueLosslessMode())
+    derivationDescription = "Lossless JPEG compression, selection value ";
+  else
+    derivationDescription = "Pseudo-Lossless JPEG compression, selection value ";
   sprintf(buf, "%u", rp->getPrediction());
   derivationDescription += buf;
   derivationDescription += ", point transform ";
@@ -86,27 +84,35 @@ void DJEncoderLossless::createDerivationDescription(
 
 
 DJEncoder *DJEncoderLossless::createEncoderInstance(
-    const DcmRepresentationParameter * toRepParam,
-    const DJCodecParameter *cp,
-    Uint8 bitsPerSample) const
+  const DcmRepresentationParameter * toRepParam,
+  const DJCodecParameter *cp,
+  Uint8 bitsPerSample) const
 {
   DJ_RPLossless defaultRP;
   const DJ_RPLossless *rp = toRepParam ? (const DJ_RPLossless *)toRepParam : &defaultRP ;
-  DJEncoder * result = NULL;
+  DJEncoder *result = NULL;
   if (bitsPerSample > 12)
     result = new DJCompressIJG16Bit(*cp, EJM_lossless, rp->getPrediction(), rp->getPointTransformation());
   else if (bitsPerSample > 8)
     result = new DJCompressIJG12Bit(*cp, EJM_lossless, rp->getPrediction(), rp->getPointTransformation());
-  else 
+  else
     result = new DJCompressIJG8Bit(*cp, EJM_lossless, rp->getPrediction(), rp->getPointTransformation());
-  return result;  
+  return result;
 }
 
 
 /*
  * CVS/RCS Log
  * $Log: djenclol.cc,v $
- * Revision 1.2  2005/12/08 15:43:44  meichel
+ * Revision 1.4  2010-11-03 11:22:38  joergr
+ * Since the pseudo-lossless encoder is not guaranteed to result in lossless
+ * compression, the modifications to the DICOM header are treated in the same
+ * way as for lossy compression (e.g Lossy Compression Flag is set to "01").
+ *
+ * Revision 1.3  2010-10-14 13:14:22  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.2  2005-12-08 15:43:44  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.1  2001/11/13 15:58:32  meichel
