@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1997-2005, OFFIS
+ *  Copyright (C) 1997-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmjpeg
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: (STATUS: OK)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:43:51 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmjpeg/libsrc/djutils.cc,v $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-11-01 08:55:56 $
+ *  CVS/RCS Revision: $Revision: 1.8 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -39,6 +34,15 @@
 #define INCLUDE_CCTYPE
 #include "dcmtk/ofstd/ofstdinc.h"
 
+OFLogger DCM_dcmjpegGetLogger()
+{
+    // We don't just use a global variable, because constructors of globals are
+    // executed in random order. This guarantees that the OFLogger is constructed
+    // before first use.
+    static OFLogger DCM_dcmjpegLogger = OFLog::getLogger("dcmtk.dcmjpeg");
+    return DCM_dcmjpegLogger;
+}
+
 const OFConditionConst EJC_Suspension(                           OFM_dcmjpeg,  1, OF_error, "IJG codec suspension return"  );
 const OFConditionConst EJC_IJG8_FrameBufferTooSmall(             OFM_dcmjpeg,  2, OF_error, "Buffer for decompressed image (8 bits/sample) too small"  );
 const OFConditionConst EJC_IJG12_FrameBufferTooSmall(            OFM_dcmjpeg,  3, OF_error, "Buffer for decompressed image (12 bits/sample) too small"  );
@@ -61,11 +65,13 @@ EP_Interpretation DcmJpegHelper::getPhotometricInterpretation(DcmItem *item)
     {
       const char *c = photometric.c_str(); // guaranteed to be zero-terminated
       char cp[17]; // legal CS cannot be larger than 16 characters plus 0 byte
-      int i=0; // current character
+      int i=0; // current character index
+      unsigned char cur; // current character
       while (*c && (i<16))
       {
-        if (isalpha(*c)) cp[i++] = toupper(*c);
-        else if (isdigit(*c)) cp[i++] = *c;
+        cur = OFstatic_cast(unsigned char, *c);
+        if (isalpha(cur)) cp[i++] = toupper(cur);
+        else if (isdigit(cur)) cp[i++] = cur;
         c++;
       }
       cp[i] = 0; // write terminating zero
@@ -87,7 +93,19 @@ EP_Interpretation DcmJpegHelper::getPhotometricInterpretation(DcmItem *item)
 /*
  * CVS/RCS Log
  * $Log: djutils.cc,v $
- * Revision 1.4  2005/12/08 15:43:51  meichel
+ * Revision 1.8  2010-11-01 08:55:56  uli
+ * Moved variable declarations in front of their loop.
+ *
+ * Revision 1.7  2010-10-20 07:41:35  uli
+ * Made sure isalpha() & friends are only called with valid arguments.
+ *
+ * Revision 1.6  2010-10-14 13:14:22  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.5  2009-10-07 12:44:34  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.4  2005-12-08 15:43:51  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.3  2005/11/30 14:13:14  onken
