@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2004, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmnet
  *
@@ -21,41 +17,39 @@
  *
  *  Purpose: Verification Service Class User (C-ECHO operation)
  *
- *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2004/04/06 18:12:26 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmnet/apps/echoscu.cc,v $
- *  CVS/RCS Revision: $Revision: 1.34 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-11-01 10:42:44 $
+ *  CVS/RCS Revision: $Revision: 1.53 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
  *
  */
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTDIO
 #define INCLUDE_CSTRING
 #define INCLUDE_CSTDARG
-#include "ofstdinc.h"
+#include "dcmtk/ofstd/ofstdinc.h"
 
-#include "dimse.h"
-#include "diutil.h"
-#include "dcfilefo.h"
-#include "dcdebug.h"
-#include "dcdict.h"
-#include "dcuid.h"
-#include "cmdlnarg.h"
-#include "ofconapp.h"
-#include "dcuid.h"    /* for dcmtk version name */
+#include "dcmtk/dcmnet/dimse.h"
+#include "dcmtk/dcmnet/diutil.h"
+#include "dcmtk/dcmdata/dcfilefo.h"
+#include "dcmtk/dcmdata/dcdict.h"
+#include "dcmtk/dcmdata/dcuid.h"
+#include "dcmtk/dcmdata/cmdlnarg.h"
+#include "dcmtk/ofstd/ofconapp.h"
+#include "dcmtk/dcmdata/dcuid.h"      /* for dcmtk version name */
 
 #ifdef WITH_OPENSSL
-#include "tlstrans.h"
-#include "tlslayer.h"
+#include "dcmtk/dcmtls/tlstrans.h"
+#include "dcmtk/dcmtls/tlslayer.h"
 #endif
 
 #ifdef WITH_ZLIB
-#include <zlib.h>     /* for zlibVersion() */
+#include <zlib.h>                     /* for zlibVersion() */
 #endif
 
 #ifdef PRIVATE_ECHOSCU_DECLARATIONS
@@ -64,6 +58,8 @@ PRIVATE_ECHOSCU_DECLARATIONS
 #define OFFIS_CONSOLE_APPLICATION "echoscu"
 #endif
 
+static OFLogger echoscuLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -71,13 +67,8 @@ static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
 #define APPLICATIONTITLE     "ECHOSCU"
 #define PEERAPPLICATIONTITLE "ANY-SCP"
 
-static OFBool opt_verbose = OFFalse;
-static OFBool opt_debug = OFFalse;
-
-static void errmsg(const char *msg)
-{
-  if (msg) fprintf(stderr, "%s: %s\n", OFFIS_CONSOLE_APPLICATION, msg);
-}
+static T_DIMSE_BlockingMode opt_blockMode = DIMSE_BLOCKING;
+static int opt_dimse_timeout = 0;
 
 static OFCondition cecho(T_ASC_Association * assoc, unsigned long num_repeat);
 
@@ -110,7 +101,10 @@ static const char* transferSyntaxes[] = {
       UID_DeflatedExplicitVRLittleEndianTransferSyntax,
       UID_JPEG2000LosslessOnlyTransferSyntax,
       UID_JPEG2000TransferSyntax,
-      UID_MPEG2MainProfileAtMainLevelTransferSyntax
+      UID_MPEG2MainProfileAtMainLevelTransferSyntax,
+      UID_MPEG2MainProfileAtHighLevelTransferSyntax,
+      UID_JPEG2000Part2MulticomponentImageCompressionLosslessOnlyTransferSyntax,
+      UID_JPEG2000Part2MulticomponentImageCompressionTransferSyntax
 };
 
 // ********************************************
@@ -130,8 +124,9 @@ main(int argc, char *argv[])
     OFBool           opt_abortAssociation    = OFFalse;
     OFCmdUnsignedInt opt_numXferSyntaxes     = 1;
     OFCmdUnsignedInt opt_numPresentationCtx  = 1;
-    OFCmdUnsignedInt maxXferSyntaxes         = (OFCmdUnsignedInt)(DIM_OF(transferSyntaxes));
+    OFCmdUnsignedInt maxXferSyntaxes         = OFstatic_cast(OFCmdUnsignedInt, (DIM_OF(transferSyntaxes)));
     OFBool           opt_secureConnection    = OFFalse; /* default: no secure connection */
+    int opt_acse_timeout = 30;
 
 #ifdef WITH_OPENSSL
     int         opt_keyFileFormat = SSL_FILETYPE_PEM;
@@ -139,7 +134,11 @@ main(int argc, char *argv[])
     const char *opt_privateKeyFile = NULL;
     const char *opt_certificateFile = NULL;
     const char *opt_passwd = NULL;
+#if OPENSSL_VERSION_NUMBER >= 0x0090700fL
+    OFString    opt_ciphersuites(TLS1_TXT_RSA_WITH_AES_128_SHA ":" SSL3_TXT_RSA_DES_192_CBC3_SHA);
+#else
     OFString    opt_ciphersuites(SSL3_TXT_RSA_DES_192_CBC3_SHA);
+#endif
     const char *opt_readSeedFile = NULL;
     const char *opt_writeSeedFile = NULL;
     DcmCertificateVerification opt_certVerification = DCV_requireCertificate;
@@ -151,6 +150,7 @@ main(int argc, char *argv[])
     DIC_NODENAME localHost;
     DIC_NODENAME peerHost;
     T_ASC_Association *assoc;
+    OFString temp_str;
 
 #ifdef HAVE_GUSI_H
     /* needed for Macintosh */
@@ -169,115 +169,115 @@ main(int argc, char *argv[])
   OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "DICOM verification (C-ECHO) SCU", rcsid);
   OFCommandLine cmd;
 
-  cmd.setParamColumn(LONGCOL+SHORTCOL+4);
+  cmd.setParamColumn(LONGCOL + SHORTCOL + 4);
   cmd.addParam("peer", "hostname of DICOM peer");
   cmd.addParam("port", "tcp/ip port number of peer");
 
   cmd.setOptionColumns(LONGCOL, SHORTCOL);
-  cmd.addGroup("general options:", LONGCOL, SHORTCOL+2);
-   cmd.addOption("--help",          "-h",      "print this help text and exit");
-   cmd.addOption("--version",                  "print version information and exit", OFTrue /* exclusive */);
-   cmd.addOption("--verbose",       "-v",      "verbose mode, print processing details");
-   cmd.addOption("--debug",         "-d",      "debug mode, print debug information");
+  cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
+   cmd.addOption("--help",                 "-h",      "print this help text and exit", OFCommandLine::AF_Exclusive);
+   cmd.addOption("--version",                         "print version information and exit", OFCommandLine::AF_Exclusive);
+   OFLog::addOptions(cmd);
 
   cmd.addGroup("network options:");
     cmd.addSubGroup("application entity titles:");
       OFString opt1 = "set my calling AE title (default: ";
       opt1 += APPLICATIONTITLE;
       opt1 += ")";
-      cmd.addOption("--aetitle",    "-aet", 1, "aetitle: string", opt1.c_str());
+      cmd.addOption("--aetitle",           "-aet", 1, "[a]etitle: string", opt1.c_str());
       OFString opt2 = "set called AE title of peer (default: ";
       opt2 += PEERAPPLICATIONTITLE;
       opt2 += ")";
-      cmd.addOption("--call",       "-aec", 1, "aetitle: string", opt2.c_str());
+      cmd.addOption("--call",              "-aec", 1, "[a]etitle: string", opt2.c_str());
     cmd.addSubGroup("association negotiation debugging:");
       OFString opt5 = "[n]umber: integer (1..";
-      sprintf(tempstr, "%ld", (long)maxXferSyntaxes);
+      sprintf(tempstr, "%ld", OFstatic_cast(long, maxXferSyntaxes));
       opt5 += tempstr;
       opt5 += ")";
-      cmd.addOption("--propose-ts", "-pts", 1, opt5.c_str(), "propose n transfer syntaxes");
-      cmd.addOption("--propose-pc", "-ppc", 1, "[n]umber: integer (1..128)", "propose n presentation contexts");
+      cmd.addOption("--propose-ts",        "-pts", 1, opt5.c_str(), "propose n transfer syntaxes");
+      cmd.addOption("--propose-pc",        "-ppc", 1, "[n]umber: integer (1..128)", "propose n presentation contexts");
 
     cmd.addSubGroup("other network options:");
-      cmd.addOption("--timeout",     "-to", 1, "[s]econds: integer (default: unlimited)", "timeout for connection requests");
+      cmd.addOption("--timeout",           "-to",  1, "[s]econds: integer (default: unlimited)", "timeout for connection requests");
+      cmd.addOption("--acse-timeout",      "-ta",  1, "[s]econds: integer (default: 30)", "timeout for ACSE messages");
+      cmd.addOption("--dimse-timeout",     "-td",  1, "[s]econds: integer (default: unlimited)", "timeout for DIMSE messages");
 
       OFString opt3 = "set max receive pdu to n bytes (default: ";
-      sprintf(tempstr, "%ld", (long)ASC_DEFAULTMAXPDU);
+      sprintf(tempstr, "%ld", OFstatic_cast(long, ASC_DEFAULTMAXPDU));
       opt3 += tempstr;
       opt3 += ")";
-      OFString opt4 = "[n]umber of bytes: integer [";
-      sprintf(tempstr, "%ld", (long)ASC_MINIMUMPDUSIZE);
+      OFString opt4 = "[n]umber of bytes: integer (";
+      sprintf(tempstr, "%ld", OFstatic_cast(long, ASC_MINIMUMPDUSIZE));
       opt4 += tempstr;
       opt4 += "..";
-      sprintf(tempstr, "%ld", (long)ASC_MAXIMUMPDUSIZE);
+      sprintf(tempstr, "%ld", OFstatic_cast(long, ASC_MAXIMUMPDUSIZE));
       opt4 += tempstr;
-      opt4 += "]";
-      cmd.addOption("--max-pdu",    "-pdu", 1, opt4.c_str(), opt3.c_str());
-      cmd.addOption("--repeat",             1, "[n]umber: integer", "repeat n times");
-      cmd.addOption("--abort",                 "abort association instead of releasing it");
+      opt4 += ")";
+      cmd.addOption("--max-pdu",           "-pdu", 1, opt4.c_str(), opt3.c_str());
+      cmd.addOption("--repeat",                    1, "[n]umber: integer", "repeat n times");
+      cmd.addOption("--abort",                        "abort association instead of releasing it");
 
 #ifdef WITH_OPENSSL
   cmd.addGroup("transport layer security (TLS) options:");
-    cmd.addSubGroup("transport protocol stack options:");
-      cmd.addOption("--disable-tls",            "-tls",      "use normal TCP/IP connection (default)");
-      cmd.addOption("--enable-tls",             "+tls",  2,  "[p]rivate key file, [c]ertificate file: string",
-                                                             "use authenticated secure TLS connection");
-      cmd.addOption("--anonymous-tls",          "+tla",      "use secure TLS connection without certificate");
-    cmd.addSubGroup("private key password options (only with --enable-tls):");
-      cmd.addOption("--std-passwd",             "+ps",       "prompt user to type password on stdin (default)");
-      cmd.addOption("--use-passwd",             "+pw",   1,  "[p]assword: string ",
-                                                             "use specified password");
-      cmd.addOption("--null-passwd",            "-pw",       "use empty string as password");
-    cmd.addSubGroup("key and certificate file format options:");
-      cmd.addOption("--pem-keys",               "-pem",      "read keys and certificates as PEM file (default)");
-      cmd.addOption("--der-keys",               "-der",      "read keys and certificates as DER file");
-    cmd.addSubGroup("certification authority options:");
-      cmd.addOption("--add-cert-file",          "+cf",   1,  "[c]ertificate filename: string",
-                                                             "add certificate file to list of certificates");
-      cmd.addOption("--add-cert-dir",           "+cd",   1,  "[c]ertificate directory: string",
-                                                             "add certificates in d to list of certificates");
-    cmd.addSubGroup("ciphersuite options:");
-      cmd.addOption("--cipher",                 "+cs",   1,  "[c]iphersuite name: string",
-                                                             "add ciphersuite to list of negotiated suites");
-      cmd.addOption("--dhparam",                "+dp",   1,  "[f]ilename: string",
-                                                             "read DH parameters for DH/DSS ciphersuites");
-    cmd.addSubGroup("pseudo random generator options:");
-      cmd.addOption("--seed",                   "+rs",   1,  "[f]ilename: string",
-                                                             "seed random generator with contents of f");
-      cmd.addOption("--write-seed",             "+ws",       "write back modified seed (only with --seed)");
-      cmd.addOption("--write-seed-file",        "+wf",   1,  "[f]ilename: string (only with --seed)",
-                                                             "write modified seed to file f");
-    cmd.addSubGroup("peer authentication options:");
-      cmd.addOption("--require-peer-cert",      "-rc",       "verify peer certificate, fail if absent (default)");
-      cmd.addOption("--verify-peer-cert",       "-vc",       "verify peer certificate if present");
-      cmd.addOption("--ignore-peer-cert",       "-ic",       "don't verify peer certificate");
+    cmd.addSubGroup("transport protocol stack:");
+      cmd.addOption("--disable-tls",       "-tls",    "use normal TCP/IP connection (default)");
+      cmd.addOption("--enable-tls",        "+tls", 2, "[p]rivate key file, [c]ertificate file: string",
+                                                      "use authenticated secure TLS connection");
+      cmd.addOption("--anonymous-tls",     "+tla",    "use secure TLS connection without certificate");
+    cmd.addSubGroup("private key password (only with --enable-tls):");
+      cmd.addOption("--std-passwd",        "+ps",     "prompt user to type password on stdin (default)");
+      cmd.addOption("--use-passwd",        "+pw",  1, "[p]assword: string ",
+                                                      "use specified password");
+      cmd.addOption("--null-passwd",       "-pw",     "use empty string as password");
+    cmd.addSubGroup("key and certificate file format:");
+      cmd.addOption("--pem-keys",          "-pem",    "read keys and certificates as PEM file (default)");
+      cmd.addOption("--der-keys",          "-der",    "read keys and certificates as DER file");
+    cmd.addSubGroup("certification authority:");
+      cmd.addOption("--add-cert-file",     "+cf",  1, "[c]ertificate filename: string",
+                                                      "add certificate file to list of certificates", OFCommandLine::AF_NoWarning);
+      cmd.addOption("--add-cert-dir",      "+cd",  1, "[c]ertificate directory: string",
+                                                      "add certificates in d to list of certificates", OFCommandLine::AF_NoWarning);
+    cmd.addSubGroup("ciphersuite:");
+      cmd.addOption("--cipher",            "+cs",  1, "[c]iphersuite name: string",
+                                                      "add ciphersuite to list of negotiated suites");
+      cmd.addOption("--dhparam",           "+dp",  1, "[f]ilename: string",
+                                                      "read DH parameters for DH/DSS ciphersuites");
+    cmd.addSubGroup("pseudo random generator:");
+      cmd.addOption("--seed",              "+rs",  1, "[f]ilename: string",
+                                                      "seed random generator with contents of f");
+      cmd.addOption("--write-seed",        "+ws",     "write back modified seed (only with --seed)");
+      cmd.addOption("--write-seed-file",   "+wf",  1, "[f]ilename: string (only with --seed)",
+                                                      "write modified seed to file f");
+    cmd.addSubGroup("peer authentication:");
+      cmd.addOption("--require-peer-cert", "-rc",     "verify peer certificate, fail if absent (default)");
+      cmd.addOption("--verify-peer-cert",  "-vc",     "verify peer certificate if present");
+      cmd.addOption("--ignore-peer-cert",  "-ic",     "don't verify peer certificate");
 #endif
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
         if (cmd.findOption("--version"))
         {
-            app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-            CERR << endl << "External libraries used:";
+          app.printHeader(OFTrue /*print host identifier*/);
+          COUT << OFendl << "External libraries used:";
 #if !defined(WITH_ZLIB) && !defined(WITH_OPENSSL)
-              CERR << " none" << endl;
+          COUT << " none" << OFendl;
 #else
-              CERR << endl;
+          COUT << OFendl;
 #endif
 #ifdef WITH_ZLIB
-              CERR << "- ZLIB, Version " << zlibVersion() << endl;
+          COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
 #ifdef WITH_OPENSSL
-              CERR << "- " << OPENSSL_VERSION_TEXT << endl;
+          COUT << "- " << OPENSSL_VERSION_TEXT << OFendl;
 #endif
-            return 0;
-         }
+          return 0;
+        }
       }
 
       /* command line parameters */
@@ -285,14 +285,7 @@ main(int argc, char *argv[])
       cmd.getParam(1, opt_peer);
       app.checkParam(cmd.getParamAndCheckMinMax(2, opt_port, 1, 65535));
 
-      if (cmd.findOption("--verbose")) opt_verbose=OFTrue;
-      if (cmd.findOption("--debug"))
-      {
-        opt_debug = OFTrue;
-        DUL_Debug(OFTrue);
-        DIMSE_debug(OFTrue);
-        SetDebugLevel(5);
-      }
+      OFLog::configureFromCommandLine(cmd, app);
 
       if (cmd.findOption("--aetitle")) app.checkValue(cmd.getValue(opt_ourTitle));
       if (cmd.findOption("--call")) app.checkValue(cmd.getValue(opt_peerTitle));
@@ -301,7 +294,22 @@ main(int argc, char *argv[])
       {
         OFCmdSignedInt opt_timeout = 0;
         app.checkValue(cmd.getValueAndCheckMin(opt_timeout, 1));
-        dcmConnectionTimeout.set((Sint32) opt_timeout);
+        dcmConnectionTimeout.set(OFstatic_cast(Sint32, opt_timeout));
+      }
+
+      if (cmd.findOption("--acse-timeout"))
+      {
+        OFCmdSignedInt opt_timeout = 0;
+        app.checkValue(cmd.getValueAndCheckMin(opt_timeout, 1));
+        opt_acse_timeout = OFstatic_cast(int, opt_timeout);
+      }
+
+      if (cmd.findOption("--dimse-timeout"))
+      {
+        OFCmdSignedInt opt_timeout = 0;
+        app.checkValue(cmd.getValueAndCheckMin(opt_timeout, 1));
+        opt_dimse_timeout = OFstatic_cast(int, opt_timeout);
+        opt_blockMode = DIMSE_NONBLOCKING;
       }
 
       if (cmd.findOption("--max-pdu")) app.checkValue(cmd.getValueAndCheckMinMax(opt_maxReceivePDULength, ASC_MINIMUMPDUSIZE, ASC_MAXIMUMPDUSIZE));
@@ -312,12 +320,6 @@ main(int argc, char *argv[])
 
 #ifdef WITH_OPENSSL
 
-#ifdef DEBUG
-      /* prevent command line code from moaning that --add-cert-dir and --add-cert-file have not been checked */
-      if (cmd.findOption("--add-cert-dir", 0, OFCommandLine::FOM_First)) /* nothing */ ;
-      if (cmd.findOption("--add-cert-file", 0, OFCommandLine::FOM_First)) /* nothing */ ;
-#endif
-
       cmd.beginOptionBlock();
       if (cmd.findOption("--disable-tls")) opt_secureConnection = OFFalse;
       if (cmd.findOption("--enable-tls"))
@@ -336,17 +338,17 @@ main(int argc, char *argv[])
       cmd.beginOptionBlock();
       if (cmd.findOption("--std-passwd"))
       {
-        if (! opt_doAuthenticate) app.printError("--std-passwd only with --enable-tls");
+        app.checkDependence("--std-passwd", "--enable-tls", opt_doAuthenticate);
         opt_passwd = NULL;
       }
       if (cmd.findOption("--use-passwd"))
       {
-        if (! opt_doAuthenticate) app.printError("--use-passwd only with --enable-tls");
+        app.checkDependence("--use-passwd", "--enable-tls", opt_doAuthenticate);
         app.checkValue(cmd.getValue(opt_passwd));
       }
       if (cmd.findOption("--null-passwd"))
       {
-        if (! opt_doAuthenticate) app.printError("--null-passwd only with --enable-tls");
+        app.checkDependence("--null-passwd", "--enable-tls", opt_doAuthenticate);
         opt_passwd = "";
       }
       cmd.endOptionBlock();
@@ -369,12 +371,12 @@ main(int argc, char *argv[])
       cmd.beginOptionBlock();
       if (cmd.findOption("--write-seed"))
       {
-        if (opt_readSeedFile == NULL) app.printError("--write-seed only with --seed");
+        app.checkDependence("--write-seed", "--seed", opt_readSeedFile != NULL);
         opt_writeSeedFile = opt_readSeedFile;
       }
       if (cmd.findOption("--write-seed-file"))
       {
-        if (opt_readSeedFile == NULL) app.printError("--write-seed-file only with --seed");
+        app.checkDependence("--write-seed-file", "--seed", opt_readSeedFile != NULL);
         app.checkValue(cmd.getValue(opt_writeSeedFile));
       }
       cmd.endOptionBlock();
@@ -395,11 +397,11 @@ main(int argc, char *argv[])
           app.checkValue(cmd.getValue(current));
           if (NULL == (currentOpenSSL = DcmTLSTransportLayer::findOpenSSLCipherSuiteName(current)))
           {
-            CERR << "ciphersuite '" << current << "' is unknown. Known ciphersuites are:" << endl;
+            OFLOG_FATAL(echoscuLogger, "ciphersuite '" << current << "' is unknown. Known ciphersuites are:");
             unsigned long numSuites = DcmTLSTransportLayer::getNumberOfCipherSuites();
             for (unsigned long cs=0; cs < numSuites; cs++)
             {
-              CERR << "    " << DcmTLSTransportLayer::getTLSCipherSuiteName(cs) << endl;
+              OFLOG_FATAL(echoscuLogger, "    " << DcmTLSTransportLayer::getTLSCipherSuiteName(cs));
             }
             return 1;
           } else {
@@ -412,16 +414,20 @@ main(int argc, char *argv[])
 #endif
     }
 
+    /* print resource identifier */
+    OFLOG_DEBUG(echoscuLogger, rcsid << OFendl);
+
     /* make sure data dictionary is loaded */
-    if (!dcmDataDict.isDictionaryLoaded()) {
-        fprintf(stderr, "Warning: no data dictionary loaded, check environment variable: %s\n",
-                DCM_DICT_ENVIRONMENT_VARIABLE);
+    if (!dcmDataDict.isDictionaryLoaded())
+    {
+        OFLOG_WARN(echoscuLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     /* initialize network, i.e. create an instance of T_ASC_Network*. */
-    OFCondition cond = ASC_initializeNetwork(NET_REQUESTOR, 0, 1000, &net);
+    OFCondition cond = ASC_initializeNetwork(NET_REQUESTOR, 0, opt_acse_timeout, &net);
     if (cond.bad()) {
-        DimseCondition::dump(cond);
+        OFLOG_FATAL(echoscuLogger, DimseCondition::dump(temp_str, cond));
         exit(1);
     }
 
@@ -433,7 +439,8 @@ main(int argc, char *argv[])
       tLayer = new DcmTLSTransportLayer(DICOM_APPLICATION_REQUESTOR, opt_readSeedFile);
       if (tLayer == NULL)
       {
-        app.printError("unable to create TLS transport layer");
+        OFLOG_FATAL(echoscuLogger, "unable to create TLS transport layer");
+        return 1;
       }
 
       if (cmd.findOption("--add-cert-file", 0, OFCommandLine::FOM_First))
@@ -444,7 +451,7 @@ main(int argc, char *argv[])
           app.checkValue(cmd.getValue(current));
           if (TCS_ok != tLayer->addTrustedCertificateFile(current, opt_keyFileFormat))
           {
-            CERR << "warning unable to load certificate file '" << current << "', ignoring" << endl;
+              OFLOG_WARN(echoscuLogger, "unable to load certificate file '" << current << "', ignoring");
           }
         } while (cmd.findOption("--add-cert-file", 0, OFCommandLine::FOM_Next));
       }
@@ -457,14 +464,14 @@ main(int argc, char *argv[])
           app.checkValue(cmd.getValue(current));
           if (TCS_ok != tLayer->addTrustedCertificateDir(current, opt_keyFileFormat))
           {
-            CERR << "warning unable to load certificates from directory '" << current << "', ignoring" << endl;
+            OFLOG_WARN(echoscuLogger, "unable to load certificates from directory '" << current << "', ignoring");
           }
         } while (cmd.findOption("--add-cert-dir", 0, OFCommandLine::FOM_Next));
       }
 
       if (opt_dhparam && ! (tLayer->setTempDHParameters(opt_dhparam)))
       {
-        CERR << "warning unable to load temporary DH parameter file '" << opt_dhparam << "', ignoring" << endl;
+        OFLOG_WARN(echoscuLogger, "unable to load temporary DH parameter file '" << opt_dhparam << "', ignoring");
       }
 
       if (opt_doAuthenticate)
@@ -473,24 +480,24 @@ main(int argc, char *argv[])
 
         if (TCS_ok != tLayer->setPrivateKeyFile(opt_privateKeyFile, opt_keyFileFormat))
         {
-          CERR << "unable to load private TLS key from '" << opt_privateKeyFile << "'" << endl;
+          OFLOG_ERROR(echoscuLogger, "unable to load private TLS key from '" << opt_privateKeyFile << "'");
           return 1;
         }
         if (TCS_ok != tLayer->setCertificateFile(opt_certificateFile, opt_keyFileFormat))
         {
-          CERR << "unable to load certificate from '" << opt_certificateFile << "'" << endl;
+          OFLOG_ERROR(echoscuLogger, "unable to load certificate from '" << opt_certificateFile << "'");
           return 1;
         }
         if (! tLayer->checkPrivateKeyMatchesCertificate())
         {
-          CERR << "private key '" << opt_privateKeyFile << "' and certificate '" << opt_certificateFile << "' do not match" << endl;
+          OFLOG_ERROR(echoscuLogger, "private key '" << opt_privateKeyFile << "' and certificate '" << opt_certificateFile << "' do not match");
           return 1;
         }
       }
 
       if (TCS_ok != tLayer->setCipherSuites(opt_ciphersuites.c_str()))
       {
-        CERR << "unable to set selected cipher suites" << endl;
+        OFLOG_ERROR(echoscuLogger, "unable to set selected cipher suites");
         return 1;
       }
 
@@ -500,7 +507,7 @@ main(int argc, char *argv[])
       cond = ASC_setTransportLayer(net, tLayer, 0);
       if (cond.bad())
       {
-          DimseCondition::dump(cond);
+          OFLOG_FATAL(echoscuLogger, DimseCondition::dump(temp_str, cond));
           return 1;
       }
     }
@@ -510,7 +517,7 @@ main(int argc, char *argv[])
     /* initialize asscociation parameters, i.e. create an instance of T_ASC_Parameters*. */
     cond = ASC_createAssociationParameters(&params, opt_maxReceivePDULength);
     if (cond.bad()) {
-        DimseCondition::dump(cond);
+        OFLOG_FATAL(echoscuLogger, DimseCondition::dump(temp_str, cond));
         exit(1);
     }
 
@@ -527,14 +534,14 @@ main(int argc, char *argv[])
     /* available the user is able to request an encrypted,secure connection. */
     cond = ASC_setTransportLayerType(params, opt_secureConnection);
     if (cond.bad()) {
-        DimseCondition::dump(cond);
+        OFLOG_FATAL(echoscuLogger, DimseCondition::dump(temp_str, cond));
         return 1;
     }
 
     /* Figure out the presentation addresses and copy the */
     /* corresponding values into the association parameters.*/
     gethostname(localHost, sizeof(localHost) - 1);
-    sprintf(peerHost, "%s:%d", opt_peer, (int)opt_port);
+    sprintf(peerHost, "%s:%d", opt_peer, OFstatic_cast(int, opt_port));
     ASC_setPresentationAddresses(params, localHost, peerHost);
 
     /* Set the presentation contexts which will be negotiated */
@@ -542,26 +549,22 @@ main(int argc, char *argv[])
     int presentationContextID = 1; /* odd byte value 1, 3, 5, .. 255 */
     for (unsigned long ii=0; ii<opt_numPresentationCtx; ii++)
     {
-      cond = ASC_addPresentationContext(params, presentationContextID, UID_VerificationSOPClass,
-                 transferSyntaxes, (int)opt_numXferSyntaxes);
-      presentationContextID += 2;
-      if (cond.bad())
-      {
-            DimseCondition::dump(cond);
+        cond = ASC_addPresentationContext(params, presentationContextID, UID_VerificationSOPClass,
+                 transferSyntaxes, OFstatic_cast(int, opt_numXferSyntaxes));
+        presentationContextID += 2;
+        if (cond.bad())
+        {
+            OFLOG_FATAL(echoscuLogger, DimseCondition::dump(temp_str, cond));
             exit(1);
-      }
+        }
     }
 
     /* dump presentation contexts if required */
-    if (opt_debug) {
-        printf("Request Parameters:\n");
-        ASC_dumpParameters(params, COUT);
-    }
+    OFLOG_DEBUG(echoscuLogger, "Request Parameters:" << OFendl << ASC_dumpParameters(temp_str, params, ASC_ASSOC_RQ));
 
     /* create association, i.e. try to establish a network connection to another */
     /* DICOM application. This call creates an instance of T_ASC_Association*. */
-    if (opt_verbose)
-        printf("Requesting Association\n");
+    OFLOG_INFO(echoscuLogger, "Requesting Association");
     cond = ASC_requestAssociation(net, params, &assoc);
     if (cond.bad()) {
         if (cond == DUL_ASSOCIATIONREJECTED)
@@ -569,35 +572,26 @@ main(int argc, char *argv[])
             T_ASC_RejectParameters rej;
 
             ASC_getRejectParameters(params, &rej);
-            errmsg("Association Rejected:");
-            ASC_printRejectParameters(stderr, &rej);
+            OFLOG_FATAL(echoscuLogger, "Association Rejected:" << OFendl << ASC_printRejectParameters(temp_str, &rej));
             exit(1);
         } else {
-            errmsg("Association Request Failed:");
-            DimseCondition::dump(cond);
+            OFLOG_FATAL(echoscuLogger, "Association Request Failed: " << DimseCondition::dump(temp_str, cond));
             exit(1);
         }
     }
 
     /* dump the presentation contexts which have been accepted/refused */
-    if (opt_debug) {
-        printf("Association Parameters Negotiated:\n");
-        ASC_dumpParameters(params, COUT);
-    }
+    OFLOG_DEBUG(echoscuLogger, "Association Parameters Negotiated:" << OFendl << ASC_dumpParameters(temp_str, params, ASC_ASSOC_AC));
 
     /* count the presentation contexts which have been accepted by the SCP */
     /* If there are none, finish the execution */
     if (ASC_countAcceptedPresentationContexts(params) == 0) {
-        errmsg("No Acceptable Presentation Contexts");
+        OFLOG_FATAL(echoscuLogger, "No Acceptable Presentation Contexts");
         exit(1);
     }
 
     /* dump general information concerning the establishment of the network connection if required */
-    if (opt_verbose) {
-        printf("Association Accepted (Max Send PDV: %lu)\n",
-                assoc->sendPDVLength);
-    }
-
+    OFLOG_INFO(echoscuLogger, "Association Accepted (Max Send PDV: " << assoc->sendPDVLength << ")");
 
     /* do the real work, i.e. send a number of C-ECHO-RQ messages to the DICOM application */
     /* this application is connected with and handle corresponding C-ECHO-RSP messages. */
@@ -607,54 +601,45 @@ main(int argc, char *argv[])
     if (cond == EC_Normal)
     {
         if (opt_abortAssociation) {
-            if (opt_verbose)
-                printf("Aborting Association\n");
+            OFLOG_INFO(echoscuLogger, "Aborting Association");
             cond = ASC_abortAssociation(assoc);
             if (cond.bad())
             {
-                errmsg("Association Abort Failed:");
-                DimseCondition::dump(cond);
+                OFLOG_FATAL(echoscuLogger, "Association Abort Failed: " << DimseCondition::dump(temp_str, cond));
                 exit(1);
             }
         } else {
             /* release association */
-            if (opt_verbose)
-                printf("Releasing Association\n");
+            OFLOG_INFO(echoscuLogger, "Releasing Association");
             cond = ASC_releaseAssociation(assoc);
             if (cond.bad())
             {
-                errmsg("Association Release Failed:");
-                DimseCondition::dump(cond);
+                OFLOG_FATAL(echoscuLogger, "Association Release Failed: " << DimseCondition::dump(temp_str, cond));
                 exit(1);
             }
         }
     }
     else if (cond == DUL_PEERREQUESTEDRELEASE)
     {
-        errmsg("Protocol Error: peer requested release (Aborting)");
-        if (opt_verbose)
-            printf("Aborting Association\n");
+        OFLOG_FATAL(echoscuLogger, "Protocol Error: Peer requested release (Aborting)");
+        OFLOG_INFO(echoscuLogger, "Aborting Association");
         cond = ASC_abortAssociation(assoc);
         if (cond.bad()) {
-            errmsg("Association Abort Failed:");
-            DimseCondition::dump(cond);
+            OFLOG_FATAL(echoscuLogger, "Association Abort Failed: " << DimseCondition::dump(temp_str, cond));
             exit(1);
         }
     }
     else if (cond == DUL_PEERABORTEDASSOCIATION)
     {
-        if (opt_verbose) printf("Peer Aborted Association\n");
+        OFLOG_INFO(echoscuLogger, "Peer Aborted Association");
     }
     else
     {
-        errmsg("SCU Failed:");
-        DimseCondition::dump(cond);
-        if (opt_verbose)
-            printf("Aborting Association\n");
+        OFLOG_ERROR(echoscuLogger, "Echo SCU Failed: " << DimseCondition::dump(temp_str, cond));
+        OFLOG_INFO(echoscuLogger, "Aborting Association");
         cond = ASC_abortAssociation(assoc);
         if (cond.bad()) {
-            errmsg("Association Abort Failed:");
-            DimseCondition::dump(cond);
+            OFLOG_FATAL(echoscuLogger, "Association Abort Failed: " << DimseCondition::dump(temp_str, cond));
             exit(1);
         }
     }
@@ -663,7 +648,7 @@ main(int argc, char *argv[])
     /* call is the counterpart of ASC_requestAssociation(...) which was called above. */
     cond = ASC_destroyAssociation(&assoc);
     if (cond.bad()) {
-        DimseCondition::dump(cond);
+        OFLOG_FATAL(echoscuLogger, DimseCondition::dump(temp_str, cond));
         exit(1);
     }
 
@@ -671,7 +656,7 @@ main(int argc, char *argv[])
     /* is the counterpart of ASC_initializeNetwork(...) which was called above. */
     cond = ASC_dropNetwork(&net);
     if (cond.bad()) {
-        DimseCondition::dump(cond);
+        OFLOG_FATAL(echoscuLogger, DimseCondition::dump(temp_str, cond));
         exit(1);
     }
 
@@ -686,10 +671,10 @@ main(int argc, char *argv[])
       {
         if (!tLayer->writeRandomSeed(opt_writeSeedFile))
         {
-          CERR << "Error while writing random seed file '" << opt_writeSeedFile << "', ignoring." << endl;
+          OFLOG_ERROR(echoscuLogger, "cannot write random seed file '" << opt_writeSeedFile << "', ignoring");
         }
       } else {
-        CERR << "Warning: cannot write random seed, ignoring." << endl;
+        OFLOG_ERROR(echoscuLogger, "cannot write random seed, ignoring");
       }
     }
     delete tLayer;
@@ -713,30 +698,22 @@ echoSCU(T_ASC_Association * assoc)
     DcmDataset *statusDetail = NULL;
 
     /* dump information if required */
-    if (opt_verbose) {
-        printf("Echo [%d], ", msgId);
-        fflush(stdout);
-    }
+    OFLOG_INFO(echoscuLogger, "Sending Echo Request: MsgID " << msgId);
 
     /* send C-ECHO-RQ and handle response */
-    OFCondition cond = DIMSE_echoUser(assoc, msgId, DIMSE_BLOCKING, 0,
-        &status, &statusDetail);
+    OFCondition cond = DIMSE_echoUser(assoc, msgId, opt_blockMode, opt_dimse_timeout, &status, &statusDetail);
 
     /* depending on if a response was received, dump some information */
     if (cond.good()) {
-        if (opt_verbose) {
-            printf("Complete [Status: %s]\n",
-                DU_cstoreStatusString(status));
-        }
+        OFLOG_INFO(echoscuLogger, "Received Echo Response (Status: " << DU_cstoreStatusString(status) << ")");
     } else {
-        errmsg("Failed:");
-        DimseCondition::dump(cond);
+        OFString temp_str;
+        OFLOG_ERROR(echoscuLogger, "Echo Failed: " << DimseCondition::dump(temp_str, cond));
     }
 
     /* check for status detail information, there should never be any */
     if (statusDetail != NULL) {
-        printf("  Status Detail (should never be any):\n");
-        statusDetail->print(COUT);
+        OFLOG_INFO(echoscuLogger, "Status Detail (should never be any):" << OFendl << DcmObject::PrintHelper(*statusDetail));
         delete statusDetail;
     }
 
@@ -760,7 +737,7 @@ cecho(T_ASC_Association * assoc, unsigned long num_repeat)
 
     /* as long as no error occured and the counter does not equal 0 */
     /* send an C-ECHO-RQ and handle the response */
-    while (cond == EC_Normal && n--) cond = echoSCU(assoc); // compare with EC_Normal since DUL_PEERREQUESTEDRELEASE is also good()
+    while (cond.good() && n--) cond = echoSCU(assoc);
 
     return cond;
 }
@@ -768,6 +745,73 @@ cecho(T_ASC_Association * assoc, unsigned long num_repeat)
 /*
 ** CVS Log
 ** $Log: echoscu.cc,v $
+** Revision 1.53  2010-11-01 10:42:44  uli
+** Fixed some compiler warnings reported by gcc with additional flags.
+**
+** Revision 1.52  2010-10-14 13:13:42  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.51  2010-09-09 08:34:09  joergr
+** Added support for "MPEG2 Main Profile @ High Level" transfer syntax.
+**
+** Revision 1.50  2010-05-18 16:10:25  joergr
+** Replaced '\n' by OFendl in log messages.
+**
+** Revision 1.49  2009-12-01 10:59:38  joergr
+** Use helper function checkDependence() where appropriate.
+** Sightly modified log messages.
+**
+** Revision 1.48  2009-11-18 11:53:58  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.47  2009-09-04 14:36:42  joergr
+** Output all --version information to COUT (and not to CERR).
+**
+** Revision 1.46  2009-07-13 09:44:18  onken
+** Removed misleading comment about dcmnet DIMSE return code and changed
+** corresponding OFCondition check from EC_Normal to .good().
+**
+** Revision 1.45  2009-06-04 10:16:24  joergr
+** Added new flag that can be used to avoid wrong warning messages (in debug
+** mode) that an option has possibly never been checked.
+**
+** Revision 1.44  2009-04-24 12:26:05  joergr
+** Fixed minor inconsistencies regarding layout/formatting in syntax usage.
+**
+** Revision 1.43  2009-04-21 14:09:22  joergr
+** Fixed minor inconsistencies in manpage / syntax usage.
+**
+** Revision 1.42  2008-09-25 16:00:58  joergr
+** Added support for printing the expanded command line arguments.
+** Always output the resource identifier of the command line tool in debug mode.
+**
+** Revision 1.41  2006/08/15 16:04:28  meichel
+** Updated the code in module dcmnet to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.40  2006/07/27 14:20:08  joergr
+** Changed parameter "exclusive" of method addOption() from type OFBool into an
+** integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+** Option "--help" is no longer an exclusive option by default.
+**
+** Revision 1.39  2005/12/08 15:44:18  meichel
+** Changed include path schema for all DCMTK header files
+**
+** Revision 1.38  2005/11/23 16:10:23  meichel
+** Added support for AES ciphersuites in TLS module. All TLS-enabled
+**   tools now support the "AES TLS Secure Transport Connection Profile".
+**
+** Revision 1.37  2005/11/17 13:45:16  meichel
+** Added command line options for DIMSE and ACSE timeouts
+**
+** Revision 1.36  2005/11/16 14:58:07  meichel
+** Set association timeout in ASC_initializeNetwork to 30 seconds. This improves
+**   the responsiveness of the tools if the peer blocks during assoc negotiation.
+**
+** Revision 1.35  2005/10/25 08:55:43  meichel
+** Updated list of UIDs and added support for new transfer syntaxes
+**   and storage SOP classes.
+**
 ** Revision 1.34  2004/04/06 18:12:26  joergr
 ** Added missing suffix "TransferSyntax" to some transfer syntax constants.
 ** Added six more transfer syntaxes to the --propose-ts option.
