@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmnet
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: network conditions and helper class
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:44:25 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmnet/libsrc/cond.cc,v $
- *  CVS/RCS Revision: $Revision: 1.14 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:27 $
+ *  CVS/RCS Revision: $Revision: 1.21 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -38,21 +33,25 @@
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
 
-const OFConditionConst ASCE_BADPRESENTATIONCONTEXTID(OFM_dcmnet, ASCC_BADPRESENTATIONCONTEXTID, OF_error, "ASC Bad presentation context ID");
-const OFConditionConst ASCE_MISSINGTRANSFERSYNTAX(   OFM_dcmnet, ASCC_MISSINGTRANSFERSYNTAX,    OF_error, "ASC Missing transfer syntax");
-const OFConditionConst ASCE_NULLKEY(                 OFM_dcmnet, ASCC_NULLKEY,                  OF_error, "ASC Caller passed in a NULL key");
-const OFConditionConst ASCE_SHUTDOWNAPPLICATION(     OFM_dcmnet, ASCC_SHUTDOWNAPPLICATION,      OF_error, "ASC Application shutdown requested");
+const OFConditionConst ASCE_BADPRESENTATIONCONTEXTID( OFM_dcmnet, ASCC_BADPRESENTATIONCONTEXTID,  OF_error, "ASC Bad presentation context ID");
+const OFConditionConst ASCE_MISSINGTRANSFERSYNTAX(    OFM_dcmnet, ASCC_MISSINGTRANSFERSYNTAX,     OF_error, "ASC Missing transfer syntax");
+const OFConditionConst ASCE_NULLKEY(                  OFM_dcmnet, ASCC_NULLKEY,                   OF_error, "ASC Caller passed in a NULL key");
+const OFConditionConst ASCE_SHUTDOWNAPPLICATION(      OFM_dcmnet, ASCC_SHUTDOWNAPPLICATION,       OF_error, "ASC Application shutdown requested");
+const OFConditionConst ASCE_USERIDENTIFICATIONFAILED( OFM_dcmnet, ASCC_USERIDENTIFICATIONFAILED,  OF_error, "ASC User Identification Negotiation failed");
+const OFConditionConst ASCE_SCPSCUROLESELECTIONFAILED(OFM_dcmnet, ASCC_SCPSCUROLESELECTIONFAILED, OF_error, "ASC SCP/SCU role selection failed");
 
-const OFCondition ASC_BADPRESENTATIONCONTEXTID(ASCE_BADPRESENTATIONCONTEXTID);
-const OFCondition ASC_MISSINGTRANSFERSYNTAX(   ASCE_MISSINGTRANSFERSYNTAX);
-const OFCondition ASC_NULLKEY(                 ASCE_NULLKEY);
-const OFCondition ASC_SHUTDOWNAPPLICATION(     ASCE_SHUTDOWNAPPLICATION);
+const OFCondition ASC_BADPRESENTATIONCONTEXTID( ASCE_BADPRESENTATIONCONTEXTID);
+const OFCondition ASC_MISSINGTRANSFERSYNTAX(    ASCE_MISSINGTRANSFERSYNTAX);
+const OFCondition ASC_NULLKEY(                  ASCE_NULLKEY);
+const OFCondition ASC_SHUTDOWNAPPLICATION(      ASCE_SHUTDOWNAPPLICATION);
+const OFCondition ASC_USERIDENTIFICATIONFAILED( ASCE_USERIDENTIFICATIONFAILED);
+const OFCondition ASC_SCPSCUROLESELECTIONFAILED(ASCE_SCPSCUROLESELECTIONFAILED);
 
 const OFConditionConst DIMSEE_BADCOMMANDTYPE(               OFM_dcmnet, DIMSEC_BADCOMMANDTYPE,               OF_error, "DIMSE Bad command type");
 const OFConditionConst DIMSEE_BADDATA(                      OFM_dcmnet, DIMSEC_BADDATA,                      OF_error, "DIMSE Inappropriate data for message");
 const OFConditionConst DIMSEE_BADMESSAGE(                   OFM_dcmnet, DIMSEC_BADMESSAGE,                   OF_error, "DIMSE Badly formed message");
 const OFConditionConst DIMSEE_ILLEGALASSOCIATION(           OFM_dcmnet, DIMSEC_ILLEGALASSOCIATION,           OF_error, "DIMSE Caller passed in an illegal association");
-const OFConditionConst DIMSEE_NODATAAVAILABLE(              OFM_dcmnet, DIMSEC_NODATAAVAILABLE,              OF_error, "DIMSE No data available (timout in non-blocking mode)");
+const OFConditionConst DIMSEE_NODATAAVAILABLE(              OFM_dcmnet, DIMSEC_NODATAAVAILABLE,              OF_error, "DIMSE No data available (timeout in non-blocking mode)");
 const OFConditionConst DIMSEE_NOVALIDPRESENTATIONCONTEXTID( OFM_dcmnet, DIMSEC_NOVALIDPRESENTATIONCONTEXTID, OF_error, "DIMSE No valid Presentation Context ID");
 const OFConditionConst DIMSEE_NULLKEY(                      OFM_dcmnet, DIMSEC_NULLKEY,                      OF_error, "DIMSE Caller passed in a NULL key");
 const OFConditionConst DIMSEE_OUTOFRESOURCES(               OFM_dcmnet, DIMSEC_OUTOFRESOURCES,               OF_error, "DIMSE Out of resources");
@@ -124,18 +123,27 @@ const OFCondition DUL_UNEXPECTEDPDU(            DULE_UNEXPECTEDPDU);
 const OFCondition DUL_UNSUPPORTEDPEERPROTOCOL(  DULE_UNSUPPORTEDPEERPROTOCOL);
 const OFCondition DUL_WRONGDATATYPE(            DULE_WRONGDATATYPE);
 
-void DimseCondition::dump(OFCondition cond, OFConsole& console)
+OFString& DimseCondition::dump(OFString& str, OFCondition cond)
 {
   char buf[16];
   sprintf(buf,"%04x:%04x ", cond.module(), cond.code());
-  console.lockCerr() << buf << cond.text() << endl;
-  console.unlockCerr();
+  str = buf;
+  str += cond.text();
+  return str;
+}
+
+void DimseCondition::dump(OFCondition cond, OFConsole& console)
+{
+    OFString str;
+    dump(str, cond);
+    console.lockCerr() << str << OFendl;
+    console.unlockCerr();
 }
 
 OFCondition DimseCondition::push(
-    unsigned short aModule, 
-    unsigned short aCode, 
-    OFStatus aStatus, 
+    unsigned short aModule,
+    unsigned short aCode,
+    OFStatus aStatus,
     const char *aText,
     OFCondition subCondition)
 {
@@ -143,8 +151,8 @@ OFCondition DimseCondition::push(
   /* declare variable outside the block structure of the OFSTRINGSTREAM_xxx macros */
   OFConditionString *condString;
   char buf[16];
-  sprintf(buf,"%04x:%04x ", subCondition.module(), subCondition.code()); 
-  os << aText << endl << buf << subCondition.text() << OFStringStream_ends;
+  sprintf(buf,"%04x:%04x ", subCondition.module(), subCondition.code());
+  os << aText << OFendl << buf << subCondition.text() << OFStringStream_ends;
   OFSTRINGSTREAM_GETSTR(os, c)
   condString = new OFConditionString(aModule, aCode, aStatus, c);
   OFSTRINGSTREAM_FREESTR(c)
@@ -155,13 +163,36 @@ OFCondition DimseCondition::push(
   OFCondition newCondition,
   OFCondition subCondition)
 {
-  return DimseCondition::push(newCondition.module(), newCondition.code(), 
+  return DimseCondition::push(newCondition.module(), newCondition.code(),
     newCondition.status(), newCondition.text(), subCondition);
 }
 
 /*
  * CVS Log
  * $Log: cond.cc,v $
+ * Revision 1.21  2010-10-14 13:14:27  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.20  2010-09-09 08:32:06  joergr
+ * Fixed typo in OFCondition constants for SCP/SCU role selection failures.
+ *
+ * Revision 1.19  2010-08-26 09:22:24  joergr
+ * Fixed incorrect behavior of association acceptors during SCP/SCU role
+ * selection negotiation.
+ *
+ * Revision 1.18  2009-11-18 11:53:59  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.17  2008-09-08 13:17:13  joergr
+ * Fixed typo in OFCondition text string.
+ *
+ * Revision 1.16  2008-04-17 15:27:35  onken
+ * Reworked and extended User Identity Negotiation code.
+ *
+ * Revision 1.15  2006-08-15 16:04:29  meichel
+ * Updated the code in module dcmnet to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
  * Revision 1.14  2005/12/08 15:44:25  meichel
  * Changed include path schema for all DCMTK header files
  *
