@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmnet
  *
@@ -22,10 +18,9 @@
  *  Purpose: 
  *    class DcmAssociationConfigurationFile
  * 
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:44:26 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmnet/libsrc/dcasccff.cc,v $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-10-20 08:09:34 $
+ *  CVS/RCS Revision: $Revision: 1.7 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -163,7 +158,7 @@ OFCondition DcmAssociationConfigurationFile::parsePresentationContexts(
   size_t separator = 0;
   size_t i;
   size_t len;
-  char c;
+  unsigned char c;
   OFCondition result = EC_Normal;
 
   config.first_section(1);
@@ -214,6 +209,7 @@ OFCondition DcmAssociationConfigurationFile::parsePresentationContexts(
 }
 
 
+#define TO_UCHAR(s) OFstatic_cast(unsigned char, (s))
 OFCondition DcmAssociationConfigurationFile::parseRoleSelectionItems(
   DcmAssociationConfiguration& cfg,
   OFConfigFile& config)
@@ -265,7 +261,7 @@ OFCondition DcmAssociationConfigurationFile::parseRoleSelectionItems(
         while (++i < len)
         {
           c = abstractSyntaxUID.at(i);
-          roleKey += (char) (toupper(c));
+          roleKey += (char) (toupper(TO_UCHAR(c)));
         }
 
         // finally cut abstract syntax name           
@@ -455,7 +451,7 @@ OFCondition DcmAssociationConfigurationFile::parseProfiles(
     scontext.clear();
     while (*c)
     {
-      if (! isspace(*c)) scontext += (char) (toupper(*c));
+      if (! isspace(TO_UCHAR(*c))) scontext += (char) (toupper(TO_UCHAR(*c)));
       ++c;
     }
     context = scontext.c_str();
@@ -467,7 +463,7 @@ OFCondition DcmAssociationConfigurationFile::parseProfiles(
       srole.clear();
       while (*c)
       {
-        if (! isspace(*c)) srole += (char) (toupper(*c));
+        if (! isspace(TO_UCHAR(*c))) srole += (char) (toupper(TO_UCHAR(*c)));
         ++c;
       }
       role = srole.c_str();
@@ -480,7 +476,7 @@ OFCondition DcmAssociationConfigurationFile::parseProfiles(
       sextneg.clear();
       while (*c)
       {
-        if (! isspace(*c)) sextneg += (char) (toupper(*c));
+        if (! isspace(TO_UCHAR(*c))) sextneg += (char) (toupper(TO_UCHAR(*c)));
         ++c;
       }
       extneg = sextneg.c_str();
@@ -493,11 +489,21 @@ OFCondition DcmAssociationConfigurationFile::parseProfiles(
 
   return result;
 }
+#undef TO_UCHAR
 
 
 /*
  * CVS/RCS Log
  * $Log: dcasccff.cc,v $
+ * Revision 1.7  2010-10-20 08:09:34  uli
+ * Also made sure toupper() and tolower() get a valid argument.
+ *
+ * Revision 1.6  2010-10-20 07:41:35  uli
+ * Made sure isalpha() & friends are only called with valid arguments.
+ *
+ * Revision 1.5  2010-10-14 13:14:27  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
  * Revision 1.4  2005/12/08 15:44:26  meichel
  * Changed include path schema for all DCMTK header files
  *
