@@ -1,30 +1,25 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmnet
  *
  *  Author:  Marco Eichelberg
  *
- *  Purpose: 
+ *  Purpose:
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:44:27 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmnet/libsrc/dcasccfg.cc,v $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:28 $
+ *  CVS/RCS Revision: $Revision: 1.7 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -137,7 +132,7 @@ OFBool DcmAssociationConfiguration::isValidSCPProfile(const char *key) const
   const DcmPresentationContextList *contextList = contexts_.getPresentationContextList(contextKey);
   if (contextList)
   {
-    // now loop through all presentation contexts  
+    // now loop through all presentation contexts
     OFListConstIterator(DcmPresentationContextItem) outerfirst = contextList->begin();
     OFListConstIterator(DcmPresentationContextItem) innerfirst;
     OFListConstIterator(DcmPresentationContextItem) last = contextList->end();
@@ -156,7 +151,7 @@ OFBool DcmAssociationConfiguration::isValidSCPProfile(const char *key) const
           return OFFalse;
         }
         ++innerfirst;
-      }  
+      }
       ++outerfirst;
     }
     // there are no duplicate abstract syntaxes, so this is a valid SCP profile.
@@ -238,7 +233,7 @@ OFCondition DcmAssociationConfiguration::setAssociationParameters(
   OFListConstIterator(DcmRoleSelectionItem) rslast;
   DcmUIDHandler uid;
 
-  // now loop through all presentation contexts  
+  // now loop through all presentation contexts
   OFListConstIterator(DcmPresentationContextItem) first = contextList->begin();
   OFListConstIterator(DcmPresentationContextItem) last = contextList->end();
   while (first != last)
@@ -291,7 +286,7 @@ OFCondition DcmAssociationConfiguration::setAssociationParameters(
       rslast = roleSelectionList->end();
       uid = abstractSyntax;
       while (rsfirst != rslast)
-      {        
+      {
         if ((*rsfirst).matches(uid))
         {
           // found abstract syntax, set role accordingly
@@ -435,7 +430,7 @@ OFCondition DcmAssociationConfiguration::evaluateAssociationParameters(
     if (!found)
     {
       // abstract syntax not supported, reject presentation context
-      result = ASC_refusePresentationContext(assoc.params, pc.presentationContextID, 
+      result = ASC_refusePresentationContext(assoc.params, pc.presentationContextID,
         ASC_P_ABSTRACTSYNTAXNOTSUPPORTED);
       if (result.bad()) return result;
     }
@@ -443,7 +438,7 @@ OFCondition DcmAssociationConfiguration::evaluateAssociationParameters(
     {
       // abstract syntax is supported, get transfer syntax list and SCP/SCU role
       transferSyntaxKey = (*first).getTransferSyntaxKey();
-      transferSyntaxList = xferSyntaxes_.getTransferSyntaxList(transferSyntaxKey);      
+      transferSyntaxList = xferSyntaxes_.getTransferSyntaxList(transferSyntaxKey);
       if (! transferSyntaxList)
       {
         // error: key undefined
@@ -451,7 +446,7 @@ OFCondition DcmAssociationConfiguration::evaluateAssociationParameters(
         s += transferSyntaxKey;
         return makeOFCondition(OFM_dcmnet, 1073, OF_error, s.c_str());
       }
-    
+
       // look up SCP/SCU role for this abstract syntax
       acceptedRole = ASC_SC_ROLE_DEFAULT;
       if (roleSelectionList)
@@ -461,7 +456,7 @@ OFCondition DcmAssociationConfiguration::evaluateAssociationParameters(
         rslast = roleSelectionList->end();
         uid = pc.abstractSyntax;
         while (rsfirst != rslast)
-        {        
+        {
           if ((*rsfirst).matches(uid))
           {
             // found abstract syntax, set role accordingly
@@ -491,17 +486,23 @@ OFCondition DcmAssociationConfiguration::evaluateAssociationParameters(
             result = ASC_acceptPresentationContext(
                 assoc.params, pc.presentationContextID,
                 pc.proposedTransferSyntaxes[j], acceptedRole);
+            // SCP/SCU role selection failed, reject presentation context
+            if (result == ASC_SCPSCUROLESELECTIONFAILED)
+            {
+              result = ASC_refusePresentationContext(assoc.params,
+                pc.presentationContextID, ASC_P_NOREASON);
+            }
             if (result.bad()) return result;
           }
         }
         ++tsfirst;
       }
 
-      // no matching transfer syntax found, reject context     
+      // no matching transfer syntax found, reject context
       if (!found)
       {
         // transfer syntax not supported, reject presentation context
-        result = ASC_refusePresentationContext(assoc.params, pc.presentationContextID, 
+        result = ASC_refusePresentationContext(assoc.params, pc.presentationContextID,
           ASC_P_TRANSFERSYNTAXESNOTSUPPORTED);
         if (result.bad()) return result;
       }
@@ -546,7 +547,17 @@ OFCondition DcmAssociationConfiguration::evaluateAssociationParameters(
 /*
  * CVS/RCS Log
  * $Log: dcasccfg.cc,v $
- * Revision 1.4  2005/12/08 15:44:27  meichel
+ * Revision 1.7  2010-10-14 13:14:28  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.6  2010-09-09 08:32:06  joergr
+ * Fixed typo in OFCondition constants for SCP/SCU role selection failures.
+ *
+ * Revision 1.5  2010-08-26 09:23:38  joergr
+ * Fixed incorrect behavior of association acceptors during SCP/SCU role
+ * selection negotiation.
+ *
+ * Revision 1.4  2005-12-08 15:44:27  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.3  2003/08/14 10:58:49  meichel
