@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2003-2005, OFFIS
+ *  Copyright (C) 2003-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmnet
  *
@@ -23,10 +19,9 @@
  *    class DcmExtendedNegotiationItem
  *    class DcmExtendedNegotiationMap
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:44:28 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmnet/libsrc/dccfenmp.cc,v $
- *  CVS/RCS Revision: $Revision: 1.6 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:28 $
+ *  CVS/RCS Revision: $Revision: 1.8 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -36,8 +31,8 @@
 #include "dcmtk/config/osconfig.h"
 #include "dcmtk/dcmnet/dccfenmp.h" /* for class DcmExtendedNegotiationMap */
 #include "dcmtk/dcmnet/dccfpcmp.h" /* for class DcmPresentationContextMap */
-#include "dcmtk/dcmdata/dcerror.h"  /* for EC_IllegalCall */
-#include "dcmtk/dcmdata/dcdefine.h" /* for memcmp() */
+#include "dcmtk/dcmdata/dcerror.h" /* for EC_IllegalCall */
+#include "dcmtk/ofstd/ofdefine.h"  /* for memcmp() */
 
 DcmExtendedNegotiationItem::DcmExtendedNegotiationItem(
   const DcmUIDHandler& abstractSyntax,
@@ -212,6 +207,13 @@ const DcmExtendedNegotiationList *DcmExtendedNegotiationMap::getExtendedNegotiat
 /*
  * CVS/RCS Log
  * $Log: dccfenmp.cc,v $
+ * Revision 1.8  2010-10-14 13:14:28  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.7  2009-09-28 13:28:15  joergr
+ * Moved general purpose definition file from module dcmdata to ofstd, and
+ * added new defines in order to make the usage easier.
+ *
  * Revision 1.6  2005/12/08 15:44:28  meichel
  * Changed include path schema for all DCMTK header files
  *
