@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmnet
  *
@@ -22,10 +18,9 @@
  *  Purpose: 
  *    class DcmUIDHandler
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:44:33 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmnet/libsrc/dccfuidh.cc,v $
- *  CVS/RCS Revision: $Revision: 1.2 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:28 $
+ *  CVS/RCS Revision: $Revision: 1.4 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,9 +30,12 @@
 #include "dcmtk/config/osconfig.h"
 #include "dcmtk/dcmnet/dccfuidh.h"
 
-#include "dcmtk/dcmdata/dcuid.h"    /* for dcmFindUIDFromName() */ 
+#include "dcmtk/dcmdata/dcuid.h"    /* for dcmFindUIDFromName() */
 #include "dcmtk/dcmdata/dcxfer.h"   /* for gLocalByteOrder */
 
+#define INCLUDE_CSTRING             /* for strcmp() */
+#include "dcmtk/ofstd/ofstdinc.h"
+
 #define SymbolicUID_LocalEndianExplicit    "LocalEndianExplicit"
 #define SymbolicUID_OppositeEndianExplicit "OppositeEndianExplicit"
 
@@ -140,7 +138,13 @@ OFBool DcmUIDHandler::isValidUID() const
 /*
  * CVS/RCS Log
  * $Log: dccfuidh.cc,v $
- * Revision 1.2  2005/12/08 15:44:33  meichel
+ * Revision 1.4  2010-10-14 13:14:28  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.3  2010-06-25 09:15:19  uli
+ * Fixed issues with compiling with HAVE_STD_STRING.
+ *
+ * Revision 1.2  2005-12-08 15:44:33  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.1  2003/06/10 14:30:15  meichel
