@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmnet
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DcmTransportConnection, DcmTCPConnection
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:44:35 $
- *  CVS/RCS Revision: $Revision: 1.9 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:28 $
+ *  CVS/RCS Revision: $Revision: 1.14 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -135,7 +131,7 @@ OFBool DcmTransportConnection::fastSelectReadableAssociation(DcmTransportConnect
     {
       socketfd = connections[i]->getSocket();
 #ifdef __MINGW32__
-      // on MinGW, FD_SET expects an unsigned first argument
+      /* on MinGW, FD_SET expects an unsigned first argument */
       FD_SET((unsigned int)socketfd, &fdset);
 #else
       FD_SET(socketfd, &fdset);
@@ -175,6 +171,12 @@ OFBool DcmTransportConnection::selectReadableAssociation(DcmTransportConnection
   return safeSelectReadableAssociation(connections, connCount, timeout);
 }
 
+void DcmTransportConnection::dumpConnectionParameters(STD_NAMESPACE ostream& out)
+{
+    OFString str;
+    out << dumpConnectionParameters(str) << OFendl;
+}
+
 /* ================================================ */
 
 DcmTCPConnection::DcmTCPConnection(int openSocket)
@@ -184,6 +186,7 @@ DcmTCPConnection::DcmTCPConnection(int openSocket)
 
 DcmTCPConnection::~DcmTCPConnection()
 {
+  close();
 }
 
 DcmTransportLayerStatus DcmTCPConnection::serverSideHandshake()
@@ -221,12 +224,17 @@ ssize_t DcmTCPConnection::write(void *buf, size_t nbyte)
 
 void DcmTCPConnection::close()
 {
+  if (getSocket() != -1)
+  {
 #ifdef HAVE_WINSOCK_H
-  (void) shutdown(getSocket(),  1 /* SD_SEND */);
-  (void) closesocket(getSocket());
+    (void) shutdown(getSocket(), 1 /* SD_SEND */);
+    (void) closesocket(getSocket());
 #else
-  (void) ::close(getSocket());
+    (void) ::close(getSocket());
 #endif
+  /* forget about this socket (now closed) */
+    setSocket(-1);
+  }
 }
 
 unsigned long DcmTCPConnection::getPeerCertificateLength()
@@ -248,7 +256,7 @@ OFBool DcmTCPConnection::networkDataAvailable(int timeout)
   FD_ZERO(&fdset);
 
 #ifdef __MINGW32__
-  // on MinGW, FD_SET expects an unsigned first argument
+  /* on MinGW, FD_SET expects an unsigned first argument */
   FD_SET((unsigned int) getSocket(), &fdset);
 #else
   FD_SET(getSocket(), &fdset);
@@ -275,9 +283,10 @@ OFBool DcmTCPConnection::isTransparentConnection()
   return OFTrue;
 }
 
-void DcmTCPConnection::dumpConnectionParameters(ostream &out)
+OFString& DcmTCPConnection::dumpConnectionParameters(OFString& str)
 {
-  out << "Transport connection: TCP/IP, unencrypted." << endl;
+  str = "Transport connection: TCP/IP, unencrypted.";
+  return str;
 }
 
 const char *DcmTCPConnection::errorString(DcmTransportLayerStatus code)
@@ -305,6 +314,24 @@ const char *DcmTCPConnection::errorString(DcmTransportLayerStatus code)
 
 /*
  *  $Log: dcmtrans.cc,v $
+ *  Revision 1.14  2010-10-14 13:14:28  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.13  2010-08-24 10:06:04  uli
+ *  Fixed some resource leaks in dcmtls (FDs and memory was leaked).
+ *
+ *  Revision 1.12  2009-11-18 11:53:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.11  2009-01-29 11:39:20  joergr
+ *  Fixed issue with missing invalidation of socket variable during close method.
+ *  Please note that this is only required if the connection objects exists after
+ *  the TCP/IP connection has been closed (which is currently not the case).
+ *
+ *  Revision 1.10  2006/08/15 16:04:29  meichel
+ *  Updated the code in module dcmnet to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.9  2005/12/08 15:44:35  meichel
  *  Changed include path schema for all DCMTK header files
  *
@@ -336,4 +363,3 @@ const char *DcmTCPConnection::errorString(DcmTransportLayerStatus code)
  *
  *
  */
-
