@@ -1,38 +1,54 @@
+/*
+ *
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
+ *
+ *  This software and supporting documentation were partly developed by
+ *
+ *    OFFIS e.V.
+ *    R&D Division Health
+ *    Escherweg 2
+ *    D-26121 Oldenburg, Germany
+ *
+ *  For further copyrights, see the following paragraphs.
+ *
+ */
+
 /*
 **  Copyright (C) 1993/1994, OFFIS, Oldenburg University and CERIUM
-**  
+**
 **  This software and supporting documentation were
-**  developed by 
-**  
+**  developed by
+**
 **    Institut OFFIS
 **    Bereich Kommunikationssysteme
 **    Westerstr. 10-12
 **    26121 Oldenburg, Germany
-**    
+**
 **    Fachbereich Informatik
 **    Abteilung Prozessinformatik
-**    Carl von Ossietzky Universitaet Oldenburg 
+**    Carl von Ossietzky Universitaet Oldenburg
 **    Ammerlaender Heerstr. 114-118
 **    26111 Oldenburg, Germany
-**    
+**
 **    CERIUM
 **    Laboratoire SIM
 **    Faculte de Medecine
 **    2 Avenue du Pr. Leon Bernard
 **    35043 Rennes Cedex, France
-**  
-**  for CEN/TC251/WG4 as a contribution to the Radiological 
-**  Society of North America (RSNA) 1993 Digital Imaging and 
+**
+**  for CEN/TC251/WG4 as a contribution to the Radiological
+**  Society of North America (RSNA) 1993 Digital Imaging and
 **  Communications in Medicine (DICOM) Demonstration.
-**  
+**
 **  THIS SOFTWARE IS MADE AVAILABLE, AS IS, AND NEITHER OFFIS,
-**  OLDENBURG UNIVERSITY NOR CERIUM MAKE ANY WARRANTY REGARDING 
-**  THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY OR 
-**  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER 
-**  DISEASES OR ITS CONFORMITY TO ANY SPECIFICATION.  THE 
-**  ENTIRE RISK AS TO QUALITY AND PERFORMANCE OF THE SOFTWARE   
-**  IS WITH THE USER. 
-**  
+**  OLDENBURG UNIVERSITY NOR CERIUM MAKE ANY WARRANTY REGARDING
+**  THE SOFTWARE, ITS PERFORMANCE, ITS MERCHANTABILITY OR
+**  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER
+**  DISEASES OR ITS CONFORMITY TO ANY SPECIFICATION.  THE
+**  ENTIRE RISK AS TO QUALITY AND PERFORMANCE OF THE SOFTWARE
+**  IS WITH THE USER.
+**
 **  Copyright of the software and supporting documentation
 **  is, unless otherwise stated, jointly owned by OFFIS,
 **  Oldenburg University and CERIUM and free access is hereby
@@ -41,33 +57,30 @@
 **  software. However, any distribution of this software
 **  source code or supporting documentation or derivative
 **  works (source code and supporting documentation) must
-**  include the three paragraphs of this copyright notice. 
-** 
+**  include the three paragraphs of this copyright notice.
+**
 */
+
 /*
-** 
-** Author:Andrew Hewett		Created: 11-08-93 
-** 	   Oldenburg University
-**	   Germany
+**
+** Author: Andrew Hewett                Created: 11-08-93
 **
 ** Module: dcompat.cc
-** 
+**
 ** Purpose:
-** This is the place to declare compatability routines
-** which can be missing on some systems.  
+**      This is the place to declare compatability routines
+**      which can be missing on some systems.
 **
 ** Base Reference System is SUNOS 4.1.3
 **
-** This include file is automatically included by dicom.h 
+** This include file is automatically included by dicom.h
 **
-** Module Prefix: none 
-** 
+** Module Prefix: none
 **
-** Last Update:		$Author: meichel $
-** Update Date:		$Date: 2005/12/08 15:44:36 $
-** Source File:		$Source: /share/dicom/cvs-depot/dcmtk/dcmnet/libsrc/dcompat.cc,v $
-** CVS/RCS Revision:	$Revision: 1.28 $
-** Status:		$State: Exp $
+** Last Update:         $Author: joergr $
+** Update Date:         $Date: 2010-12-01 08:26:35 $
+** CVS/RCS Revision:    $Revision: 1.35 $
+** Status:              $State: Exp $
 **
 ** CVS/RCS Log at end of file
 */
@@ -78,6 +91,8 @@
 #include "dcmtk/dcmnet/dicom.h"
 #include "dcmtk/ofstd/ofbmanip.h"
 #include "dcmtk/ofstd/ofconsol.h"
+#include "dcmtk/ofstd/ofstd.h"
+#include "dcmtk/dcmnet/diutil.h"
 
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTDIO
@@ -138,14 +153,14 @@ char dcompat_functionDefinedOnlyToStopLinkerMoaning;
 
 int dcmtk_flock(int fd, int operation)
 {
-  CERR << "WARNING: Unsupported flock(fd[" << fd << "],operation[0x"
-    << hex << operation << "])" << dec << endl;
+  DCMNET_WARN("Unsupported flock(fd[" << fd << "],operation[0x"
+    << hex << operation << "])");
   return 0;
 }
 
 void dcmtk_plockerr(const char *s)
 {
-  CERR << s << ": flock not implemented" << endl;
+  DCMNET_WARN(s << ": flock not implemented");
 }
 
 #else /* macintosh */
@@ -170,7 +185,7 @@ int dcmtk_flock(int fd, int operation)
 #endif
   OVERLAPPED overl;
   OFBitmanipTemplate<char>::zeroMem((char *)&overl, sizeof(overl));
-  
+
   if (operation==LOCK_SH)
   {
     if (GetVersion() < 0x80000000) // Windows NT
@@ -213,16 +228,17 @@ void dcmtk_plockerr(const char *s)
 {
   LPVOID lpMsgBuf=NULL;
 
-  FormatMessage( 
+  FormatMessage(
     FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
     NULL,
     GetLastError(),
     MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
     (LPTSTR) &lpMsgBuf, 0, NULL);
 
-  if (lpMsgBuf && s) CERR << s << ": " << (const char*)lpMsgBuf << endl;
+  if (lpMsgBuf && s)
+      DCMNET_ERROR(s << ": " << (const char*)lpMsgBuf);
   LocalFree(lpMsgBuf);
-} 
+}
 
 #else /* USE__LOCKING */
 
@@ -244,12 +260,12 @@ int dcmtk_flock(int fd, int operation)
     int mode = 0;
 
     /* we only have exclusive lock using the windows _locking function */
-    if (operation & LOCK_SH) mode = _LK_LOCK; /* shared lock */	
+    if (operation & LOCK_SH) mode = _LK_LOCK; /* shared lock */
     if (operation & LOCK_EX) mode = _LK_LOCK; /* exclusive lock */
     if (operation & LOCK_UN) mode = _LK_UNLCK; /* unlock */
     if (operation & LOCK_NB) mode = _LK_NBLCK; /* non-blocking */
     int status = _locking(fd, mode, maxSize);
-    
+
     /* reset file point back to original position */
     pos = lseek(fd, originalPosition, SEEK_SET);
     if (pos < 0) return pos;
@@ -258,7 +274,8 @@ int dcmtk_flock(int fd, int operation)
 
 void dcmtk_plockerr(const char *s)
 {
-  CERR << s << ": " << strerror(errno) << endl;
+  char buf[256];
+  DCMNET_ERROR(s << ": " << OFStandard::strerror(errno, buf, sizeof(buf)));
 }
 
 #endif /* USE__LOCKING */
@@ -298,7 +315,7 @@ int dcmtk_flock(int fd, int operation)
     	/* blocking */
 	cmd = F_SETLKW;
     }
-    
+
 #if SIZEOF_VOID_P == SIZEOF_INT
   /* some systems, e.g. NeXTStep, need the third argument
    * for fcntl calls to be casted to int. Other systems,
@@ -316,7 +333,8 @@ int dcmtk_flock(int fd, int operation)
 
 void dcmtk_plockerr(const char *s)
 {
-  CERR << s << ": " << strerror(errno) << endl;
+  char buf[256];
+  DCMNET_ERROR(s << ": " << OFStandard::strerror(errno, buf, sizeof(buf)));
 }
 
 #endif /* _WIN32 */
@@ -325,7 +343,7 @@ void dcmtk_plockerr(const char *s)
 
 #ifndef HAVE_GETHOSTNAME
 /*
-** Use the SYSV uname function (if we have it) 
+** Use the SYSV uname function (if we have it)
 */
 #ifdef HAVE_UNAME
 int gethostname(char* name, int namelen);
@@ -357,7 +375,7 @@ int access(const char* path, int /* amode */)
     struct stat buf;
 
     rc = stat(path, &buf);
-    
+
     /* WARNING
     ** on the macintosh if a file is there we can do anything with it except
     ** if it is locked or on a read only filesystem.  Trying to find out about
@@ -371,6 +389,9 @@ int access(const char* path, int /* amode */)
 
 
 #ifndef HAVE_STRERROR
+
+#warning Your system does not seem to have the strerror() function
+
 /*
  * strerror does not appear to be available on SunOs 4.1.3
  */
@@ -378,7 +399,7 @@ char *strerror(int errornum)
 {
     static char string[256];
     char *s = NULL;
-    /* 
+    /*
      * These are not in the system include files,
      * declare them here.
      */
@@ -387,7 +408,7 @@ char *strerror(int errornum)
 
     string[0] = '\0';
     if (errornum < 0 || errornum >= sys_nerr) {
-        sprintf(string,"Error number: %d", errornum);
+        sprintf(string, "Error number: %d", errornum);
 	s = string;
     } else {
         s = sys_errlist[errornum];
@@ -399,7 +420,7 @@ char *strerror(int errornum)
 
 
 #ifndef HAVE_TEMPNAM
-/* 
+/*
  * These functions are not present on NeXTs but are used by the
  * DB module.
  */
@@ -440,7 +461,7 @@ tempnam(char *dir, char *pfx)
     /* SUNOS Compatability: take the first 5 characters of prefix (pfx) */
     bzero(prefix, sizeof(prefix));
     strncpy(prefix, pfx, 5);
-    /* 
+    /*
      * Find a suitable name.
      * Use at most 14 characters for filename component of
      * path.  The last 5 characters use the process id, the middle
@@ -448,13 +469,13 @@ tempnam(char *dir, char *pfx)
      * note will recycle after about 65536 times
      */
 
-    mix++;	/* will recycle */    
+    mix++;	/* will recycle */
 
-    sprintf(name, "%s%c%s%04x%05d", tmpdir, PATH_SEPARATOR, prefix, 
-	(unsigned int)mix, getpid());
+    sprintf(name, "%s%c%s%04x%05d", tmpdir, PATH_SEPARATOR, prefix,
+	(unsigned int)mix, (int)OFStandard::getProcessID());
 
-    return name;    
-} 
+    return name;
+}
 
 #endif /* ! HAVE_TEMPNAM */
 
@@ -462,6 +483,30 @@ tempnam(char *dir, char *pfx)
 /*
 ** CVS Log
 ** $Log: dcompat.cc,v $
+** Revision 1.35  2010-12-01 08:26:35  joergr
+** Added OFFIS copyright header (beginning with the year 1994).
+**
+** Revision 1.34  2010-10-14 13:14:28  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.33  2010-06-02 14:52:03  joergr
+** Replaced calls to strerror() by new helper function OFStandard::strerror()
+** which results in using the thread safe version of strerror() if available.
+** Added #warning statement for systems where HAVE_STRERROR is not defined.
+**
+** Revision 1.32  2010-01-20 13:49:47  uli
+** Added OFStandard::getProcessID().
+**
+** Revision 1.31  2009-12-02 13:16:16  uli
+** Corrected build failures on windows.
+**
+** Revision 1.30  2009-11-18 11:53:59  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.29  2006-08-15 16:04:29  meichel
+** Updated the code in module dcmnet to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
 ** Revision 1.28  2005/12/08 15:44:36  meichel
 ** Changed include path schema for all DCMTK header files
 **
