@@ -10,10 +10,9 @@
 **
 **      Module Prefix: DIMSE_
 **
-** Last Update:         $Author: meichel $
-** Update Date:         $Date: 2005/12/08 15:44:43 $
-** Source File:         $Source: /share/dicom/cvs-depot/dcmtk/dcmnet/libsrc/dimget.cc,v $
-** CVS/RCS Revision:    $Revision: 1.6 $
+** Last Update:         $Author: joergr $
+** Update Date:         $Date: 2010-10-14 13:14:28 $
+** CVS/RCS Revision:    $Revision: 1.8 $
 ** Status:              $State: Exp $
 **
 ** CVS/RCS Log at end of file
@@ -191,16 +190,13 @@ DIMSE_getUser(
         switch (status) {
         case STATUS_Pending:
             if (*statusDetail != NULL) {
-                DIMSE_warning(assoc, 
-                    "getUser: Pending with statusDetail, ignoring detail");
+                DCMNET_WARN(DIMSE_warn_str(assoc) << "getUser: Pending with statusDetail, ignoring detail");
                 delete *statusDetail;
                 *statusDetail = NULL;
             }
             if (response->DataSetType != DIMSE_DATASET_NULL) {
-                DIMSE_warning(assoc, 
-                    "getUser: Status Pending, but DataSetType!=NULL");
-                DIMSE_warning(assoc, 
-                    "  Assuming NO response identifiers are present");
+                DCMNET_WARN(DIMSE_warn_str(assoc) << "getUser: Status Pending, but DataSetType!=NULL");
+                DCMNET_WARN(DIMSE_warn_str(assoc) << "Assuming NO response identifiers are present");
             }
 
             /* execute callback */
@@ -383,7 +379,13 @@ DIMSE_getProvider(
 /*
 ** CVS Log
 ** $Log: dimget.cc,v $
-** Revision 1.6  2005/12/08 15:44:43  meichel
+** Revision 1.8  2010-10-14 13:14:28  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.7  2009-11-18 11:53:59  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.6  2005-12-08 15:44:43  meichel
 ** Changed include path schema for all DCMTK header files
 **
 ** Revision 1.5  2002/11/27 13:04:41  meichel
