@@ -1,3 +1,19 @@
+/*
+ *
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
+ *
+ *  This software and supporting documentation were partly developed by
+ *
+ *    OFFIS e.V.
+ *    R&D Division Health
+ *    Escherweg 2
+ *    D-26121 Oldenburg, Germany
+ *
+ *  For further copyrights, see the following paragraphs.
+ *
+ */
+
 /*
           Copyright (C) 1993, 1994, RSNA and Washington University
 
@@ -29,72 +45,72 @@
           supporting documentation) must include the three paragraphs of
           the copyright notice.
 */
-/* Copyright marker.  Copyright will be inserted above.  Do not remove */
+
 /*
-** @$=@$=@$=
-*/
-/*
-**                              DICOM 93
-**                   Electronic Radiology Laboratory
-**                 Mallinckrodt Institute of Radiology
-**              Washington University School of Medicine
+**          DICOM 93
+**        Electronic Radiology Laboratory
+**      Mallinckrodt Institute of Radiology
+**    Washington University School of Medicine
 **
-** Module Name(s):      parseAssociate
-**                      parseDebug
-** Author, Date:        Stephen M. Moore, 15-Apr-93
-** Intent:              This file contains functions for parsing Dicom
-**                      Upper Layer (DUL) Protocol Data Units (PDUs)
-**                      into logical in-memory structures.
-** Last Update:         $Author: joergr $, $Date: 2004/02/04 15:33:48 $
-** Source File:         $RCSfile: dulparse.cc,v $
-** Revision:            $Revision: 1.23 $
-** Status:              $State: Exp $
+** Module Name(s):  parseAssociate
+**                  parseDebug
+** Author, Date:    Stephen M. Moore, 15-Apr-93
+** Intent:          This file contains functions for parsing Dicom
+**                  Upper Layer (DUL) Protocol Data Units (PDUs)
+**                  into logical in-memory structures.
+** Last Update:     $Author: joergr $, $Date: 2010-12-01 08:26:36 $
+** Revision:        $Revision: 1.33 $
+** Status:          $State: Exp $
 */
 
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTDIO
 #define INCLUDE_CSTRING
-#include "ofstdinc.h"
+#include "dcmtk/ofstd/ofstdinc.h"
 
-#include "ofstream.h"
-#include "dicom.h"
-#include "cond.h"
-#include "lst.h"
-#include "dul.h"
+#include "dcmtk/ofstd/ofstream.h"
+#include "dcmtk/dcmnet/dicom.h"
+#include "dcmtk/dcmnet/cond.h"
+#include "dcmtk/dcmnet/lst.h"
+#include "dcmtk/dcmnet/dul.h"
+#include "dcmtk/dcmnet/diutil.h"
 #include "dulstruc.h"
 #include "dulpriv.h"
-#include "ofconsol.h"
+#include "dcmtk/ofstd/ofconsol.h"
 
 static OFCondition
 parseSubItem(DUL_SUBITEM * subItem, unsigned char *buf,
-             unsigned long *itemLength);
+             unsigned long *itemLength, unsigned long availData);
 static OFCondition
 parsePresentationContext(unsigned char type,
                          PRV_PRESENTATIONCONTEXTITEM * context,
-                         unsigned char *buf, unsigned long *itemLength);
+                         unsigned char *buf, unsigned long *itemLength,
+                         unsigned long availData);
 static OFCondition
 parseUserInfo(DUL_USERINFO * userInfo,
-              unsigned char *buf, unsigned long *itemLength);
+              unsigned char *buf, unsigned long *itemLength,
+              unsigned char typeRQorAC, unsigned long availData);
 static OFCondition
 parseMaxPDU(DUL_MAXLENGTH * max, unsigned char *buf,
-            unsigned long *itemLength);
+            unsigned long *itemLength, unsigned long availData);
 static OFCondition
-    parseDummy(unsigned char *buf, unsigned long *itemLength);
+    parseDummy(unsigned char *buf, unsigned long *itemLength,
+            unsigned long availData);
 static OFCondition
 parseSCUSCPRole(PRV_SCUSCPROLE * role, unsigned char *buf,
-                unsigned long *length);
+                unsigned long *length, unsigned long availData);
 static void trim_trailing_spaces(char *s);
 
 static OFCondition
 parseExtNeg(SOPClassExtendedNegotiationSubItem* extNeg, unsigned char *buf,
-            unsigned long *length);
+            unsigned long *length, unsigned long availData);
 
-#ifdef DEBUG
-static OFBool debug = OFFalse;
-#endif
+static OFCondition
+makeLengthError(const char *pdu, unsigned long bufSize, unsigned long minSize = 0,
+        unsigned long length = 0);
 
 /* parseAssociate
 **
@@ -133,6 +149,10 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
     if ((assoc->presentationContextList = LST_Create()) == NULL) return EC_MemoryExhausted;
     if ((assoc->userInfo.SCUSCPRoleList = LST_Create()) == NULL) return EC_MemoryExhausted;
 
+    // Check if the PDU actually is long enough for the fields we read
+    if (pduLength < 2 + 2 + 16 + 16 + 32)
+        return makeLengthError("associate PDU", pduLength, 2 + 2 + 16 + 16 + 32);
+
     assoc->type = *buf++;
     assoc->rsv1 = *buf++;
     EXTRACT_LONG_BIG(buf, assoc->length);
@@ -152,11 +172,13 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
     assoc->rsv2[1] = *buf++;
     pduLength--;
     (void) strncpy(assoc->calledAPTitle, (char *) buf, 16);
+    assoc->calledAPTitle[16] = '\0';
     trim_trailing_spaces(assoc->calledAPTitle);
 
     buf += 16;
     pduLength -= 16;
     (void) strncpy(assoc->callingAPTitle, (char *) buf, 16);
+    assoc->callingAPTitle[16] = '\0';
     trim_trailing_spaces(assoc->callingAPTitle);
     buf += 16;
     pduLength -= 16;
@@ -164,10 +186,9 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
     buf += 32;
     pduLength -= 32;
 
-#ifdef DEBUG
-    if (debug) {
+    if (DCM_dcmnetGetLogger().isEnabledFor(OFLogger::DEBUG_LOG_LEVEL)) {
         const char *s;
-        DEBUG_DEVICE << "Parsing an A-ASSOCIATE PDU" << endl;
+        DCMNET_DEBUG("Parsing an A-ASSOCIATE PDU");
         if (assoc->type == DUL_TYPEASSOCIATERQ)
             s = "A-ASSOCIATE RQ";
         else if (assoc->type == DUL_TYPEASSOCIATEAC)
@@ -179,36 +200,30 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
 **      This function is only supposed to parse A-ASSOCIATE PDUs and
 **      expects its input to have been properly screened.
 */
-        DEBUG_DEVICE << "PDU type: " << hex << ((unsigned int)assoc->type) << dec
-        << " (" << s << "), PDU Length: " << assoc->length << endl
-            << "DICOM Protocol: " << hex << assoc->protocol << dec << endl
-            << "Called AP Title:  " << assoc->calledAPTitle << endl
-            << "Calling AP Title: " << assoc->callingAPTitle << endl;
+        DCMNET_TRACE("PDU type: "
+            << STD_NAMESPACE hex << ((unsigned int)assoc->type)
+            << STD_NAMESPACE dec << " (" << s << "), PDU Length: " << assoc->length << OFendl
+            << "DICOM Protocol: "
+            << STD_NAMESPACE hex << assoc->protocol
+            << STD_NAMESPACE dec << OFendl
+            << "Called AP Title:  " << assoc->calledAPTitle << OFendl
+            << "Calling AP Title: " << assoc->callingAPTitle);
     }
-#endif
     while ((cond.good()) && (pduLength > 0))
     {
         type = *buf;
-#ifdef DEBUG
-        if (debug) {
-            DEBUG_DEVICE << "Parsing remaining " << pduLength
-            << " bytes of A-ASSOCIATE PDU" << endl
-            << "Next item type: ";
-        DEBUG_DEVICE << hex << setfill('0') << setw(2) << ((unsigned int)type) << dec << endl;
-        }
-#endif
+        DCMNET_TRACE("Parsing remaining " << pduLength << " bytes of A-ASSOCIATE PDU" << OFendl
+                << "Next item type: "
+                << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << ((unsigned int)type));
         switch (type) {
         case DUL_TYPEAPPLICATIONCONTEXT:
             cond = parseSubItem(&assoc->applicationContext,
-                                buf, &itemLength);
+                                buf, &itemLength, pduLength);
             if (cond.good())
             {
                 buf += itemLength;
                 pduLength -= itemLength;
-#ifdef DEBUG
-                if (debug)
-                    COUT << "Successfully parsed Application Context" << endl;
-#endif
+                DCMNET_TRACE("Successfully parsed Application Context");
             }
             break;
         case DUL_TYPEPRESENTATIONCONTEXTRQ:
@@ -216,30 +231,24 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
             context = (PRV_PRESENTATIONCONTEXTITEM*)malloc(sizeof(PRV_PRESENTATIONCONTEXTITEM));
             if (context == NULL) return EC_MemoryExhausted;
             (void) memset(context, 0, sizeof(*context));
-            cond = parsePresentationContext(type, context, buf, &itemLength);
+            cond = parsePresentationContext(type, context, buf, &itemLength, pduLength);
             if (cond.bad()) return cond;
             buf += itemLength;
             pduLength -= itemLength;
             cond = LST_Enqueue(&assoc->presentationContextList, (LST_NODE*)context);
             if (cond.bad()) return cond;
-#ifdef DEBUG
-            if (debug)
-                    DEBUG_DEVICE << "Successfully parsed Presentation Context " << endl;
-#endif
+            DCMNET_TRACE("Successfully parsed Presentation Context");
             break;
         case DUL_TYPEUSERINFO:
-            cond = parseUserInfo(&assoc->userInfo, buf, &itemLength);
+            cond = parseUserInfo(&assoc->userInfo, buf, &itemLength, assoc->type, pduLength);
             if (cond.bad())
                 return cond;
             buf += itemLength;
             pduLength -= itemLength;
-#ifdef DEBUG
-            if (debug)
-                    DEBUG_DEVICE << "Successfully parsed User Information" << endl;
-#endif
+            DCMNET_TRACE("Successfully parsed User Information");
             break;
         default:
-            cond = parseDummy(buf, &itemLength);
+            cond = parseDummy(buf, &itemLength, pduLength);
             buf += itemLength;
             pduLength -= itemLength;
             break;
@@ -248,32 +257,6 @@ parseAssociate(unsigned char *buf, unsigned long pduLength,
     return cond;
 }
 
-/* parseDebug
-**
-** Purpose:
-**      Set global 'debug' flag for this module (OFTrue or OFFalse).
-**
-** Parameter Dictionary:
-**      flag    OFBool flag to be copied to global 'debug'
-**
-** Return Values:
-**      None
-**
-** Algorithm:
-*/
-
-#ifdef DEBUG
-void
-parseDebug(OFBool flag)
-{
-    debug = flag;
-}
-#else
-void
-parseDebug(OFBool /*flag*/)
-{
-}
-#endif
 
 /* ============================================================
 **  Private functions (to this module) defined below.
@@ -297,23 +280,39 @@ parseDebug(OFBool /*flag*/)
 
 static OFCondition
 parseSubItem(DUL_SUBITEM * subItem, unsigned char *buf,
-             unsigned long *itemLength)
+             unsigned long *itemLength, unsigned long availData)
 {
+    // Need at least 4 bytes (type, rsv1, two bytes length field)
+    if (availData < 4)
+        return makeLengthError("subitem", availData, 4);
+
     subItem->type = *buf++;
     subItem->rsv1 = *buf++;
     EXTRACT_SHORT_BIG(buf, subItem->length);
     buf += 2;
+
+    // Maximum allowed size and our buffer size is DICOM_UI_LENGTH
+    if (subItem->length > DICOM_UI_LENGTH)
+    {
+        char buffer[256];
+        sprintf(buffer, "DUL illegal subitem length %d. Maximum allowed size is %d.",
+               subItem->length, DICOM_UI_LENGTH);
+        return makeDcmnetCondition(DULC_ILLEGALPDULENGTH, OF_error, buffer);
+    }
+
+    // Does the subitem claim to be larger than the containing PDU?
+    if (availData - 4 < subItem->length)
+        return makeLengthError("subitem", availData, 0, subItem->length);
+
     (void) memcpy(subItem->data, buf, subItem->length);
     subItem->data[subItem->length] = '\0';
 
     *itemLength = 2 + 2 + subItem->length;
 
-#ifdef DEBUG
-    if (debug) {
-        DEBUG_DEVICE << "Subitem parse: Type " << hex << setfill('0') << setw(2) << ((unsigned int)subItem->type) << dec << ", Length ";
-        DEBUG_DEVICE << setw(4) << (int)subItem->length << ", Content: " << subItem->data << endl;
-    }
-#endif
+    DCMNET_TRACE("Subitem parse: Type "
+            << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << ((unsigned int)subItem->type)
+            << STD_NAMESPACE dec << ", Length " << STD_NAMESPACE setw(4) << (int)subItem->length
+            << ", Content: " << subItem->data);
     return EC_Normal;
 }
 
@@ -341,7 +340,7 @@ parseSubItem(DUL_SUBITEM * subItem, unsigned char *buf,
 static OFCondition
 parsePresentationContext(unsigned char type,
                   PRV_PRESENTATIONCONTEXTITEM * context, unsigned char *buf,
-                         unsigned long *itemLength)
+                         unsigned long *itemLength, unsigned long availData)
 {
     unsigned long
         length;
@@ -351,6 +350,10 @@ parsePresentationContext(unsigned char type,
     DUL_SUBITEM
         * subItem;
 
+    // We need at least 8 bytes, anything smaller would be reading past the end
+    if (availData < 8)
+        return makeLengthError("presentation context", availData, 8);
+
     if ((context->transferSyntaxList = LST_Create()) == NULL) return EC_MemoryExhausted;
 
     *itemLength = 0;
@@ -366,57 +369,46 @@ parsePresentationContext(unsigned char type,
     length = context->length;
     *itemLength = 2 + 2 + length;
 
-#ifdef DEBUG
-    if (debug) {
-        DEBUG_DEVICE << "Parsing Presentation Context: ("
-            << hex << setfill('0') << setw(2) << (unsigned int)context->type << dec
-            << "), Length: " << (unsigned long)context->length << endl
-            << "Presentation Context ID: ";
-        DEBUG_DEVICE << hex << setfill('0') << setw(2) << (unsigned int)context->contextID << dec << endl;
-    }
-#endif
+    // Does the length field claim to be larger than the containing PDU?
+    if (availData - 4 < length || length < 4)
+        return makeLengthError("presentation context", availData, 4, length);
+
+    DCMNET_TRACE("Parsing Presentation Context: ("
+            << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << (unsigned int)context->type
+            << STD_NAMESPACE dec << "), Length: " << (unsigned long)context->length << OFendl
+            << "Presentation Context ID: "
+            << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << (unsigned int)context->contextID
+            << STD_NAMESPACE dec);
     presentationLength = length - 4;
     if (!((type == DUL_TYPEPRESENTATIONCONTEXTAC) &&
           (context->result != DUL_PRESENTATION_ACCEPT))) {
         while (presentationLength > 0) {
-#ifdef DEBUG
-            if (debug) {
-              DEBUG_DEVICE << "Parsing remaining " << presentationLength
-                << " bytes of Presentation Ctx" << endl;
-              DEBUG_DEVICE << "Next item type: " << hex << setfill('0') << setw(2) << (unsigned int)*buf << dec << endl;
-            }
-#endif
+            DCMNET_TRACE("Parsing remaining " << presentationLength << " bytes of Presentation Context" << OFendl
+                    << "Next item type: "
+                    << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << (unsigned int)*buf);
             switch (*buf) {
             case DUL_TYPEABSTRACTSYNTAX:
-                cond = parseSubItem(&context->abstractSyntax, buf, &length);
+                cond = parseSubItem(&context->abstractSyntax, buf, &length, presentationLength);
                 if (cond.bad())
                     return cond;
 
                 buf += length;
                 presentationLength -= length;
-#ifdef DEBUG
-                if (debug) {
-                    DEBUG_DEVICE << "Successfully parsed Abstract Syntax" << endl;
-                }
-#endif
+                DCMNET_TRACE("Successfully parsed Abstract Syntax");
                 break;
             case DUL_TYPETRANSFERSYNTAX:
                 subItem = (DUL_SUBITEM*)malloc(sizeof(DUL_SUBITEM));
                 if (subItem == NULL) return EC_MemoryExhausted;
-                cond = parseSubItem(subItem, buf, &length);
+                cond = parseSubItem(subItem, buf, &length, presentationLength);
                 if (cond.bad()) return cond;
                 cond = LST_Enqueue(&context->transferSyntaxList, (LST_NODE*)subItem);
                 if (cond.bad()) return cond;
                 buf += length;
                 presentationLength -= length;
-#ifdef DEBUG
-                if (debug) {
-                    DEBUG_DEVICE << "Successfully parsed Transfer Syntax" << endl;
-                }
-#endif
+                DCMNET_TRACE("Successfully parsed Transfer Syntax");
                 break;
             default:
-                cond = parseDummy(buf, &length);
+                cond = parseDummy(buf, &length, presentationLength);
                 buf += length;
                 presentationLength -= length;
                 break;
@@ -450,13 +442,21 @@ parsePresentationContext(unsigned char type,
 
 static OFCondition
 parseUserInfo(DUL_USERINFO * userInfo,
-              unsigned char *buf, unsigned long *itemLength)
+              unsigned char *buf,
+              unsigned long *itemLength,
+              unsigned char typeRQorAC,
+              unsigned long availData)
 {
     unsigned short userLength;
     unsigned long length;
     OFCondition cond = EC_Normal;
     PRV_SCUSCPROLE *role;
     SOPClassExtendedNegotiationSubItem *extNeg = NULL;
+    UserIdentityNegotiationSubItem *usrIdent = NULL;
+
+    // The minimum allowed size is 4 byte, else we read past the buffer end
+    if (availData < 4)
+        return makeLengthError("user info", availData, 4);
 
     userInfo->type = *buf++;
     userInfo->rsv1 = *buf++;
@@ -466,37 +466,29 @@ parseUserInfo(DUL_USERINFO * userInfo,
     userLength = userInfo->length;
     *itemLength = userLength + 4;
 
-#ifdef DEBUG
-    if (debug) {
-        DEBUG_DEVICE << "Parsing user info field ("
-            << hex << setfill('0') << setw(2) << (unsigned int)userInfo->type << dec << "), Length: "
-            << (unsigned long)userInfo->length << endl;
-    }
-#endif
+    // Does this item claim to be larger than the available data?
+    if (availData - 4 < userLength)
+        return makeLengthError("user info", availData, 0, userLength);
+
+    DCMNET_TRACE("Parsing user info field ("
+            << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << (unsigned int)userInfo->type
+            << STD_NAMESPACE dec << "), Length: " << (unsigned long)userInfo->length);
     while (userLength > 0) {
-#ifdef DEBUG
-        if (debug) {
-            DEBUG_DEVICE << "Parsing remaining " << (long)userLength
-            << " bytes of User Information" << endl;
-            DEBUG_DEVICE << "Next item type: " << hex << setfill('0') << setw(2) << (unsigned int)*buf << dec << endl;
-        }
-#endif
+        DCMNET_TRACE("Parsing remaining " << (long)userLength << " bytes of User Information" << OFendl
+                << "Next item type: "
+                << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << (unsigned int)*buf);
         switch (*buf) {
         case DUL_TYPEMAXLENGTH:
-            cond = parseMaxPDU(&userInfo->maxLength, buf, &length);
+            cond = parseMaxPDU(&userInfo->maxLength, buf, &length, userLength);
             if (cond.bad())
                 return cond;
             buf += length;
             userLength -= (unsigned short) length;
-#ifdef DEBUG
-            if (debug) {
-                    DEBUG_DEVICE << "Successfully parsed Maximum PDU Length" << endl;
-            }
-#endif
+            DCMNET_TRACE("Successfully parsed Maximum PDU Length");
             break;
         case DUL_TYPEIMPLEMENTATIONCLASSUID:
             cond = parseSubItem(&userInfo->implementationClassUID,
-                                buf, &length);
+                                buf, &length, userLength);
             if (cond.bad())
                 return cond;
             buf += length;
@@ -504,14 +496,14 @@ parseUserInfo(DUL_USERINFO * userInfo,
             break;
 
         case DUL_TYPEASYNCOPERATIONS:
-            cond = parseDummy(buf, &length);
+            cond = parseDummy(buf, &length, userLength);
             buf += length;
             userLength -= (unsigned short) length;
             break;
         case DUL_TYPESCUSCPROLE:
             role = (PRV_SCUSCPROLE*)malloc(sizeof(PRV_SCUSCPROLE));
             if (role == NULL) return EC_MemoryExhausted;
-            cond = parseSCUSCPRole(role, buf, &length);
+            cond = parseSCUSCPRole(role, buf, &length, userLength);
             if (cond.bad()) return cond;
             cond = LST_Enqueue(&userInfo->SCUSCPRoleList, (LST_NODE*)role);
             if (cond.bad()) return cond;
@@ -520,7 +512,7 @@ parseUserInfo(DUL_USERINFO * userInfo,
             break;
         case DUL_TYPEIMPLEMENTATIONVERSIONNAME:
             cond = parseSubItem(&userInfo->implementationVersionName,
-                                buf, &length);
+                                buf, &length, userLength);
             if (cond.bad()) return cond;
             buf += length;
             userLength -= (unsigned short) length;
@@ -530,7 +522,7 @@ parseUserInfo(DUL_USERINFO * userInfo,
             /* parse an extended negotiation sub-item */
             extNeg = new SOPClassExtendedNegotiationSubItem;
             if (extNeg == NULL)  return EC_MemoryExhausted;
-            cond = parseExtNeg(extNeg, buf, &length);
+            cond = parseExtNeg(extNeg, buf, &length, userLength);
             if (cond.bad()) return cond;
             if (userInfo->extNegList == NULL)
             {
@@ -542,8 +534,24 @@ parseUserInfo(DUL_USERINFO * userInfo,
             userLength -= (unsigned short) length;
             break;
 
+        case DUL_TYPENEGOTIATIONOFUSERIDENTITY:
+          if (typeRQorAC == DUL_TYPEASSOCIATERQ)
+            usrIdent = new UserIdentityNegotiationSubItemRQ();
+          else // assume DUL_TYPEASSOCIATEAC
+            usrIdent = new UserIdentityNegotiationSubItemAC();
+          if (usrIdent == NULL) return EC_MemoryExhausted;
+          cond = usrIdent->parseFromBuffer(buf, length /*return value*/, userLength);
+          if (cond.bad())
+          {
+            delete usrIdent;
+            return cond;
+          }
+          userInfo->usrIdent = usrIdent;
+          buf += length;
+          userLength -= (unsigned short) length;
+          break;
         default:
-            cond = parseDummy(buf, &length);
+            cond = parseDummy(buf, &length, userLength);
             buf += length;
             userLength -= (unsigned short) length;
             break;
@@ -574,8 +582,12 @@ parseUserInfo(DUL_USERINFO * userInfo,
 */
 static OFCondition
 parseMaxPDU(DUL_MAXLENGTH * max, unsigned char *buf,
-            unsigned long *itemLength)
+            unsigned long *itemLength, unsigned long availData)
 {
+    // We want to read 8 bytes of data, is there enough data?
+    if (availData < 8)
+        return makeLengthError("Max PDU", availData, 8);
+
     max->type = *buf++;
     max->rsv1 = *buf++;
     EXTRACT_SHORT_BIG(buf, max->length);
@@ -583,11 +595,10 @@ parseMaxPDU(DUL_MAXLENGTH * max, unsigned char *buf,
     EXTRACT_LONG_BIG(buf, max->maxLength);
     *itemLength = 2 + 2 + max->length;
 
-#ifdef DEBUG
-    if (debug) {
-            DEBUG_DEVICE << "Maximum PDU Length: " << (unsigned long)max->maxLength << endl;
-    }
-#endif
+    if (max->length != 4)
+        DCMNET_WARN("Invalid length (" << max->length << ") for maximum length item, must be 4");
+
+    DCMNET_TRACE("Maximum PDU Length: " << (unsigned long)max->maxLength);
 
     return EC_Normal;
 }
@@ -610,16 +621,24 @@ parseMaxPDU(DUL_MAXLENGTH * max, unsigned char *buf,
 **      Description of the algorithm (optional) and any other notes.
 */
 static OFCondition
-parseDummy(unsigned char *buf, unsigned long *itemLength)
+parseDummy(unsigned char *buf, unsigned long *itemLength, unsigned long availData)
 {
     unsigned short
         userLength;
 
+    // Is there enough data for the length field?
+    if (availData < 4)
+        return makeLengthError("dummy item", availData, 4);
+
     buf++;
     buf++;
     EXTRACT_SHORT_BIG(buf, userLength);
     buf += 2;
 
+    // Is there less data than the length field claims there is?
+    if (availData - 4 < userLength)
+        return makeLengthError("dummy item", availData, 0, userLength);
+
     *itemLength = userLength + 4;
     return EC_Normal;
 }
@@ -643,11 +662,15 @@ parseDummy(unsigned char *buf, unsigned long *itemLength)
 */
 static OFCondition
 parseSCUSCPRole(PRV_SCUSCPROLE * role, unsigned char *buf,
-                unsigned long *length)
+                unsigned long *length, unsigned long availData)
 {
     unsigned short
         UIDLength;
 
+    // We need at least 8 bytes of data, else we read past the end of buf
+    if (availData < 8)
+        return makeLengthError("SCU-SCP role list", availData, 8);
+
     role->type = *buf++;
     role->rsv1 = *buf++;
     EXTRACT_SHORT_BIG(buf, role->length);
@@ -656,6 +679,15 @@ parseSCUSCPRole(PRV_SCUSCPROLE * role, unsigned char *buf,
     EXTRACT_SHORT_BIG(buf, UIDLength);
     buf += 2;
 
+    // Check if all the length fields are valid (we have the minimum needed
+    // number of bytes, no field is larger than its surrounding field).
+    if (availData - 4 < role->length)
+        return makeLengthError("SCU-SCP role list", availData, 0, role->length);
+    if (role->length < 4)
+        return makeLengthError("SCU-SCP role list UID", role->length, 4);
+    if (role->length - 4 < UIDLength)
+        return makeLengthError("SCU-SCP role list UID", role->length, 0, UIDLength);
+
     (void) memcpy(role->SOPClassUID, buf, UIDLength);
     role->SOPClassUID[UIDLength] = '\0';
     buf += UIDLength;
@@ -664,14 +696,10 @@ parseSCUSCPRole(PRV_SCUSCPROLE * role, unsigned char *buf,
 
     *length = 2 + 2 + role->length;
 
-#ifdef DEBUG
-    if (debug) {
-      DEBUG_DEVICE << "Subitem parse: Type "
-        << hex << setfill('0') << setw(2) << (unsigned int)role->type << dec << ", Length ";
-      DEBUG_DEVICE << setw(4) << (int)role->length << ", Content: " << role->SOPClassUID
-        << " " << (int)role->SCURole << " " << (int)role->SCPRole << endl;
-    }
-#endif
+    DCMNET_TRACE("Subitem parse: Type "
+            << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << (unsigned int)role->type
+            << STD_NAMESPACE dec << ", Length " << STD_NAMESPACE setw(4) << (int)role->length
+            << ", Content: " << role->SOPClassUID << " " << (int)role->SCURole << " " << (int)role->SCPRole);
     return EC_Normal;
 }
 
@@ -686,9 +714,14 @@ parseSCUSCPRole(PRV_SCUSCPROLE * role, unsigned char *buf,
 
 static OFCondition
 parseExtNeg(SOPClassExtendedNegotiationSubItem* extNeg, unsigned char *buf,
-                unsigned long *length)
+                unsigned long *length, unsigned long availData)
 {
     unsigned char *bufStart = buf;
+
+    // An extended negotiation item has to be at least 6 bytes large
+    if (availData < 6)
+        return makeLengthError("extended negotiation", availData, 6);
+
     extNeg->itemType = *buf++;
     extNeg->reserved1 = *buf++;
     EXTRACT_SHORT_BIG(buf, extNeg->itemLength);
@@ -697,6 +730,15 @@ parseExtNeg(SOPClassExtendedNegotiationSubItem* extNeg, unsigned char *buf,
     EXTRACT_SHORT_BIG(buf, extNeg->sopClassUIDLength);
     buf += 2;
 
+    // Check if all the length fields are valid (we have the minimum needed
+    // number of bytes, no field is larger than its surrounding field).
+    if (availData - 4 < extNeg->itemLength)
+        return makeLengthError("extended negotiation", availData, 0, extNeg->itemLength);
+    if (extNeg->itemLength < 2)
+        return makeLengthError("extended negotiation item", availData, 2);
+    if (extNeg->itemLength - 2 < extNeg->sopClassUIDLength)
+        return makeLengthError("extended negotiation item", extNeg->itemLength, 0, extNeg->sopClassUIDLength);
+
     extNeg->sopClassUID.append((const char*)buf, extNeg->sopClassUIDLength);
     buf += extNeg->sopClassUIDLength;
 
@@ -710,24 +752,55 @@ parseExtNeg(SOPClassExtendedNegotiationSubItem* extNeg, unsigned char *buf,
         extNeg->serviceClassAppInfo[i] = *buf++;
     }
 
-#ifdef DEBUG
-    if (debug) {
-        DEBUG_DEVICE << "ExtNeg Subitem parse: Type "
-            << hex << setfill('0') << setw(2) << (unsigned int)extNeg->itemType << dec << ", Length ";
-        DEBUG_DEVICE << setw(4) << (int)extNeg->itemLength << ", SOP Class: "
-            << extNeg->sopClassUID.c_str() << endl;
+    if (DCM_dcmnetGetLogger().isEnabledFor(OFLogger::TRACE_LOG_LEVEL)) {
+        DCMNET_TRACE("ExtNeg Subitem parse: Type "
+            << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << OFstatic_cast(unsigned int, extNeg->itemType)
+            << STD_NAMESPACE dec << ", Length " << STD_NAMESPACE setw(4) << (int)extNeg->itemLength
+            << ", SOP Class: " << extNeg->sopClassUID.c_str());
 
-        DEBUG_DEVICE << "   values: ";
+        OFOStringStream str;
+        str << "   values: ";
         for (int j=0; j<extNeg->serviceClassAppInfoLength; j++) {
-            DEBUG_DEVICE << hex << setfill('0') << setw(2) << extNeg->serviceClassAppInfo[j] << dec << " ";
+            str << STD_NAMESPACE hex << STD_NAMESPACE setfill('0') << STD_NAMESPACE setw(2) << extNeg->serviceClassAppInfo[j]
+                << STD_NAMESPACE dec << " ";
         }
-        DEBUG_DEVICE << endl;
+        str << OFStringStream_ends;
+        OFSTRINGSTREAM_GETOFSTRING(str, res)
+        DCMNET_TRACE(res);
     }
-#endif
 
     return EC_Normal;
 }
 
+/* makeLengthError
+ *
+ * This function is used to generate the OFCondition code for an invalid field
+ * length in a PDU.
+ *
+ * @param pdu The name of the field or PDU which got an invalid length field.
+ * @param bufSize The size of the buffer that we received.
+ * @param length The length as given by the length field.
+ * @param minSize The minimum size that a 'pdu' has to have.
+ */
+static OFCondition
+makeLengthError(const char *pdu, unsigned long bufSize, unsigned long minSize,
+        unsigned long length)
+{
+    OFStringStream stream;
+    stream << "DUL Illegal " << pdu << ". Got " << bufSize << " bytes of data";
+    if (length != 0)
+        stream << " with a length field of " << length << " (data before length field is not included in length field)";
+    if (minSize != 0)
+        stream << ". The minimum allowed size is " << minSize;
+    stream << "." << OFStringStream_ends;
+
+    OFCondition ret;
+    OFSTRINGSTREAM_GETSTR(stream, tmpString)
+    ret = makeDcmnetCondition(DULC_ILLEGALPDULENGTH, OF_error, tmpString);
+    OFSTRINGSTREAM_FREESTR(tmpString)
+    return ret;
+}
+
 /* trim_trailing_spaces
 **
 ** Purpose:
@@ -767,6 +840,39 @@ trim_trailing_spaces(char *s)
 /*
 ** CVS Log
 ** $Log: dulparse.cc,v $
+** Revision 1.33  2010-12-01 08:26:36  joergr
+** Added OFFIS copyright header (beginning with the year 1994).
+**
+** Revision 1.32  2010-10-14 13:14:29  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.31  2010-09-14 11:42:14  uli
+** Verify the length fields in the PDUs that we receive.
+**
+** Revision 1.30  2010-01-20 10:01:01  joergr
+** Made sure that the calling and called AE title strings are always
+** null-terminated.
+**
+** Revision 1.29  2009-11-18 11:53:59  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.28  2008-04-17 15:27:35  onken
+** Reworked and extended User Identity Negotiation code.
+**
+** Revision 1.27  2007-09-07 08:49:30  onken
+** Added basic support for Extended Negotiation of User Identity.
+**
+** Revision 1.26  2007/03/12 13:27:53  joergr
+** Updated debug code to correctly compile when all standard C++ classes remain
+** in namespace std.
+**
+** Revision 1.25  2006/08/15 16:04:29  meichel
+** Updated the code in module dcmnet to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.24  2005/12/08 15:44:52  meichel
+** Changed include path schema for all DCMTK header files
+**
 ** Revision 1.23  2004/02/04 15:33:48  joergr
 ** Removed acknowledgements with e-mail addresses from CVS log.
 **
