@@ -1,3 +1,19 @@
+/*
+ *
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
+ *
+ *  This software and supporting documentation were partly developed by
+ *
+ *    OFFIS e.V.
+ *    R&D Division Health
+ *    Escherweg 2
+ *    D-26121 Oldenburg, Germany
+ *
+ *  For further copyrights, see the following paragraphs.
+ *
+ */
+
 /*
           Copyright (C) 1993, 1994, RSNA and Washington University
 
@@ -29,18 +45,15 @@
           supporting documentation) must include the three paragraphs of
           the copyright notice.
 */
-/* Copyright marker.  Copyright will be inserted above.  Do not remove */
+
 /*
-** @$=@$=@$=
-*/
-/*
-**				DICOM 93
-**		     Electronic Radiology Laboratory
-**		   Mallinckrodt Institute of Radiology
-**		Washington University School of Medicine
+**          DICOM 93
+**        Electronic Radiology Laboratory
+**      Mallinckrodt Institute of Radiology
+**    Washington University School of Medicine
 **
 ** Module Name(s):
-** Author, Date:	Stephen M. Moore, xx-May-92
+** Author, Date:  Stephen M. Moore, xx-May-92
 ** Intent:
 **  This header contains private typedefs for the DICOM Upper Layer
 **  (DUL) protocol package.  This is to be used to compile the DUL
@@ -51,10 +64,9 @@
 **  the public definitions and prototypes on purpose so that they
 **  exist in only one location.
 **
-** Last Update:		$Author: meichel $, $Date: 2005/12/08 15:48:09 $
-** Source File:		$RCSfile: dulpriv.h,v $
-** Revision:		$Revision: 1.8 $
-** Status:		$State: Exp $
+** Last Update:   $Author: joergr $, $Date: 2010-12-01 08:26:37 $
+** Revision:      $Revision: 1.11 $
+** Status:        $State: Exp $
 */
 
 #ifndef DULPRIVATE_H
@@ -66,8 +78,6 @@
 #define	PRV_DEFAULTTIMEOUT	-1
 #define	PRV_LISTENBACKLOG	50
 
-#define DEBUG_DEVICE	COUT
-
 OFCondition DUL_InitializeFSM(void);
 OFCondition
 PRV_StateMachine(PRIVATE_NETWORKKEY ** network,
@@ -105,16 +115,21 @@ OFCondition
 PRV_NextPDUType(PRIVATE_ASSOCIATIONKEY ** association,
 		DUL_BLOCKOPTIONS block, int timeout, unsigned char *type);
 
-void fsmDebug(OFBool flag);
-void constructDebug(OFBool flag);
-void parseDebug(OFBool flag);
-
 #endif
 
 /*
 ** CVS Log
 ** $Log: dulpriv.h,v $
-** Revision 1.8  2005/12/08 15:48:09  meichel
+** Revision 1.11  2010-12-01 08:26:37  joergr
+** Added OFFIS copyright header (beginning with the year 1994).
+**
+** Revision 1.10  2010-10-14 13:19:29  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.9  2009-11-18 11:53:59  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.8  2005-12-08 15:48:09  meichel
 ** Updated Makefiles to correctly install header files
 **
 ** Revision 1.7  2004/02/25 12:31:17  meichel
