@@ -1,3 +1,19 @@
+/*
+ *
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
+ *
+ *  This software and supporting documentation were partly developed by
+ *
+ *    OFFIS e.V.
+ *    R&D Division Health
+ *    Escherweg 2
+ *    D-26121 Oldenburg, Germany
+ *
+ *  For further copyrights, see the following paragraphs.
+ *
+ */
+
 /*
           Copyright (C) 1993, 1994, RSNA and Washington University
 
@@ -29,18 +45,15 @@
           supporting documentation) must include the three paragraphs of
           the copyright notice.
 */
-/* Copyright marker.  Copyright will be inserted above.  Do not remove */
+
 /*
-** @$=@$=@$=
-*/
-/*
-**				DICOM 93
-**		     Electronic Radiology Laboratory
-**		   Mallinckrodt Institute of Radiology
-**		Washington University School of Medicine
+**          DICOM 93
+**        Electronic Radiology Laboratory
+**      Mallinckrodt Institute of Radiology
+**    Washington University School of Medicine
 **
 ** Module Name(s):
-** Author, Date:	Stephen M. Moore, 19-May-93
+** Author, Date:  Stephen M. Moore, 19-May-93
 ** Intent:
 **  This header contains private typedefs for the DICOM Upper Layer
 **  (DUL) protocol package.  This is to be used to compile the DUL
@@ -50,20 +63,23 @@
 **  get the public definitions and function prototypes.  I have omitted
 **  the public definitions and prototypes on purpose so that they
 **  exist in only one location.
-** Last Update:		$Author: meichel $, $Date: 2005/12/08 15:48:09 $
-** Source File:		$RCSfile: dulstruc.h,v $
-** Revision:		$Revision: 1.9 $
-** Status:		$State: Exp $
+** Last Update:   $Author: joergr $, $Date: 2010-12-01 08:26:37 $
+** Revision:      $Revision: 1.13 $
+** Status:        $State: Exp $
 */
 
+#ifndef DULSTRUC_H
+#define DULSTRUC_H
+
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 #include "dcmtk/dcmnet/extneg.h"
+#include "dcmtk/dcmnet/dcuserid.h"
 
 class DcmTransportConnection;
 class DcmTransportLayer;
 
-#define	NETWORK_DISCONNECTED	2
-#define	NETWORK_CONNECTED	3
+#define NETWORK_DISCONNECTED  2
+#define NETWORK_CONNECTED 3
 
 typedef enum {
     DUL_ASSOC_WAITINGFORACK,
@@ -73,9 +89,9 @@ typedef enum {
     DUL_ASSOC_DROPPED
 }   DUL_ASSOC_STATE;
 
-#define ASSOCIATION_DISCONNECTED	2
-#define ASSOCIATION_ABORTED		4
-#define ASSOCIATION_RELEASED		5
+#define ASSOCIATION_DISCONNECTED  2
+#define ASSOCIATION_ABORTED   4
+#define ASSOCIATION_RELEASED    5
 
 typedef struct {
     char keyType[40];
@@ -85,12 +101,12 @@ typedef struct {
     int timeout;
     unsigned long options;
     union {
-	struct {
-	    int port;
-	    int listenSocket;
+  struct {
+      int port;
+      int listenSocket;
             DcmTransportLayer *tLayer;
             int tLayerOwned;
-	}   TCP;
+  }   TCP;
     }   networkSpecific;
 }   PRIVATE_NETWORKKEY;
 
@@ -136,28 +152,28 @@ typedef struct {
     DUL_ModeCallback *modeCallback;
 }   PRIVATE_ASSOCIATIONKEY;
 
-#define KEY_NETWORK	"KEY NETWORK"
-#define	KEY_ASSOCIATION	"KEY ASSOCIATION"
+#define KEY_NETWORK "KEY NETWORK"
+#define KEY_ASSOCIATION "KEY ASSOCIATION"
 
-#define	AE_REQUESTOR	"AE REQUESTOR"
-#define	AE_ACCEPTOR	"AE ACCEPTOR"
-#define	AE_BOTH		"AE BOTH"
+#define AE_REQUESTOR  "AE REQUESTOR"
+#define AE_ACCEPTOR "AE ACCEPTOR"
+#define AE_BOTH   "AE BOTH"
 
-#define	NO_PDU		1
-#define	PDU_HEAD	2
-#define	PDU_DATA	2
+#define NO_PDU    1
+#define PDU_HEAD  2
+#define PDU_DATA  2
 
 /* Default timeout for waiting for PDUs.  100 seconds is high,
 ** but used for development so we have time to do things with the
 ** debugger.  A lower value would be used in a production system.
 */
 
-#define	DEFAULT_TIMEOUT			100
+#define DEFAULT_TIMEOUT     100
 
 /*  Private definitions */
 
 typedef struct dul_subitem {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned char type;
     unsigned char rsv1;
     unsigned short length;
@@ -165,7 +181,7 @@ typedef struct dul_subitem {
 }   DUL_SUBITEM;
 
 typedef struct dul_maxlength {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned char type;
     unsigned char rsv1;
     unsigned short length;
@@ -195,7 +211,7 @@ typedef struct {
 }   PRV_IMPLEMENTATIONVERSIONNAME;
 
 typedef struct {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned char type;
     unsigned char rsv1;
     unsigned short length;
@@ -206,7 +222,7 @@ typedef struct {
 }   PRV_SCUSCPROLE;
 
 typedef struct dul_presentationcontext {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned char type;
     unsigned char rsv1;
     unsigned short length;
@@ -220,7 +236,7 @@ typedef struct dul_presentationcontext {
 }   PRV_PRESENTATIONCONTEXTITEM;
 
 typedef struct user_info {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned char type;
     unsigned char rsv1;
     unsigned short length;
@@ -230,10 +246,12 @@ typedef struct user_info {
     DUL_SUBITEM implementationVersionName;               // 55H: implementation version name
     LST_HEAD *SCUSCPRoleList;                            // 54H: SCP/SCU role selection
     SOPClassExtendedNegotiationSubItemList *extNegList;  // 56H: extended negotiation
+                                                         // 57H: SOP CLASS COMMON EXTENDED NEGOTIATION (not implemented)
+    UserIdentityNegotiationSubItem *usrIdent;            // 58H: user identity negotiation RQ or AC
 }   DUL_USERINFO;
 
 typedef struct dul_associatepdu {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned char type;
     unsigned char rsv1;
     unsigned long length;
@@ -249,7 +267,7 @@ typedef struct dul_associatepdu {
 }   PRV_ASSOCIATEPDU;
 
 typedef struct dul_rejectreleaseabortpdu {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned char type;
     unsigned char rsv1;
     unsigned long length;
@@ -260,7 +278,7 @@ typedef struct dul_rejectreleaseabortpdu {
 }   DUL_REJECTRELEASEABORTPDU;
 
 typedef struct dul_presentationdatavalue {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned long length;
     unsigned char presentationContextID;
     unsigned char messageControlHeader;
@@ -268,48 +286,63 @@ typedef struct dul_presentationdatavalue {
 }   DUL_PRESENTATIONDATAVALUE;
 
 typedef struct dul_datapdu {
-    void *reserved[2]; 
+    void *reserved[2];
     unsigned char type;
     unsigned char rsv1;
     unsigned long length;
     DUL_PRESENTATIONDATAVALUE presentationDataValue;
 }   DUL_DATAPDU;
 
-#define DUL_PROTOCOL			(unsigned short) 0x01
+#define DUL_PROTOCOL      (unsigned short) 0x01
 
-#define DUL_TYPEAPPLICATIONCONTEXT	(unsigned char)0x10
-#define DUL_TYPEPRESENTATIONCONTEXTRQ	(unsigned char)0x20
-#define DUL_TYPEPRESENTATIONCONTEXTAC	(unsigned char)0x21
-#define DUL_TYPEABSTRACTSYNTAX		(unsigned char)0x30
-#define DUL_TYPETRANSFERSYNTAX		(unsigned char)0x40
-#define DUL_TYPEUSERINFO		(unsigned char)0x50
-#define	DUL_TYPEMAXLENGTH		(unsigned char)0x51
-#define	DUL_TYPEIMPLEMENTATIONCLASSUID	(unsigned char)0x52
-#define	DUL_TYPEASYNCOPERATIONS		(unsigned char)0x53
-#define	DUL_TYPESCUSCPROLE		(unsigned char)0x54
-#define	DUL_TYPEIMPLEMENTATIONVERSIONNAME (unsigned char)0x55
+#define DUL_TYPEAPPLICATIONCONTEXT  (unsigned char)0x10
+#define DUL_TYPEPRESENTATIONCONTEXTRQ (unsigned char)0x20
+#define DUL_TYPEPRESENTATIONCONTEXTAC (unsigned char)0x21
+#define DUL_TYPEABSTRACTSYNTAX    (unsigned char)0x30
+#define DUL_TYPETRANSFERSYNTAX    (unsigned char)0x40
+#define DUL_TYPEUSERINFO    (unsigned char)0x50
+#define DUL_TYPEMAXLENGTH   (unsigned char)0x51
+#define DUL_TYPEIMPLEMENTATIONCLASSUID  (unsigned char)0x52
+#define DUL_TYPEASYNCOPERATIONS   (unsigned char)0x53
+#define DUL_TYPESCUSCPROLE    (unsigned char)0x54
+#define DUL_TYPEIMPLEMENTATIONVERSIONNAME (unsigned char)0x55
 
-#define COPY_LONG_BIG(A,B) {	\
-	(B)[0] = (unsigned char)((A)>>24);		\
-	(B)[1] = (unsigned char)((A)>>16) ;	\
-	(B)[2] = (unsigned char)((A)>>8) ;	\
-	(B)[3] = (unsigned char)(A) ;	}
-#define COPY_SHORT_BIG(A,B) {	\
-	(B)[0] = (unsigned char)((A)>>8);		\
-	(B)[1] = (unsigned char)(A) ;	}
+#define COPY_LONG_BIG(A,B) {  \
+  (B)[0] = (unsigned char)((A)>>24);    \
+  (B)[1] = (unsigned char)((A)>>16) ; \
+  (B)[2] = (unsigned char)((A)>>8) ;  \
+  (B)[3] = (unsigned char)(A) ; }
+#define COPY_SHORT_BIG(A,B) { \
+  (B)[0] = (unsigned char)((A)>>8);   \
+  (B)[1] = (unsigned char)(A) ; }
 
-#define EXTRACT_LONG_BIG(A,B)	{			\
-	(B) = (unsigned long)(A)[3]				\
-	  | (((unsigned long)(A)[2]) << 8)		\
-	  | (((unsigned long)(A)[1]) << 16)		\
-	  | (((unsigned long)(A)[0]) << 24);	\
-	}
+#define EXTRACT_LONG_BIG(A,B) {     \
+  (B) = (unsigned long)(A)[3]       \
+    | (((unsigned long)(A)[2]) << 8)    \
+    | (((unsigned long)(A)[1]) << 16)   \
+    | (((unsigned long)(A)[0]) << 24);  \
+  }
 
 #define EXTRACT_SHORT_BIG(A,B)  { (B) = (unsigned short)(A)[1] | (((unsigned short)(A)[0]) << 8); }
 
+#endif // #ifndef DULSTRUC_H
+
 /*
 ** CVS Log
 ** $Log: dulstruc.h,v $
+** Revision 1.13  2010-12-01 08:26:37  joergr
+** Added OFFIS copyright header (beginning with the year 1994).
+**
+** Revision 1.12  2010-10-14 13:19:29  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.11  2008-04-17 15:27:36  onken
+** Reworked and extended User Identity Negotiation code.
+**
+** Revision 1.10  2007-09-07 08:47:54  onken
+** Added basic support for Extended Negotiation of User Identity. Added #ifndef
+** guard to header file.
+**
 ** Revision 1.9  2005/12/08 15:48:09  meichel
 ** Updated Makefiles to correctly install header files
 **
@@ -346,3 +379,4 @@ typedef struct dul_datapdu {
 **
 **
 */
+
