@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1994-2005, OFFIS
+ *  Copyright (C) 1994-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmnet
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: List class with procedural API compatible to MIR CTN
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:44:55 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmnet/libsrc/lst.cc,v $
- *  CVS/RCS Revision: $Revision: 1.6 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:29 $
+ *  CVS/RCS Revision: $Revision: 1.8 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -81,7 +76,8 @@ void *LST_HEAD::next()
 void *LST_HEAD::current() const
 {
   if (theList.size() == 0) return NULL;
-  if (theIterator == theList.end()) return NULL;
+  OFListConstIterator(void *) it = theIterator;
+  if (it == theList.end()) return NULL;
   return *theIterator;  
 }
 
@@ -164,7 +160,13 @@ void *LST_Position(LST_HEAD ** lst, void *node)
 /*
  * CVS Log
  * $Log: lst.cc,v $
- * Revision 1.6  2005/12/08 15:44:55  meichel
+ * Revision 1.8  2010-10-14 13:14:29  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.7  2009-09-04 13:53:09  meichel
+ * Minor const iterator related changes needed to compile with VC6 with HAVE_STL
+ *
+ * Revision 1.6  2005-12-08 15:44:55  meichel
  * Changed include path schema for all DCMTK header files
  *
  * Revision 1.5  2003/06/02 16:44:11  meichel
