@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2004, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmpstat
  *
@@ -22,9 +18,8 @@
  *  Purpose: This application reads a DICOM image, adds a Curve and writes it back.
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2004/02/04 15:44:38 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmpstat/apps/dcmmkcrv.cc,v $
- *  CVS/RCS Revision: $Revision: 1.17 $
+ *  Update Date:      $Date: 2010-10-14 13:13:44 $
+ *  CVS/RCS Revision: $Revision: 1.25 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,18 +27,18 @@
  */
 
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #ifdef HAVE_GUSI_H
 #include <GUSI.h>
 #endif
 
-#include "ofstream.h"
-#include "dctk.h"
-#include "cmdlnarg.h"
-#include "ofconapp.h"
-#include "ofcast.h"
-#include "dcuid.h"       /* for dcmtk version name */
+#include "dcmtk/ofstd/ofstream.h"
+#include "dcmtk/ofstd/ofconapp.h"
+#include "dcmtk/ofstd/ofcast.h"
+#include "dcmtk/dcmdata/dctk.h"
+#include "dcmtk/dcmdata/cmdlnarg.h"
+#include "dcmtk/dcmdata/dcuid.h"       /* for dcmtk version name */
 
 #ifdef WITH_ZLIB
 #include <zlib.h>        /* for zlibVersion() */
@@ -51,13 +46,13 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dcmmkcrv"
 
+static OFLogger dcmmkcrvLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
 #define MAX_POINTS 65535
 
-OFBool opt_verbose = OFFalse;
-
 // ********************************************
 
 #define SHORTCOL 3
@@ -65,7 +60,6 @@ OFBool opt_verbose = OFFalse;
 
 int main(int argc, char *argv[])
 {
-    int opt_debugMode = 0;
     const char *opt_inName = NULL;                     /* in file name */
     const char *opt_outName = NULL;                    /* out file name */
     const char *opt_curveName = NULL;                  /* curve file name */
@@ -78,59 +72,57 @@ int main(int argc, char *argv[])
     const char *opt_axis_y = NULL;
     OFCmdUnsignedInt opt_curve_vr = 0;
 
-    SetDebugLevel(( 0 ));
-
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "Add 2D curve data to image", rcsid);
     OFCommandLine cmd;
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
     cmd.setParamColumn(LONGCOL + SHORTCOL + 4);
 
-    cmd.addParam("dcmimg-in",      "DICOM input image file");
-    cmd.addParam("curvedata-in",   "curve data input file (text)");
-    cmd.addParam("dcmimg-out",     "DICOM output filename");
+    cmd.addParam("dcmfile-in", "DICOM input image file");
+    cmd.addParam("curvedata-in", "curve data input file (text)");
+    cmd.addParam("dcmfile-out", "DICOM output filename");
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-     cmd.addOption("--help",                      "-h",        "print this help text and exit");
-     cmd.addOption("--version",                                "print version information and exit", OFTrue /* exclusive */);
-     cmd.addOption("--verbose",                   "-v",        "verbose mode, print processing details");
-     cmd.addOption("--debug",                     "-d",        "debug mode, print debug information");
+     cmd.addOption("--help",           "-h",    "print this help text and exit", OFCommandLine::AF_Exclusive);
+     cmd.addOption("--version",                 "print version information and exit", OFCommandLine::AF_Exclusive);
+     OFLog::addOptions(cmd);
+
     cmd.addGroup("curve creation options:");
       cmd.addSubGroup("curve type:");
-        cmd.addOption("--poly",        "-r",     "create as POLY curve (default)");
-        cmd.addOption("--roi",         "+r",     "create as ROI curve");
+        cmd.addOption("--poly",        "-r",    "create as POLY curve (default)");
+        cmd.addOption("--roi",         "+r",    "create as ROI curve");
 
       cmd.addSubGroup("curve value representation:");
-        cmd.addOption("--data-vr",     "+v", 1,  "[n]umber: integer 0..4 (default: 4)",
-                                                 "select curve data VR: 0=US, 1=SS, 2=FL, 3=FD, 4=SL");
-        cmd.addOption("--curve-vr",    "-c", 1,  "[n]umber: integer 0..2 (default: 0)",
-                                                 "select VR with which the Curve Data element is written\n"
-                                                 "0=VR according to --data-vr, 1=OB, 2=OW");
+        cmd.addOption("--data-vr",     "+v", 1, "[n]umber: integer 0..4 (default: 4)",
+                                                "select curve data VR: 0=US, 1=SS, 2=FL, 3=FD, 4=SL");
+        cmd.addOption("--curve-vr",    "-c", 1, "[n]umber: integer 0..2 (default: 0)",
+                                                "select VR with which the Curve Data element is written\n"
+                                                "0=VR according to --data-vr, 1=OB, 2=OW");
       cmd.addSubGroup("repeating group:");
-        cmd.addOption("--group",       "-g", 1,  "[n]umber: integer 0..15 (default: 0)",
-                                                 "select repeating group: 0=0x5000, 1=0x5002 etc.");
+        cmd.addOption("--group",       "-g", 1, "[n]umber: integer 0..15 (default: 0)",
+                                                "select repeating group: 0=0x5000, 1=0x5002 etc.");
       cmd.addSubGroup("curve description:");
-        cmd.addOption("--label",       "-l", 1,  "s: string",
-                                                 "set Curve Label to s (default: absent)");
-        cmd.addOption("--description", "+d", 1,  "s: string",
-                                                 "set Curve Description to s (default: absent)");
-        cmd.addOption("--axis",        "-a", 2,  "x: string, y: string",
-                                                 "set Axis Units to x\\y (default: absent)");
+        cmd.addOption("--label",       "-l", 1, "s: string",
+                                                "set Curve Label to s (default: absent)");
+        cmd.addOption("--description", "+d", 1, "s: string",
+                                                "set Curve Description to s (default: absent)");
+        cmd.addOption("--axis",        "-a", 2, "x: string, y: string",
+                                                "set Axis Units to x\\y (default: absent)");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
         if (cmd.findOption("--version"))
         {
-            app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-            CERR << endl << "External libraries used:";
+            app.printHeader(OFTrue /*print host identifier*/);
+            COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-            CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+            COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-            CERR << " none" << endl;
+            COUT << " none" << OFendl;
 #endif
             return 0;
          }
@@ -141,8 +133,8 @@ int main(int argc, char *argv[])
       cmd.getParam(2, opt_curveName);
       cmd.getParam(3, opt_outName);
 
-      if (cmd.findOption("--verbose")) opt_verbose=OFTrue;
-      if (cmd.findOption("--debug")) opt_debugMode = 3;
+      OFLog::configureFromCommandLine(cmd, app);
+
       cmd.beginOptionBlock();
       if (cmd.findOption("--roi")) opt_poly = OFFalse;
       if (cmd.findOption("--poly")) opt_poly = OFTrue;
@@ -161,46 +153,45 @@ int main(int argc, char *argv[])
       }
     }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmmkcrvLogger, rcsid << OFendl);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded()) {
-	CERR << "Warning: no data dictionary loaded, "
-	     << "check environment variable: "
-	     << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dcmmkcrvLogger, "no data dictionary loaded, "
+            << "check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     DcmFileFormat *fileformat = new DcmFileFormat;
     if (!fileformat)
     {
-      CERR << "memory exhausted\n";
+      OFLOG_FATAL(dcmmkcrvLogger, "memory exhausted");
       return 1;
     }
 
     OFCondition error = fileformat->loadFile(opt_inName);
     if (! error.good())
     {
-	CERR << "Error: "
-	     << error.text()
-	     << ": reading file: " <<  opt_inName << endl;
-	return 1;
+      OFLOG_FATAL(dcmmkcrvLogger, error.text() << ": reading file: " <<  opt_inName);
+      return 1;
     }
 
     DcmDataset *dataset = fileformat->getDataset();
 
     /* read curve data */
 
-    ifstream curvefile(opt_curveName);
+    STD_NAMESPACE ifstream curvefile(opt_curveName);
     if (!curvefile)
     {
-      CERR << "cannot open curve file: " << opt_curveName << endl;
+      OFLOG_FATAL(dcmmkcrvLogger, "cannot open curve file: " << opt_curveName);
       return 1;
     }
 
     double *array = new double[MAX_POINTS*2];
     if (array==NULL)
     {
-      CERR << "out of memory" << endl;
+      OFLOG_FATAL(dcmmkcrvLogger, "out of memory");
       return 1;
     }
 
@@ -212,7 +203,7 @@ int main(int argc, char *argv[])
       curvefile >> d;
       if (idx == MAX_POINTS*2)
       {
-      	CERR << "warning: too many curve points, can only handle " << MAX_POINTS << "." << endl;
+        OFLOG_WARN(dcmmkcrvLogger, "too many curve points, can only handle " << MAX_POINTS << ".");
         done = OFTrue;
       } else {
       	if (curvefile.good()) array[idx++] = d;
@@ -220,18 +211,18 @@ int main(int argc, char *argv[])
     }
 
     /* create curve description data */
-    DcmUnsignedShort *curveDimensions = new DcmUnsignedShort(DCM_CurveDimensions);
-    DcmUnsignedShort *numberOfPoints = new DcmUnsignedShort(DCM_NumberOfPoints);
-    DcmCodeString    *typeOfData = new DcmCodeString(DCM_TypeOfData);
-    DcmUnsignedShort *dataValueRepresentation = new DcmUnsignedShort(DCM_DataValueRepresentation);
-    DcmLongString    *curveDescription = new DcmLongString(DCM_CurveDescription);
-    DcmShortString   *axisUnits = new DcmShortString(DCM_AxisUnits);
-    DcmLongString    *curveLabel = new DcmLongString(DCM_CurveLabel);
+    DcmUnsignedShort *curveDimensions = new DcmUnsignedShort(DCM_RETIRED_CurveDimensions);
+    DcmUnsignedShort *numberOfPoints = new DcmUnsignedShort(DCM_RETIRED_NumberOfPoints);
+    DcmCodeString    *typeOfData = new DcmCodeString(DCM_RETIRED_TypeOfData);
+    DcmUnsignedShort *dataValueRepresentation = new DcmUnsignedShort(DCM_RETIRED_DataValueRepresentation);
+    DcmLongString    *curveDescription = new DcmLongString(DCM_RETIRED_CurveDescription);
+    DcmShortString   *axisUnits = new DcmShortString(DCM_RETIRED_AxisUnits);
+    DcmLongString    *curveLabel = new DcmLongString(DCM_RETIRED_CurveLabel);
 
     if ((!curveDimensions)||(!numberOfPoints)||(!typeOfData)||(!dataValueRepresentation)
        ||(!curveDescription)||(!axisUnits)||(!curveLabel))
     {
-      CERR << "out of memory" << endl;
+      OFLOG_FATAL(dcmmkcrvLogger, "out of memory");
       return 1;
     }
 
@@ -284,47 +275,47 @@ int main(int argc, char *argv[])
     switch (opt_data_vr)
     {
       case 0: // US
-        if (opt_verbose) CERR << "creating curve, VR=US, points=" << idx/2 << endl;
+        OFLOG_INFO(dcmmkcrvLogger, "creating curve, VR=US, points=" << idx/2);
         rawData = new Uint16[idx];
-        if (rawData==NULL) { CERR << "out of memory" << endl; return 1; }
+        if (rawData==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
         byteLength = sizeof(Uint16)*idx;
         for (i=0; i<idx; i++) OFstatic_cast(Uint16 *,rawData)[i] = OFstatic_cast(Uint16,array[i]);
         align = sizeof(Uint16);
         break;
       case 1: // SS
-        if (opt_verbose) CERR << "creating curve, VR=SS, points=" << idx/2 << endl;
+        OFLOG_INFO(dcmmkcrvLogger, "creating curve, VR=SS, points=" << idx/2);
         rawData = new Sint16[idx];
-        if (rawData==NULL) { CERR << "out of memory" << endl; return 1; }
+        if (rawData==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
         byteLength = sizeof(Sint16)*idx;
         for (i=0; i<idx; i++) OFstatic_cast(Sint16 *,rawData)[i] = OFstatic_cast(Sint16,array[i]);
         align = sizeof(Sint16);
         break;
       case 2: // FL
-        if (opt_verbose) CERR << "creating curve, VR=FL, points=" << idx/2 << endl;
+        OFLOG_INFO(dcmmkcrvLogger, "creating curve, VR=FL, points=" << idx/2);
         rawData = new Float32[idx];
-        if (rawData==NULL) { CERR << "out of memory" << endl; return 1; }
+        if (rawData==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
         byteLength = sizeof(Float32)*idx;
         for (i=0; i<idx; i++) OFstatic_cast(Float32 *,rawData)[i] = OFstatic_cast(Float32,array[i]);
         align = sizeof(Float32);
         break;
       case 3: // FD
-        if (opt_verbose) CERR << "creating curve, VR=FD, points=" << idx/2 << endl;
+        OFLOG_INFO(dcmmkcrvLogger, "creating curve, VR=FD, points=" << idx/2);
         rawData = new Float64[idx];
-        if (rawData==NULL) { CERR << "out of memory" << endl; return 1; }
+        if (rawData==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
         byteLength = sizeof(Float64)*idx;
         for (i=0; i<idx; i++) OFstatic_cast(Float64 *,rawData)[i] = OFstatic_cast(Float64,array[i]);
         align = sizeof(Float64);
         break;
       case 4: // SL
-        if (opt_verbose) CERR << "creating curve, VR=SL, points=" << idx/2 << endl;
+        OFLOG_INFO(dcmmkcrvLogger, "creating curve, VR=SL, points=" << idx/2);
         rawData = new Sint32[idx];
-        if (rawData==NULL) { CERR << "out of memory" << endl; return 1; }
+        if (rawData==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
         byteLength = sizeof(Sint32)*idx;
         for (i=0; i<idx; i++) OFstatic_cast(Sint32 *,rawData)[i] = OFstatic_cast(Sint32,array[i]);
         align = sizeof(Sint32);
         break;
       default:
-        CERR << "unknown data VR, bailing out" << endl;
+        OFLOG_FATAL(dcmmkcrvLogger, "unknown data VR, bailing out");
         return 1;
     }
 
@@ -335,37 +326,37 @@ int main(int argc, char *argv[])
         switch (opt_data_vr)
         {
           case 0: // US
-            if (opt_verbose) CERR << "encoding curve data element as VR=US" << endl;
-            element = new DcmUnsignedShort(DcmTag(DCM_CurveData, EVR_US));
-            if (element==NULL) { CERR << "out of memory" << endl; return 1; }
+            OFLOG_INFO(dcmmkcrvLogger, "encoding curve data element as VR=US");
+            element = new DcmUnsignedShort(DcmTag(DCM_RETIRED_CurveData, EVR_US));
+            if (element==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
             element->putUint16Array(OFstatic_cast(Uint16 *,rawData), byteLength/sizeof(Uint16));
             break;
           case 1: // SS
-            if (opt_verbose) CERR << "encoding curve data element as VR=SS" << endl;
-            element = new DcmSignedShort(DcmTag(DCM_CurveData, EVR_SS));
-            if (element==NULL) { CERR << "out of memory" << endl; return 1; }
+            OFLOG_INFO(dcmmkcrvLogger, "encoding curve data element as VR=SS");
+            element = new DcmSignedShort(DcmTag(DCM_RETIRED_CurveData, EVR_SS));
+            if (element==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
             element->putSint16Array(OFstatic_cast(Sint16 *,rawData), byteLength/sizeof(Sint16));
             break;
           case 2: // FL
-            if (opt_verbose) CERR << "encoding curve data element as VR=FL" << endl;
-            element = new DcmFloatingPointSingle(DcmTag(DCM_CurveData, EVR_FL));
-            if (element==NULL) { CERR << "out of memory" << endl; return 1; }
+            OFLOG_INFO(dcmmkcrvLogger, "encoding curve data element as VR=FL");
+            element = new DcmFloatingPointSingle(DcmTag(DCM_RETIRED_CurveData, EVR_FL));
+            if (element==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
             element->putFloat32Array(OFstatic_cast(Float32 *,rawData), byteLength/sizeof(Float32));
             break;
           case 3: // FD
-            if (opt_verbose) CERR << "encoding curve data element as VR=FD" << endl;
-            element = new DcmFloatingPointDouble(DcmTag(DCM_CurveData, EVR_FD));
-            if (element==NULL) { CERR << "out of memory" << endl; return 1; }
+            OFLOG_INFO(dcmmkcrvLogger, "encoding curve data element as VR=FD");
+            element = new DcmFloatingPointDouble(DcmTag(DCM_RETIRED_CurveData, EVR_FD));
+            if (element==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
             element->putFloat64Array(OFstatic_cast(Float64 *,rawData), byteLength/sizeof(Float64));
             break;
           case 4: // SL
-            if (opt_verbose) CERR << "encoding curve data element as VR=SL" << endl;
-            element = new DcmSignedLong(DcmTag(DCM_CurveData, EVR_SL));
-            if (element==NULL) { CERR << "out of memory" << endl; return 1; }
+            OFLOG_INFO(dcmmkcrvLogger, "encoding curve data element as VR=SL");
+            element = new DcmSignedLong(DcmTag(DCM_RETIRED_CurveData, EVR_SL));
+            if (element==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
             element->putSint32Array(OFstatic_cast(Sint32 *,rawData), byteLength/sizeof(Sint32));
             break;
           default:
-            CERR << "unknown data VR, bailing out" << endl;
+            OFLOG_FATAL(dcmmkcrvLogger, "unknown data VR, bailing out");
             return 1;
         }
         element->setGTag(OFstatic_cast(Uint16,0x5000+2*opt_group));
@@ -373,10 +364,10 @@ int main(int argc, char *argv[])
         break;
       case 1: // OB
         // create little endian byte order
-        if (opt_verbose) CERR << "encoding curve data element as VR=OB" << endl;
+        OFLOG_INFO(dcmmkcrvLogger, "encoding curve data element as VR=OB");
         swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, rawData, byteLength, align);
-        element = new DcmOtherByteOtherWord(DCM_CurveData);
-        if (element==NULL) { CERR << "out of memory" << endl; return 1; }
+        element = new DcmOtherByteOtherWord(DCM_RETIRED_CurveData);
+        if (element==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
         element->setGTag(OFstatic_cast(Uint16,0x5000+2*opt_group));
         element->setVR(EVR_OB);
         element->putUint8Array(OFstatic_cast(Uint8 *,rawData), byteLength);
@@ -384,21 +375,21 @@ int main(int argc, char *argv[])
         break;
       case 2: // OW
         // create little endian byte order
-        if (opt_verbose) CERR << "encoding curve data element as VR=OW" << endl;
+        OFLOG_INFO(dcmmkcrvLogger, "encoding curve data element as VR=OW");
         if (align != sizeof(Uint16))
         {
           swapIfNecessary(EBO_LittleEndian, gLocalByteOrder, rawData, byteLength, align);
           swapIfNecessary(gLocalByteOrder, EBO_LittleEndian, rawData, byteLength, sizeof(Uint16));
         }
-        element = new DcmOtherByteOtherWord(DCM_CurveData);
-        if (element==NULL) { CERR << "out of memory" << endl; return 1; }
+        element = new DcmOtherByteOtherWord(DCM_RETIRED_CurveData);
+        if (element==NULL) { OFLOG_FATAL(dcmmkcrvLogger, "out of memory"); return 1; }
         element->setGTag(OFstatic_cast(Uint16,0x5000+2*opt_group));
         element->setVR(EVR_OW);
         element->putUint16Array(OFstatic_cast(Uint16 *,rawData), byteLength/sizeof(Uint16));
         dataset->insert(element, OFTrue);
         break;
       default:
-        CERR << "unsupported VR, bailing out" << endl;
+        OFLOG_FATAL(dcmmkcrvLogger, "unsupported VR, bailing out");
         return 1;
     }
     /* write back */
@@ -406,10 +397,9 @@ int main(int argc, char *argv[])
     error = fileformat->saveFile(opt_outName, dataset->getOriginalXfer());
     if (error != EC_Normal)
     {
-	CERR << "Error: "
-	     << error.text()
-	     << ": writing file: " <<  opt_outName << endl;
-	return 1;
+      OFLOG_FATAL(dcmmkcrvLogger, error.text()
+          << ": writing file: " <<  opt_outName);
+          return 1;
     }
 
     return 0;
@@ -420,6 +410,37 @@ int main(int argc, char *argv[])
 /*
 ** CVS/RCS Log:
 ** $Log: dcmmkcrv.cc,v $
+** Revision 1.25  2010-10-14 13:13:44  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.24  2009-11-24 14:12:56  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.23  2008-09-25 16:30:24  joergr
+** Added support for printing the expanded command line arguments.
+** Always output the resource identifier of the command line tool in debug mode.
+**
+** Revision 1.22  2008-04-30 12:38:42  meichel
+** Fixed compile errors due to changes in attribute tag names
+**
+** Revision 1.21  2006/08/15 16:57:01  meichel
+** Updated the code in module dcmpstat to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.20  2006/07/27 14:33:49  joergr
+** Changed parameter "exclusive" of method addOption() from type OFBool into an
+** integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+** Option "--help" is no longer an exclusive option by default.
+** Made naming conventions for command line parameters more consistent, e.g.
+** used "dcmfile-in", "dcmfile-out" and "bitmap-out".
+**
+** Revision 1.19  2005/12/08 15:46:02  meichel
+** Changed include path schema for all DCMTK header files
+**
+** Revision 1.18  2005/11/28 15:29:05  meichel
+** File dcdebug.h is not included by any other header file in the toolkit
+**   anymore, to minimize the risk of name clashes of macro debug().
+**
 ** Revision 1.17  2004/02/04 15:44:38  joergr
 ** Removed acknowledgements with e-mail addresses from CVS log.
 **
