@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmpstat
  *
@@ -24,10 +20,9 @@
  *    The LUT has a gamma curve shape or can be imported from an external
  *    file.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:03 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmpstat/apps/dcmmklut.cc,v $
- *  CVS/RCS Revision: $Revision: 1.39 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-12-15 17:03:38 $
+ *  CVS/RCS Revision: $Revision: 1.47 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -44,7 +39,7 @@
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/dcmdata/dctk.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
-#include "dcmtk/dcmdata/dcuid.h"    /* for dcmtk version name */
+#include "dcmtk/dcmdata/dcuid.h"      /* for dcmtk version name */
 #include "dcmtk/ofstd/ofconapp.h"
 #include "dcmtk/ofstd/ofstring.h"
 #include "dcmtk/dcmimgle/dicrvfit.h"
@@ -52,7 +47,6 @@
 #include "dcmtk/dcmimgle/diutils.h"
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofstd.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTDIO
@@ -66,13 +60,11 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dcmmklut"
 
+static OFLogger dcmmklutLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
-OFBool opt_verbose = OFFalse;
-OFBool opt_debug = OFFalse;
-
-
 // ********************************************
 
 
@@ -94,8 +86,7 @@ OFCondition readMapFile(const char *filename,
     OFCondition result = EC_IllegalCall;
     if ((filename != NULL) && (strlen(filename) > 0))
     {
-        if (opt_verbose)
-            CERR << "reading map file ..." << endl;
+        OFLOG_INFO(dcmmklutLogger, "reading map file ...");
         unsigned char buffer[1000];
         FILE *inf = fopen(filename, "rb");
         if (inf != NULL)
@@ -121,14 +112,14 @@ OFCondition readMapFile(const char *filename,
                             result = EC_Normal;
                         }
                     } else
-                        CERR << "Warning: magic word wrong, not a map file ... ignoring !" << endl;
+                        OFLOG_WARN(dcmmklutLogger, "magic word wrong, not a map file ... ignoring !");
                 } else
-                    CERR << "Warning: file too large, not a map file ... ignoring !" << endl;
+                    OFLOG_WARN(dcmmklutLogger, "file too large, not a map file ... ignoring !");
             } else
-                CERR << "Warning: read error in map file ... ignoring !" << endl;
+                OFLOG_WARN(dcmmklutLogger, "read error in map file ... ignoring !");
             fclose(inf);
         } else
-            CERR << "Warning: cannot open map file ... ignoring !" << endl;
+            OFLOG_WARN(dcmmklutLogger, "cannot open map file ... ignoring !");
     }
     return result;
 }
@@ -143,12 +134,11 @@ OFCondition readTextFile(const char *filename,
 {
     if ((filename != NULL) && (strlen(filename) > 0))
     {
-        if (opt_verbose)
-            CERR << "reading text file ..." << endl;
+        OFLOG_INFO(dcmmklutLogger, "reading text file ...");
 #ifdef HAVE_IOS_NOCREATE
-        ifstream file(filename, ios::in|ios::nocreate);
+        STD_NAMESPACE ifstream file(filename, STD_NAMESPACE ios::in | STD_NAMESPACE ios::nocreate);
 #else
-        ifstream file(filename, ios::in);
+        STD_NAMESPACE ifstream file(filename, STD_NAMESPACE ios::in);
 #endif
         if (file)
         {
@@ -165,7 +155,7 @@ OFCondition readTextFile(const char *filename,
                 {
                     while (file.get(c) && (c != '\n') && (c != '\r'));      // skip comments
                 }
-                else if (!isspace(c))                                       // skip whitespaces
+                else if (!isspace(OFstatic_cast(unsigned char, c)))         // skip whitespaces
                 {
                     file.putback(c);
                     if (inputEntries == 0)                                  // read number of entries
@@ -182,11 +172,11 @@ OFCondition readTextFile(const char *filename,
                                 if ((inputXData == NULL) || (inputYData == NULL))
                                     return EC_IllegalCall;
                             } else {
-                                CERR << "Error: invalid or missing value for number of entries in text file ... ignoring !" << endl;
+                                OFLOG_ERROR(dcmmklutLogger, "invalid or missing value for number of entries in text file ... ignoring !");
                                 return EC_IllegalCall;                      // abort
                             }
                         } else {
-                            CERR << "Error: missing keyword 'count' for number of entries in text file ... ignoring !" << endl;
+                            OFLOG_ERROR(dcmmklutLogger, "missing keyword 'count' for number of entries in text file ... ignoring !");
                             return EC_IllegalCall;                          // abort
                         }
                     }
@@ -199,11 +189,10 @@ OFCondition readTextFile(const char *filename,
                             file >> inputXMax;
                             if (inputXMax <= 0)
                             {
-                                if (opt_debug)
-                                    CERR << "Warning: invalid value for xMax in text file ...ignoring !" << endl;
+                                OFLOG_DEBUG(dcmmklutLogger, "invalid value for xMax in text file ...ignoring !");
                             }
                         } else {
-                            CERR << "Error: invalid text file ... ignoring !" << endl;
+                            OFLOG_ERROR(dcmmklutLogger, "invalid text file ... ignoring !");
                             return EC_IllegalCall;                          // abort
                         }
                     }
@@ -216,11 +205,10 @@ OFCondition readTextFile(const char *filename,
                             file >> inputYMax;
                             if (inputYMax <= 0)
                             {
-                                if (opt_debug)
-                                    CERR << "Warning: invalid value for yMax in text file ...ignoring !" << endl;
+                                OFLOG_DEBUG(dcmmklutLogger, "invalid value for yMax in text file ...ignoring !");
                             }
                         } else {
-                            CERR << "Error: invalid text file ... ignoring !" << endl;
+                            OFLOG_ERROR(dcmmklutLogger, "invalid text file ... ignoring !");
                             return EC_IllegalCall;                          // abort
                         }
                     } else {
@@ -230,39 +218,30 @@ OFCondition readTextFile(const char *filename,
                             file >> inputYData[count];                      // read y value
                             if (file.fail())
                             {
-                                if (opt_debug)
-                                    CERR << "Warning: missing y value in text file ... ignoring last entry !" << endl;
+                                OFLOG_DEBUG(dcmmklutLogger, "missing y value in text file ... ignoring last entry !");
                             } else {
                                 if ((count > 0) && (inputXData[count] <= xmax))
                                 {
-                                    if (opt_debug)
-                                        CERR << "Warning: x values in text file not strictly monotonous ... ignoring entry #" << (count + 1) << " !" << endl;
+                                    OFLOG_DEBUG(dcmmklutLogger, "x values in text file not strictly monotonous ... ignoring entry #" << (count + 1) << " !");
                                 } else {
                                     xmax = inputXData[count];
                                     if (inputYData[count] > ymax)
                                         ymax = inputYData[count];
                                     if ((inputXMax != 0) && (inputXData[count] > inputXMax))
                                     {
-                                        if (opt_debug)
-                                        {
-                                            CERR << "Warning: x value (" << inputXData[count] << ") exceeds maximum value (";
-                                            CERR << inputXMax << ") in text file ..." << endl << "         ... ignoring value !" << endl;
-                                        }
+                                        OFLOG_DEBUG(dcmmklutLogger, "x value (" << inputXData[count] << ") exceeds maximum value ("
+                                            << inputXMax << ") in text file ..." << OFendl << "         ... ignoring value !");
                                     }
                                     else if ((inputYMax != 0) && (inputYData[count] > inputYMax))
                                     {
-                                        if (opt_debug)
-                                        {
-                                            CERR << "Warning: y value (" << inputYData[count] << ") exceeds maximum value (";
-                                            CERR << inputYMax << ") in text file ..." << endl << "         ... ignoring value !" << endl;
-                                        }
+                                        OFLOG_DEBUG(dcmmklutLogger, "y value (" << inputYData[count] << ") exceeds maximum value ("
+                                            << inputYMax << ") in text file ..." << OFendl << "         ... ignoring value !");
                                     } else
                                         count++;
                                 }
                             }
                         } else {
-                            if (opt_debug)
-                                CERR << "Warning: too many values in text file ... ignoring last line(s) !" << endl;
+                            OFLOG_DEBUG(dcmmklutLogger, "too many values in text file ... ignoring last line(s) !");
                             break;
                         }
                     }
@@ -271,8 +250,7 @@ OFCondition readTextFile(const char *filename,
             if (count  < inputEntries)
             {
                 inputEntries = count;
-                if (opt_debug)
-                    CERR << "Warning: automatically setting number of entries in text file to " << inputEntries << " !" << endl;
+                OFLOG_DEBUG(dcmmklutLogger, "automatically setting number of entries in text file to " << inputEntries << " !");
             }
             if (inputXMax == 0)                                             // automatic calculation
                 inputXMax = xmax;
@@ -281,9 +259,9 @@ OFCondition readTextFile(const char *filename,
             if (/*(inputXMax > 0) && (inputYMax > 0) &&*/ (inputEntries > 0) && (inputXData != NULL) && (inputYData != NULL))
                 return EC_Normal;
             else
-                CERR << "Warning: invalid text file ... ignoring !" << endl;
+                OFLOG_WARN(dcmmklutLogger, "invalid text file ... ignoring !");
         } else
-            CERR << "Warning: can't open text file ... ignoring !" << endl;
+            OFLOG_WARN(dcmmklutLogger, "can't open text file ... ignoring !");
     }
     return EC_IllegalCall;
 }
@@ -300,16 +278,15 @@ OFCondition writeTextOutput(const char *filename,
     {
         if ((outputData != NULL) && (numberOfEntries > 0))
         {
-            if (opt_verbose)
-                CERR << "writing text file ..." << endl;
-            ofstream file(filename);
+            OFLOG_INFO(dcmmklutLogger, "writing text file ...");
+            STD_NAMESPACE ofstream file(filename);
             if (file)
             {
-                file << header << endl;
+                file << header << OFendl;
                 for (unsigned long i = 0; i < numberOfEntries; i++)
-                    file << (firstMapped + (signed long)i) << "\t" << outputData[i] << endl;
+                    file << (firstMapped + (signed long)i) << "\t" << outputData[i] << OFendl;
             } else
-               CERR << "Warning: can't create output text file ... ignoring !" << endl;
+                OFLOG_WARN(dcmmklutLogger, "can't create output text file ... ignoring !");
         }
     }
     return result;
@@ -341,45 +318,40 @@ OFCondition convertInputLUT(const unsigned int numberOfBits,
                     DicomImageClass::tobits((int)inputXMax), DicomImageClass::tobits((int)inputYMax),
                     (numberOfEntries < 65536) ? (Uint16)numberOfEntries : 0, firstMapped, numberOfBits);
             }
-            oss << "# " << explanation << endl;
+            oss << "# " << explanation << OFendl;
         }
         const double factor = (double)(DicomImageClass::maxval(numberOfBits)) / inputYMax;
         if (factor != 1.0)
         {
-            if (opt_verbose)
-            {
-                CERR.setf(ios::fixed, ios::floatfield);
-                CERR << "multiplying input values by " << factor << " ..." << endl;
-            }
+            OFLOG_INFO(dcmmklutLogger, "multiplying input values by "
+                << STD_NAMESPACE ios::fixed << factor << " ...");
             for (unsigned long i = 0; i < inputEntries; i++)
                 inputYData[i] *= factor;
         }
         if (numberOfEntries == inputEntries)
         {
-            if (opt_verbose)
-                CERR << "importing LUT data directly ..." << endl;
+            OFLOG_INFO(dcmmklutLogger, "importing LUT data directly ...");
             for (unsigned long i = 0; i < numberOfEntries; i++)
                 outputData[i] = (Uint16)inputYData[i];
             result = EC_Normal;
         } else {
-            if (opt_verbose)
-                CERR << "using polynomial curve fitting algorithm ..." << endl;
+            OFLOG_INFO(dcmmklutLogger, "using polynomial curve fitting algorithm ...");
             double *coeff = new double[order + 1];
             if (DiCurveFitting<double, double>::calculateCoefficients(inputXData, inputYData, (unsigned int)inputEntries, order, coeff))
             {
                 if (DiCurveFitting<double, Uint16>::calculateValues(0, inputXMax, outputData, (unsigned int)numberOfEntries, order, coeff))
                 {
-                    oss << "# using polynomial curve fitting algorithm (order = " << order << ")" << endl;
-                    oss << "# equation: y = C0 + C1*x + C2*x^2 + C3*x^3 + ... + Cn*x^n" << endl;
+                    oss << "# using polynomial curve fitting algorithm (order = " << order << ")" << OFendl;
+                    oss << "# equation: y = C0 + C1*x + C2*x^2 + C3*x^3 + ... + Cn*x^n" << OFendl;
                     oss << "# where: ";
                     for (unsigned int i = 0; i <= order; i++)
                     {
                         oss << "C" << i << " = ";
-                        oss.setf(ios::fixed, ios::floatfield);
+                        oss.setf(STD_NAMESPACE ios::fixed, STD_NAMESPACE ios::floatfield);
                         //oss.setf(ios::showpos);
                         oss.precision(5);
                         oss.width(10);
-                        oss << coeff[i] << endl;
+                        oss << coeff[i] << OFendl;
                         if (i < order)
                         {
                             oss << "#       ";
@@ -399,7 +371,7 @@ OFCondition convertInputLUT(const unsigned int numberOfBits,
             header += tmpString;
             OFSTRINGSTREAM_FREESTR(tmpString)
         } else
-            CERR << "Warning: can't create lookup table from text file ... ignoring !" << endl;
+            OFLOG_WARN(dcmmklutLogger, "can't create lookup table from text file ... ignoring !");
     }
     return result;
 }
@@ -416,8 +388,7 @@ void gammaLUT(const unsigned int numberOfBits,
 {
     if (outputData != NULL)
     {
-        if (opt_verbose)
-            CERR << "computing gamma function ..." << endl;
+        OFLOG_INFO(dcmmklutLogger, "computing gamma function ...");
         OFOStringStream oss;
         if (explanation != NULL)
         {
@@ -429,7 +400,7 @@ void gammaLUT(const unsigned int numberOfBits,
                 sprintf(explanation, "LUT with gamma %s, descriptor %u/%ld/%u", gammabuf,
                     (numberOfEntries < 65536) ? (Uint16)numberOfEntries : 0, firstMapped, numberOfBits);
             }
-            oss << "# " << explanation << endl;
+            oss << "# " << explanation << OFendl;
         }
         Uint16 maxValue = 0xFFFF >> (16 - numberOfBits);
         double step = (double)maxValue / ((double)numberOfEntries - 1.0);
@@ -474,8 +445,7 @@ void applyInverseGSDF(const unsigned int numberOfBits,
 {
     if (outputData != NULL)
     {
-        if (opt_verbose)
-            CERR << "applying inverse GSDF ..." << endl;
+        OFLOG_INFO(dcmmklutLogger, "applying inverse GSDF ...");
         OFOStringStream oss;
         if ((explanation != NULL) && (strlen(explanation) > 0))
             strcat(explanation, ", inverse GSDF");
@@ -500,7 +470,7 @@ void applyInverseGSDF(const unsigned int numberOfBits,
                 outputData[i] = (Uint16)((DiGSDFunction::getJNDIndex(la + l0 * pow((double)10, -(dmin + (double)outputData[i] * density))) - jmin) * factor);
         }
         oss << "# applied inverse GSDF with Dmin/max = " << minDensity << "/" << maxDensity << ", L0/La = "
-            << illumination << "/" << reflection << endl;
+            << illumination << "/" << reflection << OFendl;
         oss << OFStringStream_ends;
         OFSTRINGSTREAM_GETSTR(oss, tmpString)
         header += tmpString;
@@ -525,8 +495,7 @@ void mixingUpLUT(const unsigned long numberOfEntries,
 {
     if (outputData != NULL)
     {
-        if (opt_verbose)
-            CERR << "mixing up LUT entries ..." << endl;
+        OFLOG_INFO(dcmmklutLogger, "mixing up LUT entries ...");
         if ((explanation != NULL) && (strlen(explanation) > 0))
             strcat(explanation, ", mixed-up entries");
         srand(randomSeed);
@@ -578,17 +547,17 @@ OFCondition createLUT(const unsigned int numberOfBits,
     Uint16 numEntries16 = 0;
 
     if (numberOfEntries == 0)
-        CERR << "Warning: creating LUT without LUT data" << endl;
+        OFLOG_WARN(dcmmklutLogger, "creating LUT without LUT data");
     if (numberOfEntries > 65536)
     {
-        CERR << "Error: cannot create LUT with more than 65536 entries" << endl;
+        OFLOG_ERROR(dcmmklutLogger, "cannot create LUT with more than 65536 entries");
         return EC_IllegalCall;
     }
     if (numberOfEntries < 65536)
         numEntries16 = (Uint16)numberOfEntries;
     if ((numberOfBits < 8) || (numberOfBits > 16))
     {
-        CERR << "Error: cannot create LUT with " << numberOfBits << " bit entries, only 8..16" << endl;
+        OFLOG_ERROR(dcmmklutLogger, "cannot create LUT with " << numberOfBits << " bit entries, only 8..16");
         return EC_IllegalCall;
     }
 
@@ -598,7 +567,7 @@ OFCondition createLUT(const unsigned int numberOfBits,
         // LUT Descriptor is SS
         if (firstMapped < -32768)
         {
-            CERR << "Error: cannot create LUT - first value mapped < -32768" << endl;
+            OFLOG_ERROR(dcmmklutLogger, "cannot create LUT - first value mapped < -32768");
             return EC_IllegalCall;
         }
         descriptor = new DcmSignedShort(DcmTag(DCM_LUTDescriptor, EVR_SS));
@@ -614,7 +583,7 @@ OFCondition createLUT(const unsigned int numberOfBits,
         // LUT Descriptor is US
         if (firstMapped > 0xFFFF)
         {
-            CERR << "Error: cannot create LUT - first value mapped > 65535" << endl;
+            OFLOG_ERROR(dcmmklutLogger, "cannot create LUT - first value mapped > 65535");
             return EC_IllegalCall;
         }
         descriptor = new DcmUnsignedShort(DcmTag(DCM_LUTDescriptor, EVR_US));
@@ -638,7 +607,7 @@ OFCondition createLUT(const unsigned int numberOfBits,
         wordsToWrite = numberOfEntries;
     if ((wordsToWrite > 32767) && (lutVR != EVR_OW))
     {
-        CERR << "Warning: LUT data >= 64K, writing as OW" << endl;
+        OFLOG_WARN(dcmmklutLogger, "LUT data >= 64K, writing as OW");
         lutVR = EVR_OW;
     }
 
@@ -674,7 +643,7 @@ OFCondition createLUT(const unsigned int numberOfBits,
                 return EC_MemoryExhausted;
             break;
         default:
-            CERR << "Error: unsupported VR for LUT Data" << endl;
+            OFLOG_ERROR(dcmmklutLogger, "unsupported VR for LUT Data");
             return EC_IllegalCall;
             /* break; */
   }
@@ -702,7 +671,6 @@ OFCondition createLUT(const unsigned int numberOfBits,
 
 int main(int argc, char *argv[])
 {
-    int opt_debugMode = 0;
     const char *opt_inName = NULL;                     /* in file name */
     const char *opt_outName = NULL;                    /* out file name */
     const char *opt_outText = NULL;
@@ -726,86 +694,86 @@ int main(int argc, char *argv[])
     OFBool opt_replaceMode = OFTrue;
     DcmEVR opt_lutVR = EVR_OW;
 
-    SetDebugLevel(( 0 ));
-
     OFCommandLine cmd;
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "Create DICOM look-up tables", rcsid);
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
     cmd.setParamColumn(LONGCOL + SHORTCOL + 4);
 
-    cmd.addParam("dcmimg-out",                   "DICOM output filename" /* , OFCmdParam::PM_Optional */);
+    cmd.addParam("dcmimg-out",                   "DICOM output filename");
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-     cmd.addOption("--help",           "-h",     "print this help text and exit");
-     cmd.addOption("--version",                  "print version information and exit", OFTrue /* exclusive */);
-     cmd.addOption("--verbose",        "-v",     "verbose mode, print processing details");
-     cmd.addOption("--debug",          "-d",     "debug mode, print debug information");
+     cmd.addOption("--help",           "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+     cmd.addOption("--version",                  "print version information and exit", OFCommandLine::AF_Exclusive);
+     OFLog::addOptions(cmd);
+
     cmd.addGroup("LUT creation options:");
       cmd.addSubGroup("LUT type:");
        cmd.addOption("--modality",     "+Tm",    "create as Modality LUT");
        cmd.addOption("--presentation", "+Tp",    "create as Presentation LUT");
        cmd.addOption("--voi",          "+Tv",    "create as VOI LUT (default)");
       cmd.addSubGroup("LUT placement:");
-       cmd.addOption("--add",          "+Pa",    "add to existing transform (def. for and only with +Tv)");
-       cmd.addOption("--replace",      "+Pr",    "replace existing transform (default for +Tm and +Tp)");
+       cmd.addOption("--add",          "+Pa",    "add to existing transform\n(default for and only with --voi)");
+       cmd.addOption("--replace",      "+Pr",    "replace existing transform\n(default for --modality and --presentation)");
       cmd.addSubGroup("LUT content:");
-       cmd.addOption("--gamma",        "+Cg", 1, "[g]amma : float",
+       cmd.addOption("--gamma",        "+Cg", 1, "[g]amma: float",
                                                  "use gamma value (default: 1.0)");
-       cmd.addOption("--map-file",     "+Cm", 1, "[f]ilename : string",
+       cmd.addOption("--map-file",     "+Cm", 1, "[f]ilename: string",
                                                  "read input data from MAP file");
-       cmd.addOption("--text-file",    "+Ct", 1, "[f]ilename : string",
+       cmd.addOption("--text-file",    "+Ct", 1, "[f]ilename: string",
                                                  "read input data from text file");
       cmd.addSubGroup("LUT options:");
        cmd.addOption("--inverse-gsdf", "+Og",    "apply inverse GSDF (print presentation LUT in OD)");
-       cmd.addOption("--min-density",         1, "[v]alue : integer (0..65535, default: 20)",
+       cmd.addOption("--min-density",         1, "[v]alue: integer (0..65535, default: 20)",
                                                  "set min density to v (in hundreds of OD)");
-       cmd.addOption("--max-density",         1, "[v]alue : integer (0..65535, default: 300)",
+       cmd.addOption("--max-density",         1, "[v]alue: integer (0..65535, default: 300)",
                                                  "set max density to v (in hundreds of OD)");
-       cmd.addOption("--illumination", "+Oi", 1, "[v]alue : integer (0..65535, default: 2000)",
+       cmd.addOption("--illumination", "+Oi", 1, "[v]alue: integer (0..65535, default: 2000)",
                                                  "set illumination to v (in cd/m^2)");
-       cmd.addOption("--reflection",   "+Or", 1, "[v]alue : integer (0..65535, default: 10)",
+       cmd.addOption("--reflection",   "+Or", 1, "[v]alue: integer (0..65535, default: 10)",
                                                  "set reflected ambient light to v (in cd/m^2)");
       cmd.addSubGroup("LUT structure:");
-       cmd.addOption("--bits",         "-b",  1, "[n]umber : integer",
+       cmd.addOption("--bits",         "-b",  1, "[n]umber: integer",
                                                  "create LUT with n bit values (8..16, default: 16)");
-       cmd.addOption("--entries",      "-e",  1, "[n]umber : integer",
+       cmd.addOption("--entries",      "-e",  1, "[n]umber: integer",
                                                  "create LUT with n entries (1..65536, default: 256)");
-       cmd.addOption("--first-mapped", "-f",  1, "[n]umber : integer",
+       cmd.addOption("--first-mapped", "-f",  1, "[n]umber: integer",
                                                  "first input value mapped (-31768..65535, default: 0)");
-       cmd.addOption("--random",       "-r",  1, "[n]umber : unsigned integer",
+       cmd.addOption("--random",       "-r",  1, "[n]umber: unsigned integer",
                                                  "perform n randomly selected permutations on the LUT");
-       cmd.addOption("--random-seed",  "-rs", 1, "[n]umber : unsigned integer",
-                                                 "initialise the random-number generator with n\n(default: 0, for reproduceable results)");
-       cmd.addOption("--order",        "-o",  1, "[n]umber : integer",
+       cmd.addOption("--random-seed",  "-rs", 1, "[n]umber: unsigned integer",
+                                                 "initialize the random-number generator with n\n(default: 0, for reproducible results)");
+       cmd.addOption("--order",        "-o",  1, "[n]umber: integer",
                                                  "use polynomial curve fitting algorithm with order n\n(0..99, default: 5)");
-       cmd.addOption("--explanation",  "-E",  1, "[n]ame : string",
+       cmd.addOption("--explanation",  "-E",  1, "[n]ame: string",
                                                  "LUT explanation (default: automatically created)");
-       cmd.addOption("--byte-align",   "-a",     "create byte-aligned LUT (implies -b 8)");
+      cmd.addSubGroup("LUT data alignment:");
+       cmd.addOption("--byte-align",   "-a",     "create byte-aligned LUT\n(default for and only with 8 bit values)");
+       cmd.addOption("--word-align",   "+a",     "create word-aligned LUT\n(default for 9-16 bit values)");
       cmd.addSubGroup("LUT data VR:");
        cmd.addOption("--data-ow",      "+Dw",    "write LUT Data as OW (default)");
        cmd.addOption("--data-us",      "+Du",    "write LUT Data as US");
        cmd.addOption("--data-ss",      "+Ds",    "write LUT Data as SS (minimal support)");
     cmd.addGroup("file options:", LONGCOL, SHORTCOL + 2);
-     cmd.addOption("--dicom-input",    "+Fi", 1, "[f]ilename : string",
+     cmd.addOption("--dicom-input",    "+Fi", 1, "[f]ilename: string",
                                                  "read dataset from DICOM file f");
-     cmd.addOption("--text-output",    "+Fo", 1, "[f]ilename : string",
+     cmd.addOption("--text-output",    "+Fo", 1, "[f]ilename: string",
                                                  "write LUT data to tabbed text file f");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
         /* check exclusive options first */
-        if (cmd.getParamCount() == 0)
+        if (cmd.hasExclusiveOption())
         {
           if (cmd.findOption("--version"))
           {
-              app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-              CERR << endl << "External libraries used:";
+              app.printHeader(OFTrue /*print host identifier*/);
+              COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-              CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+              COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-              CERR << " none" << endl;
+              COUT << " none" << OFendl;
 #endif
               return 0;
            }
@@ -814,10 +782,7 @@ int main(int argc, char *argv[])
         /* command line parameters */
         cmd.getParam(1, opt_outName);
 
-        if (cmd.findOption("--verbose"))
-            opt_verbose = OFTrue;
-        if (cmd.findOption("--debug"))
-            opt_debugMode = 3;
+        OFLog::configureFromCommandLine(cmd, app);
 
         cmd.beginOptionBlock();
         if (cmd.findOption("--modality"))
@@ -864,7 +829,10 @@ int main(int argc, char *argv[])
             app.checkValue(cmd.getValue(opt_reflection));
 
         if (cmd.findOption("--bits"))
+        {
             app.checkValue(cmd.getValueAndCheckMinMax(opt_bits, 8, 16));
+            opt_byteAlign = (opt_bits == 8);   /* default */
+        }
         if (cmd.findOption("--entries"))
             app.checkValue(cmd.getValueAndCheckMinMax(opt_entries, 1, 65536));
         if (cmd.findOption("--first-mapped"))
@@ -877,11 +845,13 @@ int main(int argc, char *argv[])
             app.checkValue(cmd.getValue(opt_randomSeed));
         if (cmd.findOption("--order"))
             app.checkValue(cmd.getValueAndCheckMinMax(opt_order, 0, 99));
+
+        cmd.beginOptionBlock();
         if (cmd.findOption("--byte-align"))
-        {
             opt_byteAlign = OFTrue;
-            opt_bits = 8;
-        }
+        if (cmd.findOption("--word-align"))
+            opt_byteAlign = OFFalse;
+        cmd.endOptionBlock();
 
         cmd.beginOptionBlock();
         if (cmd.findOption("--data-ow"))
@@ -898,29 +868,30 @@ int main(int argc, char *argv[])
             app.checkValue(cmd.getValue(opt_outText));
     }
 
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmmklutLogger, rcsid << OFendl);
+
     if ((opt_lutType == LUT_Modality) && (opt_bits != 8) && (opt_bits != 16))
     {
-        CERR << "Error: --modality cannot be used with --bits other than 8 or 16" << endl;
+        OFLOG_FATAL(dcmmklutLogger, "--modality cannot be used with --bits other than 8 or 16");
         return 1;
     }
     if ((opt_bits != 8) && opt_byteAlign)
     {
-        CERR << "Error: --byte-align cannot be used with --bits other than 8" << endl;
+        OFLOG_FATAL(dcmmklutLogger, "--byte-align cannot be used with --bits other than 8");
         return 1;
     }
 
-    SetDebugLevel(( opt_debugMode ));
-
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
-        CERR << "Warning: no data dictionary loaded, check environment variable: " << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dcmmklutLogger, "no data dictionary loaded, check environment variable: " << DCM_DICT_ENVIRONMENT_VARIABLE);
 
     E_TransferSyntax Xfer= EXS_LittleEndianExplicit;
     OFCondition result = EC_Normal;
     DcmFileFormat *fileformat = new DcmFileFormat();
     if (!fileformat)
     {
-        CERR << "Error: memory exhausted" << endl;
+        OFLOG_FATAL(dcmmklutLogger, "memory exhausted");
         return 1;
     }
     DcmDataset *dataset = fileformat->getDataset();
@@ -930,7 +901,7 @@ int main(int argc, char *argv[])
         OFCondition cond = fileformat->loadFile(opt_inName);
         if (! cond.good())
         {
-            CERR << "Error: cannot open file: " << opt_inName << endl;
+            OFLOG_FATAL(dcmmklutLogger, "cannot open file: " << opt_inName);
             return 1;
         }
         Xfer = dataset->getOriginalXfer();
@@ -985,7 +956,7 @@ int main(int argc, char *argv[])
         delete[] outputData;
         if (EC_Normal != result)
         {
-            CERR << "Error: could not create LUT, bailing out." << endl;
+            OFLOG_FATAL(dcmmklutLogger, "could not create LUT, bailing out.");
             return 1;
         }
     } else
@@ -1028,7 +999,7 @@ int main(int argc, char *argv[])
                         if (EC_Normal == dataset->search(DCM_PresentationLUTSequence, stack, ESM_fromHere, OFFalse))
                             dseq=(DcmSequenceOfItems *)stack.top();
                     }
-                    if (dseq==NULL)
+                    if (dseq == NULL)
                     {
                         dseq = new DcmSequenceOfItems(DCM_PresentationLUTSequence);
                         if (dseq)
@@ -1049,7 +1020,7 @@ int main(int argc, char *argv[])
                         if (EC_Normal == dataset->search(DCM_VOILUTSequence, stack, ESM_fromHere, OFFalse))
                             dseq=(DcmSequenceOfItems *)stack.top();
                     }
-                    if (dseq==NULL)
+                    if (dseq == NULL)
                     {
                         dseq = new DcmSequenceOfItems(DCM_VOILUTSequence);
                         if (dseq)
@@ -1071,17 +1042,16 @@ int main(int argc, char *argv[])
 
         if (result != EC_Normal)
         {
-            CERR << "error while adding LUT to image dataset. Bailing out."<< endl;
+            OFLOG_FATAL(dcmmklutLogger, "Error while adding LUT to image dataset. Bailing out.");
             return 1;
         }
 
-        if (opt_verbose)
-            CERR << "writing DICOM file ..." << endl;
+        OFLOG_INFO(dcmmklutLogger, "writing DICOM file ...");
 
         result = fileformat->saveFile(opt_outName, Xfer);
         if (result.bad())
         {
-            CERR << "Error: " << result.text() << ": writing file: " <<  opt_outName << endl;
+            OFLOG_FATAL(dcmmklutLogger, result.text() << ": writing file: " <<  opt_outName);
             return 1;
         }
     }
@@ -1093,6 +1063,37 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcmmklut.cc,v $
+ * Revision 1.47  2010-12-15 17:03:38  joergr
+ * Added missing prefix "ios::" to I/O manipulator "fixed" (reported on HP-UX).
+ *
+ * Revision 1.46  2010-10-20 07:41:36  uli
+ * Made sure isalpha() & friends are only called with valid arguments.
+ *
+ * Revision 1.45  2010-10-14 13:13:44  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.44  2009-11-24 14:12:56  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.43  2009-02-27 11:46:11  joergr
+ * Added new command line option --word-align which was previously the default
+ * for all bit values.
+ * Changed behavior of option --byte-align which previously implied --bits 8.
+ * Instead, --bits 8 now implies --byte-align (if not specified manually).
+ *
+ * Revision 1.42  2008-09-25 16:30:24  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.41  2006/08/15 16:57:01  meichel
+ * Updated the code in module dcmpstat to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.40  2006/07/27 14:34:40  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
  * Revision 1.39  2005/12/08 15:46:03  meichel
  * Changed include path schema for all DCMTK header files
  *
