@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmpstat
  *
@@ -25,10 +21,9 @@
  *    of the presentation state. Non-grayscale transformations are
  *    ignored. If no presentation state is loaded, a default is created.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:04 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmpstat/apps/dcmp2pgm.cc,v $
- *  CVS/RCS Revision: $Revision: 1.36 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:44 $
+ *  CVS/RCS Revision: $Revision: 1.43 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -44,15 +39,14 @@
 
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/dcmpstat/dviface.h"
-#include "dcmtk/dcmpstat/dvpstx.h"  /* for DVPSTextObject */
-#include "dcmtk/dcmpstat/dvpsgr.h"  /* for DVPSGraphicObject */
-#include "dcmtk/dcmpstat/dvpscu.h"  /* for DVPSCurve */
+#include "dcmtk/dcmpstat/dvpstx.h"    /* for DVPSTextObject */
+#include "dcmtk/dcmpstat/dvpsgr.h"    /* for DVPSGraphicObject */
+#include "dcmtk/dcmpstat/dvpscu.h"    /* for DVPSCurve */
 #include "dcmtk/dcmimgle/dcmimage.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/ofstd/ofcmdln.h"
 #include "dcmtk/ofstd/ofconapp.h"
-#include "dcmtk/dcmdata/dcuid.h"    /* for dcmtk version name */
-#include "dcmtk/dcmdata/dcdebug.h"
+#include "dcmtk/dcmdata/dcuid.h"      /* for dcmtk version name */
 
 #ifdef WITH_ZLIB
 #include <zlib.h>     /* for zlibVersion() */
@@ -60,6 +54,8 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dcmp2pgm"
 
+static OFLogger dcmp2pgmLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -69,271 +65,273 @@ void dumpPresentationState(DVPresentationState &ps)
   size_t i, j, max;
   const char *c;
 
-  COUT << "DUMPING PRESENTATION STATE" << endl
-       << "--------------------------" << endl << endl;
+  OFOStringStream oss;
+
+  oss << "DUMPING PRESENTATION STATE" << OFendl
+       << "--------------------------" << OFendl << OFendl;
 
   c = ps.getPresentationLabel();
-  COUT << "Presentation Label: "; if (c) COUT << c << endl; else COUT << "none" << endl;
+  oss << "Presentation Label: "; if (c) oss << c << OFendl; else oss << "none" << OFendl;
   c = ps.getPresentationDescription();
-  COUT << "Presentation Description: "; if (c) COUT << c << endl; else COUT << "none" << endl;
+  oss << "Presentation Description: "; if (c) oss << c << OFendl; else oss << "none" << OFendl;
   c = ps.getPresentationCreatorsName();
-  COUT << "Presentation Creator's Name: "; if (c) COUT << c << endl; else COUT << "none" << endl;
+  oss << "Presentation Creator's Name: "; if (c) oss << c << OFendl; else oss << "none" << OFendl;
 
-  COUT << "VOI transformation: ";
+  oss << "VOI transformation: ";
   if (ps.haveActiveVOIWindow())
   {
     double width=0.0, center=0.0;
     ps.getCurrentWindowWidth(width);
     ps.getCurrentWindowCenter(center);
-    COUT << "window center=" << center << " width=" << width << " description=\"";
+    oss << "window center=" << center << " width=" << width << " description=\"";
     c = ps.getCurrentVOIDescription();
-    if (c) COUT << c << "\"" << endl; else COUT << "(none)\"" << endl;
+    if (c) oss << c << "\"" << OFendl; else oss << "(none)\"" << OFendl;
   }
   else if (ps.haveActiveVOILUT())
   {
-    COUT << "lut description=\"";
+    oss << "lut description=\"";
     c = ps.getCurrentVOIDescription();
-    if (c) COUT << c << "\"" << endl; else COUT << "(none)\"" << endl;
+    if (c) oss << c << "\"" << OFendl; else oss << "(none)\"" << OFendl;
   }
-  else COUT << "none" << endl;
+  else oss << "none" << OFendl;
 
-  COUT << "Rotation: ";
+  oss << "Rotation: ";
   switch (ps.getRotation())
   {
     case DVPSR_0_deg:
-      COUT << "none";
+      oss << "none";
       break;
     case DVPSR_90_deg:
-      COUT << "90 degrees";
+      oss << "90 degrees";
       break;
     case DVPSR_180_deg:
-      COUT << "180 degrees";
+      oss << "180 degrees";
       break;
     case DVPSR_270_deg:
-      COUT << "270 degrees";
+      oss << "270 degrees";
       break;
   }
-  COUT << endl;
-  COUT << "Flip: ";
-  if (ps.getFlip()) COUT << "yes" << endl; else COUT << "no" << endl;
+  oss << OFendl;
+  oss << "Flip: ";
+  if (ps.getFlip()) oss << "yes" << OFendl; else oss << "no" << OFendl;
 
   Sint32 tlhcX=0;
   Sint32 tlhcY=0;
   Sint32 brhcX=0;
   Sint32 brhcY=0;
-  COUT << "Displayed area:" << endl;
+  oss << "Displayed area:" << OFendl;
 
   DVPSPresentationSizeMode sizemode = ps.getDisplayedAreaPresentationSizeMode();
   double factor=1.0;
   switch (sizemode)
   {
     case DVPSD_scaleToFit:
-      COUT << "  presentation size mode: SCALE TO FIT" << endl;
+      oss << "  presentation size mode: SCALE TO FIT" << OFendl;
       break;
     case DVPSD_trueSize:
-      COUT << "  presentation size mode: TRUE SIZE" << endl;
+      oss << "  presentation size mode: TRUE SIZE" << OFendl;
       break;
     case DVPSD_magnify:
       ps.getDisplayedAreaPresentationPixelMagnificationRatio(factor);
-      COUT << "  presentation size mode: MAGNIFY factor=" << factor << endl;
+      oss << "  presentation size mode: MAGNIFY factor=" << factor << OFendl;
       break;
   }
   ps.getStandardDisplayedArea(tlhcX, tlhcY, brhcX, brhcY);
-  COUT << "  displayed area TLHC=" << tlhcX << "\\" << tlhcY << " BRHC=" << brhcX << "\\" << brhcY << endl;
+  oss << "  displayed area TLHC=" << tlhcX << "\\" << tlhcY << " BRHC=" << brhcX << "\\" << brhcY << OFendl;
 
   double x, y;
   if (EC_Normal == ps.getDisplayedAreaPresentationPixelSpacing(x,y))
   {
-    COUT << "  presentation pixel spacing: X=" << x << "mm Y=" << y << " mm" << endl;
+    oss << "  presentation pixel spacing: X=" << x << "mm Y=" << y << " mm" << OFendl;
   } else {
-    COUT << "  presentation pixel aspect ratio: " << ps.getDisplayedAreaPresentationPixelAspectRatio() << endl;
+    oss << "  presentation pixel aspect ratio: " << ps.getDisplayedAreaPresentationPixelAspectRatio() << OFendl;
   }
 
-  COUT << "Rectangular shutter: ";
+  oss << "Rectangular shutter: ";
   if (ps.haveShutter(DVPSU_rectangular))
   {
-    COUT << "LV=" << ps.getRectShutterLV()
+    oss << "LV=" << ps.getRectShutterLV()
          << " RV=" << ps.getRectShutterRV()
          << " UH=" << ps.getRectShutterUH()
-         << " LH=" << ps.getRectShutterLH() << endl;
+         << " LH=" << ps.getRectShutterLH() << OFendl;
 
-  } else COUT << "none" << endl;
-  COUT << "Circular shutter: ";
+  } else oss << "none" << OFendl;
+  oss << "Circular shutter: ";
   if (ps.haveShutter(DVPSU_circular))
   {
-    COUT << "center=" << ps.getCenterOfCircularShutter_x()
+    oss << "center=" << ps.getCenterOfCircularShutter_x()
          << "\\" << ps.getCenterOfCircularShutter_y()
-         << " radius=" << ps.getRadiusOfCircularShutter() << endl;
-  } else COUT << "none" << endl;
-  COUT << "Polygonal shutter: ";
+         << " radius=" << ps.getRadiusOfCircularShutter() << OFendl;
+  } else oss << "none" << OFendl;
+  oss << "Polygonal shutter: ";
   if (ps.haveShutter(DVPSU_polygonal))
   {
-     COUT << "points=" << ps.getNumberOfPolyShutterVertices() << " coordinates=";
+     oss << "points=" << ps.getNumberOfPolyShutterVertices() << " coordinates=";
      j = ps.getNumberOfPolyShutterVertices();
      Sint32 polyX, polyY;
      for (i=0; i<j; i++)
      {
-     	if (EC_Normal == ps.getPolyShutterVertex(i, polyX, polyY))
-     	{
-     	  COUT << polyX << "\\" << polyY << ", ";
-     	} else COUT << "???\\???,";
+        if (EC_Normal == ps.getPolyShutterVertex(i, polyX, polyY))
+        {
+          oss << polyX << "\\" << polyY << ", ";
+        } else oss << "???\\???,";
      }
-     COUT << endl;
-  } else COUT << "none" << endl;
-  COUT << "Bitmap shutter: ";
+     oss << OFendl;
+  } else oss << "none" << OFendl;
+  oss << "Bitmap shutter: ";
   if (ps.haveShutter(DVPSU_bitmap))
   {
-     COUT << "present" << endl;
-  } else COUT << "none" << endl;
-  COUT << "Shutter presentation value: 0x" << hex << ps.getShutterPresentationValue() << dec << endl;
-  COUT << endl;
+     oss << "present" << OFendl;
+  } else oss << "none" << OFendl;
+  oss << "Shutter presentation value: 0x" << STD_NAMESPACE hex << ps.getShutterPresentationValue() << STD_NAMESPACE dec << OFendl;
+  oss << OFendl;
 
   ps.sortGraphicLayers();  // to order of display
   for (size_t layer=0; layer<ps.getNumberOfGraphicLayers(); layer++)
   {
     c = ps.getGraphicLayerName(layer);
-    COUT << "Graphic Layer #" << layer+1 << " ["; if (c) COUT << c; else COUT << "(unnamed)";
-    COUT << "]" << endl;
+    oss << "Graphic Layer #" << layer+1 << " ["; if (c) oss << c; else oss << "(unnamed)";
+    oss << "]" << OFendl;
     c = ps.getGraphicLayerDescription(layer);
-    COUT << "  Description: "; if (c) COUT << c << endl; else COUT << "none" << endl;
-    COUT << "  Recomm. display value: ";
+    oss << "  Description: "; if (c) oss << c << OFendl; else oss << "none" << OFendl;
+    oss << "  Recomm. display value: ";
     if (ps.haveGraphicLayerRecommendedDisplayValue(layer))
     {
       Uint16 r, g, b;
-      COUT << "gray ";
+      oss << "gray ";
       if (EC_Normal == ps.getGraphicLayerRecommendedDisplayValueGray(layer, g))
       {
-      	  COUT << "0x" << hex << g << dec << endl;
-      } else COUT << "error" << endl;
-      COUT << "color ";
+        oss << "0x" << STD_NAMESPACE hex << g << STD_NAMESPACE dec << OFendl;
+      } else oss << "error" << OFendl;
+      oss << "color ";
       if (EC_Normal == ps.getGraphicLayerRecommendedDisplayValueRGB(layer, r, g, b))
       {
-      	  COUT << "0x" << hex << r << "\\0x" << g << "\\0x" << b << dec << endl;
-      } else COUT << "error" << endl;
-    } else COUT << "none" << endl;
+        oss << "0x" << STD_NAMESPACE hex << r << "\\0x" << g << "\\0x" << b << STD_NAMESPACE dec << OFendl;
+      } else oss << "error" << OFendl;
+    } else oss << "none" << OFendl;
 
     // text objects
     max = ps.getNumberOfTextObjects(layer);
-    COUT << "  Number of text objects: " << max << endl;
+    oss << "  Number of text objects: " << max << OFendl;
     DVPSTextObject *ptext = NULL;
     for (size_t textidx=0; textidx<max; textidx++)
     {
       ptext = ps.getTextObject(layer, textidx);
       if (ptext)
       {
-      	// display contents of text object
-        COUT << "      text " << textidx+1 << ": \"" << ptext->getText() << "\"" << endl;
-        COUT << "        anchor point: ";
+        // display contents of text object
+        oss << "      text " << textidx+1 << ": \"" << ptext->getText() << "\"" << OFendl;
+        oss << "        anchor point: ";
         if (ptext->haveAnchorPoint())
         {
-          COUT << ptext->getAnchorPoint_x() << "\\" << ptext->getAnchorPoint_y() << " units=";
-          if (ptext->getAnchorPointAnnotationUnits()==DVPSA_display) COUT << "display"; else COUT << "pixel";
-          COUT << " visible=";
-          if (ptext->anchorPointIsVisible()) COUT << "yes"; else COUT << "no";
-          COUT << endl;
-        } else COUT << "none" << endl;
-        COUT << "        bounding box: ";
+          oss << ptext->getAnchorPoint_x() << "\\" << ptext->getAnchorPoint_y() << " units=";
+          if (ptext->getAnchorPointAnnotationUnits()==DVPSA_display) oss << "display"; else oss << "pixel";
+          oss << " visible=";
+          if (ptext->anchorPointIsVisible()) oss << "yes"; else oss << "no";
+          oss << OFendl;
+        } else oss << "none" << OFendl;
+        oss << "        bounding box: ";
         if (ptext->haveBoundingBox())
         {
-          COUT << "TLHC=";
-          COUT << ptext->getBoundingBoxTLHC_x() << "\\" << ptext->getBoundingBoxTLHC_y()
+          oss << "TLHC=";
+          oss << ptext->getBoundingBoxTLHC_x() << "\\" << ptext->getBoundingBoxTLHC_y()
                << " BRHC=" << ptext->getBoundingBoxBRHC_x() << "\\" << ptext->getBoundingBoxBRHC_y()
                << " units=";
-          if (ptext->getBoundingBoxAnnotationUnits()==DVPSA_display) COUT << "display"; else COUT << "pixel";
+          if (ptext->getBoundingBoxAnnotationUnits()==DVPSA_display) oss << "display"; else oss << "pixel";
 
           DVPSTextJustification justification = ptext->getBoundingBoxHorizontalJustification();
-          COUT << " justification=";
+          oss << " justification=";
           switch (justification)
           {
             case DVPSX_left:
-              COUT << "left";
+              oss << "left";
               break;
             case DVPSX_right:
-              COUT << "right";
+              oss << "right";
               break;
             case DVPSX_center:
-              COUT << "center";
+              oss << "center";
               break;
           }
-          COUT << endl;
-        } else COUT << "none" << endl;
+          oss << OFendl;
+        } else oss << "none" << OFendl;
       }
     }
 
     // graphic objects
     max = ps.getNumberOfGraphicObjects(layer);
-    COUT << "  Number of graphic objects: " << max << endl;
+    oss << "  Number of graphic objects: " << max << OFendl;
     DVPSGraphicObject *pgraphic = NULL;
     for (size_t graphicidx=0; graphicidx<max; graphicidx++)
     {
       pgraphic = ps.getGraphicObject(layer, graphicidx);
       if (pgraphic)
       {
-      	// display contents of graphic object
-        COUT << "      graphic " << graphicidx+1 << ": points=" << pgraphic->getNumberOfPoints()
+        // display contents of graphic object
+        oss << "      graphic " << graphicidx+1 << ": points=" << pgraphic->getNumberOfPoints()
              << " type=";
         switch (pgraphic->getGraphicType())
         {
-          case DVPST_polyline: COUT << "polyline filled="; break;
-          case DVPST_interpolated: COUT << "interpolated filled="; break;
-          case DVPST_circle: COUT << "circle filled="; break;
-          case DVPST_ellipse: COUT << "ellipse filled="; break;
-          case DVPST_point: COUT << "point filled="; break;
+          case DVPST_polyline: oss << "polyline filled="; break;
+          case DVPST_interpolated: oss << "interpolated filled="; break;
+          case DVPST_circle: oss << "circle filled="; break;
+          case DVPST_ellipse: oss << "ellipse filled="; break;
+          case DVPST_point: oss << "point filled="; break;
         }
-        if (pgraphic->isFilled()) COUT << "yes units="; else COUT << "no units=";
-        if (pgraphic->getAnnotationUnits()==DVPSA_display) COUT << "display"; else COUT << "pixel";
-        COUT << endl << "        coordinates: ";
+        if (pgraphic->isFilled()) oss << "yes units="; else oss << "no units=";
+        if (pgraphic->getAnnotationUnits()==DVPSA_display) oss << "display"; else oss << "pixel";
+        oss << OFendl << "        coordinates: ";
         j = pgraphic->getNumberOfPoints();
         Float32 fx=0.0, fy=0.0;
         for (i=0; i<j; i++)
         {
           if (EC_Normal==pgraphic->getPoint(i,fx,fy))
           {
-            COUT << fx << "\\" << fy << ", ";
-          } else COUT << "???\\???, ";
+            oss << fx << "\\" << fy << ", ";
+          } else oss << "???\\???, ";
         }
-        COUT << endl;
+        oss << OFendl;
       }
     }
 
     // curve objects
     max = ps.getNumberOfCurves(layer);
-    COUT << "  Number of activated curves: " << max << endl;
+    oss << "  Number of activated curves: " << max << OFendl;
     DVPSCurve *pcurve = NULL;
     for (size_t curveidx=0; curveidx<max; curveidx++)
     {
       pcurve = ps.getCurve(layer, curveidx);
       if (pcurve)
       {
-      	// display contents of curve
-        COUT << "      curve " << curveidx+1 << ": points=" << pcurve->getNumberOfPoints()
-             << " type=";
+        // display contents of curve
+        oss << "      curve " << curveidx+1 << ": points=" << pcurve->getNumberOfPoints()
+            << " type=";
         switch (pcurve->getTypeOfData())
         {
-          case DVPSL_roiCurve: COUT << "roi units="; break;
-          case DVPSL_polylineCurve: COUT << "poly units="; break;
+          case DVPSL_roiCurve: oss << "roi units="; break;
+          case DVPSL_polylineCurve: oss << "poly units="; break;
         }
         c = pcurve->getCurveAxisUnitsX();
-        if (c && (strlen(c)>0)) COUT << c << "\\"; else COUT << "(none)\\";
+        if (c && (strlen(c)>0)) oss << c << "\\"; else oss << "(none)\\";
         c = pcurve->getCurveAxisUnitsY();
-        if (c && (strlen(c)>0)) COUT << c << endl; else COUT << "(none)" << endl;
-        COUT << "        label=";
+        if (c && (strlen(c)>0)) oss << c << OFendl; else oss << "(none)" << OFendl;
+        oss << "        label=";
         c = pcurve->getCurveLabel();
-        if (c && (strlen(c)>0)) COUT << c << " description="; else COUT << "(none) description=";
+        if (c && (strlen(c)>0)) oss << c << " description="; else oss << "(none) description=";
         c = pcurve->getCurveDescription();
-        if (c && (strlen(c)>0)) COUT << c << endl; else COUT << "(none)" << endl;
-        COUT << "        coordinates: ";
+        if (c && (strlen(c)>0)) oss << c << OFendl; else oss << "(none)" << OFendl;
+        oss << "        coordinates: ";
         j = pcurve->getNumberOfPoints();
         double dx=0.0, dy=0.0;
         for (i=0; i<j; i++)
         {
           if (EC_Normal==pcurve->getPoint(i,dx,dy))
           {
-            COUT << dx << "\\" << dy << ", ";
-          } else COUT << "???\\???, ";
+            oss << dx << "\\" << dy << ", ";
+          } else oss << "???\\???, ";
         }
-        COUT << endl;
-      } else COUT << "      curve " << curveidx+1 << " not present in image." << endl;
+        oss << OFendl;
+      } else oss << "      curve " << curveidx+1 << " not present in image." << OFendl;
     }
 
     // overlay objects
@@ -345,28 +343,28 @@ void dumpPresentationState(DVPresentationState &ps)
     FILE *ofile=NULL;
 
     max = ps.getNumberOfActiveOverlays(layer);
-    COUT << "  Number of activated overlays: " << max << endl;
+    oss << "  Number of activated overlays: " << max << OFendl;
     for (size_t ovlidx=0; ovlidx<max; ovlidx++)
     {
-      COUT << "      overlay " << ovlidx+1 << ": group=0x" << hex
-           << ps.getActiveOverlayGroup(layer, ovlidx) << dec << " label=\"";
+      oss << "      overlay " << ovlidx+1 << ": group=0x" << STD_NAMESPACE hex
+           << ps.getActiveOverlayGroup(layer, ovlidx) << STD_NAMESPACE dec << " label=\"";
       c=ps.getActiveOverlayLabel(layer, ovlidx);
-      if (c) COUT << c; else COUT << "(none)";
-      COUT << "\" description=\"";
+      if (c) oss << c; else oss << "(none)";
+      oss << "\" description=\"";
       c=ps.getActiveOverlayDescription(layer, ovlidx);
-      if (c) COUT << c; else COUT << "(none)";
-      COUT << "\" type=";
-      if (ps.activeOverlayIsROI(layer, ovlidx)) COUT << "ROI"; else COUT << "graphic";
-      COUT << endl;
+      if (c) oss << c; else oss << "(none)";
+      oss << "\" type=";
+      if (ps.activeOverlayIsROI(layer, ovlidx)) oss << "ROI"; else oss << "graphic";
+      oss << OFendl;
 
       /* get overlay data */
       if (EC_Normal == ps.getOverlayData(layer, ovlidx, overlayData, overlayWidth, overlayHeight,
           overlayLeft, overlayTop, overlayROI, overlayTransp))
       {
-      	COUT << "        columns=" << overlayWidth << " rows=" << overlayHeight << " left="
-      	<< overlayLeft << " top=" << overlayTop << endl;
-      	sprintf(overlayfile, "ovl_%02d%02d.pgm", (int)layer+1, (int)ovlidx+1);
-      	COUT << "        filename=\"" << overlayfile << "\"";
+        oss << "        columns=" << overlayWidth << " rows=" << overlayHeight << " left="
+            << overlayLeft << " top=" << overlayTop << OFendl;
+        sprintf(overlayfile, "ovl_%02d%02d.pgm", (int)layer+1, (int)ovlidx+1);
+        oss << "        filename=\"" << overlayfile << "\"";
 
         ofile = fopen(overlayfile, "wb");
         if (ofile)
@@ -374,59 +372,61 @@ void dumpPresentationState(DVPresentationState &ps)
            fprintf(ofile, "P5\n%d %d 255\n", overlayWidth, overlayHeight);
            fwrite(overlayData, overlayWidth, overlayHeight, ofile);
            fclose(ofile);
-           COUT << " - written." << endl;
-        } else COUT << " -write error-" << endl;
+           oss << " - written." << OFendl;
+        } else oss << " -write error-" << OFendl;
       } else {
-      	COUT << "        unable to access overlay data!" << endl;
+        oss << "        unable to access overlay data!" << OFendl;
       }
     }
   }
 
-  COUT << endl;
+  oss << OFendl;
 
   max = ps.getNumberOfVOILUTsInImage();
-  COUT << "VOI LUTs available in attached image: " << max << endl;
+  oss << "VOI LUTs available in attached image: " << max << OFendl;
   for (size_t lutidx=0; lutidx<max; lutidx++)
   {
-    COUT << "  LUT #" << lutidx+1 << ": description=";
+    oss << "  LUT #" << lutidx+1 << ": description=";
     c=ps.getDescriptionOfVOILUTsInImage(lutidx);
-    if (c) COUT << c << endl; else COUT << "(none)" << endl;
+    if (c) oss << c << OFendl; else oss << "(none)" << OFendl;
   }
 
   max = ps.getNumberOfVOIWindowsInImage();
-  COUT << "VOI windows available in attached image: " << max << endl;
+  oss << "VOI windows available in attached image: " << max << OFendl;
   for (size_t winidx=0; winidx<max; winidx++)
   {
-    COUT << "  Window #" << winidx+1 << ": description=";
+    oss << "  Window #" << winidx+1 << ": description=";
     c=ps.getDescriptionOfVOIWindowsInImage(winidx);
-    if (c) COUT << c << endl; else COUT << "(none)" << endl;
+    if (c) oss << c << OFendl; else oss << "(none)" << OFendl;
   }
 
   max = ps.getNumberOfOverlaysInImage();
-  COUT << "Overlays available (non-shadowed) in attached image: " << max << endl;
+  oss << "Overlays available (non-shadowed) in attached image: " << max << OFendl;
   for (size_t oidx=0; oidx<max; oidx++)
   {
-    COUT << "  Overlay #" << oidx+1 << ": group=0x" << hex << ps.getOverlayInImageGroup(oidx) << dec << " label=\"";
+    oss << "  Overlay #" << oidx+1 << ": group=0x" << STD_NAMESPACE hex << ps.getOverlayInImageGroup(oidx) << STD_NAMESPACE dec << " label=\"";
     c=ps.getOverlayInImageLabel(oidx);
-    if (c) COUT << c; else COUT << "(none)";
-    COUT << "\" description=\"";
+    if (c) oss << c; else oss << "(none)";
+    oss << "\" description=\"";
     c=ps.getOverlayInImageDescription(oidx);
-    if (c) COUT << c; else COUT << "(none)";
-    COUT << "\" type=";
-    if (ps.overlayInImageIsROI(oidx)) COUT << "ROI"; else COUT << "graphic";
-    COUT << endl;
+    if (c) oss << c; else oss << "(none)";
+    oss << "\" type=";
+    if (ps.overlayInImageIsROI(oidx)) oss << "ROI"; else oss << "graphic";
+    oss << OFendl;
   }
-  COUT << endl;
 
+  oss << OFStringStream_ends;
+  OFSTRINGSTREAM_GETSTR(oss, res)
+  OFLOG_INFO(dcmp2pgmLogger, res);
+  OFSTRINGSTREAM_FREESTR(res)
 }
 
 
-#define SHORTCOL 2
+#define SHORTCOL 3
 #define LONGCOL 13
 
 int main(int argc, char *argv[])
 {
-    int    opt_debugMode       = 0;                       /* default: no debug */
     OFBool opt_dump_pstate     = OFFalse;                 /* default: do not dump presentation state */
     OFBool opt_dicom_mode      = OFFalse;                 /* default: create PGM, not DICOM SC */
     OFCmdUnsignedInt opt_frame = 1;                       /* default: first frame */
@@ -436,22 +436,18 @@ int main(int argc, char *argv[])
     const char *opt_savName    = NULL;                    /* pstate save file name */
     const char *opt_cfgName    = NULL;                    /* config read file name */
 
-    SetDebugLevel(( 0 ));
-    DicomImageClass::setDebugLevel(DicomImageClass::DL_NoMessages);
-
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, "Read DICOM image and presentation state and render bitmap", rcsid);
     OFCommandLine cmd;
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
     cmd.setParamColumn(LONGCOL + SHORTCOL + 2);
 
-    cmd.addParam("dcmimage_in",              "input DICOM image");
-    cmd.addParam("bitmap_out",               "output DICOM image or PGM bitmap", OFCmdParam::PM_Optional);
+    cmd.addParam("dcmfile-in", "input DICOM image");
+    cmd.addParam("bitmap-out", "output DICOM image or PGM bitmap", OFCmdParam::PM_Optional);
 
     cmd.addGroup("general options:");
-     cmd.addOption("--help",        "-h",    "print this help text and exit");
-     cmd.addOption("--version",              "print version information and exit", OFTrue /* exclusive */);
-     cmd.addOption("--verbose",     "-v",    "verbose mode, dump presentation state contents");
-     cmd.addOption("--debug",       "-d",    "debug mode, print debug information");
+     cmd.addOption("--help",        "-h",    "print this help text and exit", OFCommandLine::AF_Exclusive);
+     cmd.addOption("--version",              "print version information and exit", OFCommandLine::AF_Exclusive);
+     OFLog::addOptions(cmd);
 
     cmd.addGroup("processing options:");
      cmd.addOption("--pstate",      "-p", 1, "[f]ilename: string",
@@ -470,19 +466,19 @@ int main(int argc, char *argv[])
                                              "save presentation state to file");
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
         if (cmd.findOption("--version"))
         {
-            app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-            CERR << endl << "External libraries used:";
+            app.printHeader(OFTrue /*print host identifier*/);
+            COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-            CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+            COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-            CERR << " none" << endl;
+            COUT << " none" << OFendl;
 #endif
             return 0;
          }
@@ -492,8 +488,11 @@ int main(int argc, char *argv[])
       cmd.getParam(1, opt_imgName);
       if (cmd.getParamCount() > 1)
         cmd.getParam(2, opt_pgmName);
-      if (cmd.findOption("--verbose"))     opt_dump_pstate=OFTrue;
-      if (cmd.findOption("--debug"))       opt_debugMode = 3;
+
+      OFLog::configureFromCommandLine(cmd, app);
+
+      opt_dump_pstate = dcmp2pgmLogger.isEnabledFor(OFLogger::INFO_LOG_LEVEL);
+
       if (cmd.findOption("--pstate"))      app.checkValue(cmd.getValue(opt_pstName));
       if (cmd.findOption("--config"))      app.checkValue(cmd.getValue(opt_cfgName));
       if (cmd.findOption("--frame"))       app.checkValue(cmd.getValueAndCheckMin(opt_frame, 1));
@@ -502,15 +501,15 @@ int main(int argc, char *argv[])
       if (cmd.findOption("--save-pstate")) app.checkValue(cmd.getValue(opt_savName));
     }
 
-    SetDebugLevel((opt_debugMode));
-    DicomImageClass::setDebugLevel(opt_debugMode);
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmp2pgmLogger, rcsid << OFendl);
 
     if (opt_cfgName)
     {
       FILE *cfgfile = fopen(opt_cfgName, "rb");
       if (cfgfile) fclose(cfgfile); else
       {
-        CERR << "error: can't open configuration file '" << opt_cfgName << "'" << endl;
+        OFLOG_FATAL(dcmp2pgmLogger, "can't open configuration file '" << opt_cfgName << "'");
         return 10;
       }
     }
@@ -519,61 +518,66 @@ int main(int argc, char *argv[])
 
     if (opt_pstName == NULL)
     {
-        if (opt_debugMode > 0)
-            CERR << "reading DICOM image file: " << opt_imgName << endl;
+        OFLOG_DEBUG(dcmp2pgmLogger, "reading DICOM image file: " << opt_imgName);
         status = dvi.loadImage(opt_imgName);
     } else {
-        if (opt_debugMode > 0)
-        {
-            CERR << "reading DICOM pstate file: " << opt_pstName << endl;
-            CERR << "reading DICOM image file: " << opt_imgName << endl;
-        }
+        OFLOG_DEBUG(dcmp2pgmLogger, "reading DICOM pstate file: " << opt_pstName);
+        OFLOG_DEBUG(dcmp2pgmLogger, "reading DICOM image file: " << opt_imgName);
         status = dvi.loadPState(opt_pstName, opt_imgName);
     }
 
     if (status == EC_Normal)
     {
-    	if (opt_dump_pstate) dumpPresentationState(dvi.getCurrentPState());
+        if (opt_dump_pstate) dumpPresentationState(dvi.getCurrentPState());
         if (opt_pgmName != NULL)
         {
             const void *pixelData = NULL;
             unsigned long width = 0;
             unsigned long height = 0;
-            if (opt_debugMode > 0) CERR << "creating pixel data" << endl;
+            OFLOG_DEBUG(dcmp2pgmLogger, "creating pixel data");
             if ((opt_frame > 0) && (dvi.getCurrentPState().selectImageFrameNumber(opt_frame) != EC_Normal))
-               CERR << "cannot select frame " << opt_frame << endl;
+               OFLOG_ERROR(dcmp2pgmLogger, "cannot select frame " << opt_frame);
             if ((dvi.getCurrentPState().getPixelData(pixelData, width, height) == EC_Normal) && (pixelData != NULL))
             {
               if (opt_dicom_mode)
               {
                 double pixelAspectRatio = dvi.getCurrentPState().getPrintBitmapPixelAspectRatio(); // works for rotated images
-                if (opt_debugMode > 0) CERR << "writing DICOM SC file: " << opt_pgmName << endl;
+                OFLOG_DEBUG(dcmp2pgmLogger, "writing DICOM SC file: " << opt_pgmName);
                 if (EC_Normal != dvi.saveDICOMImage(opt_pgmName, pixelData, width, height, pixelAspectRatio))
                 {
-                  CERR << "error during creation of DICOM file" << endl;
+                  OFLOG_ERROR(dcmp2pgmLogger, "error during creation of DICOM file");
                 }
               } else {
                 FILE *outfile = fopen(opt_pgmName, "wb");
                 if (outfile)
                 {
-                    if (opt_debugMode > 0)
-                        CERR << "writing PGM file: " << opt_pgmName << endl;
+                    OFLOG_DEBUG(dcmp2pgmLogger, "writing PGM file: " << opt_pgmName);
                     fprintf(outfile, "P5\n%ld %ld 255\n", width, height);
                     fwrite(pixelData, (size_t)width, (size_t)height, outfile);
                     fclose(outfile);
-                } else app.printError("Can't create output file.");
+                } else {
+                    OFLOG_FATAL(dcmp2pgmLogger, "Can't create output file.");
+                    return 10;
+                }
               }
-            } else app.printError("Can't create output data.");
+            } else {
+                OFLOG_FATAL(dcmp2pgmLogger, "Can't create output data.");
+                return 10;
+            }
         }
         if (opt_savName != NULL)
         {
-            if (opt_debugMode > 0)
-                CERR << "writing pstate file: " << opt_savName << endl;
+            OFLOG_DEBUG(dcmp2pgmLogger, "writing pstate file: " << opt_savName);
             if (dvi.savePState(opt_savName, OFFalse) != EC_Normal)
-                app.printError("Can't write pstate file.");
+            {
+                OFLOG_FATAL(dcmp2pgmLogger, "Can't write pstate file.");
+                return 10;
+            }
         }
-    } else
-        app.printError("Can't open input file(s).");
+    } else {
+        OFLOG_FATAL(dcmp2pgmLogger, "Can't open input file(s).");
+        return 10;
+    }
 
 #ifdef DEBUG
     dcmDataDict.clear();  /* useful for debugging with dmalloc */
@@ -586,6 +590,34 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcmp2pgm.cc,v $
+ * Revision 1.43  2010-10-14 13:13:44  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.42  2009-11-27 10:52:54  joergr
+ * Fixed various issues with syntax usage (e.g. layout and formatting).
+ * Replaced remaining tabs by spaces.
+ *
+ * Revision 1.41  2009-11-24 14:12:56  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.40  2009-10-28 09:53:41  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.39  2008-09-25 16:30:24  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.38  2006/08/15 16:57:01  meichel
+ * Updated the code in module dcmpstat to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.37  2006/07/27 14:35:25  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ * Made naming conventions for command line parameters more consistent, e.g.
+ * used "dcmfile-in", "dcmfile-out" and "bitmap-out".
+ *
  * Revision 1.36  2005/12/08 15:46:04  meichel
  * Changed include path schema for all DCMTK header files
  *
