@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2004, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmpstat
  *
@@ -22,16 +18,15 @@
  *  Purpose: Presentation State Viewer - Print Server
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2004/02/04 15:44:38 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmpstat/apps/dcmprscp.cc,v $
- *  CVS/RCS Revision: $Revision: 1.15 $
+ *  Update Date:      $Date: 2010-10-14 13:13:45 $
+ *  CVS/RCS Revision: $Revision: 1.32 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
  *
  */
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #ifdef HAVE_GUSI_H
 #include <GUSI.h>
@@ -43,21 +38,22 @@ BEGIN_EXTERN_C
 #endif
 END_EXTERN_C
 
-#include "ofstream.h"
-#include "dvpsdef.h"     /* for constants and macros */
-#include "dviface.h"
-#include "ofbmanip.h"    /* for OFBitmanipTemplate */
-#include "ofdatime.h"    /* for OFDateTime */
-#include "dcuid.h"       /* for dcmtk version name */
-#include "diutil.h"
-#include "cmdlnarg.h"
-#include "ofconapp.h"
-#include "dvpsprt.h"
-#include "dvpshlp.h"
+#include "dcmtk/ofstd/ofstream.h"
+#include "dcmtk/dcmpstat/dvpsdef.h"     /* for constants and macros */
+#include "dcmtk/dcmpstat/dviface.h"
+#include "dcmtk/ofstd/ofbmanip.h"       /* for OFBitmanipTemplate */
+#include "dcmtk/ofstd/ofdatime.h"       /* for OFDateTime */
+#include "dcmtk/dcmdata/dcuid.h"        /* for dcmtk version name */
+#include "dcmtk/dcmnet/diutil.h"
+#include "dcmtk/dcmdata/cmdlnarg.h"
+#include "dcmtk/ofstd/ofconapp.h"
+#include "dcmtk/dcmpstat/dvpsprt.h"
+#include "dcmtk/dcmpstat/dvpshlp.h"
+#include "dcmtk/oflog/fileap.h"
 
 #ifdef WITH_OPENSSL
-#include "tlstrans.h"
-#include "tlslayer.h"
+#include "dcmtk/dcmtls/tlstrans.h"
+#include "dcmtk/dcmtls/tlslayer.h"
 #endif
 
 #ifdef WITH_ZLIB
@@ -66,44 +62,16 @@ END_EXTERN_C
 
 #define OFFIS_CONSOLE_APPLICATION "dcmprscp"
 
+static OFLogger dcmprscpLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
 /* command line options */
-static OFBool           opt_verbose         = OFFalse;             /* default: not verbose */
-static int              opt_debugMode       = 0;
-static OFBool           opt_dumpMode        = OFFalse;
-static OFBool           opt_logFile         = OFFalse;
-static OFBool           opt_binaryLog       = OFFalse;
-static const char *     opt_cfgName         = NULL;                /* config file name */
-static const char *     opt_printer         = NULL;                /* printer name */
-static ostream *        logstream           = &CERR;
-
-/* print scp data, taken from configuration file */
-static OFBool         haveHandledClients    = OFFalse;
-
-static int errorCond(OFCondition cond, const char *message)
-{
-  int result = (cond.bad());
-  if (result)
-  {
-    CERR << message << endl;
-    DimseCondition::dump(cond);
-  }
-  return result;
-}
-
-void closeLog()
-{
-  ofConsole.setCout();
-  ofConsole.split();
-  if (logstream != &CERR)
-  {
-    *logstream << endl << OFDateTime::getCurrentDateTime() << endl << "terminating" << endl;
-    delete logstream;
-    logstream = &CERR;
-  }
-}
+static OFBool      opt_binaryLog = OFFalse;
+static OFBool      opt_logFile   = OFFalse;
+static const char *opt_cfgName   = NULL;                /* config file name */
+static const char *opt_printer   = NULL;                /* printer name */
 
 static void cleanChildren()
 {
@@ -131,15 +99,19 @@ static void cleanChildren()
 #endif
         if (child < 0)
         {
-           if (errno != ECHILD) CERR << "wait for child failed: " << strerror(errno) << endl;
+            if (errno != ECHILD)
+            {
+                char buf[256];
+                OFLOG_ERROR(dcmprscpLogger, "wait for child failed: " << OFStandard::strerror(errno, buf, sizeof(buf)));
+            }
         }
     }
 #endif
 }
 
 
-#define SHORTCOL 2
-#define LONGCOL 14
+#define SHORTCOL 3
+#define LONGCOL 12
 
 int main(int argc, char *argv[])
 {
@@ -156,7 +128,6 @@ int main(int argc, char *argv[])
     WSAStartup(winSockVersionNeeded, &winSockData);
 #endif
 
-    SetDebugLevel((0));
     dcmDisableGethostbyaddr.set(OFTrue);  // disable hostname lookup
 
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "DICOM basic grayscale print management SCP", rcsid);
@@ -165,66 +136,77 @@ int main(int argc, char *argv[])
     cmd.setParamColumn(LONGCOL + SHORTCOL + 2);
 
     cmd.addGroup("general options:");
-     cmd.addOption("--help",        "-h",    "print this help text and exit");
-     cmd.addOption("--version",              "print version information and exit", OFTrue /* exclusive */);
-     cmd.addOption("--verbose",     "-v",    "verbose mode, print actions");
-     cmd.addOption("--debug",       "-d",    "debug mode, print debug information");
+     cmd.addOption("--help",    "-h",    "print this help text and exit", OFCommandLine::AF_Exclusive);
+     cmd.addOption("--version",          "print version information and exit", OFCommandLine::AF_Exclusive);
+     OFLog::addOptions(cmd);
+     cmd.addOption("--logfile", "-l",    "write a log file (not with --log-config)");
 
     cmd.addGroup("processing options:");
-     cmd.addOption("--config",      "-c", 1, "[f]ilename: string",
-                                             "process using settings from configuration file");
-     cmd.addOption("--printer",     "-p", 1, "[n]ame: string (default: 1st printer in cfg file)",
-                                             "select printer with identifier [n] from cfg file");
-     cmd.addOption("--dump",        "+d",    "print all DIMSE messages");
-     cmd.addOption("--logfile",     "-l",    "print to log file instead of stdout");
+     cmd.addOption("--config",  "-c", 1, "[f]ilename: string",
+                                         "process using settings from configuration file");
+     cmd.addOption("--printer", "-p", 1, "[n]ame: string (default: 1st printer in config file)",
+                                         "select printer with identifier n from config file");
+     cmd.addOption("--dump",    "+d",    "dump all DIMSE messages");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
         if (cmd.findOption("--version"))
         {
-            app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-            CERR << endl << "External libraries used:";
+            app.printHeader(OFTrue /*print host identifier*/);
+            COUT << OFendl << "External libraries used:";
 #if !defined(WITH_ZLIB) && !defined(WITH_OPENSSL)
-            CERR << " none" << endl;
+            COUT << " none" << OFendl;
 #else
-            CERR << endl;
+            COUT << OFendl;
 #endif
 #ifdef WITH_ZLIB
-            CERR << "- ZLIB, Version " << zlibVersion() << endl;
+            COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
 #ifdef WITH_OPENSSL
-            CERR << "- " << OPENSSL_VERSION_TEXT << endl;
+            COUT << "- " << OPENSSL_VERSION_TEXT << OFendl;
 #endif
             return 0;
          }
       }
 
       /* options */
-      if (cmd.findOption("--verbose")) opt_verbose = OFTrue;
-      if (cmd.findOption("--debug"))   opt_debugMode = 3;
-      if (cmd.findOption("--dump"))    opt_dumpMode = OFTrue;
-      if (cmd.findOption("--logfile")) opt_logFile = OFTrue;
+      if (cmd.findOption("--dump"))
+      {
+        // Messages to the "dump" logger are always written with the debug log
+        // level, thus enabling that logger for this level shows the dumps
+        log4cplus::Logger log = log4cplus::Logger::getInstance("dcmtk.dcmpstat.dump");
+        log.setLogLevel(OFLogger::DEBUG_LOG_LEVEL);
+      }
+
+      OFLog::configureFromCommandLine(cmd, app);
+
+      if (cmd.findOption("--logfile"))
+      {
+        app.checkConflict("--logfile", "--log-config", cmd.findOption("--log-config"));
+        opt_logFile = OFTrue;
+      }
       if (cmd.findOption("--config"))  app.checkValue(cmd.getValue(opt_cfgName));
       if (cmd.findOption("--printer")) app.checkValue(cmd.getValue(opt_printer));
     }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmprscpLogger, rcsid << OFendl);
 
     if (opt_cfgName)
     {
       FILE *cfgfile = fopen(opt_cfgName, "rb");
       if (cfgfile) fclose(cfgfile); else
       {
-        *logstream << "error: can't open configuration file '" << opt_cfgName << "'" << endl;
+        OFLOG_FATAL(dcmprscpLogger, "can't open configuration file '" << opt_cfgName << "'");
         return 10;
       }
     } else {
-        *logstream << "error: no configuration file specified" << endl;
+        OFLOG_FATAL(dcmprscpLogger, "no configuration file specified");
         return 10;
     }
 
@@ -234,14 +216,14 @@ int main(int argc, char *argv[])
     {
       if (DVPSE_printLocal != dvi.getTargetType(opt_printer))
       {
-        *logstream << "error: no print scp definition for '" << opt_printer << "' found in config file." << endl;
+        OFLOG_FATAL(dcmprscpLogger, "no print scp definition for '" << opt_printer << "' found in config file");
         return 10;
       }
     } else {
       opt_printer = dvi.getTargetID(0, DVPSE_printLocal); // use default print scp
       if (opt_printer==NULL)
       {
-        *logstream << "error: no default print scp available - no config file?" << endl;
+        OFLOG_FATAL(dcmprscpLogger, "no default print scp available - no config file?");
         return 10;
       }
     }
@@ -253,10 +235,7 @@ int main(int argc, char *argv[])
     unsigned long logcounter = 0;
     char logcounterbuf[20];
 
-    if (dvi.getLogFolder() != NULL)
-        logfileprefix = dvi.getLogFolder();
-    else
-        logfileprefix = dvi.getSpoolFolder();
+    logfileprefix = dvi.getSpoolFolder();
 
     logfileprefix += PATH_SEPARATOR;
     logfileprefix += "PrintSCP_";
@@ -268,48 +247,40 @@ int main(int argc, char *argv[])
     DVPSHelper::currentTime(aString);
     logfileprefix += aString;
 
-    OFString logfilename;
     if (opt_logFile)
     {
-      logfilename = logfileprefix;
+      const char *pattern = "%m%n";
+      OFString logfilename = logfileprefix;
       logfilename += ".log";
 
-      ofstream *newstream = new ofstream(logfilename.c_str());
-      if (newstream && (newstream->good()))
-      {
-        logstream=newstream;
-        ofConsole.setCout(logstream);
-        ofConsole.join();
-      }
-      else
-      {
-      	delete newstream;
-      	logfilename.clear();
-      }
+      OFauto_ptr<log4cplus::Layout> layout(new log4cplus::PatternLayout(pattern));
+      log4cplus::SharedAppenderPtr logfile(new log4cplus::FileAppender(logfilename));
+      log4cplus::Logger log = log4cplus::Logger::getRoot();
+
+      logfile->setLayout(layout);
+      log.removeAllAppenders();
+      log.addAppender(logfile);
     }
 
-    *logstream << rcsid << endl << OFDateTime::getCurrentDateTime() << endl << "started" << endl;
-
-    dvi.setLog(&ofConsole, opt_verbose, opt_debugMode > 0);
+    OFLOG_WARN(dcmprscpLogger, rcsid << OFendl << OFDateTime::getCurrentDateTime() << OFendl << "started");
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
-        *logstream << "Warning: no data dictionary loaded, check environment variable: " << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+       OFLOG_WARN(dcmprscpLogger, "no data dictionary loaded, check environment variable: " << DCM_DICT_ENVIRONMENT_VARIABLE);
 
     /* check if we can get access to the database */
     const char *dbfolder = dvi.getDatabaseFolder();
-    DB_Handle *dbhandle = NULL;
+    OFLOG_INFO(dcmprscpLogger, "Using database in directory '" << dbfolder << "'");
 
-    if (opt_verbose)
+    OFCondition cond2 = EC_Normal;
+    DcmQueryRetrieveIndexDatabaseHandle *dbhandle = new DcmQueryRetrieveIndexDatabaseHandle(dbfolder, PSTAT_MAXSTUDYCOUNT, PSTAT_STUDYSIZE, cond2);
+    delete dbhandle;
+
+    if (cond2.bad())
     {
-      *logstream << "Using database in directory '" << dbfolder << "'" << endl;
-    }
-    if (DB_createHandle(dbfolder, PSTAT_MAXSTUDYCOUNT, PSTAT_STUDYSIZE, &dbhandle).bad())
-    {
-      *logstream << "Unable to access database '" << dbfolder << "'" << endl;
+      OFLOG_FATAL(dcmprscpLogger, "Unable to access database '" << dbfolder << "'");
       return 10;
     }
-    DB_destroyHandle(&dbhandle);
 
     /* get print scp data from configuration file */
     unsigned short targetPort   = dvi.getTargetPort(opt_printer);
@@ -318,8 +289,7 @@ int main(int argc, char *argv[])
 
     if (targetPort == 0)
     {
-        *logstream << "error: no or invalid port number for print scp '" << opt_printer << "'" << endl;
-        closeLog();
+        OFLOG_FATAL(dcmprscpLogger, "no or invalid port number for print scp '" << opt_printer << "'");
         return 10;
     }
 
@@ -394,7 +364,11 @@ int main(int argc, char *argv[])
     if (! dvi.getTLSPEMFormat()) keyFileFormat = SSL_FILETYPE_ASN1;
 
     /* ciphersuites */
+#if OPENSSL_VERSION_NUMBER >= 0x0090700fL
+    OFString tlsCiphersuites(TLS1_TXT_RSA_WITH_AES_128_SHA ":" SSL3_TXT_RSA_DES_192_CBC3_SHA);
+#else
     OFString tlsCiphersuites(SSL3_TXT_RSA_DES_192_CBC3_SHA);
+#endif
     Uint32 tlsNumberOfCiphersuites = dvi.getTargetNumberOfCipherSuites(opt_printer);
     if (tlsNumberOfCiphersuites > 0)
     {
@@ -403,14 +377,14 @@ int main(int argc, char *argv[])
       const char *currentOpenSSL;
       for (Uint32 ui=0; ui<tlsNumberOfCiphersuites; ui++)
       {
-      	dvi.getTargetCipherSuite(opt_printer, ui, currentSuite);
+        dvi.getTargetCipherSuite(opt_printer, ui, currentSuite);
         if (NULL == (currentOpenSSL = DcmTLSTransportLayer::findOpenSSLCipherSuiteName(currentSuite.c_str())))
         {
-          CERR << "ciphersuite '" << currentSuite << "' is unknown. Known ciphersuites are:" << endl;
+          OFLOG_WARN(dcmprscpLogger, "ciphersuite '" << currentSuite << "' is unknown. Known ciphersuites are:");
           unsigned long numSuites = DcmTLSTransportLayer::getNumberOfCipherSuites();
           for (unsigned long cs=0; cs < numSuites; cs++)
           {
-            CERR << "    " << DcmTLSTransportLayer::getTLSCipherSuiteName(cs) << endl;
+            OFLOG_WARN(dcmprscpLogger, "    " << DcmTLSTransportLayer::getTLSCipherSuiteName(cs));
           }
           return 1;
         } else {
@@ -426,37 +400,38 @@ int main(int argc, char *argv[])
       tLayer = new DcmTLSTransportLayer(DICOM_APPLICATION_ACCEPTOR, tlsRandomSeedFile.c_str());
       if (tLayer == NULL)
       {
-        app.printError("unable to create TLS transport layer");
+        OFLOG_FATAL(dcmprscpLogger, "unable to create TLS transport layer");
+        return 1;
       }
 
       if (tlsCACertificateFolder && (TCS_ok != tLayer->addTrustedCertificateDir(tlsCACertificateFolder, keyFileFormat)))
       {
-        CERR << "warning unable to load certificates from directory '" << tlsCACertificateFolder << "', ignoring" << endl;
+        OFLOG_WARN(dcmprscpLogger, "unable to load certificates from directory '" << tlsCACertificateFolder << "', ignoring");
       }
       if ((tlsDHParametersFile.size() > 0) && ! (tLayer->setTempDHParameters(tlsDHParametersFile.c_str())))
       {
-        CERR << "warning unable to load temporary DH parameter file '" << tlsDHParametersFile << "', ignoring" << endl;
+        OFLOG_WARN(dcmprscpLogger, "unable to load temporary DH parameter file '" << tlsDHParametersFile << "', ignoring");
       }
       tLayer->setPrivateKeyPasswd(tlsPrivateKeyPassword); // never prompt on console
 
       if (TCS_ok != tLayer->setPrivateKeyFile(tlsPrivateKeyFile.c_str(), keyFileFormat))
       {
-        CERR << "unable to load private TLS key from '" << tlsPrivateKeyFile<< "'" << endl;
+        OFLOG_FATAL(dcmprscpLogger, "unable to load private TLS key from '" << tlsPrivateKeyFile<< "'");
         return 1;
       }
       if (TCS_ok != tLayer->setCertificateFile(tlsCertificateFile.c_str(), keyFileFormat))
       {
-        CERR << "unable to load certificate from '" << tlsCertificateFile << "'" << endl;
+        OFLOG_FATAL(dcmprscpLogger, "unable to load certificate from '" << tlsCertificateFile << "'");
         return 1;
       }
       if (! tLayer->checkPrivateKeyMatchesCertificate())
       {
-        CERR << "private key '" << tlsPrivateKeyFile << "' and certificate '" << tlsCertificateFile << "' do not match" << endl;
+        OFLOG_FATAL(dcmprscpLogger, "private key '" << tlsPrivateKeyFile << "' and certificate '" << tlsCertificateFile << "' do not match");
         return 1;
       }
       if (TCS_ok != tLayer->setCipherSuites(tlsCiphersuites.c_str()))
       {
-        CERR << "unable to set selected cipher suites" << endl;
+        OFLOG_FATAL(dcmprscpLogger, "unable to set selected cipher suites");
         return 1;
       }
 
@@ -466,14 +441,19 @@ int main(int argc, char *argv[])
 #else
     if (targetUseTLS)
     {
-        CERR << "error: not compiled with OpenSSL, cannot use TLS." << endl;
+        OFLOG_FATAL(dcmprscpLogger, "not compiled with OpenSSL, cannot use TLS");
         return 10;
     }
 #endif
 
     /* open listen socket */
-    OFCondition cond = ASC_initializeNetwork(NET_ACCEPTOR, targetPort, 10, &net);
-    if (errorCond(cond, "Error initialising network:")) return 1;
+    OFCondition cond = ASC_initializeNetwork(NET_ACCEPTOR, targetPort, 30, &net);
+    if (cond.bad())
+    {
+      OFString temp_str;
+      OFLOG_FATAL(dcmprscpLogger, "cannot initialise network:\n" << DimseCondition::dump(temp_str, cond));
+      return 1;
+    }
 
 #ifdef WITH_OPENSSL
     if (tLayer)
@@ -481,7 +461,8 @@ int main(int argc, char *argv[])
       cond = ASC_setTransportLayer(net, tLayer, 0);
       if (cond.bad())
       {
-        DimseCondition::dump(cond);
+        OFString temp_str;
+        OFLOG_FATAL(dcmprscpLogger, DimseCondition::dump(temp_str, cond));
         return 1;
       }
     }
@@ -506,8 +487,6 @@ int main(int argc, char *argv[])
     {
       DVPSPrintSCP printSCP(dvi, opt_printer); // use new print SCP object for each association
 
-      printSCP.setLog(&ofConsole, opt_verbose, opt_debugMode > 0, opt_dumpMode);
-
       if (opt_binaryLog)
       {
         aString = logfileprefix;
@@ -532,10 +511,14 @@ int main(int argc, char *argv[])
         case DVPSJ_terminate:
           finished=OFTrue;
           cond = ASC_dropNetwork(&net);
-          if (errorCond(cond, "Error dropping network:")) return 10;
+          if (cond.bad())
+          {
+            OFString temp_str;
+            OFLOG_FATAL(dcmprscpLogger, "cannot drop network:\n" << DimseCondition::dump(temp_str, cond));
+            return 10;
+          }
           break;
         case DVPSJ_success:
-          haveHandledClients = OFTrue;
           printSCP.handleClient();
           break;
       }
@@ -550,14 +533,6 @@ int main(int argc, char *argv[])
     dcmDataDict.clear();  /* useful for debugging with dmalloc */
 #endif
 
-    closeLog();
-    OFBool deleteUnusedLogs = OFTrue;
-    if (deleteUnusedLogs && (! haveHandledClients))
-    {
-      // log unused, attempt to delete file
-      if (logfilename.size() > 0) unlink(logfilename.c_str());
-    }
-
 #ifdef WITH_OPENSSL
     if (tLayer)
     {
@@ -565,10 +540,10 @@ int main(int argc, char *argv[])
       {
         if (!tLayer->writeRandomSeed(tlsRandomSeedFile.c_str()))
         {
-  	  CERR << "Error while writing back random seed file '" << tlsRandomSeedFile << "', ignoring." << endl;
+          OFLOG_ERROR(dcmprscpLogger, "cannot write back random seed file '" << tlsRandomSeedFile << "', ignoring");
         }
       } else {
-	CERR << "Warning: cannot write back random seed, ignoring." << endl;
+        OFLOG_WARN(dcmprscpLogger, "cannot write back random seed, ignoring");
       }
     }
     delete tLayer;
@@ -580,6 +555,67 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dcmprscp.cc,v $
+ * Revision 1.32  2010-10-14 13:13:45  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.31  2010-06-03 10:32:58  joergr
+ * Replaced calls to strerror() by new helper function OFStandard::strerror()
+ * which results in using the thread safe version of strerror() if available.
+ *
+ * Revision 1.30  2010-04-29 10:36:52  joergr
+ * Fixed typo in log message.
+ *
+ * Revision 1.29  2009-12-16 14:12:18  joergr
+ * Slightly modified description of command line option --logfile.
+ *
+ * Revision 1.28  2009-12-15 14:50:49  uli
+ * Fixes some issues with --logfile and the config's log options.
+ *
+ * Revision 1.27  2009-12-15 12:34:40  uli
+ * Re-added and fixed the command line option --logfile.
+ *
+ * Revision 1.26  2009-12-11 15:23:25  joergr
+ * Changed description of command line option --dump.
+ *
+ * Revision 1.25  2009-11-27 10:52:01  joergr
+ * Fixed various issues with syntax usage (e.g. layout and formatting).
+ * Sightly modifed log messages.
+ *
+ * Revision 1.24  2009-11-24 14:12:56  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.23  2008-09-25 16:30:24  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.22  2006/08/15 16:57:01  meichel
+ * Updated the code in module dcmpstat to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.21  2006/07/27 14:36:27  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
+ * Revision 1.20  2005/12/08 15:46:05  meichel
+ * Changed include path schema for all DCMTK header files
+ *
+ * Revision 1.19  2005/11/28 15:29:05  meichel
+ * File dcdebug.h is not included by any other header file in the toolkit
+ *   anymore, to minimize the risk of name clashes of macro debug().
+ *
+ * Revision 1.18  2005/11/23 16:10:32  meichel
+ * Added support for AES ciphersuites in TLS module. All TLS-enabled
+ *   tools now support the "AES TLS Secure Transport Connection Profile".
+ *
+ * Revision 1.17  2005/11/16 14:58:23  meichel
+ * Set association timeout in ASC_initializeNetwork to 30 seconds. This improves
+ *   the responsiveness of the tools if the peer blocks during assoc negotiation.
+ *
+ * Revision 1.16  2005/04/04 10:11:53  meichel
+ * Module dcmpstat now uses the dcmqrdb API instead of imagectn for maintaining
+ *   the index database
+ *
  * Revision 1.15  2004/02/04 15:44:38  joergr
  * Removed acknowledgements with e-mail addresses from CVS log.
  *
