@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -23,9 +19,9 @@
  *    sample application that reads a DICOM image and creates
  *    a matching presentation state.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/14 17:43:42 $
- *  CVS/RCS Revision: $Revision: 1.22 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:45 $
+ *  CVS/RCS Revision: $Revision: 1.29 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -44,14 +40,13 @@
 #include <GUSI.h>
 #endif
 
-#include "dcmtk/dcmdata/dctk.h"
-#include "dcmtk/dcmdata/dcdebug.h"
-#include "dcmtk/dcmpstat/dcmpstat.h"
-#include "dcmtk/dcmpstat/dvpshlp.h"
-#include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/ofstd/ofconapp.h"
+#include "dcmtk/dcmdata/dctk.h"
+#include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/dcmdata/dcuid.h"       /* for dcmtk version name */
 #include "dcmtk/dcmnet/dul.h"
+#include "dcmtk/dcmpstat/dcmpstat.h"
+#include "dcmtk/dcmpstat/dvpshlp.h"
 
 #ifdef WITH_ZLIB
 #include <zlib.h>        /* for zlibVersion() */
@@ -59,6 +54,8 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dcmpsmk"
 
+static OFLogger dcmpsmkLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -82,8 +79,6 @@ int main(int argc, char *argv[])
     dcmTCPWrapperDaemonName.set(NULL);
 #endif
 
-    int opt_debugMode = 0;
-
     // Variables for input parameters
     const char* opt_ifname = NULL;
     E_FileReadMode opt_readMode = ERM_autoDetect;
@@ -91,9 +86,7 @@ int main(int argc, char *argv[])
 
     // Variables for output parameters
     const char* opt_ofname = NULL;
-    OFBool verbosemode = OFFalse;
     E_TransferSyntax opt_oxfer = EXS_Unknown;
-    OFBool opt_oDataset = OFFalse;                 // currently not available as command line option
     E_GrpLenEncoding oglenc = EGL_recalcGL;        // currently not available as command line option
     E_EncodingType oenctype = EET_ExplicitLength;  // currently not available as command line option
     E_PaddingEncoding opadenc = EPD_noChange;      // currently not available as command line option
@@ -112,8 +105,6 @@ int main(int argc, char *argv[])
     const char *          opt_filesetID          = NULL;
     const char *          opt_filesetUID         = NULL;
 
-    SetDebugLevel((0));
-
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION , "Create DICOM grayscale softcopy presentation state", rcsid);
     OFCommandLine cmd;
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
@@ -123,74 +114,73 @@ int main(int argc, char *argv[])
     cmd.addParam("dcmfile-out", "DICOM presentation state file to be created");
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-      cmd.addOption("--help",                     "-h",        "print this help text and exit");
-      cmd.addOption("--version",                               "print version information and exit", OFTrue /* exclusive */);
-      cmd.addOption("--verbose",                  "-v",        "verbose mode, print processing details");
-      cmd.addOption("--debug",                    "-d",        "debug mode, print debug information");
+      cmd.addOption("--help",                 "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+      cmd.addOption("--version",                        "print version information and exit", OFCommandLine::AF_Exclusive);
+      OFLog::addOptions(cmd);
 
     cmd.addGroup("input options:");
       cmd.addSubGroup("input file format:");
-       cmd.addOption("--read-file",               "+f",        "read file format or data set (default)");
-       cmd.addOption("--read-file-only",          "+fo",       "read file format only");
-       cmd.addOption("--read-dataset",            "-f",        "read data set without file meta information");
+       cmd.addOption("--read-file",           "+f",     "read file format or data set (default)");
+       cmd.addOption("--read-file-only",      "+fo",    "read file format only");
+       cmd.addOption("--read-dataset",        "-f",     "read data set without file meta information");
       cmd.addSubGroup("input transfer syntax:", LONGCOL, SHORTCOL);
-       cmd.addOption("--read-xfer-auto",          "-t=",       "use TS recognition (default)");
-       cmd.addOption("--read-xfer-detect",        "-td",       "ignore TS specified in the file meta header");
-       cmd.addOption("--read-xfer-little",        "-te",       "read with explicit VR little endian TS");
-       cmd.addOption("--read-xfer-big",           "-tb",       "read with explicit VR big endian TS");
-       cmd.addOption("--read-xfer-implicit",      "-ti",       "read with implicit VR little endian TS");
+       cmd.addOption("--read-xfer-auto",      "-t=",    "use TS recognition (default)");
+       cmd.addOption("--read-xfer-detect",    "-td",    "ignore TS specified in the file meta header");
+       cmd.addOption("--read-xfer-little",    "-te",    "read with explicit VR little endian TS");
+       cmd.addOption("--read-xfer-big",       "-tb",    "read with explicit VR big endian TS");
+       cmd.addOption("--read-xfer-implicit",  "-ti",    "read with implicit VR little endian TS");
 
     cmd.addGroup("processing options:");
       cmd.addSubGroup("VOI transform handling:");
-       cmd.addOption("--voi-lut",                 "+Vl",       "use first VOI LUT if present (default)");
-       cmd.addOption("--voi-window",              "+Vw",       "use first window center/width if present");
-       cmd.addOption("--voi-ignore",              "-V",        "ignore VOI LUT and window center/width");
+       cmd.addOption("--voi-lut",             "+Vl",    "use first VOI LUT if present (default)");
+       cmd.addOption("--voi-window",          "+Vw",    "use first window center/width if present");
+       cmd.addOption("--voi-ignore",          "-V",     "ignore VOI LUT and window center/width");
       cmd.addSubGroup("curve handling:");
-       cmd.addOption("--curve-activate",          "+c",        "activate curve data if present (default)");
-       cmd.addOption("--curve-ignore",            "-c",        "ignore curve data");
+       cmd.addOption("--curve-activate",      "+c",     "activate curve data if present (default)");
+       cmd.addOption("--curve-ignore",        "-c",     "ignore curve data");
       cmd.addSubGroup("overlay handling:");
-       cmd.addOption("--overlay-copy",            "+oc",       "copy overlays if not embedded,\nactivate otherwise (default)");
-       cmd.addOption("--overlay-activate",        "+oa",       "activate overlays");
-       cmd.addOption("--overlay-ignore",          "-o",        "ignore overlays");
+       cmd.addOption("--overlay-copy",        "+oc",    "copy overlays if not embedded,\nactivate otherwise (default)");
+       cmd.addOption("--overlay-activate",    "+oa",    "activate overlays");
+       cmd.addOption("--overlay-ignore",      "-o",     "ignore overlays");
       cmd.addSubGroup("shutter handling:");
-       cmd.addOption("--shutter-activate",        "+s",        "use shutter if present in image (default)");
-       cmd.addOption("--shutter-ignore",          "-s",        "ignore shutter");
+       cmd.addOption("--shutter-activate",    "+s",     "use shutter if present in image (default)");
+       cmd.addOption("--shutter-ignore",      "-s",     "ignore shutter");
       cmd.addSubGroup("presentation LUT shape handling:");
-       cmd.addOption("--plut-activate",           "+p",        "use presentation LUT shape if present (default)");
-       cmd.addOption("--plut-ignore",             "-p",        "ignore presentation LUT shape");
+       cmd.addOption("--plut-activate",       "+p",     "use presentation LUT shape if present (default)");
+       cmd.addOption("--plut-ignore",         "-p",     "ignore presentation LUT shape");
       cmd.addSubGroup("layering:");
-       cmd.addOption("--layer-single",            "+l1",       "all curves and overlays are in one layer");
-       cmd.addOption("--layer-double",            "+l2",       "one layer for curves, one for overlays (default)");
-       cmd.addOption("--layer-separate",          "+ls",       "separate layers for each curve and overlay");
+       cmd.addOption("--layer-single",        "+l1",    "all curves and overlays are in one layer");
+       cmd.addOption("--layer-double",        "+l2",    "one layer for curves, one for overlays (default)");
+       cmd.addOption("--layer-separate",      "+ls",    "separate layers for each curve and overlay");
       cmd.addSubGroup("location of referenced image:");
-       cmd.addOption("--location-none",           "-lx",       "image reference without location (default)");
-       cmd.addOption("--location-network",        "-ln",    1, "[a]etitle: string",
-                                                               "image located at application entity a");
-       cmd.addOption("--location-media",          "-lm",    2, "[f]ilesetID, fileset[UID]: string",
-                                                               "image located on storage medium");
+       cmd.addOption("--location-none",       "-lx",    "image reference without location (default)");
+       cmd.addOption("--location-network",    "-ln", 1, "[a]etitle: string",
+                                                        "image located at application entity a");
+       cmd.addOption("--location-media",      "-lm", 2, "[f]ilesetID, fileset[UID]: string",
+                                                        "image located on storage medium");
 
     cmd.addGroup("output options:");
       cmd.addSubGroup("output transfer syntax:");
-       cmd.addOption("--write-xfer-same",         "+t=",       "write with same TS as image file (default)");
-       cmd.addOption("--write-xfer-little",       "+te",       "write with explicit VR little endian TS");
-       cmd.addOption("--write-xfer-big",          "+tb",       "write with explicit VR big endian TS");
-       cmd.addOption("--write-xfer-implicit",     "+ti",       "write with implicit VR little endian TS");
+       cmd.addOption("--write-xfer-same",     "+t=",    "write with same TS as image file (default)");
+       cmd.addOption("--write-xfer-little",   "+te",    "write with explicit VR little endian TS");
+       cmd.addOption("--write-xfer-big",      "+tb",    "write with explicit VR big endian TS");
+       cmd.addOption("--write-xfer-implicit", "+ti",    "write with implicit VR little endian TS");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
       /* check exclusive options first */
-      if (cmd.getParamCount() == 0)
+      if (cmd.hasExclusiveOption())
       {
         if (cmd.findOption("--version"))
         {
-            app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-            CERR << endl << "External libraries used:";
+            app.printHeader(OFTrue /*print host identifier*/);
+            COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-            CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+            COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-            CERR << " none" << endl;
+            COUT << " none" << OFendl;
 #endif
             return 0;
          }
@@ -200,8 +190,7 @@ int main(int argc, char *argv[])
       cmd.getParam(1, opt_ifname);
       cmd.getParam(cmd.getParamCount(), opt_ofname);
 
-      if (cmd.findOption("--verbose")) verbosemode=OFTrue;
-      if (cmd.findOption("--debug")) opt_debugMode=3;
+      OFLog::configureFromCommandLine(cmd, app);
 
       cmd.beginOptionBlock();
       if (cmd.findOption("--read-file")) opt_readMode = ERM_autoDetect;
@@ -285,43 +274,39 @@ int main(int argc, char *argv[])
 
     }
 
+    /* print resource identifier */
+    OFLOG_DEBUG(dcmpsmkLogger, rcsid << OFendl);
+
     // additional checks
     if ((opt_ifname == NULL) || (strlen(opt_ifname) == 0))
     {
-        CERR << "invalid input filename: <empty string>" << endl;
+        OFLOG_FATAL(dcmpsmkLogger, "invalid input filename: <empty string>");
         return 1;
     }
 
     if ((opt_ofname == NULL) || (strlen(opt_ofname) == 0))
     {
-        CERR << "invalid output filename: <empty string>" << endl;
+        OFLOG_FATAL(dcmpsmkLogger, "invalid output filename: <empty string>");
         return 1;
     }
 
-    SetDebugLevel((opt_debugMode));
-
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
+        OFLOG_WARN(dcmpsmkLogger, "no data dictionary loaded, "
              << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+             << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     // open input file
     DcmFileFormat fileformat;
 
-    if (verbosemode)
-        COUT << "read and interpret DICOM file "
-             << opt_ifname << endl;
-
+    OFLOG_INFO(dcmpsmkLogger, "read and interpret DICOM file " << opt_ifname);
 
     OFCondition error = fileformat.loadFile(opt_ifname, opt_ixfer, EGL_noChange, DCM_MaxReadLength, opt_readMode);
     if (error.bad())
     {
-        CERR << "Error: "
-             << error.text()
-             << ": reading file: " <<  opt_ifname << endl;
+        OFLOG_FATAL(dcmpsmkLogger, error.text() << ": reading file: " << opt_ifname);
         return 1;
     }
 
@@ -329,26 +314,20 @@ int main(int argc, char *argv[])
 
     /* create presentation state */
     DcmPresentationState state;
-    if (verbosemode)
-    {
-        COUT << "creating presentation state object" << endl;
-    }
+    OFLOG_INFO(dcmpsmkLogger, "creating presentation state object");
 
     error = state.createFromImage(*dataset, overlayActivation, voiActivation,
       curveActivation, shutterActivation, presentationActivation, layering, opt_aetitle, opt_filesetID, opt_filesetUID);
     if (error != EC_Normal)
     {
-        CERR << "Error: "
-             << error.text()
-             << ": creating presentation state from image file: " << opt_ifname << endl;
+        OFLOG_FATAL(dcmpsmkLogger, error.text() << ": creating presentation state from image file: " << opt_ifname);
         return 1;
     }
 
     /* add additional image references to pstate */
     if (cmd.getParamCount() > 2)
     {
-        if (verbosemode)
-            COUT << "adding additonal image reference(s)" << endl;
+        OFLOG_INFO(dcmpsmkLogger, "adding additonal image reference(s)");
         const int count = cmd.getParamCount();
         for (int i = 2; i < count; i++)
         {
@@ -376,21 +355,17 @@ int main(int argc, char *argv[])
     error = state.write(*dataset2, OFTrue);
     if (error != EC_Normal)
     {
-        CERR << "Error: "
-             << error.text()
-             << ": re-encoding presentation state : " <<  opt_ifname << endl;
+        OFLOG_FATAL(dcmpsmkLogger, error.text() << ": re-encoding presentation state : " << opt_ifname);
         return 1;
     }
 
     if (opt_oxfer == EXS_Unknown)
     {
-        if (verbosemode)
-            COUT << "set output transfersyntax to input transfer syntax\n";
+        OFLOG_INFO(dcmpsmkLogger, "set output transfersyntax to input transfer syntax");
         opt_oxfer = dataset->getOriginalXfer();
     }
 
-    if (verbosemode)
-        COUT << "Check if new output transfer syntax is possible\n";
+    OFLOG_INFO(dcmpsmkLogger, "Check if new output transfer syntax is possible");
 
     DcmXfer oxferSyn(opt_oxfer);
 
@@ -398,29 +373,24 @@ int main(int argc, char *argv[])
 
     if (dataset2->canWriteXfer(opt_oxfer))
     {
-        if (verbosemode)
-           COUT << "Output transfer syntax " << oxferSyn.getXferName()
-                << " can be written\n";
+        OFLOG_INFO(dcmpsmkLogger, "Output transfer syntax " << oxferSyn.getXferName()
+                << " can be written");
     } else {
-        CERR << "No conversion to transfer syntax " << oxferSyn.getXferName()
-             << " possible!\n";
+        OFLOG_FATAL(dcmpsmkLogger, "No conversion to transfer syntax " << oxferSyn.getXferName()
+             << " possible!");
         return 1;
     }
 
-    if (verbosemode)
-        COUT << "write converted DICOM file\n";
+    OFLOG_INFO(dcmpsmkLogger, "write converted DICOM file");
 
-    error = fileformat2.saveFile(opt_ofname, opt_oxfer, oenctype, oglenc, opadenc, padlen, subPadlen, opt_oDataset);
+    error = fileformat2.saveFile(opt_ofname, opt_oxfer, oenctype, oglenc, opadenc, padlen, subPadlen);
     if (error.bad())
     {
-        CERR << "Error: "
-             << error.text()
-             << ": writing file: " <<  opt_ofname << endl;
+        OFLOG_FATAL(dcmpsmkLogger, error.text() << ": writing file: " <<  opt_ofname);
         return 1;
     }
 
-    if (verbosemode)
-        COUT << "conversion successful\n";
+    OFLOG_INFO(dcmpsmkLogger, "conversion successful");
 
     return 0;
 }
@@ -429,6 +399,31 @@ int main(int argc, char *argv[])
 /*
 ** CVS/RCS Log:
 ** $Log: dcmpsmk.cc,v $
+** Revision 1.29  2010-10-14 13:13:45  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.28  2009-11-24 14:12:56  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.27  2009-08-21 09:48:48  joergr
+** Removed unused option 'opt_oDataset'.
+**
+** Revision 1.26  2009-04-21 14:10:54  joergr
+** Fixed minor inconsistencies in manpage / syntax usage.
+**
+** Revision 1.25  2008-09-25 16:30:24  joergr
+** Added support for printing the expanded command line arguments.
+** Always output the resource identifier of the command line tool in debug mode.
+**
+** Revision 1.24  2006/08/15 16:57:01  meichel
+** Updated the code in module dcmpstat to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.23  2006/07/27 14:39:02  joergr
+** Changed parameter "exclusive" of method addOption() from type OFBool into an
+** integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+** Option "--help" is no longer an exclusive option by default.
+**
 ** Revision 1.22  2005/12/14 17:43:42  meichel
 ** Adapted code for compilation with TCP wrappers to NetBSD
 **
@@ -508,4 +503,3 @@ int main(int argc, char *argv[])
 ** Initial Release.
 **
 */
-
