@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVConfiguration
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 16:03:36 $
- *  CVS/RCS Revision: $Revision: 1.32 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:16:36 $
+ *  CVS/RCS Revision: $Revision: 1.34 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -39,9 +35,9 @@
 #include "dcmtk/ofstd/ofstring.h"   /* for class OFString */
 #include "dcmtk/dcmdata/dctypes.h"    /* for Uint32 */
 #include "dcmtk/dcmpstat/dvpstyp.h"    /* for DVPS enums */
+#include "dcmtk/oflog/oflog.h"         /* for OFLogger::LogLevel */
 
 class OFConfigFile;
-class OFConsole;
 
 /** Configuration class for the Softcopy Presentation State viewer.
  *  This class manages the configuration file content used by the
@@ -612,9 +608,9 @@ class DVConfiguration
   /** returns the log level / filter to be used for general application messages.
    *  Value is taken from the section GENERAL/APPLICATION/LOGLEVEL
    *  in the config file.
-   *  @return log level, default: DVPSM_none.
+   *  @return log level, default: OFLogger::FATAL_LOG_LEVEL
    */
-  DVPSLogMessageLevel getLogLevel();
+  OFLogger::LogLevel getLogLevel();
 
   /** returns the port on which the GUI application accepts notification 
    *  messages from the network processes.
@@ -1066,29 +1062,6 @@ class DVConfiguration
    *  @return key file for the given user
    */
   const char *getUserPrivateKey(const char *userID);
-  
-  /* Other settings */
-  
-  /** sets a new log stream
-   *  @param stream new log stream, NULL for default logstream
-   *  @param verbMode verbose mode flag
-   *  @param dbgMode debug mode flag
-   */
-  virtual void setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode);
-
-protected:
-
-  /** output stream for error messages, never NULL
-   */
-  OFConsole *logstream;
-  
-  /** flag indicating whether we're operating in verbose mode
-   */
-  OFBool verboseMode;
-   
-  /** flag indicating whether we're operating in debug mode
-   */
-  OFBool debugMode;
 
 private:
 
@@ -1131,7 +1104,13 @@ private:
 /*
  *  CVS/RCS Log:
  *  $Log: dvpscf.h,v $
- *  Revision 1.32  2005/12/08 16:03:36  meichel
+ *  Revision 1.34  2010-10-14 13:16:36  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.33  2009-11-24 14:12:57  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.32  2005-12-08 16:03:36  meichel
  *  Changed include path schema for all DCMTK header files
  *
  *  Revision 1.31  2003/04/29 10:13:56  meichel
