@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DcmPresentationState
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:14 $
- *  CVS/RCS Revision: $Revision: 1.8 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:31 $
+ *  CVS/RCS Revision: $Revision: 1.15 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -63,17 +59,35 @@
 #define INCLUDE_UNISTD
 #include "dcmtk/ofstd/ofstdinc.h"
 
+OFLogger DCM_dcmpstatGetLogger()
+{
+    static OFLogger DCM_dcmpstatLogger = OFLog::getLogger("dcmtk.dcmpstat");
+    return DCM_dcmpstatLogger;
+}
+
+OFLogger DCM_dcmpstatDumpGetLogger()
+{
+    static OFLogger DCM_dcmpstatLogger = OFLog::getLogger("dcmtk.dcmpstat.dump");
+    return DCM_dcmpstatLogger;
+}
+
+OFLogger DCM_dcmpstatLogfileGetLogger()
+{
+    static OFLogger DCM_dcmpstatLogger = OFLog::getLogger("dcmtk.dcmpstat.logfile");
+    return DCM_dcmpstatLogger;
+}
+
 /* --------------- class DcmPresentationState --------------- */
 
 DcmPresentationState::DcmPresentationState()
-: patientName(DCM_PatientsName)
+: patientName(DCM_PatientName)
 , patientID(DCM_PatientID)
-, patientBirthDate(DCM_PatientsBirthDate)
-, patientSex(DCM_PatientsSex)
+, patientBirthDate(DCM_PatientBirthDate)
+, patientSex(DCM_PatientSex)
 , studyInstanceUID(DCM_StudyInstanceUID)
 , studyDate(DCM_StudyDate)
 , studyTime(DCM_StudyTime)
-, referringPhysiciansName(DCM_ReferringPhysiciansName)
+, referringPhysicianName(DCM_ReferringPhysicianName)
 , studyID(DCM_StudyID)
 , accessionNumber(DCM_AccessionNumber)
 , seriesInstanceUID(DCM_SeriesInstanceUID)
@@ -86,7 +100,7 @@ DcmPresentationState::DcmPresentationState()
 , presentationDescription(DCM_ContentDescription)
 , presentationCreationDate(DCM_PresentationCreationDate)
 , presentationCreationTime(DCM_PresentationCreationTime)
-, presentationCreatorsName(DCM_ContentCreatorsName)
+, presentationCreatorsName(DCM_ContentCreatorName)
 , referencedSeriesList()
 , sOPInstanceUID(DCM_SOPInstanceUID)
 , specificCharacterSet(DCM_SpecificCharacterSet)
@@ -123,9 +137,6 @@ DcmPresentationState::DcmPresentationState()
 , rescaleSlope(DCM_RescaleSlope)
 , rescaleType(DCM_RescaleType)
 , softcopyVOIList()
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
   createInstanceUID();
 }
@@ -144,7 +155,7 @@ void DcmPresentationState::clear()
   studyInstanceUID.clear();
   studyDate.clear();
   studyTime.clear();
-  referringPhysiciansName.clear();
+  referringPhysicianName.clear();
   studyID.clear();
   accessionNumber.clear();
   seriesInstanceUID.clear();
@@ -316,61 +327,37 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
   if (sopclassuid.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: SOPClassUID absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("SOPClassUID absent or empty in presentation state");
   }
   else if (sopclassuid.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: SOPClassUID VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("SOPClassUID VM != 1 in presentation state");
   }
 
   if (modality.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: Modality absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("Modality absent or empty in presentation state");
   }
   else if (modality.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: Modality VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("Modality VM != 1 in presentation state");
   }
 
   sopclassuid.getOFString(aString,0);
   if (aString != UID_GrayscaleSoftcopyPresentationStateStorage)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: SOP Class UID does not match GrayscaleSoftcopyPresentationStateStorage" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("SOP Class UID does not match GrayscaleSoftcopyPresentationStateStorage");
   }
 
   modality.getOFString(aString,0);
   if (aString != "PR")
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: Modality does not match 'PR' for presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("Modality does not match 'PR' for presentation state");
   }
 
   if (result==EC_Normal)
@@ -382,7 +369,7 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
     READ_FROM_DATASET(DcmUniqueIdentifier, studyInstanceUID)
     READ_FROM_DATASET(DcmDate, studyDate)
     READ_FROM_DATASET(DcmTime, studyTime)
-    READ_FROM_DATASET(DcmPersonName, referringPhysiciansName)
+    READ_FROM_DATASET(DcmPersonName, referringPhysicianName)
     READ_FROM_DATASET(DcmShortString, studyID)
     READ_FROM_DATASET(DcmShortString, accessionNumber)
     READ_FROM_DATASET(DcmUniqueIdentifier, seriesInstanceUID)
@@ -452,11 +439,7 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
          }
       } else {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: Modality LUT SQ does not have exactly one item in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("Modality LUT SQ does not have exactly one item in presentation state");
       }
     }
   }
@@ -478,165 +461,97 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
   if (patientName.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: patientName absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("patientName absent or empty in presentation state");
   }
   else if (patientName.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: patientName VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("patientName VM != 1 in presentation state");
   }
 
   if (studyInstanceUID.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: studyInstanceUID absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("studyInstanceUID absent or empty in presentation state");
   }
   else if (studyInstanceUID.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: studyInstanceUID VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("studyInstanceUID VM != 1 in presentation state");
   }
 
   if (displayedAreaSelectionList.size() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: displayedAreaSelectionSQ absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("displayedAreaSelectionSQ absent or empty in presentation state");
   }
 
   if (imageNumber.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: instanceNumber absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("instanceNumber absent or empty in presentation state");
   }
   else if (imageNumber.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: instanceNumber VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("instanceNumber VM != 1 in presentation state");
   }
 
   if (presentationLabel.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentationLabel absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentationLabel absent or empty in presentation state");
   }
   else if (presentationLabel.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentationLabel VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentationLabel VM != 1 in presentation state");
   }
 
   if (presentationCreationDate.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentationCreationDate absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentationCreationDate absent or empty in presentation state");
   }
   else if (presentationCreationDate.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentationCreationDate VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentationCreationDate VM != 1 in presentation state");
   }
 
   if (presentationCreationTime.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentationCreationTime absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentationCreationTime absent or empty in presentation state");
   }
   else if (presentationCreationTime.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentationCreationTime VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentationCreationTime VM != 1 in presentation state");
   }
 
   if (sOPInstanceUID.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: sOPInstanceUID absent or empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("sOPInstanceUID absent or empty in presentation state");
   }
   else if (sOPInstanceUID.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: sOPInstanceUID VM != 1 in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("sOPInstanceUID VM != 1 in presentation state");
   }
 
     /* if imageRotation or imageHorizontalFlip are present, then both must be present. */
     if ((imageRotation.getLength() > 0)&&(imageHorizontalFlip.getLength() == 0))
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: imageRotation present but imageHorizontalFlip absent or empty in presentation state" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("imageRotation present but imageHorizontalFlip absent or empty in presentation state");
     }
 
     if ((imageRotation.getLength() == 0)&&(imageHorizontalFlip.getLength() > 0))
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: imageHorizontalFlip present but imageRotation absent or empty in presentation state" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("imageHorizontalFlip present but imageRotation absent or empty in presentation state");
     }
 
     /* Modality LUT */
@@ -647,47 +562,27 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
       if (rescaleSlope.getLength() == 0)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rescaleIntercept present but rescaleSlope absent or empty in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rescaleIntercept present but rescaleSlope absent or empty in presentation state");
       }
       else if (rescaleSlope.getVM() != 1)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rescaleIntercept present but rescaleSlope VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rescaleIntercept present but rescaleSlope VM != 1 in presentation state");
       }
       if (rescaleType.getLength() == 0)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rescaleIntercept present but rescaleType absent or empty in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rescaleIntercept present but rescaleType absent or empty in presentation state");
       }
       else if (rescaleType.getVM() != 1)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rescaleIntercept present but rescaleType VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rescaleIntercept present but rescaleType VM != 1 in presentation state");
       }
       if (rescaleIntercept.getVM() != 1)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rescaleIntercept present but VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rescaleIntercept present but VM != 1 in presentation state");
       }
     } else useModalityRescale = OFFalse;
     if (modalityLUTData.getLength() > 0)
@@ -697,20 +592,12 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
       if (modalityLUTDescriptor.getLength() == 0)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: modalityLUTData present but modalityLUTDescriptor absent or empty in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("modalityLUTData present but modalityLUTDescriptor absent or empty in presentation state");
       }
       else if (modalityLUTDescriptor.getVM() != 3)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: modalityLUTData present but modalityLUTDescriptor VM != 3 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("modalityLUTData present but modalityLUTDescriptor VM != 3 in presentation state");
       }
 
     } else useModalityLUT = OFFalse;
@@ -718,11 +605,7 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
     if (useModalityRescale && useModalityLUT)
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: both modality rescale and LUT present in presentation state" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("both modality rescale and LUT present in presentation state");
     }
 
   } /* end result==EC_Normal */
@@ -747,11 +630,7 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
       else
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: unknown shutter type '" << aString << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("unknown shutter type '" << aString << "'");
       }
     }
 
@@ -760,38 +639,22 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
       if ((shutterLeftVerticalEdge.getLength() == 0)||(shutterLeftVerticalEdge.getVM() != 1))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rectangular shutter used but shutterLeftVerticalEdge absent or VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rectangular shutter used but shutterLeftVerticalEdge absent or VM != 1 in presentation state");
       }
       if ((shutterRightVerticalEdge.getLength() == 0)||(shutterRightVerticalEdge.getVM() != 1))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rectangular shutter used but shutterRightVerticalEdge absent or VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rectangular shutter used but shutterRightVerticalEdge absent or VM != 1 in presentation state");
       }
       if ((shutterUpperHorizontalEdge.getLength() == 0)||(shutterUpperHorizontalEdge.getVM() != 1))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rectangular shutter used but shutterUpperHorizontalEdge absent or VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rectangular shutter used but shutterUpperHorizontalEdge absent or VM != 1 in presentation state");
       }
       if ((shutterLowerHorizontalEdge.getLength() == 0)||(shutterLowerHorizontalEdge.getVM() != 1))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: rectangular shutter used but shutterLowerHorizontalEdge absent or VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("rectangular shutter used but shutterLowerHorizontalEdge absent or VM != 1 in presentation state");
       }
     }
     if (useShutterCircular)
@@ -799,20 +662,12 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
       if ((centerOfCircularShutter.getLength() == 0)||(centerOfCircularShutter.getVM() != 2))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: circular shutter used but centerOfCircularShutter absent or VM != 2 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("circular shutter used but centerOfCircularShutter absent or VM != 2 in presentation state");
       }
       if ((radiusOfCircularShutter.getLength() == 0)||(radiusOfCircularShutter.getVM() != 1))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: circular shutter used but radiusOfCircularShutter absent or VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("circular shutter used but radiusOfCircularShutter absent or VM != 1 in presentation state");
       }
     }
     if (useShutterPolygonal)
@@ -823,11 +678,7 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
           ((verticesOfThePolygonalShutter.getVM() % 2) != 0))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: polygonal shutter used but verticesOfThePolygonalShutter absent or VM != 2-2n in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("polygonal shutter used but verticesOfThePolygonalShutter absent or VM != 2-2n in presentation state");
       }
     }
     if (useShutterBitmap)
@@ -835,11 +686,7 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
       if ((shutterOverlayGroup.getLength() == 0)||(shutterOverlayGroup.getVM() != 1))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: bitmap shutter used but shutterOverlayGroup absent or VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("bitmap shutter used but shutterOverlayGroup absent or VM != 1 in presentation state");
       }
     }
     if (useShutterRectangular || useShutterCircular || useShutterPolygonal || useShutterBitmap)
@@ -847,22 +694,14 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
       if ((shutterPresentationValue.getLength() == 0)||(shutterPresentationValue.getVM() != 1))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: shutter used but shutterPresentationValue absent or VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("shutter used but shutterPresentationValue absent or VM != 1 in presentation state");
       }
     }
     /* we can either have rect/circ/poly shutter or bitmap shutter but not both */
     if (useShutterBitmap && (useShutterRectangular || useShutterCircular || useShutterPolygonal))
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: both bitmap and rect/circ/poly shutter specified in presentation state" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("both bitmap and rect/circ/poly shutter specified in presentation state");
     }
   }
 
@@ -876,19 +715,11 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
       if (!overlayList.haveOverlayGroup(shuttergroup))
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: bitmap shutter specified but referenced overlay group missing in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("bitmap shutter specified but referenced overlay group missing in presentation state");
       }
     } else {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: wrong overlay group specified for bitmap shutter in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("wrong overlay group specified for bitmap shutter in presentation state");
     }
   }
 
@@ -908,21 +739,13 @@ OFCondition DcmPresentationState::read(DcmItem &dset)
   if (EC_Normal == dset.search(DCM_MaskSubtractionSequence, stack, ESM_fromHere, OFFalse))
   {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: mask module present in presentation state, but unsupported" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("mask module present in presentation state, but unsupported");
   }
   stack.clear();
   if (EC_Normal == dset.search(DCM_RecommendedViewingMode, stack, ESM_fromHere, OFFalse))
   {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: mask module present in presentation state, but unsupported" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("mask module present in presentation state, but unsupported");
   }
 
   return result;
@@ -1035,7 +858,7 @@ OFCondition DcmPresentationState::createFromImage(
   READ_FROM_DATASET(DcmUniqueIdentifier, studyInstanceUID)
   READ_FROM_DATASET(DcmDate, studyDate)
   READ_FROM_DATASET(DcmTime, studyTime)
-  READ_FROM_DATASET(DcmPersonName, referringPhysiciansName)
+  READ_FROM_DATASET(DcmPersonName, referringPhysicianName)
   READ_FROM_DATASET(DcmShortString, studyID)
   READ_FROM_DATASET(DcmShortString, accessionNumber)
   READ_FROM_DATASET(DcmLongString, manufacturer)
@@ -1126,11 +949,7 @@ OFCondition DcmPresentationState::createFromImage(
     else if ((aString != "MONOCHROME2")&&(aString != "MONOCHROME 2"))
     {
       result = EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: Wrong image photometric interpretation - not MONOCHROME1/2" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("Wrong image photometric interpretation - not MONOCHROME1/2");
     }
   }
 
@@ -1176,11 +995,7 @@ OFCondition DcmPresentationState::createFromImage(
       if (aString == "INVERSE") presentationLUT.setType(DVPSP_inverse);
       if (aString == "LIN OD")
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Warning LIN OD found in prsentation state; set to IDENTITY" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("LIN OD found in presentation state; set to IDENTITY");
         presentationLUT.setType(DVPSP_identity);
       }
     }
@@ -1204,7 +1019,7 @@ OFCondition DcmPresentationState::createFromImage(
     // of the Modality LUT transformation is "inversersed" and, therefore,
     // must not be copied into the presentation state
     if ((ofsopclassUID == UID_XRayAngiographicImageStorage) ||
-        (ofsopclassUID == UID_XRayFluoroscopyImageStorage) ||
+        (ofsopclassUID == UID_XRayRadiofluoroscopicImageStorage) ||
         (ofsopclassUID == UID_RETIRED_XRayAngiographicBiPlaneImageStorage))
     {
       modalityLUTData.clear();
@@ -1337,7 +1152,7 @@ OFCondition DcmPresentationState::write(DcmItem &dset, OFBool replaceSOPInstance
   ADD_TO_DATASET(DcmUniqueIdentifier, studyInstanceUID)
   ADD_TO_DATASET(DcmDate, studyDate)
   ADD_TO_DATASET(DcmTime, studyTime)
-  ADD_TO_DATASET(DcmPersonName, referringPhysiciansName)
+  ADD_TO_DATASET(DcmPersonName, referringPhysicianName)
   ADD_TO_DATASET(DcmShortString, studyID)
   ADD_TO_DATASET(DcmShortString, accessionNumber)
   ADD_TO_DATASET(DcmCodeString, modality)
@@ -1505,11 +1320,7 @@ OFCondition DcmPresentationState::addImageReference(
   studyInstanceUID.getOFString(study,0);
   if (study != studyUID)
   {
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot add reference to image with different Study Instance UID." << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot add reference to image with different Study Instance UID.");
     return EC_IllegalCall;
   }
   return referencedSeriesList.addImageReference(seriesUID, sopclassUID, instanceUID, frames, aetitle, filesetID, filesetUID);
@@ -2144,24 +1955,35 @@ OFCondition DcmPresentationState::moveOverlay(size_t old_layer, size_t idx, size
   return activationLayerList.setActivation(group, lname);
 }
 
-void DcmPresentationState::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-  displayedAreaSelectionList.setLog(logstream, verbMode, dbgMode);
-  presentationLUT.setLog(logstream, verbMode, dbgMode);
-  referencedSeriesList.setLog(logstream, verbMode, dbgMode);
-  overlayList.setLog(logstream, verbMode, dbgMode);
-  activationLayerList.setLog(logstream, verbMode, dbgMode);
-  graphicAnnotationList.setLog(logstream, verbMode, dbgMode);
-  graphicLayerList.setLog(logstream, verbMode, dbgMode);
-  softcopyVOIList.setLog(logstream, verbMode, dbgMode);
-}
-
 
 /*
  *  $Log: dcmpstat.cc,v $
+ *  Revision 1.15  2010-10-14 13:14:31  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.14  2010-09-24 13:32:58  joergr
+ *  Compared names of SOP Class UIDs with 2009 edition of the DICOM standard. The
+ *  resulting name changes are mainly caused by the fact that the corresponding
+ *  SOP Class is now retired.
+ *
+ *  Revision 1.13  2010-08-09 13:21:56  joergr
+ *  Updated data dictionary to 2009 edition of the DICOM standard. From now on,
+ *  the official "keyword" is used for the attribute name which results in a
+ *  number of minor changes (e.g. "PatientsName" is now called "PatientName").
+ *
+ *  Revision 1.12  2010-04-29 10:36:20  joergr
+ *  Fixed typo in log message.
+ *
+ *  Revision 1.11  2009-12-15 14:50:49  uli
+ *  Fixes some issues with --logfile and the config's log options.
+ *
+ *  Revision 1.10  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.9  2006-08-15 16:57:01  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.8  2005/12/08 15:46:14  meichel
  *  Changed include path schema for all DCMTK header files
  *
