@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSAnnotationContent
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:16 $
- *  CVS/RCS Revision: $Revision: 1.9 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:31 $
+ *  CVS/RCS Revision: $Revision: 1.13 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,7 +28,8 @@
  */
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
-#include "dcmtk/ofstd/ofstring.h"
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcitem.h"
 #include "dcmtk/dcmpstat/dvpsab.h"
 #include "dcmtk/dcmpstat/dvpsdef.h"     /* for constants and macros */
 
@@ -43,9 +40,6 @@ DVPSAnnotationContent::DVPSAnnotationContent()
 : sOPInstanceUID(DCM_SOPInstanceUID)
 , annotationPosition(DCM_AnnotationPosition)
 , textString(DCM_TextString)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -53,9 +47,6 @@ DVPSAnnotationContent::DVPSAnnotationContent(const DVPSAnnotationContent& copy)
 : sOPInstanceUID(copy.sOPInstanceUID)
 , annotationPosition(copy.annotationPosition)
 , textString(copy.textString)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -103,29 +94,17 @@ OFCondition DVPSAnnotationContent::read(DcmItem &dset)
     if ((sOPInstanceUID.getLength() == 0)||(sOPInstanceUID.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: SOPInstanceUID missing or incorrect in Stored Print Annotation" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("SOPInstanceUID missing or incorrect in Stored Print Annotation");
     }
     if ((annotationPosition.getLength() == 0)||(annotationPosition.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: AnnotationPosition missing or incorrect in Stored Print Annotation" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("AnnotationPosition missing or incorrect in Stored Print Annotation");
     }
     if ((textString.getLength() == 0)||(textString.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: TextString missing or incorrect in Stored Print Annotation" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("TextString missing or incorrect in Stored Print Annotation");
     }
   }
 
@@ -141,29 +120,17 @@ OFCondition DVPSAnnotationContent::write(DcmItem &dset)
   if (sOPInstanceUID.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Annotation: SOPInstanceUID empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Annotation: SOPInstanceUID empty");
   }
   if (annotationPosition.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Annotation: AnnotationPosition empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Annotation: AnnotationPosition empty");
   }
   if (textString.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Annotation: TextString empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Annotation: TextString empty");
   }
 
   ADD_TO_DATASET(DcmUniqueIdentifier, sOPInstanceUID)
@@ -199,15 +166,22 @@ const char *DVPSAnnotationContent::getSOPInstanceUID()
   if (EC_Normal == sOPInstanceUID.getString(c)) return c; else return NULL;
 }
 
-void DVPSAnnotationContent::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 /*
  *  $Log: dvpsab.cc,v $
+ *  Revision 1.13  2010-10-14 13:14:31  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.12  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.11  2009-09-30 10:42:38  uli
+ *  Make dcmpstat's include headers self-sufficient by including all
+ *  needed headers directly and stop using dctk.h
+ *
+ *  Revision 1.10  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.9  2005/12/08 15:46:16  meichel
  *  Changed include path schema for all DCMTK header files
  *
