@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSAnnotationContent_PList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:17 $
- *  CVS/RCS Revision: $Revision: 1.11 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:31 $
+ *  CVS/RCS Revision: $Revision: 1.15 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,6 +28,7 @@
  */
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/dcmdata/dcdeftag.h"
 #include "dcmtk/dcmpstat/dvpsabl.h"
 #include "dcmtk/dcmpstat/dvpsab.h"      /* for DVPSAnnotationContent */
 #include "dcmtk/dcmpstat/dvpshlp.h"     /* for class DVPSHelper */
@@ -40,17 +37,11 @@
 
 DVPSAnnotationContent_PList::DVPSAnnotationContent_PList()
 : list_()
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
 DVPSAnnotationContent_PList::DVPSAnnotationContent_PList(const DVPSAnnotationContent_PList &arg)
 : list_()
-, logstream(arg.logstream)
-, verboseMode(arg.verboseMode)
-, debugMode(arg.debugMode)
 {
   OFListConstIterator(DVPSAnnotationContent *) first = arg.list_.begin();
   OFListConstIterator(DVPSAnnotationContent *) last = arg.list_.end();
@@ -85,7 +76,7 @@ OFCondition DVPSAnnotationContent_PList::read(DcmItem &dset)
   DcmSequenceOfItems *dseq=NULL;
   DcmItem *ditem=NULL;
 
-  if (EC_Normal == dset.search(DCM_AnnotationContentSequence, stack, ESM_fromHere, OFFalse))
+  if (EC_Normal == dset.search(DCM_RETIRED_AnnotationContentSequence, stack, ESM_fromHere, OFFalse))
   {
     dseq=(DcmSequenceOfItems *)stack.top();
     if (dseq)
@@ -97,7 +88,6 @@ OFCondition DVPSAnnotationContent_PList::read(DcmItem &dset)
         newAnnotation = new DVPSAnnotationContent();
         if (newAnnotation && ditem)
         {
-          newAnnotation->setLog(logstream, verboseMode, debugMode);
           result = newAnnotation->read(*ditem);
           list_.push_back(newAnnotation);
         } else result = EC_MemoryExhausted;
@@ -116,7 +106,7 @@ OFCondition DVPSAnnotationContent_PList::write(DcmItem &dset)
   DcmSequenceOfItems *dseq=NULL;
   DcmItem *ditem=NULL;
 
-  dseq = new DcmSequenceOfItems(DCM_AnnotationContentSequence);
+  dseq = new DcmSequenceOfItems(DCM_RETIRED_AnnotationContentSequence);
   if (dseq)
   {
     OFListIterator(DVPSAnnotationContent *) first = list_.begin();
@@ -149,7 +139,6 @@ OFCondition DVPSAnnotationContent_PList::addAnnotationBox(
   DVPSAnnotationContent *newAnnotation = new DVPSAnnotationContent();
   if (newAnnotation)
   {
-    newAnnotation->setLog(logstream, verboseMode, debugMode);
     result = newAnnotation->setContent(instanceuid, text, position);
     if (EC_Normal == result) list_.push_back(newAnnotation); else delete newAnnotation;
   } else result = EC_MemoryExhausted;
@@ -217,20 +206,6 @@ OFCondition DVPSAnnotationContent_PList::prepareBasicAnnotationBox(size_t idx, D
   return EC_IllegalCall;
 }
 
-void DVPSAnnotationContent_PList::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-  OFListIterator(DVPSAnnotationContent *) first = list_.begin();
-  OFListIterator(DVPSAnnotationContent *) last = list_.end();
-  while (first != last)
-  {
-    (*first)->setLog(logstream, verbMode, dbgMode);
-    ++first;
-  }
-}
-
 void DVPSAnnotationContent_PList::clearAnnotationSOPInstanceUIDs()
 {
   OFListIterator(DVPSAnnotationContent *) first = list_.begin();
@@ -244,6 +219,19 @@ void DVPSAnnotationContent_PList::clearAnnotationSOPInstanceUIDs()
 
 /*
  *  $Log: dvpsabl.cc,v $
+ *  Revision 1.15  2010-10-14 13:14:31  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.14  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.13  2009-09-30 10:42:38  uli
+ *  Make dcmpstat's include headers self-sufficient by including all
+ *  needed headers directly and stop using dctk.h
+ *
+ *  Revision 1.12  2008-04-30 12:38:43  meichel
+ *  Fixed compile errors due to changes in attribute tag names
+ *
  *  Revision 1.11  2005/12/08 15:46:17  meichel
  *  Changed include path schema for all DCMTK header files
  *
