@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSOverlayCurveActivationLayer_PList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:19 $
- *  CVS/RCS Revision: $Revision: 1.14 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:31 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -44,17 +40,11 @@
 
 DVPSOverlayCurveActivationLayer_PList::DVPSOverlayCurveActivationLayer_PList()
 : list_()
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
 DVPSOverlayCurveActivationLayer_PList::DVPSOverlayCurveActivationLayer_PList(const DVPSOverlayCurveActivationLayer_PList &arg)
 : list_()
-, logstream(arg.logstream)
-, verboseMode(arg.verboseMode)
-, debugMode(arg.debugMode)
 {
   OFListConstIterator(DVPSOverlayCurveActivationLayer *) first = arg.list_.begin();
   OFListConstIterator(DVPSOverlayCurveActivationLayer *) last = arg.list_.end();
@@ -85,7 +75,7 @@ OFCondition DVPSOverlayCurveActivationLayer_PList::read(DcmItem &dset)
 {
   OFCondition result = EC_Normal;
   DcmStack stack;
-  DcmTagKey key(DCM_CurveActivationLayer);
+  DcmTagKey key(DCM_RETIRED_CurveActivationLayer);
   DVPSOverlayCurveActivationLayer *newLayer = NULL;
 
   Uint16 i = 0x5000;
@@ -100,7 +90,6 @@ OFCondition DVPSOverlayCurveActivationLayer_PList::read(DcmItem &dset)
         newLayer = new DVPSOverlayCurveActivationLayer();
         if (newLayer)
         {
-          newLayer->setLog(logstream, verboseMode, debugMode);
           result = newLayer->read(dset,i);
           list_.push_back(newLayer);
         } else result = EC_MemoryExhausted;
@@ -151,11 +140,11 @@ OFCondition DVPSOverlayCurveActivationLayer_PList::createFromImage(
   DcmTagKey overlayBitsAllocated(DCM_OverlayBitsAllocated);
   DcmTagKey overlayBitPosition(DCM_OverlayBitPosition);
 
-  DcmTagKey curveDimensions(DCM_CurveDimensions);
-  DcmTagKey numberOfPoints(DCM_NumberOfPoints);
-  DcmTagKey typeOfData(DCM_TypeOfData);
-  DcmTagKey dataValueRepresentation(DCM_DataValueRepresentation);
-  DcmTagKey curveData(DCM_CurveData);
+  DcmTagKey curveDimensions(DCM_RETIRED_CurveDimensions);
+  DcmTagKey numberOfPoints(DCM_RETIRED_NumberOfPoints);
+  DcmTagKey typeOfData(DCM_RETIRED_TypeOfData);
+  DcmTagKey dataValueRepresentation(DCM_RETIRED_DataValueRepresentation);
+  DcmTagKey curveData(DCM_RETIRED_CurveData);
 
   OFBool haveOverlays = OFFalse;
   /* first we handle overlays */
@@ -259,8 +248,8 @@ OFCondition DVPSOverlayCurveActivationLayer_PList::createFromImage(
       if (found)
       {
         /* read the curve dimensions and curve type from the dataset */
-        DcmUnsignedShort curveDimensionsValue(DCM_CurveDimensions);
-        DcmCodeString typeOfDataValue(DCM_TypeOfData);
+        DcmUnsignedShort curveDimensionsValue(DCM_RETIRED_CurveDimensions);
+        DcmCodeString typeOfDataValue(DCM_RETIRED_TypeOfData);
         curveDimensionsValue.setGTag(group);
         typeOfDataValue.setGTag(group);
         READ_FROM_DATASET(DcmUnsignedShort, curveDimensionsValue)
@@ -472,23 +461,18 @@ Uint16 DVPSOverlayCurveActivationLayer_PList::getActivationGroup(const char *lay
   return 0;
 }
 
-void DVPSOverlayCurveActivationLayer_PList::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-  OFListIterator(DVPSOverlayCurveActivationLayer *) first = list_.begin();
-  OFListIterator(DVPSOverlayCurveActivationLayer *) last = list_.end();
-  while (first != last)
-  {
-    (*first)->setLog(logstream, verbMode, dbgMode);
-    ++first;
-  }
-}
-
 
 /*
  *  $Log: dvpsall.cc,v $
+ *  Revision 1.17  2010-10-14 13:14:31  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.16  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.15  2008-04-30 12:38:43  meichel
+ *  Fixed compile errors due to changes in attribute tag names
+ *
  *  Revision 1.14  2005/12/08 15:46:19  meichel
  *  Changed include path schema for all DCMTK header files
  *
