@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSCurve
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:21 $
- *  CVS/RCS Revision: $Revision: 1.6 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.8 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -45,13 +41,9 @@ DVPSCurve::DVPSCurve()
 , curveLabel()
 , axisUnitsX()
 , axisUnitsY()
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
-  
 DVPSCurve::DVPSCurve(const DVPSCurve& copy)
 : curveGroup(copy.curveGroup)
 , numberOfPoints(copy.numberOfPoints)
@@ -61,9 +53,6 @@ DVPSCurve::DVPSCurve(const DVPSCurve& copy)
 , curveLabel(copy.curveLabel)
 , axisUnitsX(copy.axisUnitsX)
 , axisUnitsY(copy.axisUnitsY)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
   if (copy.curveData)
   {
@@ -360,17 +349,15 @@ OFCondition DVPSCurve::getPoint(size_t idx, double& x, double& y)
   return EC_Normal;
 }
 
-void DVPSCurve::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
-
 /*
  *  $Log: dvpscu.cc,v $
- *  Revision 1.6  2005/12/08 15:46:21  meichel
+ *  Revision 1.8  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.7  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.6  2005-12-08 15:46:21  meichel
  *  Changed include path schema for all DCMTK header files
  *
  *  Revision 1.5  2001/09/26 15:36:23  meichel
