@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSFilmSession
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:25 $
- *  CVS/RCS Revision: $Revision: 1.14 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -76,9 +72,6 @@ DVPSFilmSession::DVPSFilmSession(Uint16 illumin, Uint16 reflection)
 , reflectedAmbientLight(DCM_ReflectedAmbientLight)
 , referencedPresentationLUTInstanceUID(DCM_ReferencedSOPInstanceUID)
 , referencedPresentationLUTAlignment(DVPSK_other)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
   illumination.putUint16(illumin, 0);
   reflectedAmbientLight.putUint16(reflection, 0);
@@ -96,9 +89,6 @@ DVPSFilmSession::DVPSFilmSession(const DVPSFilmSession& copy)
 , reflectedAmbientLight(copy.reflectedAmbientLight)
 , referencedPresentationLUTInstanceUID(copy.referencedPresentationLUTInstanceUID)
 , referencedPresentationLUTAlignment(copy.referencedPresentationLUTAlignment)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -139,11 +129,7 @@ OFBool DVPSFilmSession::printSCPCreate(
       {
         numberOfCopies.getString(numCopiesString);
         if (numCopiesString==NULL) numCopiesString = (char *)"";
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot create Basic Film Session: illegal number of copies: '" << numCopiesString << "'" << endl; 
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot create Basic Film Session: illegal number of copies: '" << numCopiesString << "'");
         rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
@@ -161,11 +147,7 @@ OFBool DVPSFilmSession::printSCPCreate(
       printPriority.getOFString(aString, 0, OFTrue);
       if ((aString != "HIGH")&&(aString != "MED")&&(aString != "LOW"))
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot create Basic Film Session: illegal print priority: '" << aString.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot create Basic Film Session: illegal print priority: '" << aString.c_str() << "'");
         rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
@@ -204,11 +186,7 @@ OFBool DVPSFilmSession::printSCPCreate(
       }
       if (! found)
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot create Basic Film Session: illegal medium type: '" << theMedium.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot create Basic Film Session: illegal medium type: '" << theMedium.c_str() << "'");
         rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
@@ -247,11 +225,7 @@ OFBool DVPSFilmSession::printSCPCreate(
       }
       if (! found)
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot create Basic Film Session: illegal film destination: '" << theDestination.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot create Basic Film Session: illegal film destination: '" << theDestination.c_str() << "'");
         rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
@@ -331,11 +305,7 @@ OFBool DVPSFilmSession::printSCPCreate(
              DVPSPresentationLUT *currentPLUT = globalPresentationLUTList.findPresentationLUT(aString.c_str());
              if (NULL == currentPLUT)
              {
-               if (verboseMode)
-               {
-                 logstream->lockCerr() << "cannot create Basic Film Session: presentation LUT reference cannot be resolved" << endl;
-                 logstream->unlockCerr();
-               }
+               DCMPSTAT_INFO("cannot create Basic Film Session: presentation LUT reference cannot be resolved");
                rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
                result = OFFalse;
              } else {
@@ -349,13 +319,8 @@ OFBool DVPSFilmSession::printSCPCreate(
                   refClassUID.getOFString(aString,0, OFTrue);
                   if (aString != UID_PresentationLUTSOPClass)
                   {
-                    if (verboseMode)
-                    {
-                      ostream &mycerr = logstream->lockCerr();
-                      mycerr << "cannot create Basic Film Session: referenced SOP class UID in referenced presentation LUT sequence incorrect:" << endl;
-                      (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-                      logstream->unlockCerr();            
-                    }
+                    DCMPSTAT_INFO("cannot create Basic Film Session: referenced SOP class UID in referenced presentation LUT sequence incorrect:\n"
+                        << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
                     rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
                     result = OFFalse;
                   } else {
@@ -363,30 +328,18 @@ OFBool DVPSFilmSession::printSCPCreate(
                     referencedPresentationLUTAlignment = currentPLUT->getAlignment();
                   }
                } else {
-                  if (verboseMode)
-                  {
-                    logstream->lockCerr() << "cannot create Basic Film Session: no referenced SOP class UID in referenced presentation LUT sequence" << endl;
-                    logstream->unlockCerr();
-                  }
+                  DCMPSTAT_INFO("cannot create Basic Film Session: no referenced SOP class UID in referenced presentation LUT sequence");
                   rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
                   result = OFFalse;
                }
              }
            } else {
-             if (verboseMode)
-             {
-               logstream->lockCerr() << "cannot create Basic Film Session: no referenced SOP instance UID in referenced presentation LUT sequence" << endl;
-               logstream->unlockCerr();
-             }
+             DCMPSTAT_INFO("cannot create Basic Film Session: no referenced SOP instance UID in referenced presentation LUT sequence");
              rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
              result = OFFalse;
            }
         } else {
-          if (verboseMode)
-          {
-            logstream->lockCerr() << "cannot create Basic Film Session: referenced presentation LUT sequence number of items != 1" << endl;
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot create Basic Film Session: referenced presentation LUT sequence number of items != 1");
           rsp.msg.NCreateRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
           result = OFFalse;
         }
@@ -413,26 +366,16 @@ OFBool DVPSFilmSession::printSCPCreate(
       else if (currentTag == DCM_OwnerID) /* OK */ ;
       else if (currentTag == DCM_MemoryAllocation)
       {
-        if (verboseMode)
-        {
-          ostream &mycerr = logstream->lockCerr();
-          mycerr << "warning while creating Basic Film Session: memory allocation not supported" << endl;
-          (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-          logstream->unlockCerr();
-        }
-      	if (rsp.msg.NCreateRSP.DimseStatus == 0) rsp.msg.NCreateRSP.DimseStatus = STATUS_N_PRINT_BFS_Warn_MemoryAllocation;
+        DCMPSTAT_INFO("warning while creating Basic Film Session: memory allocation not supported:\n"
+            << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
+        if (rsp.msg.NCreateRSP.DimseStatus == 0) rsp.msg.NCreateRSP.DimseStatus = STATUS_N_PRINT_BFS_Warn_MemoryAllocation;
       }
       else if (currentTag == DCM_Illumination)
       {
         if (! presentationLUTnegotiated)
         {
-          if (verboseMode)
-          {
-            ostream &mycerr = logstream->lockCerr();
-            mycerr << "cannot create Basic Film Session: illumination received:" << endl;
-            (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot create Basic Film Session: illumination received:\n"
+              << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
           rsp.msg.NCreateRSP.DimseStatus = STATUS_N_NoSuchAttribute;          
           result = OFFalse;
         }
@@ -441,13 +384,8 @@ OFBool DVPSFilmSession::printSCPCreate(
       {
         if (! presentationLUTnegotiated)
         {
-          if (verboseMode)
-          {
-            ostream &mycerr = logstream->lockCerr();
-            mycerr << "cannot create Basic Film Session: reflected ambient light received:" << endl;
-            (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot create Basic Film Session: reflected ambient light received:\n"
+              << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
           rsp.msg.NCreateRSP.DimseStatus = STATUS_N_NoSuchAttribute;          
           result = OFFalse;
         }
@@ -456,26 +394,16 @@ OFBool DVPSFilmSession::printSCPCreate(
       {
         if (! presentationLUTnegotiated)
         {
-          if (verboseMode)
-          {
-            ostream &mycerr = logstream->lockCerr();
-            mycerr << "cannot create Basic Film Session: referenced presentation LUT sequence received:" << endl;
-            (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot create Basic Film Session: referenced presentation LUT sequence received:\n"
+              << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
           rsp.msg.NCreateRSP.DimseStatus = STATUS_N_NoSuchAttribute;          
           result = OFFalse;
         }
       }
       else
       {
-        if (verboseMode)
-        {
-          ostream &mycerr = logstream->lockCerr();
-          mycerr << "cannot create Basic Film Session: unsupported attribute received:" << endl;
-          (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot create Basic Film Session: unsupported attribute received:\n"
+            << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
       	rsp.msg.NCreateRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       }
@@ -571,11 +499,7 @@ OFBool DVPSFilmSession::printSCPSet(
       {
         numberOfCopies.getString(numCopiesString);
         if (numCopiesString==NULL) numCopiesString = (char *)"";
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Film Session: illegal number of copies: '" << numCopiesString << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Film Session: illegal number of copies: '" << numCopiesString << "'");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       } else {
@@ -595,11 +519,7 @@ OFBool DVPSFilmSession::printSCPSet(
       printPriority.getOFString(aString, 0, OFTrue);
       if ((aString != "HIGH")&&(aString != "MED")&&(aString != "LOW"))
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Film Session: illegal print priority: '" << aString.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Film Session: illegal print priority: '" << aString.c_str() << "'");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       } else {
@@ -631,11 +551,7 @@ OFBool DVPSFilmSession::printSCPSet(
       }
       if (! found)
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Film Session: illegal medium type: '" << theMedium.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Film Session: illegal medium type: '" << theMedium.c_str() << "'");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       } else {
@@ -667,11 +583,7 @@ OFBool DVPSFilmSession::printSCPSet(
       }
       if (! found)
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Film Session: illegal film destination: '" << theDestination.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Film Session: illegal film destination: '" << theDestination.c_str() << "'");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       } else {
@@ -749,11 +661,7 @@ OFBool DVPSFilmSession::printSCPSet(
              DVPSPresentationLUT *currentPLUT = globalPresentationLUTList.findPresentationLUT(aString.c_str());
              if (NULL == currentPLUT)
              {
-               if (verboseMode)
-               {
-                 logstream->lockCerr() << "cannot update Basic Film Session: presentation LUT reference cannot be resolved" << endl;
-                 logstream->unlockCerr();
-               }
+               DCMPSTAT_INFO("cannot update Basic Film Session: presentation LUT reference cannot be resolved");
                rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
                result = OFFalse;
              } else {
@@ -767,13 +675,8 @@ OFBool DVPSFilmSession::printSCPSet(
                   refClassUID.getOFString(aString,0, OFTrue);
                   if (aString != UID_PresentationLUTSOPClass)
                   {
-                    if (verboseMode)
-                    {
-                      ostream &mycerr = logstream->lockCerr();
-                      mycerr << "cannot update Basic Film Session: referenced SOP class UID in referenced presentation LUT sequence incorrect:" << endl;
-                      (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-                      logstream->unlockCerr();
-                    }
+                    DCMPSTAT_INFO("cannot update Basic Film Session: referenced SOP class UID in referenced presentation LUT sequence incorrect:\n"
+                        << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
                     rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
                     result = OFFalse;
                   } else {
@@ -781,11 +684,7 @@ OFBool DVPSFilmSession::printSCPSet(
                     if ((cfg.getTargetPrinterPresentationLUTMatchRequired(cfgname)) &&
                         (! basicFilmBoxList.matchesPresentationLUT(referencedPresentationLUTAlignment)))
                     {
-                      if (verboseMode)
-                      {
-                        logstream->lockCerr() << "cannot update Basic Film Session: referenced presentation LUT number of entries does not match image bit depth." << endl;
-                        logstream->unlockCerr();
-                      }
+                      DCMPSTAT_INFO("cannot update Basic Film Session: referenced presentation LUT number of entries does not match image bit depth.");
                       rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
                       result = OFFalse;
                     } else {
@@ -800,30 +699,18 @@ OFBool DVPSFilmSession::printSCPSet(
                     }
                   }
                } else {
-                  if (verboseMode)
-                  {
-                    logstream->lockCerr() << "cannot update Basic Film Session: no referenced SOP class UID in referenced presentation LUT sequence" << endl;
-                    logstream->unlockCerr();
-                  }
+                  DCMPSTAT_INFO("cannot update Basic Film Session: no referenced SOP class UID in referenced presentation LUT sequence");
                   rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
                   result = OFFalse;
                }
              }
            } else {
-             if (verboseMode)
-             {
-               logstream->lockCerr() << "cannot update Basic Film Session: no referenced SOP instance UID in referenced presentation LUT sequence" << endl;
-               logstream->unlockCerr();
-             }
+             DCMPSTAT_INFO("cannot update Basic Film Session: no referenced SOP instance UID in referenced presentation LUT sequence");
              rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
              result = OFFalse;
            }
         } else {
-          if (verboseMode)
-          {
-            logstream->lockCerr() << "cannot update Basic Film Session: referenced presentation LUT sequence number of items != 1" << endl;
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot update Basic Film Session: referenced presentation LUT sequence number of items != 1");
           rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
           result = OFFalse;
         }
@@ -850,26 +737,16 @@ OFBool DVPSFilmSession::printSCPSet(
       else if (currentTag == DCM_OwnerID) /* OK */ ;
       else if (currentTag == DCM_MemoryAllocation)
       {
-        if (verboseMode)
-        {
-          ostream &mycerr = logstream->lockCerr();
-          mycerr << "warning while updating Basic Film Session: memory allocation not supported" << endl;
-          (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("warning while updating Basic Film Session: memory allocation not supported\n"
+            << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
       	if (rsp.msg.NSetRSP.DimseStatus == 0) rsp.msg.NSetRSP.DimseStatus = STATUS_N_PRINT_BFS_Warn_MemoryAllocation;
       }
       else if (currentTag == DCM_Illumination)
       {
         if (! presentationLUTnegotiated)
         {
-          if (verboseMode)
-          {
-            ostream &mycerr = logstream->lockCerr();
-            mycerr << "cannot update Basic Film Session: illumination received:" << endl;
-            (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot update Basic Film Session: illumination received:\n"
+              << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
           rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;          
           result = OFFalse;
         }
@@ -878,13 +755,8 @@ OFBool DVPSFilmSession::printSCPSet(
       {
         if (! presentationLUTnegotiated)
         {
-          if (verboseMode)
-          {
-            ostream &mycerr = logstream->lockCerr();
-            mycerr << "cannot update Basic Film Session: reflected ambient light received:" << endl;
-            (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-            logstream->unlockCerr();            
-          }
+          DCMPSTAT_INFO("cannot update Basic Film Session: reflected ambient light received:\n"
+              << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
           rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;          
           result = OFFalse;
         }
@@ -893,26 +765,16 @@ OFBool DVPSFilmSession::printSCPSet(
       {
         if (! presentationLUTnegotiated)
         {
-          if (verboseMode)
-          {
-            ostream &mycerr = logstream->lockCerr();
-            mycerr << "cannot update Basic Film Session: referenced presentation LUT sequence received:" << endl;
-            (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-            logstream->unlockCerr();            
-          }
+          DCMPSTAT_INFO("cannot update Basic Film Session: referenced presentation LUT sequence received:\n"
+              << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
           rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;          
           result = OFFalse;
         }
       }
       else
       {
-        if (verboseMode)
-        {
-          ostream &mycerr = logstream->lockCerr();
-          mycerr << "cannot update Basic Film Session: unsupported attribute received:" << endl;
-          (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Film Session: unsupported attribute received:\n"
+            << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
       	rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       }
@@ -937,13 +799,6 @@ OFBool DVPSFilmSession::printSCPSet(
   return result;
 }
 
-void DVPSFilmSession::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 OFCondition DVPSFilmSession::addPresentationLUTReference(DcmItem& dset)
 {
   DcmElement *delem=NULL;
@@ -987,6 +842,16 @@ void DVPSFilmSession::copyPresentationLUTSettings(DVPSStoredPrint& sp)
 
 /*
  *  $Log: dvpsfs.cc,v $
+ *  Revision 1.17  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.16  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.15  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.14  2005/12/08 15:46:25  meichel
  *  Changed include path schema for all DCMTK header files
  *
