@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSGraphicObject
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:30 $
- *  CVS/RCS Revision: $Revision: 1.11 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.14 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -44,9 +40,6 @@ DVPSGraphicObject::DVPSGraphicObject()
 , graphicData(DCM_GraphicData)
 , graphicType(DCM_GraphicType)
 , graphicFilled(DCM_GraphicFilled)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -56,9 +49,6 @@ DVPSGraphicObject::DVPSGraphicObject(const DVPSGraphicObject& copy)
 , graphicData(copy.graphicData)
 , graphicType(copy.graphicType)
 , graphicFilled(copy.graphicFilled)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -84,108 +74,64 @@ OFCondition DVPSGraphicObject::read(DcmItem &dset)
   if (graphicAnnotationUnits.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicAnnotationUnits absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicAnnotationUnits absent or empty");
   }
   else if (graphicAnnotationUnits.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicAnnotationUnits VM != 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicAnnotationUnits VM != 1");
   }
 
   if (graphicDimensions.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicDimensions VM != 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicDimensions VM != 1");
   } else {
     Uint16 dimension=0;
     if ((EC_Normal != graphicDimensions.getUint16(dimension,0))||(dimension != 2))
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicDimensions != 2" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicDimensions != 2");
     }
   }
   
   if (numberOfGraphicPoints.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with numberOfGraphicPoints absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with numberOfGraphicPoints absent or empty");
   }
   else if (numberOfGraphicPoints.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with numberOfGraphicPoints VM != 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with numberOfGraphicPoints VM != 1");
   }
   
   if (graphicData.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicData absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicData absent or empty");
   }
   else if (graphicData.getVM() < 2)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicData VM < 2" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicData VM < 2");
   }
   
   if (graphicType.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicType absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicType absent or empty");
   }
   else if (graphicType.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicType VM != 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicType VM != 1");
   }
   
   if ((graphicFilled.getLength() > 0)&&(graphicFilled.getVM() != 1))
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a graphic object SQ item with graphicFilled present but VM != 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a graphic object SQ item with graphicFilled present but VM != 1");
   }
   
   return result;
@@ -319,16 +265,19 @@ OFCondition DVPSGraphicObject::setFilled(OFBool filled)
   return result;
 }
 
-void DVPSGraphicObject::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 
 /*
  *  $Log: dvpsgr.cc,v $
+ *  Revision 1.14  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.13  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.12  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.11  2005/12/08 15:46:30  meichel
  *  Changed include path schema for all DCMTK header files
  *
