@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmpstat
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: DVPSHelper
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:32 $
- *  CVS/RCS Revision: $Revision: 1.14 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.19 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -33,9 +29,9 @@
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 #include "dcmtk/dcmpstat/dvpshlp.h"
+#include "dcmtk/dcmpstat/dvpsdef.h"
 #include "dcmtk/dcmnet/dcompat.h"     /* compatability routines */
-#include "dcmtk/dcmdata/dcvrda.h"
-#include "dcmtk/dcmdata/dcvrtm.h"
+#include "dcmtk/dcmdata/dctk.h"
 
 #define INCLUDE_CSTDIO
 #define INCLUDE_CERRNO
@@ -139,7 +135,7 @@ OFCondition DVPSHelper::putUint16Value(DcmItem *item, DcmTagKey tag, Uint16 valu
     return result;
 }
 
-void DVPSHelper::cleanChildren(OFConsole *logconsole)
+void DVPSHelper::cleanChildren()
 {
 #ifdef HAVE_WAITPID
     int stat_loc;
@@ -159,21 +155,18 @@ void DVPSHelper::cleanChildren(OFConsole *logconsole)
     while (child > 0)
     {
 #ifdef HAVE_WAITPID
-    child = (int)(waitpid(-1, &stat_loc, options));
+      child = (int)(waitpid(-1, &stat_loc, options));
 #elif defined(HAVE_WAIT3)
-    child = wait3(&status, options, &rusage);
+      child = wait3(&status, options, &rusage);
 #endif
-        if (child < 0)
+      if (child < 0)
+      {
+        if ((errno != ECHILD) && (errno != 0))
         {
-          if ((errno != ECHILD) && (errno != 0))
-          {
-            if (logconsole)
-            {
-              logconsole->lockCerr() << "wait for child failed: " << strerror(errno) << endl;
-              logconsole->unlockCerr();
-            }
-          }
+          char buf[256];
+          DCMPSTAT_ERROR("wait for child failed: " << OFStandard::strerror(errno, buf, sizeof(buf)));
         }
+      }
     }
 #endif
 }
@@ -237,6 +230,24 @@ OFCondition DVPSHelper::addReferencedUIDItem(DcmSequenceOfItems& seq, const char
 /*
  *  CVS/RCS Log:
  *  $Log: dvpshlp.cc,v $
+ *  Revision 1.19  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.18  2010-06-03 10:33:00  joergr
+ *  Replaced calls to strerror() by new helper function OFStandard::strerror()
+ *  which results in using the thread safe version of strerror() if available.
+ *
+ *  Revision 1.17  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.16  2009-09-30 10:42:38  uli
+ *  Make dcmpstat's include headers self-sufficient by including all
+ *  needed headers directly and stop using dctk.h
+ *
+ *  Revision 1.15  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.14  2005/12/08 15:46:32  meichel
  *  Changed include path schema for all DCMTK header files
  *
