@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSImageBoxContent
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:33 $
- *  CVS/RCS Revision: $Revision: 1.33 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.40 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -45,7 +41,7 @@
 
 DVPSImageBoxContent::DVPSImageBoxContent()
 : sOPInstanceUID(DCM_SOPInstanceUID)
-, imageBoxPosition(DCM_ImagePosition)
+, imageBoxPosition(DCM_ImageBoxPosition)
 , polarity(DCM_Polarity)
 , magnificationType(DCM_MagnificationType)
 , configurationInformation(DCM_ConfigurationInformation)
@@ -61,9 +57,6 @@ DVPSImageBoxContent::DVPSImageBoxContent()
 , patientID(DCM_PatientID)
 , referencedPresentationLUTInstanceUID(DCM_ReferencedSOPInstanceUID)
 , imageDepth(DVPSN_undefined)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -85,9 +78,6 @@ DVPSImageBoxContent::DVPSImageBoxContent(const DVPSImageBoxContent& copy)
 , patientID(copy.patientID)
 , referencedPresentationLUTInstanceUID(copy.referencedPresentationLUTInstanceUID)
 , imageDepth(copy.imageDepth)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -188,11 +178,7 @@ OFCondition DVPSImageBoxContent::read(DcmItem &dset, DVPSPresentationLUT_PList&
          READ_FROM_DATASET2(DcmLongString, patientID)
       } else {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: found ReferencedImageSequence in Stored Print Image Box with number of items != 1" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("found ReferencedImageSequence in Stored Print Image Box with number of items != 1");
       }
     }
   }
@@ -216,20 +202,12 @@ OFCondition DVPSImageBoxContent::read(DcmItem &dset, DVPSPresentationLUT_PList&
            if (NULL == presentationLUTList.findPresentationLUT(aString.c_str()))
            {
              result=EC_IllegalCall;
-             if (verboseMode)
-             {
-               logstream->lockCerr() << "Error: ImageBoxContentSequence presentation LUT reference cannot be resolved" << endl;
-               logstream->unlockCerr();
-             }
+             DCMPSTAT_INFO("ImageBoxContentSequence presentation LUT reference cannot be resolved");
            }
          }
       } else {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: found ImageBoxContentSequence in Stored Print with ReferencedPresentationLUTSequence number of items != 1" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("found ImageBoxContentSequence in Stored Print with ReferencedPresentationLUTSequence number of items != 1");
       }
     }
   }
@@ -242,11 +220,7 @@ OFCondition DVPSImageBoxContent::read(DcmItem &dset, DVPSPresentationLUT_PList&
     if (EC_Normal == dset.search(DCM_RETIRED_ReferencedImageOverlayBoxSequence, stack, ESM_fromHere, OFFalse))
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: Stored Print: retired ReferencedImageOverlayBoxSequence not supported" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("Stored Print: retired ReferencedImageOverlayBoxSequence not supported");
 
     }
   }
@@ -258,74 +232,42 @@ OFCondition DVPSImageBoxContent::read(DcmItem &dset, DVPSPresentationLUT_PList&
     if ((sOPInstanceUID.getLength() == 0)||(sOPInstanceUID.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: SOPInstanceUID missing or incorrect in Stored Print Image Box" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("SOPInstanceUID missing or incorrect in Stored Print Image Box");
     }
     if ((imageBoxPosition.getLength() == 0)||(imageBoxPosition.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: ImageBoxPosition missing or incorrect in Stored Print Image Box" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("ImageBoxPosition missing or incorrect in Stored Print Image Box");
     }
     if (retrieveAETitle.getLength() == 0)
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: RetrieveAETitle missing in Stored Print Image Box" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("RetrieveAETitle missing in Stored Print Image Box");
     }
     if ((referencedSOPClassUID.getLength() == 0)||(referencedSOPClassUID.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: ReferencedSOPClassUID missing or incorrect in Stored Print Image Box" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("ReferencedSOPClassUID missing or incorrect in Stored Print Image Box");
     }
     if ((referencedSOPInstanceUID.getLength() == 0)||(referencedSOPInstanceUID.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: ReferencedSOPInstanceUID missing or incorrect in Stored Print Image Box" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("ReferencedSOPInstanceUID missing or incorrect in Stored Print Image Box");
     }
     if ((studyInstanceUID.getLength() == 0)||(studyInstanceUID.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: StudyInstanceUID missing or incorrect in Stored Print Image Box" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("StudyInstanceUID missing or incorrect in Stored Print Image Box");
     }
     if ((seriesInstanceUID.getLength() == 0)||(seriesInstanceUID.getVM() != 1))
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: SeriesInstanceUID missing or incorrect in Stored Print Image Box" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("SeriesInstanceUID missing or incorrect in Stored Print Image Box");
     }
     if (referencedFrameNumber.getVM() > 1)
     {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: ReferencedFrameNumber VM>1 in Stored Print Image Box" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("ReferencedFrameNumber VM>1 in Stored Print Image Box");
     }
   }
 
@@ -343,65 +285,37 @@ OFCondition DVPSImageBoxContent::write(DcmItem &dset, OFBool writeRequestedImage
   if (sOPInstanceUID.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Image Box: SOPInstanceUID empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Image Box: SOPInstanceUID empty");
   }
   if (imageBoxPosition.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Image Box: ImageBoxPosition empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Image Box: ImageBoxPosition empty");
   }
   if (retrieveAETitle.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Image Box: RetrieveAETitle empty" << endl;
-      logstream->unlockCerr();
-    }    
+    DCMPSTAT_INFO("cannot write Stored Print Image Box: RetrieveAETitle empty");
   }
   if (referencedSOPClassUID.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Image Box: ReferencedSOPClassUID empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Image Box: ReferencedSOPClassUID empty");
   }
   if (referencedSOPInstanceUID.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Image Box: ReferencedSOPInstanceUID empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Image Box: ReferencedSOPInstanceUID empty");
   }
   if (studyInstanceUID.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Image Box: StudyInstanceUID empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Image Box: StudyInstanceUID empty");
   }
   if (seriesInstanceUID.getLength() == 0)
   {
     result=EC_TagNotFound;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: cannot write Stored Print Image Box: SeriesInstanceUID empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot write Stored Print Image Box: SeriesInstanceUID empty");
   }
 
   ADD_TO_DATASET(DcmUniqueIdentifier, sOPInstanceUID)
@@ -512,7 +426,7 @@ OFCondition DVPSImageBoxContent::createDefaultValues(OFBool renumber, unsigned l
   OFCondition result = EC_Normal;
   char uid[100];
   OFBool isEmpty = OFFalse;
-  
+
   SET_UID(sOPInstanceUID)
 
   if (renumber)
@@ -771,11 +685,7 @@ OFBool DVPSImageBoxContent::printSCPSet(
       // the image box position is checked elsewhere
       ADD_TO_PDATASET(DcmUnsignedShort, imageBoxPosition)
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: attribute (2020,0010) Image Position missing." << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: attribute (2020,0010) Image Position missing.");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -804,11 +714,7 @@ OFBool DVPSImageBoxContent::printSCPSet(
       }
       if (! found)
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal magnification type: '" << theMagnification.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal magnification type: '" << theMagnification.c_str() << "'");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       } else {
@@ -841,21 +747,13 @@ OFBool DVPSImageBoxContent::printSCPSet(
       }
       if (numSmoothings == 0)
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: smoothing type requested but not supported." << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: smoothing type requested but not supported.");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       }
       else if (! found)
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal smoothing type: '" << theSmoothing.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal smoothing type: '" << theSmoothing.c_str() << "'");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
@@ -876,11 +774,7 @@ OFBool DVPSImageBoxContent::printSCPSet(
       Uint32 numConfigurationInformation = cfg.getTargetPrinterNumberOfConfigurationSettings(cfgname);
       if (numConfigurationInformation == 0) // we don't support configuration information
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: configuration information requested but not supported." << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: configuration information requested but not supported.");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       } else {
@@ -897,11 +791,7 @@ OFBool DVPSImageBoxContent::printSCPSet(
         }
         if (! found)
         {
-          if (verboseMode)
-          {
-            logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal configuration information: '" << theConfiguration.c_str() << "'" << endl;
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal configuration information: '" << theConfiguration.c_str() << "'");
           rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
           result = OFFalse;
         }
@@ -924,11 +814,7 @@ OFBool DVPSImageBoxContent::printSCPSet(
       polarity.getOFString(thePolarity, 0, OFTrue);
       if ((thePolarity != "NORMAL")&&(thePolarity != "REVERSE"))
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal polarity: '" << thePolarity.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal polarity: '" << thePolarity.c_str() << "'");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       } else {
@@ -945,11 +831,7 @@ OFBool DVPSImageBoxContent::printSCPSet(
     {
       if (! cfg.getTargetPrinterSupportsRequestedImageSize(cfgname))
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: requested image size not supported." << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: requested image size not supported.");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       }
@@ -970,11 +852,7 @@ OFBool DVPSImageBoxContent::printSCPSet(
     {
       if (! cfg.getTargetPrinterSupportsDecimateCrop(cfgname))
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: requested decimate/crop behaviour not supported." << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: requested decimate/crop behaviour not supported.");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       }
@@ -983,14 +861,10 @@ OFBool DVPSImageBoxContent::printSCPSet(
         requestedDecimateCropBehavior = *((DcmCodeString *)(stack.top()));
 
         OFString theBehaviour;
-        polarity.getOFString(theBehaviour, 0, OFTrue);
+        requestedDecimateCropBehavior.getOFString(theBehaviour, 0, OFTrue);
         if ((theBehaviour != "DECIMATE")&&(theBehaviour != "CROP")&&(theBehaviour != "FAIL"))
         {
-          if (verboseMode)
-          {
-            logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal decimate/crop behaviour: '" << theBehaviour.c_str() << "'" << endl;
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal decimate/crop behaviour: '" << theBehaviour.c_str() << "'");
           rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
           result = OFFalse;
         } else {
@@ -1012,20 +886,12 @@ OFBool DVPSImageBoxContent::printSCPSet(
          DcmItem *item = seq->getItem(0);
          result = printSCPEvaluateBasicGrayscaleImageSequence(cfg, cfgname, item, rsp, imageDataset, align, presentationLUTnegotiated);
       } else {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: basic grayscale image sequence number of items != 1" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: basic grayscale image sequence number of items != 1");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: basic grayscale image sequence missing." << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: basic grayscale image sequence missing.");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1041,7 +907,7 @@ OFBool DVPSImageBoxContent::printSCPSet(
       intoSub = OFFalse;
       const DcmTagKey& currentTag = (stack.top())->getTag();
       if (currentTag.getElement() == 0x0000) /* group length */ ;
-      else if (currentTag == DCM_ImagePosition) /* OK */ ;
+      else if (currentTag == DCM_ImageBoxPosition) /* OK */ ;
       else if (currentTag == DCM_Polarity) /* OK */ ;
       else if (currentTag == DCM_RequestedDecimateCropBehavior) /* OK */ ;
       else if (currentTag == DCM_RequestedImageSize) /* OK */ ;
@@ -1051,19 +917,14 @@ OFBool DVPSImageBoxContent::printSCPSet(
       else if (currentTag == DCM_BasicGrayscaleImageSequence) /* OK */ ;
       else
       {
-        if (verboseMode)
-        {
-          ostream &mycerr = logstream->lockCerr();
-          mycerr << "cannot update Basic Grayscale Image Box: unsupported attribute received:" << endl;
-          (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: unsupported attribute received:\n"
+            << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       }
     }
   }
-  
+
   // if n-set was successful, send back response dataset
   if (result && (EC_Normal == writeresult))
   {
@@ -1112,7 +973,7 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
   Uint16 val=0;
   char newuid[70];
   OFString aString;
-    
+
   // samplesPerPixel
   if (result)
   {
@@ -1125,20 +986,12 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       {
         ADD_TO_PDATASET(DcmUnsignedShort, samplesPerPixel)
       } else {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal samples per pixel value: " << val << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal samples per pixel value: " << val);
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: samples per pixel missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: samples per pixel missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1156,20 +1009,12 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       {
         ADD_TO_PDATASET(DcmUnsignedShort, rows)
       } else {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal rows value: " << val << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal rows value: " << val);
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: rows missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: rows missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1187,27 +1032,19 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       {
         ADD_TO_PDATASET(DcmUnsignedShort, columns)
       } else {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal columns value: " << val << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal columns value: " << val);
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: columns missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: columns missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
   }
 
   Uint16 bitsStoredValue = 0;
-  
+
   // bitsStored
   if (result)
   {
@@ -1223,42 +1060,26 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
         OFBool supports12Bit = cfg.getTargetPrinterSupports12BitTransmission(cfgname);
         if ((bitsStoredValue == 12)&&(! supports12Bit))
         {
-          if (verboseMode)
-          {
-            logstream->lockCerr() << "cannot update Basic Grayscale Image Box: image transmission with 12 bits/pixel not supported." << endl;
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: image transmission with 12 bits/pixel not supported.");
           rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
           result = OFFalse;
         } else {
           if (presentationLUTnegotiated && (cfg.getTargetPrinterPresentationLUTMatchRequired(cfgname)) && (! matchesPresentationLUT(align)))
           {
-            if (verboseMode)
-            {
-              logstream->lockCerr() << "cannot update Basic Grayscale Image Box: image data with " << bitsStoredValue << " bits/pixel does not match characteristics of active Presentation LUT." << endl;
-              logstream->unlockCerr();
-            }
+            DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: image data with " << bitsStoredValue << " bits/pixel does not match characteristics of active Presentation LUT.");
             rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
             result = OFFalse;
           } else {
             ADD_TO_PDATASET(DcmUnsignedShort, bitsStored)
           }
-        }      
-      } else {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal bits stored value: " << val << endl;
-          logstream->unlockCerr();
         }
+      } else {
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal bits stored value: " << val);
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: bits stored missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: bits stored missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1276,20 +1097,12 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       {
         ADD_TO_PDATASET(DcmUnsignedShort, bitsAllocated)
       } else {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal bits allocated value: " << val << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal bits allocated value: " << val);
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: bits allocated missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: bits allocated missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1307,20 +1120,12 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       {
         ADD_TO_PDATASET(DcmUnsignedShort, highBit)
       } else {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal high bit value: " << val << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal high bit value: " << val);
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: high bit missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: high bit missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1338,20 +1143,12 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       {
         ADD_TO_PDATASET(DcmUnsignedShort, pixelRepresentation)
       } else {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal pixel representation value: " << val << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal pixel representation value: " << val);
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: pixel representation missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: pixel representation missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1368,22 +1165,14 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       photometricInterpretation.getOFString(theColorModel, 0, OFTrue);
       if ((theColorModel != "MONOCHROME1")&&(theColorModel != "MONOCHROME2"))
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal photometric interpretation: '" << theColorModel.c_str() << "'" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal photometric interpretation: '" << theColorModel.c_str() << "'");
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       } else {
         ADD_TO_PDATASET(DcmCodeString, photometricInterpretation)
       }
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: photometric interpretation missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: photometric interpretation missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1398,11 +1187,7 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       pixelAspectRatio = *((DcmIntegerString *)(stack.top()));
       if (pixelAspectRatio.getVM() != 2)
       {
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "cannot update Basic Grayscale Image Box: illegal pixel aspect ratio, VM=: '" << pixelAspectRatio.getVM() << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: illegal pixel aspect ratio, VM=: '" << pixelAspectRatio.getVM());
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_InvalidAttributeValue;
         result = OFFalse;
       } else {
@@ -1426,28 +1211,20 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
         if ((EC_Normal == oldPxData->getUint16Array(pxdata16)) && pxdata16)
         {
           pixelData->putUint16Array(pxdata16, oldPxData->getLength()/sizeof(Uint16));
-          rspDataset->insert(pixelData, OFTrue /*replaceOld*/);         	
-        } 
+          rspDataset->insert(pixelData, OFTrue /*replaceOld*/);
+        }
         else if ((EC_Normal == oldPxData->getUint8Array(pxdata8)) && pxdata8)
         {
           pixelData->putUint8Array(pxdata8, oldPxData->getLength()/sizeof(Uint8));
-          rspDataset->insert(pixelData, OFTrue /*replaceOld*/);         	
+          rspDataset->insert(pixelData, OFTrue /*replaceOld*/);
         } else {
-          if (verboseMode)
-          {
-            logstream->lockCerr() << "cannot update Basic Grayscale Image Box: cannot access pixel data" << endl;
-            logstream->unlockCerr();
-          }
+          DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: cannot access pixel data");
           rsp.msg.NSetRSP.DimseStatus = STATUS_N_ProcessingFailure;
-          result = OFFalse;    
+          result = OFFalse;
         }
-      } else writeresult=EC_MemoryExhausted; 
+      } else writeresult=EC_MemoryExhausted;
     } else {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot update Basic Grayscale Image Box: pixel data missing in basic grayscale image sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: pixel data missing in basic grayscale image sequence");
       rsp.msg.NSetRSP.DimseStatus = STATUS_N_MissingAttribute;
       result = OFFalse;
     }
@@ -1475,13 +1252,8 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
       else if (currentTag == DCM_PixelData) /* OK */ ;
       else
       {
-        if (verboseMode)
-        {
-          ostream &mycerr = logstream->lockCerr();
-          mycerr << "cannot update Basic Grayscale Image Box: unsupported attribute in basic grayscale image sequence:" << endl;
-          (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("cannot update Basic Grayscale Image Box: unsupported attribute in basic grayscale image sequence:\n"
+            << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
         rsp.msg.NSetRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       }
@@ -1492,18 +1264,18 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
   if (result && (EC_Normal == writeresult))
   {
     // complete Hardcopy Grayscale Image
-    
+
     // write patient module
-    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_PatientsName, DEFAULT_patientName);
+    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_PatientName, DEFAULT_patientName);
     if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_PatientID);
-    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_PatientsBirthDate);
-    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_PatientsSex);
+    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_PatientBirthDate);
+    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_PatientSex);
 
     // general study and general series modules are written somewhere else
 
     // Hardcopy Equipment Module
-    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_HardcopyDeviceManufacturer, "OFFIS");
-    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_HardcopyDeviceSoftwareVersion, OFFIS_DTK_IMPLEMENTATION_VERSION_NAME);
+    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_RETIRED_HardcopyDeviceManufacturer, "OFFIS");
+    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_RETIRED_HardcopyDeviceSoftwareVersion, OFFIS_DTK_IMPLEMENTATION_VERSION_NAME);
 
     // General Image Module
     if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_InstanceNumber);
@@ -1512,8 +1284,8 @@ OFBool DVPSImageBoxContent::printSCPEvaluateBasicGrayscaleImageSequence(
     if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_DerivationDescription, "Hardcopy");
 
     // SOP Common Module
-    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_SOPClassUID, UID_HardcopyGrayscaleImageStorage);
-    if (EC_Normal==writeresult) writeresult = referencedSOPClassUID.putString(UID_HardcopyGrayscaleImageStorage);
+    if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_SOPClassUID, UID_RETIRED_HardcopyGrayscaleImageStorage);
+    if (EC_Normal==writeresult) writeresult = referencedSOPClassUID.putString(UID_RETIRED_HardcopyGrayscaleImageStorage);
     dcmGenerateUniqueIdentifier(newuid);
     if (EC_Normal==writeresult) writeresult = DVPSHelper::putStringValue(rspDataset, DCM_SOPInstanceUID, newuid);
     if (EC_Normal==writeresult) writeresult = referencedSOPInstanceUID.putString(newuid);
@@ -1535,22 +1307,41 @@ Uint16 DVPSImageBoxContent::getImageBoxPosition()
 OFCondition DVPSImageBoxContent::setUIDsAndAETitle(DcmUniqueIdentifier& studyUID, DcmUniqueIdentifier& seriesUID, const char *aetitle)
 {
   if (aetitle==NULL) return EC_IllegalCall;
-  
+
   studyInstanceUID = studyUID;
   seriesInstanceUID = seriesUID;
   return retrieveAETitle.putString(aetitle);
 }
 
-void DVPSImageBoxContent::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
-
 /*
  *  $Log: dvpsib.cc,v $
+ *  Revision 1.40  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.39  2010-09-24 13:32:58  joergr
+ *  Compared names of SOP Class UIDs with 2009 edition of the DICOM standard. The
+ *  resulting name changes are mainly caused by the fact that the corresponding
+ *  SOP Class is now retired.
+ *
+ *  Revision 1.38  2010-08-09 13:21:56  joergr
+ *  Updated data dictionary to 2009 edition of the DICOM standard. From now on,
+ *  the official "keyword" is used for the attribute name which results in a
+ *  number of minor changes (e.g. "PatientsName" is now called "PatientName").
+ *
+ *  Revision 1.37  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.36  2008-04-30 12:38:43  meichel
+ *  Fixed compile errors due to changes in attribute tag names
+ *
+ *  Revision 1.35  2007/10/31 14:16:40  meichel
+ *  Fixed bug in DICOMscope support code that caused the Print SCU to send
+ *    wrong values for Decimate/Crop Behavior.
+ *
+ *  Revision 1.34  2006/08/15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.33  2005/12/08 15:46:33  meichel
  *  Changed include path schema for all DCMTK header files
  *
