@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSImageBoxContent_PList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:34 $
- *  CVS/RCS Revision: $Revision: 1.28 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.31 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -40,17 +36,11 @@
 
 DVPSImageBoxContent_PList::DVPSImageBoxContent_PList()
 : list_()
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
 DVPSImageBoxContent_PList::DVPSImageBoxContent_PList(const DVPSImageBoxContent_PList &arg)
 : list_()
-, logstream(arg.logstream)
-, verboseMode(arg.verboseMode)
-, debugMode(arg.debugMode)
 {
   OFListConstIterator(DVPSImageBoxContent *) first = arg.list_.begin();
   OFListConstIterator(DVPSImageBoxContent *) last = arg.list_.end();
@@ -85,7 +75,7 @@ OFCondition DVPSImageBoxContent_PList::read(DcmItem &dset, DVPSPresentationLUT_P
   DcmSequenceOfItems *dseq=NULL;
   DcmItem *ditem=NULL;
   
-  if (EC_Normal == dset.search(DCM_ImageBoxContentSequence, stack, ESM_fromHere, OFFalse))
+  if (EC_Normal == dset.search(DCM_RETIRED_ImageBoxContentSequence, stack, ESM_fromHere, OFFalse))
   {
     dseq=(DcmSequenceOfItems *)stack.top();
     if (dseq)
@@ -97,7 +87,6 @@ OFCondition DVPSImageBoxContent_PList::read(DcmItem &dset, DVPSPresentationLUT_P
         newImage = new DVPSImageBoxContent();
         if (newImage && ditem)
         {
-          newImage->setLog(logstream, verboseMode, debugMode);
           result = newImage->read(*ditem, presentationLUTList);
           list_.push_back(newImage);
         } else result = EC_MemoryExhausted;
@@ -123,7 +112,7 @@ OFCondition DVPSImageBoxContent_PList::write(
   OFBool working = OFTrue;
   unsigned long numWritten = 0;
   
-  dseq = new DcmSequenceOfItems(DCM_ImageBoxContentSequence);
+  dseq = new DcmSequenceOfItems(DCM_RETIRED_ImageBoxContentSequence);
   if (dseq)
   {
     OFListIterator(DVPSImageBoxContent *) first = list_.begin();
@@ -203,7 +192,6 @@ OFCondition DVPSImageBoxContent_PList::addImageBox(
   DVPSImageBoxContent *newImage = new DVPSImageBoxContent();
   if (newImage)
   {
-    newImage->setLog(logstream, verboseMode, debugMode);  	
     result = newImage->setContent(instanceuid, retrieveaetitle, refstudyuid,
                refseriesuid, refsopclassuid, refsopinstanceuid,
                requestedimagesize, patientid, presentationlutuid);
@@ -397,21 +385,6 @@ OFCondition DVPSImageBoxContent_PList::prepareBasicImageBox(size_t idx, DcmItem
   return EC_IllegalCall; 
 }
 
-
-void DVPSImageBoxContent_PList::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-  OFListIterator(DVPSImageBoxContent *) first = list_.begin();
-  OFListIterator(DVPSImageBoxContent *) last = list_.end();
-  while (first != last)
-  {
-    (*first)->setLog(logstream, verbMode, dbgMode);
-    ++first;
-  }	
-}
-
 OFBool DVPSImageBoxContent_PList::presentationLUTInstanceUIDisUsed(const char *uid)
 {
   OFString uidS;
@@ -484,7 +457,6 @@ OFBool DVPSImageBoxContent_PList::printSCPCreate(
       if ((EC_Normal == box->setSOPInstanceUID(dcmGenerateUniqueIdentifier(uid))) &&
           (EC_Normal == box->setUIDsAndAETitle(studyUID, seriesUID, aetitle)))
       {
-      	box->setLog(logstream, verboseMode, debugMode);
         list_.push_back(box);
       }
       else
@@ -618,6 +590,15 @@ OFBool DVPSImageBoxContent_PList::emptyPageWarning()
 
 /*
  *  $Log: dvpsibl.cc,v $
+ *  Revision 1.31  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.30  2009-11-24 14:12:58  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.29  2008-04-30 12:38:43  meichel
+ *  Fixed compile errors due to changes in attribute tag names
+ *
  *  Revision 1.28  2005/12/08 15:46:34  meichel
  *  Changed include path schema for all DCMTK header files
  *
