@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSOverlay_PList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:37 $
- *  CVS/RCS Revision: $Revision: 1.12 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.14 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -38,17 +34,11 @@
 
 DVPSOverlay_PList::DVPSOverlay_PList()
 : list_()
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
 DVPSOverlay_PList::DVPSOverlay_PList(const DVPSOverlay_PList &arg)
 : list_()
-, logstream(arg.logstream)
-, verboseMode(arg.verboseMode)
-, debugMode(arg.debugMode)
 {
   OFListConstIterator(DVPSOverlay *) first = arg.list_.begin();
   OFListConstIterator(DVPSOverlay *) last = arg.list_.end();
@@ -93,7 +83,6 @@ OFCondition DVPSOverlay_PList::read(DcmItem &dset)
         newOverlay = new DVPSOverlay();
         if (newOverlay)
         {
-          newOverlay->setLog(logstream, verboseMode, debugMode);
           result = newOverlay->read(dset,i);
           list_.push_back(newOverlay);
         } else result = EC_MemoryExhausted;
@@ -196,7 +185,6 @@ OFCondition DVPSOverlay_PList::addOverlay(DcmItem& overlayIOD, Uint16 groupInIte
     newOverlay = new DVPSOverlay();
     if (newOverlay)
     {
-      newOverlay->setLog(logstream, verboseMode, debugMode);
       result = newOverlay->read(overlayIOD,(Uint8)(groupInItem-0x6000), (Uint8)(newGroup-0x6000));
       if (EC_Normal==result) list_.push_back(newOverlay); else delete newOverlay;
     } else result = EC_MemoryExhausted;
@@ -204,23 +192,15 @@ OFCondition DVPSOverlay_PList::addOverlay(DcmItem& overlayIOD, Uint16 groupInIte
   return result;
 }
 
-void DVPSOverlay_PList::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-  OFListIterator(DVPSOverlay *) first = list_.begin();
-  OFListIterator(DVPSOverlay *) last = list_.end();
-  while (first != last)
-  {
-    (*first)->setLog(logstream, verbMode, dbgMode);
-    ++first;
-  }
-}
-
 /*
  *  $Log: dvpsovl.cc,v $
- *  Revision 1.12  2005/12/08 15:46:37  meichel
+ *  Revision 1.14  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.13  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.12  2005-12-08 15:46:37  meichel
  *  Changed include path schema for all DCMTK header files
  *
  *  Revision 1.11  2004/02/04 15:57:49  joergr
