@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSPresentationLUT
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:38 $
- *  CVS/RCS Revision: $Revision: 1.27 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.31 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,7 +28,9 @@
  */
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
-#include "dcmtk/ofstd/ofstring.h"
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcsequen.h"
+#include "dcmtk/dcmdata/dcvrcs.h"
 #include "dcmtk/dcmpstat/dvpspl.h"
 #include "dcmtk/dcmpstat/dvpsdef.h"     /* for constants and macros */
 #include "dcmtk/dcmnet/dimse.h"
@@ -45,9 +43,6 @@ DVPSPresentationLUT::DVPSPresentationLUT()
 , presentationLUTExplanation(DCM_LUTExplanation)
 , presentationLUTData(DCM_LUTData)
 , sOPInstanceUID(DCM_SOPInstanceUID)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -57,9 +52,6 @@ DVPSPresentationLUT::DVPSPresentationLUT(const DVPSPresentationLUT& copy)
 , presentationLUTExplanation(copy.presentationLUTExplanation)
 , presentationLUTData(copy.presentationLUTData)
 , sOPInstanceUID(copy.sOPInstanceUID)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -120,12 +112,8 @@ OFCondition DVPSPresentationLUT::read(DcmItem &dset, OFBool withSOPInstance)
          }
       } else {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: found Presentation LUT SQ with number of items != 1" << endl;
-          logstream->unlockCerr();
-        }
-      } 
+        DCMPSTAT_INFO("found Presentation LUT SQ with number of items != 1");
+      }
     }
   }
 
@@ -139,39 +127,23 @@ OFCondition DVPSPresentationLUT::read(DcmItem &dset, OFBool withSOPInstance)
     if (presentationLUTDescriptor.getLength() == 0)
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: presentationLUTShape and presentationLUTDescriptor absent or empty" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("presentationLUTShape and presentationLUTDescriptor absent or empty");
     }
     else if (presentationLUTDescriptor.getVM() != 3)
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: presentationLUTDescriptor present but VM != 3 in presentation state" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("presentationLUTDescriptor present but VM != 3 in presentation state");
     }
     if (presentationLUTData.getLength() == 0)
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: presentationLUTShape and presentationLUTData absent or empty" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("presentationLUTShape and presentationLUTData absent or empty");
     }
   } else {
     if (presentationLUTShape.getVM() != 1)
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: presentationLUTShape present but VM != 1" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("presentationLUTShape present but VM != 1");
     } else {
       // check presentation LUT shape
       aString.clear();
@@ -182,11 +154,7 @@ OFCondition DVPSPresentationLUT::read(DcmItem &dset, OFBool withSOPInstance)
       else
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: unknown presentationLUTShape keyword: " << aString << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("unknown presentationLUTShape keyword: " << aString);
       }
     }
   }
@@ -196,20 +164,12 @@ OFCondition DVPSPresentationLUT::read(DcmItem &dset, OFBool withSOPInstance)
     if (sOPInstanceUID.getLength() == 0)
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: sOPInstanceUID absent in Presentation LUT Content Sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("sOPInstanceUID absent in Presentation LUT Content Sequence");
     }
     else if (sOPInstanceUID.getVM() != 1)
     {
       result=EC_IllegalCall;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: sOPInstanceUID VM != 1 in Presentation LUT Content Sequence" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("sOPInstanceUID VM != 1 in Presentation LUT Content Sequence");
     }
   }
   
@@ -419,11 +379,7 @@ OFBool DVPSPresentationLUT::printSCPCreate(
   
   if ((rqDataset==NULL)||(EC_Normal != read(*rqDataset, OFFalse)))
   {
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "cannot create Presentation LUT: attribute list error." << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("cannot create Presentation LUT: attribute list error.");
     rsp.msg.NCreateRSP.DimseStatus = STATUS_N_NoSuchAttribute;
     result = OFFalse;
   }
@@ -449,14 +405,9 @@ OFBool DVPSPresentationLUT::printSCPCreate(
       else if (currentTag == DCM_PresentationLUTSequence) /* OK */ ;
       else
       {
-        if (verboseMode)
-        {
-          ostream &mycerr = logstream->lockCerr();
-          mycerr << "cannot create Presentation LUT: unsupported attribute received:" << endl;
-          (stack.top())->print(mycerr, DCMTypes::PF_shortenLongTagValues);
-          logstream->unlockCerr();
-        }
-      	rsp.msg.NCreateRSP.DimseStatus = STATUS_N_NoSuchAttribute;
+        DCMPSTAT_INFO("cannot create Presentation LUT: unsupported attribute received:" << OFendl
+            << DcmObject::PrintHelper(*stack.top(), DCMTypes::PF_shortenLongTagValues));
+        rsp.msg.NCreateRSP.DimseStatus = STATUS_N_NoSuchAttribute;
         result = OFFalse;
       }
     }
@@ -481,11 +432,7 @@ OFBool DVPSPresentationLUT::printSCPCreate(
     }
     if (!matches)
     {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "cannot create Presentation LUT: Mismatch between LUT entries and image pixel depth." << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("cannot create Presentation LUT: Mismatch between LUT entries and image pixel depth.");
       rsp.msg.NCreateRSP.DimseStatus = STATUS_N_NoSuchAttribute;
       result = OFFalse;
     }
@@ -514,15 +461,22 @@ OFBool DVPSPresentationLUT::printSCPCreate(
   return result;
 }
 
-void DVPSPresentationLUT::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 /*
  *  $Log: dvpspl.cc,v $
+ *  Revision 1.31  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.30  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.29  2009-09-30 10:42:38  uli
+ *  Make dcmpstat's include headers self-sufficient by including all
+ *  needed headers directly and stop using dctk.h
+ *
+ *  Revision 1.28  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.27  2005/12/08 15:46:38  meichel
  *  Changed include path schema for all DCMTK header files
  *
