@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSPresentationLUT 
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:39 $
- *  CVS/RCS Revision: $Revision: 1.3 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.6 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -99,39 +95,27 @@ OFBool DVPSPresentationLUT::activate(DicomImage *image, OFBool printLUT)
       {
       	result = image->setPresentationLutShape(ESP_Identity);
       }
-      if ((!result) && verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to set identity presentation LUT shape, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      if (!result)
+        DCMPSTAT_INFO("unable to set identity presentation LUT shape, ignoring.");
       break;
     case DVPSP_inverse:
       if (!printLUT)
         result = image->setPresentationLutShape(ESP_Inverse);
-      if ((!result) && verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to set inverse presentation LUT shape, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      if (!result)
+        DCMPSTAT_INFO("unable to set inverse presentation LUT shape, ignoring.");
       break;      
     case DVPSP_lin_od:
       result = image->setPresentationLutShape(ESP_LinOD);
-      if ((!result) && verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to set linear optical density presentation LUT shape, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      if (!result)
+        DCMPSTAT_INFO("unable to set linear optical density presentation LUT shape, ignoring.");
       break;
     case DVPSP_table:
       if (printLUT)
         result = image->setVoiLut(presentationLUTData, presentationLUTDescriptor, &presentationLUTExplanation);
       else
         result = image->setPresentationLut(presentationLUTData, presentationLUTDescriptor, &presentationLUTExplanation);
-      if ((!result) && verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to set presentation LUT, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      if (!result)
+        DCMPSTAT_INFO("unable to set presentation LUT, ignoring.");
       break;
   }
   if (result) return OFTrue; else return OFFalse;
@@ -143,11 +127,8 @@ OFBool DVPSPresentationLUT::activateInverseLUT(DicomImage *image)
   if ((image != NULL) && (presentationLUT == DVPSP_table))
   {
       result = image->setInversePresentationLut(presentationLUTData, presentationLUTDescriptor);
-      if ((!result) && verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to set inverse presentation LUT, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      if (!result)
+        DCMPSTAT_INFO("unable to set inverse presentation LUT, ignoring.");
   }
   if (result) return OFTrue; else return OFFalse;
 }
@@ -177,6 +158,16 @@ OFBool DVPSPresentationLUT::isInverse()
 
 /*
  *  $Log: dvpspl2.cc,v $
+ *  Revision 1.6  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.5  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.4  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.3  2005/12/08 15:46:39  meichel
  *  Changed include path schema for all DCMTK header files
  *
