@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSPrintMessageHandler
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:41 $
- *  CVS/RCS Revision: $Revision: 1.20 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.23 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -44,10 +40,6 @@ DVPSPrintMessageHandler::DVPSPrintMessageHandler()
 , eventHandler(NULL)
 , blockMode(DIMSE_BLOCKING)
 , timeout(0)
-, dumpStream(NULL)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -58,16 +50,13 @@ DVPSPrintMessageHandler::~DVPSPrintMessageHandler()
 
 void DVPSPrintMessageHandler::dumpNMessage(T_DIMSE_Message &msg, DcmItem *dataset, OFBool outgoing)
 {
-    if (dumpStream == NULL) return;    
-    if (outgoing)
-    {
-      *dumpStream << "===================== OUTGOING DIMSE MESSAGE ====================" << endl;
+    OFString str;
+    if (outgoing) {
+        DIMSE_dumpMessage(str, msg, DIMSE_OUTGOING, dataset);
     } else {
-      *dumpStream << "===================== INCOMING DIMSE MESSAGE ====================" << endl;
+        DIMSE_dumpMessage(str, msg, DIMSE_INCOMING, dataset);
     }
-    DIMSE_printMessage(*dumpStream, msg, dataset);
-    *dumpStream << "======================= END DIMSE MESSAGE =======================" << endl << endl;  
-    return;
+    DCMPSTAT_DUMP(str);
 }
 
 OFCondition DVPSPrintMessageHandler::sendNRequest(
@@ -555,11 +544,7 @@ OFCondition DVPSPrintMessageHandler::negotiateAssociation(
   }
   
   /* create association */
-  if (verboseMode)
-  {
-    logstream->lockCerr() << "Requesting Association" << endl;
-    logstream->unlockCerr();
-  }
+  DCMPSTAT_INFO("Requesting Association");
     
   if (cond.good()) 
   {
@@ -567,14 +552,10 @@ OFCondition DVPSPrintMessageHandler::negotiateAssociation(
 
     if (cond == DUL_ASSOCIATIONREJECTED)
     {
+      OFString temp_str;
       T_ASC_RejectParameters rej;
       ASC_getRejectParameters(params, &rej);
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Association Rejected" << endl;
-        logstream->unlockCerr();
-        ASC_printRejectParameters(stderr, &rej);
-      }
+      DCMPSTAT_INFO("Association Rejected" << OFendl << ASC_printRejectParameters(temp_str, &rej));
     } else {
       if (cond.bad()) 
       {
@@ -593,22 +574,14 @@ OFCondition DVPSPrintMessageHandler::negotiateAssociation(
                         
   if ((cond.good()) && (0 == ASC_findAcceptedPresentationContextID(assoc, UID_BasicGrayscalePrintManagementMetaSOPClass)))
   {                     
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Peer does not support Basic Grayscale Print Management, aborting association." << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("Peer does not support Basic Grayscale Print Management, aborting association.");
     abortAssociation();
     cond = DIMSE_NOVALIDPRESENTATIONCONTEXTID;
   }
   
   if (cond.good())
   {
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Association accepted (Max Send PDV: " << assoc->sendPDVLength << ")" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("Association accepted (Max Send PDV: " << assoc->sendPDVLength << ")");
   } else {
     // params is now an alias to assoc->params. Don't call ASC_destroyAssociationParameters.
     if (assoc) ASC_destroyAssociation(&assoc);
@@ -632,15 +605,18 @@ OFBool DVPSPrintMessageHandler::printerSupportsAnnotationBox()
   return OFFalse;
 }
 
-void DVPSPrintMessageHandler::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 /*
  *  $Log: dvpspr.cc,v $
+ *  Revision 1.23  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.22  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.21  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.20  2005/12/08 15:46:41  meichel
  *  Changed include path schema for all DCMTK header files
  *
