@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSReferencedImage
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:43 $
- *  CVS/RCS Revision: $Revision: 1.16 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.20 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,9 +28,10 @@
  */
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
-#include "dcmtk/ofstd/ofstring.h"
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcitem.h"
 #include "dcmtk/dcmpstat/dvpsri.h"
-#include "dcmtk/dcmpstat/dvpsdef.h"     /* for constants and macros */
+#include "dcmtk/dcmpstat/dvpsdef.h"   /* for constants and macros */
 
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
@@ -48,9 +45,6 @@ DVPSReferencedImage::DVPSReferencedImage()
 , referencedFrameNumber(DCM_ReferencedFrameNumber)
 , frameCache(NULL)
 , frameCacheEntries(0)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -60,9 +54,6 @@ DVPSReferencedImage::DVPSReferencedImage(const DVPSReferencedImage& copy)
 , referencedFrameNumber(copy.referencedFrameNumber)
 , frameCache(NULL) // we don't copy the frame cache
 , frameCacheEntries(0)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -87,39 +78,23 @@ OFCondition DVPSReferencedImage::read(DcmItem &dset)
   if (referencedSOPClassUID.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a referenced image SQ item with referencedSOPClassUID absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a referenced image SQ item with referencedSOPClassUID absent or empty");
   }
   else if (referencedSOPClassUID.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a referenced image SQ item with referencedSOPClassUID VM != 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a referenced image SQ item with referencedSOPClassUID VM != 1");
   }
 
   if (referencedSOPInstanceUID.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a referenced image SQ item with referencedSOPInstanceUID absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a referenced image SQ item with referencedSOPInstanceUID absent or empty");
   }
   else if (referencedSOPInstanceUID.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a referenced image SQ item with referencedSOPInstanceUID VM != 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a referenced image SQ item with referencedSOPInstanceUID VM != 1");
   }
 
   return result;
@@ -148,11 +123,7 @@ OFBool DVPSReferencedImage::validateSOPClassUID(OFString& sopclassuid)
     if (currentUID != sopclassuid)
     {
       result = OFFalse;
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Error: images of different SOP classes referenced in presentation state" << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("images of different SOP classes referenced in presentation state");
     }
   }
   return result;
@@ -294,15 +265,22 @@ void DVPSReferencedImage::removeFrameReference(unsigned long frame, unsigned lon
 }
 
 
-void DVPSReferencedImage::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 /*
  *  $Log: dvpsri.cc,v $
+ *  Revision 1.20  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.19  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.18  2009-09-30 10:42:39  uli
+ *  Make dcmpstat's include headers self-sufficient by including all
+ *  needed headers directly and stop using dctk.h
+ *
+ *  Revision 1.17  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.16  2005/12/08 15:46:43  meichel
  *  Changed include path schema for all DCMTK header files
  *
