@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSReferencedSeries_PList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:46 $
- *  CVS/RCS Revision: $Revision: 1.17 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:32 $
+ *  CVS/RCS Revision: $Revision: 1.21 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,24 +28,20 @@
  */
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
-#include "dcmtk/ofstd/ofstring.h"
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcsequen.h"
 #include "dcmtk/dcmpstat/dvpsrsl.h"
 #include "dcmtk/dcmpstat/dvpsrs.h"      /* for DVPSReferencedSeries */
 #include "dcmtk/dcmpstat/dvpsri.h"      /* for DVPSReferencedImage, needed by MSVC5 with STL */
+#include "dcmtk/dcmpstat/dvpsdef.h"
 
 DVPSReferencedSeries_PList::DVPSReferencedSeries_PList()
 : list_()
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
 DVPSReferencedSeries_PList::DVPSReferencedSeries_PList(const DVPSReferencedSeries_PList &arg)
 : list_()
-, logstream(arg.logstream)
-, verboseMode(arg.verboseMode)
-, debugMode(arg.debugMode)
 {
   OFListConstIterator(DVPSReferencedSeries *) first = arg.list_.begin();
   OFListConstIterator(DVPSReferencedSeries *) last = arg.list_.end();
@@ -96,7 +88,6 @@ OFCondition DVPSReferencedSeries_PList::read(DcmItem &dset)
         newSeries = new DVPSReferencedSeries();
         if (newSeries && ditem)
         {
-          newSeries->setLog(logstream, verboseMode, debugMode);
           result = newSeries->read(*ditem);
           list_.push_back(newSeries);
         } else result = EC_MemoryExhausted;
@@ -140,11 +131,7 @@ OFBool DVPSReferencedSeries_PList::isValid()
 {
   if (list_.size() == 0)
   {
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: referenced series SQ is empty in presentation state" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("referenced series SQ is empty in presentation state");
     return OFFalse;
   }
 
@@ -291,22 +278,22 @@ OFCondition DVPSReferencedSeries_PList::getImageReference(
   return EC_IllegalCall;
 }
 
-void DVPSReferencedSeries_PList::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-  OFListIterator(DVPSReferencedSeries *) first = list_.begin();
-  OFListIterator(DVPSReferencedSeries *) last = list_.end();
-  while (first != last)
-  {
-    (*first)->setLog(logstream, verbMode, dbgMode);
-    ++first;
-  }
-}
-
 /*
  *  $Log: dvpsrsl.cc,v $
+ *  Revision 1.21  2010-10-14 13:14:32  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.20  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.19  2009-09-30 10:42:39  uli
+ *  Make dcmpstat's include headers self-sufficient by including all
+ *  needed headers directly and stop using dctk.h
+ *
+ *  Revision 1.18  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.17  2005/12/08 15:46:46  meichel
  *  Changed include path schema for all DCMTK header files
  *
