@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSSoftcopyVOI
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:49 $
- *  CVS/RCS Revision: $Revision: 1.12 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:33 $
+ *  CVS/RCS Revision: $Revision: 1.16 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,7 +28,8 @@
  */
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
-#include "dcmtk/ofstd/ofstring.h"
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcsequen.h"
 #include "dcmtk/dcmpstat/dvpssv.h"
 #include "dcmtk/dcmpstat/dvpsri.h"      /* for DVPSReferencedImage */
 #include "dcmtk/dcmpstat/dvpsrsl.h"     /* DVPSReferencedSeries_PList */
@@ -51,9 +48,6 @@ DVPSSoftcopyVOI::DVPSSoftcopyVOI()
 , windowCenter(DCM_WindowCenter)
 , windowWidth(DCM_WindowWidth)
 , windowCenterWidthExplanation(DCM_WindowCenterWidthExplanation)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -66,9 +60,6 @@ DVPSSoftcopyVOI::DVPSSoftcopyVOI(const DVPSSoftcopyVOI& copy)
 , windowCenter(copy.windowCenter)
 , windowWidth(copy.windowWidth)
 , windowCenterWidthExplanation(copy.windowCenterWidthExplanation)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -117,12 +108,8 @@ OFCondition DVPSSoftcopyVOI::read(DcmItem &dset)
          }
       } else {
         result=EC_TagNotFound;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: VOI LUT SQ does not have exactly one item in presentation state" << endl;
-          logstream->unlockCerr();
-        }
-      } 
+        DCMPSTAT_INFO("VOI LUT SQ does not have exactly one item in presentation state");
+      }
     }
   }
 
@@ -139,29 +126,17 @@ OFCondition DVPSSoftcopyVOI::read(DcmItem &dset)
       if (windowWidth.getLength() == 0)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: windowCenter present but windowWidth absent or empty in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("windowCenter present but windowWidth absent or empty in presentation state");
       }
       else if (windowWidth.getVM() != 1)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: windowCenter present but windowWidth VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("windowCenter present but windowWidth VM != 1 in presentation state");
       }
       if (windowCenter.getVM() != 1)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: windowCenter present but VM != 1 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("windowCenter present but VM != 1 in presentation state");
       }
     } else useLUT = OFTrue;
     
@@ -171,40 +146,24 @@ OFCondition DVPSSoftcopyVOI::read(DcmItem &dset)
       if (! useLUT)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: both VOI window and LUT present in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("both VOI window and LUT present in presentation state");
       }
 
       if (voiLUTDescriptor.getLength() == 0)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: voiLUTData present but voiLUTDescriptor absent or empty in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("voiLUTData present but voiLUTDescriptor absent or empty in presentation state");
       }
       else if (voiLUTDescriptor.getVM() != 3)
       {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: voiLUTData present but voiLUTDescriptor VM != 3 in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("voiLUTData present but voiLUTDescriptor VM != 3 in presentation state");
       }
     } 
     else if (useLUT)
     {
         result=EC_IllegalCall;
-        if (verboseMode)
-        {
-          logstream->lockCerr() << "Error: neither VOI window nor LUT present in presentation state" << endl;
-          logstream->unlockCerr();
-        }
+        DCMPSTAT_INFO("neither VOI window nor LUT present in presentation state");
     }
   }
   return result;
@@ -335,11 +294,7 @@ OFCondition DVPSSoftcopyVOI::setVOIWindow(double wCenter, double wWidth, const c
 {
   if (wWidth < 1.0) 
   {
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: Window Width < 1 not allowed." << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("Window Width < 1 not allowed.");
     return EC_IllegalCall;
   }
   DcmDecimalString wc(DCM_WindowCenter);
@@ -383,15 +338,22 @@ OFCondition DVPSSoftcopyVOI::setVOILUT(
   return EC_Normal;
 }
 
-void DVPSSoftcopyVOI::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 /*
  *  $Log: dvpssv.cc,v $
+ *  Revision 1.16  2010-10-14 13:14:33  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.15  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.14  2009-09-30 10:42:39  uli
+ *  Make dcmpstat's include headers self-sufficient by including all
+ *  needed headers directly and stop using dctk.h
+ *
+ *  Revision 1.13  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.12  2005/12/08 15:46:49  meichel
  *  Changed include path schema for all DCMTK header files
  *
