@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPresentationState
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:51 $
- *  CVS/RCS Revision: $Revision: 1.81 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:33 $
+ *  CVS/RCS Revision: $Revision: 1.86 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -560,20 +556,12 @@ OFCondition DVPresentationState::attachImage(DcmDataset *dataset, OFBool transfe
 
     if (EC_Normal != rescaleSlope.getFloat64(slope, 0))
     {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to evaluate Modality Rescale Slope, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("unable to evaluate Modality Rescale Slope, ignoring.");
       slope = 1.0;
     }
     if (EC_Normal != rescaleIntercept.getFloat64(intercept, 0))
     {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to evaluate Modality Rescale Slope, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("unable to evaluate Modality Rescale Slope, ignoring.");
       intercept = 0.0;
     }
     image = new DicomImage(dataset, dataset->getOriginalXfer(),
@@ -1131,7 +1119,7 @@ OFCondition DVPresentationState::setGammaVOILUT(double gammaValue, DVPSObjectApp
   }
 
   if ((numberOfEntries > 0) && (numberOfEntries <= 65536) &&
-     ((firstMapped >= -32768) && (firstMapped <= 32767)) || (firstMapped >= 0) && (firstMapped <= 65535))
+     (((firstMapped >= -32768) && (firstMapped <= 32767)) || ((firstMapped >= 0) && (firstMapped <= 65535))))
   {
     Uint16 *data = new Uint16[numberOfEntries];
     if (data != NULL)
@@ -1547,11 +1535,8 @@ void DVPresentationState::renderPixelData(OFBool display)
        if (previewImage != NULL)
          previewImage->setNoVoiTransformation();
      }
-     if ((!result) && verboseMode)
-     {
-       logstream->lockCerr() << "warning: unable to set VOI transformation, ignoring." << endl;
-       logstream->unlockCerr();
-     }
+     if (!result)
+       DCMPSTAT_INFO("unable to set VOI transformation, ignoring.");
   } /* VOI transform */
 
   if (! currentImagePLUTValid)
@@ -1595,11 +1580,8 @@ void DVPresentationState::renderPixelData(OFBool display)
     {
       result = currentImage->flipImage();
       if (previewImage != NULL) previewImage->flipImage();
-      if ((!result) && verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to flip image horizontally, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      if (!result)
+        DCMPSTAT_INFO("unable to flip image horizontally, ignoring.");
       currentImageFlip = OFFalse;
     }
     signed int srot=0;
@@ -1615,21 +1597,15 @@ void DVPresentationState::renderPixelData(OFBool display)
       result = currentImage->rotateImage(srot);
       if (previewImage != NULL)
         previewImage->rotateImage(srot);
-      if ((!result) && verboseMode)
-      {
-        logstream->lockCerr() << "warning: unable to rotate image by " << srot << " degrees, ignoring." << endl;
-        logstream->unlockCerr();
-      }
+      if (!result)
+        DCMPSTAT_INFO("unable to rotate image by " << srot << " degrees, ignoring.");
     }
     currentImageRotation = DVPSR_0_deg;
 
     // deactivate all overlays first
     result = currentImage->removeAllOverlays();
-    if ((!result) && verboseMode)
-    {
-      logstream->lockCerr() << "warning: unable to disable external overlays, ignoring." << endl;
-      logstream->unlockCerr();
-    }
+    if (!result)
+      DCMPSTAT_INFO("unable to disable external overlays, ignoring.");
 
     size_t numOverlays = overlayList.size();
     DVPSOverlay *overlay = NULL;
@@ -1644,12 +1620,9 @@ void DVPresentationState::renderPixelData(OFBool display)
         {
           if (activateOverlayHelper(*overlay, *currentImage).bad())
           {
-            if ((!result) && verboseMode)
-            {
-              logstream->lockCerr() << "warning: unable to set external overlay group 0x"
-                << hex << ovgroup << dec << ", ignoring." << endl;
-              logstream->unlockCerr();
-            }
+            if (!result)
+              DCMPSTAT_INFO("unable to set external overlay group 0x"
+                << STD_NAMESPACE hex << ovgroup << STD_NAMESPACE dec << ", ignoring.");
           }
         }
         else if ((useShutterBitmap)&&(ovgroup == bitmapShutterGroup))
@@ -1657,12 +1630,9 @@ void DVPresentationState::renderPixelData(OFBool display)
           //activate bitmap overlay
           if (activateOverlayHelper(*overlay, *currentImage, OFTrue, bitmapShutterPValue).bad())
           {
-            if ((!result) && verboseMode)
-            {
-              logstream->lockCerr() << "warning: unable to activate bitmap shutter 0x"
-                << hex << ovgroup << dec << ", ignoring." << endl;
-              logstream->unlockCerr();
-            }
+            if (!result)
+              DCMPSTAT_INFO("unable to activate bitmap shutter 0x"
+                << STD_NAMESPACE hex << ovgroup << STD_NAMESPACE dec << ", ignoring.");
           }
         }
       }
@@ -1787,22 +1757,16 @@ void DVPresentationState::renderPixelData(OFBool display)
   {
     result = currentImage->rotateImage(rot);
     if (previewImage != NULL) previewImage->rotateImage(rot);
-    if ((!result) && verboseMode)
-    {
-      logstream->lockCerr() << "warning: unable to rotate image by " << rot << " degrees, ignoring." << endl;
-      logstream->unlockCerr();
-    }
+    if (!result)
+      DCMPSTAT_INFO("unable to rotate image by " << rot << " degrees, ignoring.");
   }
 
   if (flp)
   {
     result = currentImage->flipImage();
     if (previewImage != NULL) previewImage->flipImage();
-    if ((!result) && verboseMode)
-    {
-      logstream->lockCerr() << "warning: unable to flip image horizontally, ignoring." << endl;
-      logstream->unlockCerr();
-    }
+    if (!result)
+      DCMPSTAT_INFO("unable to flip image horizontally, ignoring.");
   }
 
   currentImageRotation = pstateRotation;
@@ -1964,11 +1928,7 @@ DVPSDisplayedArea *DVPresentationState::getDisplayedAreaSelection()
   DVPSDisplayedArea * area = displayedAreaSelectionList.findDisplayedArea(currentImageSOPInstanceUID, currentImageSelectedFrame);
   if (area==NULL)
   {
-      if (verboseMode)
-      {
-        logstream->lockCerr() << "Warning: no displayed area selection item for current image found, creating default." << endl;
-        logstream->unlockCerr();
-      }
+      DCMPSTAT_INFO("no displayed area selection item for current image found, creating default.");
       if ((currentImageDataset)&&(EC_Normal == createDefaultDisplayedArea(*currentImageDataset)))
       {
         area = displayedAreaSelectionList.findDisplayedArea(currentImageSOPInstanceUID, currentImageSelectedFrame);
@@ -2146,15 +2106,6 @@ const char *DVPresentationState::getCurrentImageModality()
   if (EC_Normal == currentImageModality.getString(c)) return c; else return NULL;
 }
 
-void DVPresentationState::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  DcmPresentationState::setLog(stream, verbMode, dbgMode);
-  currentImageCurveList.setLog(logstream, verbMode, dbgMode);
-  currentImageVOILUTList.setLog(logstream, verbMode, dbgMode);
-  currentImageVOIWindowList.setLog(logstream, verbMode, dbgMode);
-}
-
-
 const char *DVPresentationState::getAttachedImageSOPClassUID()
 {
   return currentImageSOPClassUID;
@@ -2224,6 +2175,23 @@ OFCondition DVPresentationState::createFromImage(
 
 /*
  *  $Log: dvpstat.cc,v $
+ *  Revision 1.86  2010-10-14 13:14:33  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.85  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.84  2009-09-17 06:56:54  joergr
+ *  Added parentheses around && within || in order to avoid compiler warnings.
+ *
+ *  Revision 1.83  2009-08-26 07:52:21  joergr
+ *  Added parentheses around && within || in order to avoid warnings reported by
+ *  gcc 4.3.2.
+ *
+ *  Revision 1.82  2006/08/15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.81  2005/12/08 15:46:51  meichel
  *  Changed include path schema for all DCMTK header files
  *
