@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSTextObject
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:53 $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:33 $
+ *  CVS/RCS Revision: $Revision: 1.16 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -51,9 +47,6 @@ DVPSTextObject::DVPSTextObject()
 , boundingBoxTextHorizontalJustification(DCM_BoundingBoxTextHorizontalJustification)
 , anchorPoint(DCM_AnchorPoint)
 , anchorPointVisibility(DCM_AnchorPointVisibility)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -66,9 +59,6 @@ DVPSTextObject::DVPSTextObject(const DVPSTextObject& copy)
 , boundingBoxTextHorizontalJustification(copy.boundingBoxTextHorizontalJustification)
 , anchorPoint(copy.anchorPoint)
 , anchorPointVisibility(copy.anchorPointVisibility)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -95,117 +85,69 @@ OFCondition DVPSTextObject::read(DcmItem &dset)
   if (unformattedTextValue.getLength() == 0)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with unformattedTextValue absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with unformattedTextValue absent or empty");
   }
   else if (unformattedTextValue.getVM() != 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with unformattedTextValue VM != 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with unformattedTextValue VM != 1");
   }
 
   if (boundingBoxAnnotationUnits.getVM() > 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with boundingBoxAnnotationUnits VM > 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with boundingBoxAnnotationUnits VM > 1");
   }
 
   if (anchorPointAnnotationUnits.getVM() > 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with anchorPointAnnotationUnits VM > 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with anchorPointAnnotationUnits VM > 1");
   }
 
   if (anchorPointVisibility.getVM() > 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with anchorPointVisibility VM > 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with anchorPointVisibility VM > 1");
   }
 
   if (boundingBoxTLHC.getVM() ==1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with boundingBoxTLHC VM == 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with boundingBoxTLHC VM == 1");
   }
   else if (boundingBoxTLHC.getVM() > 2)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with boundingBoxTLHC VM > 2" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with boundingBoxTLHC VM > 2");
   }
 
   if (boundingBoxBRHC.getVM() ==1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with boundingBoxBRHC VM == 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with boundingBoxBRHC VM == 1");
   }
   else if (boundingBoxBRHC.getVM() > 2)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with boundingBoxBRHC VM > 2" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with boundingBoxBRHC VM > 2");
   }
 
   if (boundingBoxTextHorizontalJustification.getVM() > 1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with boundingBoxTextHorizontalJustification VM > 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with boundingBoxTextHorizontalJustification VM > 1");
   }
 
   if (anchorPoint.getVM() ==1)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with anchorPoint VM == 1" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with anchorPoint VM == 1");
   }
   else if (anchorPoint.getVM() > 2)
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with anchorPoint VM > 2" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with anchorPoint VM > 2");
   }
 
   /* test for the various type 1c conditions */
@@ -214,62 +156,38 @@ OFCondition DVPSTextObject::read(DcmItem &dset)
      && ((boundingBoxTLHC.getVM() >0) || (boundingBoxBRHC.getVM() >0)))
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with bounding box but boundingBoxAnnotationUnits absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with bounding box but boundingBoxAnnotationUnits absent or empty");
   }
 
   if ((boundingBoxTextHorizontalJustification.getVM() == 0)
      && ((boundingBoxTLHC.getVM() >0) || (boundingBoxBRHC.getVM() >0)))
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with bounding box but boundingBoxTextHorizontalJustification absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with bounding box but boundingBoxTextHorizontalJustification absent or empty");
   }
 
   if ((anchorPointAnnotationUnits.getVM() == 0) && (anchorPoint.getVM() >0)) 
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with anchor point but anchorPointAnnotationUnits absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with anchor point but anchorPointAnnotationUnits absent or empty");
   }
 
   if ((anchorPointVisibility.getVM() == 0) && (anchorPoint.getVM() >0)) 
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item with anchor point but anchorPointVisibility absent or empty" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item with anchor point but anchorPointVisibility absent or empty");
   }
 
   if ((boundingBoxTLHC.getVM() == 0) && (anchorPoint.getVM() == 0)) 
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item without bounding box and anchor point" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item without bounding box and anchor point");
   }
 
   if ((boundingBoxBRHC.getVM() == 0) && (anchorPoint.getVM() == 0)) 
   {
     result=EC_IllegalCall;
-    if (verboseMode)
-    {
-      logstream->lockCerr() << "Error: presentation state contains a text object SQ item without bounding box and anchor point" << endl;
-      logstream->unlockCerr();
-    }
+    DCMPSTAT_INFO("presentation state contains a text object SQ item without bounding box and anchor point");
   }
 
   return result;
@@ -503,15 +421,18 @@ DVPSannotationUnit DVPSTextObject::getAnchorPointAnnotationUnits()
   return aresult;
 }
 
-void DVPSTextObject::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 /*
  *  $Log: dvpstx.cc,v $
+ *  Revision 1.16  2010-10-14 13:14:33  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.15  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.14  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.13  2005/12/08 15:46:53  meichel
  *  Changed include path schema for all DCMTK header files
  *
