@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSVOILUT
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:55 $
- *  CVS/RCS Revision: $Revision: 1.9 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:33 $
+ *  CVS/RCS Revision: $Revision: 1.11 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -44,9 +40,6 @@ DVPSVOILUT::DVPSVOILUT()
 : voiLUTDescriptor(DCM_LUTDescriptor)
 , voiLUTExplanation(DCM_LUTExplanation)
 , voiLUTData(DCM_LUTData)
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
@@ -54,9 +47,6 @@ DVPSVOILUT::DVPSVOILUT(const DVPSVOILUT& copy)
 : voiLUTDescriptor(copy.voiLUTDescriptor)
 , voiLUTExplanation(copy.voiLUTExplanation)
 , voiLUTData(copy.voiLUTData)
-, logstream(copy.logstream)
-, verboseMode(copy.verboseMode)
-, debugMode(copy.debugMode)
 {
 }
 
@@ -109,16 +99,15 @@ OFCondition DVPSVOILUT::assign(DVPSSoftcopyVOI& voi)
   return voi.setVOILUT(voiLUTDescriptor, voiLUTData, voiLUTExplanation);
 }
 
-void DVPSVOILUT::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-}
-
 /*
  *  $Log: dvpsvl.cc,v $
- *  Revision 1.9  2005/12/08 15:46:55  meichel
+ *  Revision 1.11  2010-10-14 13:14:33  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.10  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.9  2005-12-08 15:46:55  meichel
  *  Changed include path schema for all DCMTK header files
  *
  *  Revision 1.8  2003/06/04 12:30:29  meichel
