@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVPSVOILUT_PList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:56 $
- *  CVS/RCS Revision: $Revision: 1.10 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:33 $
+ *  CVS/RCS Revision: $Revision: 1.12 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -38,17 +34,11 @@
 
 DVPSVOILUT_PList::DVPSVOILUT_PList()
 : list_()
-, logstream(&ofConsole)
-, verboseMode(OFFalse)
-, debugMode(OFFalse)
 {
 }
 
 DVPSVOILUT_PList::DVPSVOILUT_PList(const DVPSVOILUT_PList &arg)
 : list_()
-, logstream(arg.logstream)
-, verboseMode(arg.verboseMode)
-, debugMode(arg.debugMode)
 {
   OFListConstIterator(DVPSVOILUT *) first = arg.list_.begin();
   OFListConstIterator(DVPSVOILUT *) last = arg.list_.end();
@@ -95,7 +85,6 @@ OFCondition DVPSVOILUT_PList::read(DcmItem &dset)
         newObject = new DVPSVOILUT();
         if (newObject && ditem)
         {
-          newObject->setLog(logstream, verboseMode, debugMode);
           if (EC_Normal == newObject->read(*ditem)) list_.push_back(newObject); else delete(newObject);
         } else result = EC_MemoryExhausted;
       }
@@ -119,24 +108,15 @@ DVPSVOILUT *DVPSVOILUT_PList::getVOILUT(size_t idx)
   return NULL;
 }
 
-void DVPSVOILUT_PList::setLog(OFConsole *stream, OFBool verbMode, OFBool dbgMode)
-{
-  if (stream) logstream = stream; else logstream = &ofConsole;
-  verboseMode = verbMode;
-  debugMode = dbgMode;
-  OFListIterator(DVPSVOILUT *) first = list_.begin();
-  OFListIterator(DVPSVOILUT *) last = list_.end();
-  while (first != last)
-  {
-    (*first)->setLog(logstream, verbMode, dbgMode);
-    ++first;
-  }
-}
-
-
 /*
  *  $Log: dvpsvll.cc,v $
- *  Revision 1.10  2005/12/08 15:46:56  meichel
+ *  Revision 1.12  2010-10-14 13:14:33  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.11  2009-11-24 14:12:59  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.10  2005-12-08 15:46:56  meichel
  *  Changed include path schema for all DCMTK header files
  *
  *  Revision 1.9  2004/02/04 15:57:49  joergr
