@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2001-2005, OFFIS
+ *  Copyright (C) 2001-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmpstat
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DVSignatureHandler
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:59 $
- *  CVS/RCS Revision: $Revision: 1.14 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:33 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -38,6 +34,7 @@
 #include "dcmtk/dcmdata/dcobject.h"
 #include "dcmtk/dcmdata/dcsequen.h"
 #include "dcmtk/dcmdata/dcvrat.h"
+#include "dcmtk/dcmdata/dcitem.h"
 #include "dcmtk/dcmpstat/dvpscf.h"
 #include "dcmtk/dcmsign/sicert.h"
 #include "dcmtk/dcmsign/sitypes.h"
@@ -154,7 +151,7 @@ void DVSignatureHandler::replaceString(DVPSObjectType objtype, const char *str)
   }
 }
 
-void DVSignatureHandler::printSignatureItemPosition(DcmStack& stack, ostream& os)
+void DVSignatureHandler::printSignatureItemPosition(DcmStack& stack, STD_NAMESPACE ostream& os)
 {
   DcmObject *elem = NULL;
   DcmSequenceOfItems *sq = NULL;
@@ -387,19 +384,19 @@ void DVSignatureHandler::updateDigitalSignatureInformation(DcmItem& /*dataset*/,
   switch (objtype)
   {
     case DVPSS_structuredReport:
-      if (counter == 0) os << "The current structured report does not contain any digital signature." << endl;
+      if (counter == 0) os << "The current structured report does not contain any digital signature." << OFendl;
       corruptSignaturesSR = corrupt_counter;
       untrustSignaturesSR = untrustworthy_counter;  
       correctSignaturesSR = counter - corrupt_counter - untrustworthy_counter;
       break;
     case DVPSS_image:
-      if (counter == 0) os << "The current image does not contain any digital signature." << endl;
+      if (counter == 0) os << "The current image does not contain any digital signature." << OFendl;
       corruptSignaturesImage = corrupt_counter;
       untrustSignaturesImage = untrustworthy_counter;  
       correctSignaturesImage = counter - corrupt_counter - untrustworthy_counter;
       break;
     case DVPSS_presentationState:
-      if (counter == 0) os << "The current presentation state does not contain any digital signature." << endl;
+      if (counter == 0) os << "The current presentation state does not contain any digital signature." << OFendl;
       corruptSignaturesPState = corrupt_counter;
       untrustSignaturesPState = untrustworthy_counter;  
       correctSignaturesPState = counter - corrupt_counter - untrustworthy_counter;
@@ -877,6 +874,16 @@ OFCondition DVSignatureHandler::createSignature(
 
 /*
  *  $Log: dvsighdl.cc,v $
+ *  Revision 1.17  2010-10-14 13:14:33  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.16  2010-03-01 09:08:49  uli
+ *  Removed some unnecessary include directives in the headers.
+ *
+ *  Revision 1.15  2006-08-15 16:57:02  meichel
+ *  Updated the code in module dcmpstat to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.14  2005/12/08 15:46:59  meichel
  *  Changed include path schema for all DCMTK header files
  *
