@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1993-2005, OFFIS
+ *  Copyright (C) 1993-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmqrdb
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: Telnet Initiator (ti) Main Program
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:03 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmqrdb/apps/dcmqrti.cc,v $
- *  CVS/RCS Revision: $Revision: 1.5 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-11-01 13:37:32 $
+ *  CVS/RCS Revision: $Revision: 1.20 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -45,6 +40,10 @@ BEGIN_EXTERN_C
 #ifdef HAVE_SYS_FILE_H
 #include <sys/file.h>
 #endif
+#ifdef HAVE_SIGNAL_H
+// On Solaris with Sun Workshop 11, <signal.h> declares signal() but <csignal> does not
+#include <signal.h>
+#endif
 END_EXTERN_C
 #include "dcmtk/dcmqrdb/dcmqrtis.h"
 #include "dcmtk/dcmnet/assoc.h"
@@ -53,7 +52,6 @@ END_EXTERN_C
 #include "dcmtk/dcmqrdb/dcmqrcnf.h"
 #include "dcmtk/dcmdata/dcdict.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/dcuid.h"
 #include "dcmtk/ofstd/ofconapp.h"
 #ifdef WITH_ZLIB
@@ -64,7 +62,9 @@ END_EXTERN_C
 #define MAXREMOTEDBTITLES 20
 #define APPLICATIONTITLE "TELNET_INITIATOR"
 #define SHORTCOL 4
-#define LONGCOL 21
+#define LONGCOL 18
+
+static OFLogger dcmqrtiLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
 
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v" OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 DcmQueryRetrieveConfig config;
@@ -88,11 +88,9 @@ extern "C" void TI_signalHandler(int)
 int main( int argc, char *argv[] )
 {
 
-  OFBool verbose = OFFalse;
-  OFBool debug = OFFalse;
   const char *remoteDBTitles[ MAXREMOTEDBTITLES ];
   int remoteDBTitlesCount = 0;
-  const char *configFileName = "dcmqrdb.cfg";
+  const char *configFileName = DEFAULT_CONFIGURATION_DIR "dcmqrscp.cfg";
   E_TransferSyntax networkTransferSyntax = EXS_Unknown;
   int opt_acse_timeout = 30;
 
@@ -101,6 +99,7 @@ int main( int argc, char *argv[] )
   int peerCount, j, n, returnValue = 0;
   OFCondition cond = EC_Normal;
   char tempstr[20];
+  OFString temp_str;
 
 #ifdef HAVE_GUSI_H
   // needed for Macintosh
@@ -127,81 +126,81 @@ int main( int argc, char *argv[] )
 
   cmd.setOptionColumns( LONGCOL, SHORTCOL );
   cmd.addGroup( "general options:");
-    cmd.addOption( "--help",                      "-h",      "print this help text and exit" );
-    cmd.addOption( "--version",                              "print version information and exit", OFTrue );
-    cmd.addOption( "--verbose",                   "-v",      "verbose mode, print processing details" );
-    cmd.addOption( "--debug",                     "-d",      "debug mode, print debug information" );
-    OFString opt0 = "use configuration file f (default: ";
-    opt0 += configFileName;
-    opt0 += ")";
-    cmd.addOption( "--config",                    "-c",   1, "[f]ilename: string", opt0.c_str() );
+    cmd.addOption( "--help",                      "-h",      "print this help text and exit", OFCommandLine::AF_Exclusive );
+    cmd.addOption( "--version",                              "print version information and exit", OFCommandLine::AF_Exclusive );
+    OFLog::addOptions(cmd);
+
+    if (strlen(configFileName) > 21)
+    {
+        OFString opt0 = "use specific configuration file\n(default: ";
+        opt0 += configFileName;
+        opt0 += ")";
+        cmd.addOption( "--config",                "-c",   1, "[f]ilename: string", opt0.c_str() );
+    } else {
+        OFString opt0 = "[f]ilename: string (default: ";
+        opt0 += configFileName;
+        opt0 += ")";
+        cmd.addOption( "--config",                "-c",   1, opt0.c_str(), "use specific configuration file" );
+    }
 
   cmd.addGroup( "network options:" );
     cmd.addOption( "--timeout",                   "-to",  1, "[s]econds: integer (default: unlimited)", "timeout for connection requests");
-      cmd.addOption("--acse-timeout",  "-ta", 1, "[s]econds: integer (default: 30)", "timeout for ACSE messages");
-      cmd.addOption("--dimse-timeout", "-td", 1, "[s]econds: integer (default: unlimited)", "timeout for DIMSE messages");
+      cmd.addOption("--acse-timeout",             "-ta",  1, "[s]econds: integer (default: 30)", "timeout for ACSE messages");
+      cmd.addOption("--dimse-timeout",            "-td",  1, "[s]econds: integer (default: unlimited)", "timeout for DIMSE messages");
 
     cmd.addOption( "--propose-implicit",          "-xi",     "propose implicit VR little endian TS only" );
     OFString opt1 = "set my AE title (default: ";
     opt1 += APPLICATIONTITLE;
     opt1 += ")";
-    cmd.addOption( "--aetitle",                   "-aet", 1, "aetitle: string", opt1.c_str() );
-    OFString opt2 = "[n]umber of bytes: integer [";
-    sprintf(tempstr, "%ld", (long)ASC_MINIMUMPDUSIZE);
+    cmd.addOption( "--aetitle",                   "-aet", 1, "[a]etitle: string", opt1.c_str() );
+    OFString opt2 = "[n]umber of bytes: integer (";
+    sprintf(tempstr, "%ld", OFstatic_cast(long, ASC_MINIMUMPDUSIZE));
     opt2 += tempstr;
     opt2 += "..";
-    sprintf(tempstr, "%ld", (long)ASC_MAXIMUMPDUSIZE);
+    sprintf(tempstr, "%ld", OFstatic_cast(long, ASC_MAXIMUMPDUSIZE));
     opt2 += tempstr;
-    opt2 += "]";
-    cmd.addOption( "--max-pdu",                   "-pdu", 1,  opt2.c_str(), "set max receive pdu to n bytes\n(default: use value from configuration file)" );
+    opt2 += ")";
+    cmd.addOption( "--max-pdu",                   "-pdu", 1, opt2.c_str(), "set max receive pdu to n bytes\n(default: use value from configuration file)" );
 
   cmd.addGroup( "other options:" );
-    cmd.addOption( "--disable-new-vr",            "-u",       "disable support for new VRs, convert to OB" );
-    cmd.addOption( "--remote",                    "-rmt", 1,  "[t]itle: string", "connect to remote database defined in cfg file" );
+    cmd.addOption( "--disable-new-vr",            "-u",      "disable support for new VRs, convert to OB" );
+    cmd.addOption( "--remote",                    "-rmt", 1, "[t]itle: string", "connect to remote database defined in cfg file" );
 
   // evaluate command line
   prepareCmdLineArgs( argc, argv, OFFIS_CONSOLE_APPLICATION );
-  if( app.parseCommandLine( cmd, argc, argv, OFCommandLine::ExpandWildcards ) )
+  if( app.parseCommandLine( cmd, argc, argv, OFCommandLine::PF_ExpandWildcards ) )
   {
-    // check exclusive options first
-    if( cmd.getParamCount() == 0 )
+    /* check exclusive options first */
+    if (cmd.hasExclusiveOption())
     {
       if( cmd.findOption("--version") )
       {
-        app.printHeader( OFTrue );
-        CERR << endl << "External libraries used:";
+        app.printHeader( OFTrue /*print host identifier*/ );
+        COUT << OFendl << "External libraries used:";
 #if !defined(WITH_ZLIB)
-        CERR << " none" << endl;
+        COUT << " none" << OFendl;
 #else
-        CERR << endl;
+        COUT << OFendl;
 #endif
 #ifdef WITH_ZLIB
-        CERR << "- ZLIB, Version " << zlibVersion() << endl;
+        COUT << "- ZLIB, Version " << zlibVersion() << OFendl;
 #endif
         return( 0 );
       }
     }
 
     // command line parameters
-    if( cmd.findOption("--verbose") ) verbose = OFTrue;
-    if( cmd.findOption("--debug") )
-    {
-      debug = OFTrue;
-      verbose = OFTrue;
-      DUL_Debug(OFTrue);
-      DIMSE_debug(OFTrue);
-      SetDebugLevel(3);
-    }
+    OFLog::configureFromCommandLine(cmd, app);
+
     if( cmd.findOption("--config") ) app.checkValue( cmd.getValue( configFileName ) );
     if( cmd.findOption("--propose-implicit") ) networkTransferSyntax = EXS_LittleEndianImplicit;
 
-    conf.setDebug(verbose, debug);
     conf.setXferSyntax(networkTransferSyntax);
-    
+
     const char *myAE = NULL;
-    if( cmd.findOption("--aetitle") ) 
+    if( cmd.findOption("--aetitle") )
     {
-    	app.checkValue( cmd.getValue( myAE ) );
+        app.checkValue( cmd.getValue( myAE ) );
         conf.setAETitle(myAE);
     }
     if( cmd.findOption("--max-pdu") )
@@ -216,7 +215,7 @@ int main( int argc, char *argv[] )
     {
       OFCmdSignedInt opt_timeout = 0;
       app.checkValue(cmd.getValueAndCheckMin(opt_timeout, 1));
-      dcmConnectionTimeout.set((Sint32) opt_timeout);
+      dcmConnectionTimeout.set(OFstatic_cast(Sint32, opt_timeout));
     }
 
     if (cmd.findOption("--acse-timeout"))
@@ -248,12 +247,15 @@ int main( int argc, char *argv[] )
           app.checkValue( cmd.getValue( remoteDBTitles[remoteDBTitlesCount] ) );
           remoteDBTitlesCount++;
         }
-        else CERR << "ti: Too many remote database titles." << endl;
+        else OFLOG_ERROR(dcmqrtiLogger, "ti: Too many remote database titles");
       } while (cmd.findOption("--remote", 0, OFCommandLine::FOM_Next));
     }
 
   }
 
+  /* print resource identifier */
+  OFLOG_DEBUG(dcmqrtiLogger, rcsid << OFendl);
+
   // in case accessing the configuration file for reading is successful
   if( access( configFileName, R_OK ) != -1 )
   {
@@ -261,7 +263,7 @@ int main( int argc, char *argv[] )
     if( config.init( configFileName ) == 1 )
     {
       // dump information
-      if( verbose )
+      if (dcmqrtiLogger.isEnabledFor(OFLogger::INFO_LOG_LEVEL))
         config.printConfig();
 
       // determine max pdu size from configuration file
@@ -271,7 +273,7 @@ int main( int argc, char *argv[] )
       // in case its value is not in a certain range, use the default value
       if( maxPDU == 0 || maxPDU < ASC_MINIMUMPDUSIZE || maxPDU > ASC_MAXIMUMPDUSIZE )
       {
-        COUT << "ti: no or invalid max pdu size found in configuration file." << endl;
+        OFLOG_WARN(dcmqrtiLogger, "ti: no or invalid max pdu size found in configuration file");
         maxPDU = ASC_DEFAULTMAXPDU;
       }
 
@@ -336,12 +338,12 @@ int main( int argc, char *argv[] )
       if( conf.getdbCount() > 0 )
       {
         // dump information
-        if( verbose )
+        if (dcmqrtiLogger.isEnabledFor(OFLogger::INFO_LOG_LEVEL))
           conf.printConfig();
 
         // make sure data dictionary is loaded
         if( !dcmDataDict.isDictionaryLoaded() )
-          CERR << "Warning: no data dictionary loaded, check environment variable: " << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+          OFLOG_WARN(dcmqrtiLogger, "no data dictionary loaded, check environment variable: " << DCM_DICT_ENVIRONMENT_VARIABLE);
 
         // if starting up network is successful
         cond = ASC_initializeNetwork( NET_REQUESTOR, 0, opt_acse_timeout, conf.accessNet() );
@@ -368,33 +370,31 @@ int main( int argc, char *argv[] )
           cond = ASC_dropNetwork( conf.accessNet() );
           if( cond.bad() )
           {
-            CERR << "ti: error dropping network: ";
-            DimseCondition::dump( cond );
+            OFLOG_ERROR(dcmqrtiLogger, "ti: cannot drop network: " << DimseCondition::dump(temp_str, cond));
             returnValue = 1;
           }
         }
         else
         {
-          CERR << "ti: error initialising network: ";
-          DimseCondition::dump( cond );
+          OFLOG_ERROR(dcmqrtiLogger, "ti: cannot initialize network: " << DimseCondition::dump(temp_str, cond));
           returnValue = 1;
         }
       }
       else
       {
-        CERR << "ti: no accessable databases." << endl;
+        OFLOG_ERROR(dcmqrtiLogger, "ti: no accessable databases");
         returnValue = 1;
       }
     }
     else
     {
-      CERR << "ti: error while reading configuration file '" << configFileName << "'." << endl;
+      OFLOG_ERROR(dcmqrtiLogger, "ti: cannot read configuration file '" << configFileName << "'");
       returnValue = 1;
     }
   }
   else
   {
-    CERR << "ti: cannot access configuration file '" << configFileName << "'." << endl;
+    OFLOG_ERROR(dcmqrtiLogger, "ti: cannot access configuration file '" << configFileName << "'");
     returnValue = 1;
   }
 
@@ -412,6 +412,57 @@ int main( int argc, char *argv[] )
 /*
  * CVS Log
  * $Log: dcmqrti.cc,v $
+ * Revision 1.20  2010-11-01 13:37:32  uli
+ * Fixed some compiler warnings reported by gcc with additional flags.
+ *
+ * Revision 1.19  2010-10-14 13:13:47  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.18  2010-09-09 14:59:30  joergr
+ * Made log messages more consistent. Replaced '\n' by OFendl where appropriate.
+ *
+ * Revision 1.17  2009-11-24 10:10:41  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.16  2009-11-18 12:17:30  uli
+ * Fix compiler errors due to removal of DUL_Debug() and DIMSE_Debug().
+ *
+ * Revision 1.15  2009-08-21 09:49:41  joergr
+ * Replaced tabs by spaces and updated copyright date.
+ *
+ * Revision 1.14  2009-08-19 11:56:32  meichel
+ * Function passed as 4th parameter to qsort() now declared extern "C",
+ *   needed for Sun Studio 11 on Solaris.
+ *
+ * Revision 1.13  2009-04-24 12:29:29  joergr
+ * Fixed minor inconsistencies regarding layout/formatting in syntax usage.
+ *
+ * Revision 1.12  2009-04-21 14:11:45  joergr
+ * Fixed minor inconsistencies in manpage / syntax usage.
+ *
+ * Revision 1.11  2008-09-25 15:34:37  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.10  2006/10/27 09:01:30  joergr
+ * Fixed wrong name of configuration file.
+ *
+ * Revision 1.9  2006/08/15 16:09:33  meichel
+ * Updated the code in module dcmqrdb to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.8  2006/07/27 14:48:05  joergr
+ * Fixed typo.
+ *
+ * Revision 1.7  2006/07/27 14:47:05  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
+ * Revision 1.6  2006/07/17 11:38:03  joergr
+ * Modified behaviour of option "--config": By default, the file "dcmqrscp.cfg"
+ * in the configuration directory (e.g. "/usr/local/etc") is used.
+ *
  * Revision 1.5  2005/12/08 15:47:03  meichel
  * Changed include path schema for all DCMTK header files
  *
