@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1993-2005, OFFIS
+ *  Copyright (C) 1993-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmqrdb
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: class DcmQueryRetrieveConfig
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/16 13:10:24 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmqrdb/libsrc/dcmqrcnf.cc,v $
- *  CVS/RCS Revision: $Revision: 1.6 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-12-15 13:59:58 $
+ *  CVS/RCS Revision: $Revision: 1.14 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -39,9 +34,16 @@
 #define INCLUDE_CSTDIO
 #define INCLUDE_CCTYPE
 #define INCLUDE_CSTDARG
+#define INCLUDE_CSTRING
 #include "dcmtk/ofstd/ofstdinc.h"
 #include "dcmtk/ofstd/ofcmdln.h"
 
+OFLogger DCM_dcmqrdbGetLogger()
+{
+    static OFLogger DCM_dcmqrdbLogger = OFLog::getLogger("dcmtk.dcmqrdb");
+    return DCM_dcmqrdbLogger;
+}
+
 int DcmQueryRetrieveConfig::aeTitlesForPeer(const char *hostName, const char *** aeTitleList) const
 {
     int n = 0;
@@ -185,13 +187,8 @@ int DcmQueryRetrieveConfig::countCtnTitles() const
 }
 
 
-void DcmQueryRetrieveConfig::initConfigStruct() 
+void DcmQueryRetrieveConfig::initConfigStruct()
 {
-   applicationTitle_ = "CTN";
-   applicationContext_ = "1.2.840.10008.3.1.1.1";
-   implementationClass_ = "1.2.3.4.5.6.7.8.9.10";
-   implementationVersion_ = "CEN-DICOM-1.0";
-   networkType_ = "tcp";
    UserName_ = "";
    GroupName_ = "";
    networkTCPPort_ = 104;
@@ -206,11 +203,27 @@ void DcmQueryRetrieveConfig::initConfigStruct()
 void DcmQueryRetrieveConfig::panic(const char *fmt, ...)
 {
    va_list  ap;
-
    va_start(ap, fmt);
+
+#if defined(HAVE_VSNPRINTF) && defined(HAVE_PROTOTYPE_VSNPRINTF)
+   char buf[4096];
+
+#ifdef HAVE_PROTOTYPE_STD__VSNPRINTF
+   std::vsnprintf(buf, sizeof(buf), fmt, ap);
+#else
+   vsnprintf(buf, sizeof(buf), fmt, ap);
+#endif
+
+   // Since we can't do anything about a too small buffer for vsnprintf(), we
+   // ignore it. But we do make sure the buffer is null-terminated!
+   buf[4095] = '\0';
+
+   DCMQRDB_ERROR("CONFIG Error: " << buf << "!");
+#else
    fprintf(stderr, "CONFIG Error: ");
    vfprintf(stderr, fmt, ap);
    fprintf(stderr, "!\n");
+#endif
    va_end(ap);
 }
 
@@ -224,7 +237,7 @@ int DcmQueryRetrieveConfig::readConfigLines(FILE *cnffp)
         value[256],       /* parameter value */
         *valueptr;        /* pointer to value list */
    char *c;
-   
+
    while (!feof(cnffp)) {
       fgets(rcline, sizeof(rcline), cnffp); /* read line in configuration file */
       lineno++;
@@ -238,29 +251,19 @@ int DcmQueryRetrieveConfig::readConfigLines(FILE *cnffp)
       valueptr = skipmnemonic(rcline);
 
       if (!strcmp("ApplicationTitle", mnemonic)) {
-         c = parsevalues(&valueptr);
-         applicationTitle_ = c;
-         free(c);
+        // ignore this entry which was used (really?) in previous versions
       }
       else if (!strcmp("ApplicationContext", mnemonic)) {
-         c = parsevalues(&valueptr);
-         applicationContext_ = c;
-         free(c);
+        // ignore this entry which was used (really?) in previous versions
       }
       else if (!strcmp("ImplementationClass", mnemonic)) {
-         c = parsevalues(&valueptr);
-         implementationClass_ = c;
-         free(c);
+        // ignore this entry which was used (really?) in previous versions
       }
       else if (!strcmp("ImplementationVersion", mnemonic)) {
-         c = parsevalues(&valueptr);
-         implementationVersion_ = c;
-         free(c);
+        // ignore this entry which was used (really?) in previous versions
       }
       else if (!strcmp("NetworkType", mnemonic)) {
-         c = parsevalues(&valueptr);
-         networkType_ = c;
-         free(c);
+        // ignore this entry which was used (really?) in previous versions
       }
       else if (!strcmp("UserName", mnemonic)) {
          c = parsevalues(&valueptr);
@@ -276,7 +279,7 @@ int DcmQueryRetrieveConfig::readConfigLines(FILE *cnffp)
          sscanf(valueptr, "%d", &networkTCPPort_);
       }
       else if (!strcmp("MaxPDUSize", mnemonic)) {
-      	 unsigned long ul = 0;
+         unsigned long ul = 0;
          sscanf(valueptr, "%lu", &ul);
          maxPDUSize_ = OFstatic_cast(Uint32, ul);
       }
@@ -525,7 +528,7 @@ DcmQueryRetrieveConfigQuota *DcmQueryRetrieveConfig::parseQuota(char **valuehand
    DcmQueryRetrieveConfigQuota *helpquota;
 
    if ((helpquota = (DcmQueryRetrieveConfigQuota *)malloc(sizeof(DcmQueryRetrieveConfigQuota))) == NULL)
-      panic("Memory allocation4");
+      panic("Memory allocation 4");
    helpvalue = parsevalues(valuehandle);
    sscanf(helpvalue, "%d , %s", &studies, helpval);
    helpquota->maxStudies = studies;
@@ -627,7 +630,7 @@ char *DcmQueryRetrieveConfig::skipmnemonic (char *rcline)
       else break;
     }
    while(*help != '\0') {
-      if (!isspace(*help)) help++;    /* Mnemonic */
+      if (!isspace(OFstatic_cast(unsigned char, *help))) help++;    /* Mnemonic */
       else break;
    }
    while(*help != '\0') {
@@ -640,7 +643,9 @@ char *DcmQueryRetrieveConfig::skipmnemonic (char *rcline)
 
 int DcmQueryRetrieveConfig::isgap (char gap)
 {
-   if (isspace(gap) || gap == '=' || gap == ',' || gap == 10 || gap == 13)
+   if (isspace(OFstatic_cast(unsigned char, gap)))
+      return(1);
+   if (gap == '=' || gap == ',' || gap == 10 || gap == 13)
       return(1);
    else
       return(0);
@@ -774,75 +779,43 @@ void DcmQueryRetrieveConfig::printConfig()
 {
    int i,j;
 
-   printf("\nHostTable: %d\n", CNF_HETable.noOfHostEntries);
+   DCMQRDB_INFO("\nHostTable: " <<  CNF_HETable.noOfHostEntries);
    for(i = 0; i < CNF_HETable.noOfHostEntries; i++) {
-      printf("%s %d\n", CNF_HETable.HostEntries[i].SymbolicName, CNF_HETable.HostEntries[i].noOfPeers);
+      DCMQRDB_INFO(CNF_HETable.HostEntries[i].SymbolicName << " " << CNF_HETable.HostEntries[i].noOfPeers);
       for(j = 0; j < CNF_HETable.HostEntries[i].noOfPeers; j++) {
-         printf("%s %s %d\n", CNF_HETable.HostEntries[i].Peers[j].ApplicationTitle,
-            CNF_HETable.HostEntries[i].Peers[j].HostName, CNF_HETable.HostEntries[i].Peers[j].PortNumber);
+         DCMQRDB_INFO(CNF_HETable.HostEntries[i].Peers[j].ApplicationTitle << " " <<
+            CNF_HETable.HostEntries[i].Peers[j].HostName << " " << CNF_HETable.HostEntries[i].Peers[j].PortNumber);
       }
    }
-   printf("\nVendorTable: %d\n", CNF_VendorTable.noOfHostEntries);
+   DCMQRDB_INFO("\nVendorTable: " << CNF_VendorTable.noOfHostEntries);
    for(i = 0; i < CNF_VendorTable.noOfHostEntries; i++) {
-      printf("%s %d\n", CNF_VendorTable.HostEntries[i].SymbolicName, CNF_VendorTable.HostEntries[i].noOfPeers);
+      DCMQRDB_INFO(CNF_VendorTable.HostEntries[i].SymbolicName << " " << CNF_VendorTable.HostEntries[i].noOfPeers);
       for(j = 0; j < CNF_VendorTable.HostEntries[i].noOfPeers; j++) {
-         printf("%s %s %d\n", CNF_VendorTable.HostEntries[i].Peers[j].ApplicationTitle,
-            CNF_VendorTable.HostEntries[i].Peers[j].HostName, CNF_VendorTable.HostEntries[i].Peers[j].PortNumber);
+         DCMQRDB_INFO(CNF_VendorTable.HostEntries[i].Peers[j].ApplicationTitle << " " <<
+            CNF_VendorTable.HostEntries[i].Peers[j].HostName << " " << CNF_VendorTable.HostEntries[i].Peers[j].PortNumber);
       }
    }
-   printf("\nGlobal Parameters:\n%s\n%s\n%s\n%s\n%s\n%d\n%lu\n%d\n",
-      applicationTitle_.c_str(), applicationContext_.c_str(), implementationClass_.c_str(),
-      implementationVersion_.c_str(), networkType_.c_str(), networkTCPPort_, OFstatic_cast(unsigned long, maxPDUSize_),
-      maxAssociations_);
-   printf("\nAEEntries: %d\n", CNF_Config.noOfAEEntries);
+   DCMQRDB_INFO("\nGlobal Parameters:\n" << networkTCPPort_ << "\n" << OFstatic_cast(unsigned long, maxPDUSize_)
+      << "\n" << maxAssociations_);
+   DCMQRDB_INFO("\nAEEntries: " << CNF_Config.noOfAEEntries);
    for(i = 0; i < CNF_Config.noOfAEEntries; i++) {
-      printf("%s\n%s\n%s\n%d, %ld\n", CNF_Config.AEEntries[i].ApplicationTitle, CNF_Config.AEEntries[i].StorageArea,
-         CNF_Config.AEEntries[i].Access, CNF_Config.AEEntries[i].StorageQuota->maxStudies,
-         CNF_Config.AEEntries[i].StorageQuota->maxBytesPerStudy);
+      DCMQRDB_INFO(CNF_Config.AEEntries[i].ApplicationTitle << "\n" << CNF_Config.AEEntries[i].StorageArea
+         << "\n" << CNF_Config.AEEntries[i].Access << "\n" << CNF_Config.AEEntries[i].StorageQuota->maxStudies
+         << ", " << CNF_Config.AEEntries[i].StorageQuota->maxBytesPerStudy);
       if (CNF_Config.AEEntries[i].noOfPeers == -1)
-         printf("Peers: ANY\n");
+         DCMQRDB_INFO("Peers: ANY");
       else {
-         printf("Peers: %d\n", CNF_Config.AEEntries[i].noOfPeers);
+         DCMQRDB_INFO("Peers: " << CNF_Config.AEEntries[i].noOfPeers);
          for(j = 0; j < CNF_Config.AEEntries[i].noOfPeers; j++) {
-            printf("%s %s %d\n", CNF_Config.AEEntries[i].Peers[j].ApplicationTitle,
-               CNF_Config.AEEntries[i].Peers[j].HostName, CNF_Config.AEEntries[i].Peers[j].PortNumber);
+            DCMQRDB_INFO(CNF_Config.AEEntries[i].Peers[j].ApplicationTitle << " " <<
+               CNF_Config.AEEntries[i].Peers[j].HostName << " " << CNF_Config.AEEntries[i].Peers[j].PortNumber);
          }
       }
-      printf("----------------------------------\n");
+      DCMQRDB_INFO("----------------------------------\n");
    }
 }
 
 
-const char *DcmQueryRetrieveConfig::getApplicationTitle() const
-{
-   return(applicationTitle_.c_str());
-}
-
-
-const char *DcmQueryRetrieveConfig::getApplicationContext() const
-{
-   return(applicationContext_.c_str());
-}
-
-
-const char *DcmQueryRetrieveConfig::getImplementationClass() const
-{
-   return(implementationClass_.c_str());
-}
-
-
-const char *DcmQueryRetrieveConfig::getImplementationVersion() const
-{
-   return(implementationVersion_.c_str());
-}
-
-
-const char *DcmQueryRetrieveConfig::getNetworkType() const
-{
-   return(networkType_.c_str());
-}
-
-
 int DcmQueryRetrieveConfig::getNetworkTCPPort() const
 {
    return(networkTCPPort_);
@@ -1035,6 +1008,30 @@ const char *DcmQueryRetrieveConfig::getGroupName() const
 /*
  * CVS Log
  * $Log: dcmqrcnf.cc,v $
+ * Revision 1.14  2010-12-15 13:59:58  uli
+ * Fixed a problem with a missing prototype for vsnprintf on HP-UX.
+ *
+ * Revision 1.13  2010-10-20 07:41:36  uli
+ * Made sure isalpha() & friends are only called with valid arguments.
+ *
+ * Revision 1.12  2010-10-14 13:14:35  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.11  2010-09-09 17:20:42  joergr
+ * Removed unused (or never used?) configuration entries.
+ *
+ * Revision 1.10  2010-09-09 16:54:32  joergr
+ * Further code clean-up and minor changes to log messages.
+ *
+ * Revision 1.9  2010-06-25 09:15:19  uli
+ * Fixed issues with compiling with HAVE_STD_STRING.
+ *
+ * Revision 1.8  2009-11-24 10:10:42  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.7  2009-08-21 09:54:11  joergr
+ * Replaced tabs by spaces and updated copyright date.
+ *
  * Revision 1.6  2005/12/16 13:10:24  meichel
  * Added type safety code for 64bit platforms
  *
