@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1993-2005, OFFIS
+ *  Copyright (C) 1993-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmqrdb
  *
@@ -22,9 +18,8 @@
  *  Purpose: class DcmQueryRetrieveSCP
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2005/12/16 12:41:35 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmqrdb/libsrc/dcmqrsrv.cc,v $
- *  CVS/RCS Revision: $Revision: 1.1 $
+ *  Update Date:      $Date: 2010-10-14 13:14:36 $
+ *  CVS/RCS Revision: $Revision: 1.12 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,6 +30,8 @@
 #include "dcmtk/dcmqrdb/dcmqrsrv.h"
 #include "dcmtk/dcmqrdb/dcmqropt.h"
 #include "dcmtk/dcmdata/dcfilefo.h"
+#include "dcmtk/dcmdata/dcdeftag.h"
+#include "dcmtk/dcmdata/dcmetinf.h"
 #include "dcmtk/dcmqrdb/dcmqrdba.h"
 #include "dcmtk/dcmqrdb/dcmqrcbf.h"    /* for class DcmQueryRetrieveFindContext */
 #include "dcmtk/dcmqrdb/dcmqrcbm.h"    /* for class DcmQueryRetrieveMoveContext */
@@ -90,8 +87,8 @@ static void storeCallback(
     void *callbackData,
     T_DIMSE_StoreProgress *progress,    /* progress state */
     T_DIMSE_C_StoreRQ *req,             /* original store request */
-    char *imageFileName,       /* being received into */
-    DcmDataset **imageDataSet, /* being received into */
+    char *imageFileName,                /* being received into */
+    DcmDataset **imageDataSet,          /* being received into */
     /* out */
     T_DIMSE_C_StoreRSP *rsp,            /* final store response */
     DcmDataset **stDetail)
@@ -113,7 +110,6 @@ DcmQueryRetrieveSCP::DcmQueryRetrieveSCP(
 : config_(&config)
 , dbCheckFindIdentifier_(OFFalse)
 , dbCheckMoveIdentifier_(OFFalse)
-, dbDebug_(OFFalse)
 , factory_(factory)
 , options_(options)
 {
@@ -140,18 +136,17 @@ OFCondition DcmQueryRetrieveSCP::dispatch(T_ASC_Association *assoc, OFBool corre
 
         if (cond.bad())
         {
-          DcmQueryRetrieveOptions::errmsg("dispatch: cannot create DB Handle");
+          DCMQRDB_ERROR("dispatch: cannot create DB Handle");
           return cond;
         }
 
         if (dbHandle == NULL)
         {
           // this should not happen, but we check it anyway
-          DcmQueryRetrieveOptions::errmsg("dispatch: cannot create DB Handle");
+          DCMQRDB_ERROR("dispatch: cannot create DB Handle");
           return EC_IllegalCall;
         }
 
-        dbHandle->setDebugLevel(dbDebug_ ? 1 : 0);
         dbHandle->setIdentifierChecking(dbCheckFindIdentifier_, dbCheckMoveIdentifier_);
         firstLoop = OFTrue;
 
@@ -185,14 +180,12 @@ OFCondition DcmQueryRetrieveSCP::dispatch(T_ASC_Association *assoc, OFBool corre
                     break;
                 case DIMSE_C_CANCEL_RQ:
                     /* This is a late cancel request, just ignore it */
-                    if (options_.verbose_) {
-                        printf("dispatch: late C-CANCEL-RQ, ignoring\n");
-                    }
+                    DCMQRDB_INFO("dispatch: late C-CANCEL-RQ, ignoring");
                     break;
                 default:
                     /* we cannot handle this kind of message */
                     cond = DIMSE_BADCOMMANDTYPE;
-                    DcmQueryRetrieveOptions::errmsg("Cannot handle command: 0x%x\n",
+                    DCMQRDB_ERROR("Cannot handle command: 0x" << STD_NAMESPACE hex <<
                             (unsigned)msg.CommandField);
                     /* the condition will be returned, the caller will abort the association. */
                 }
@@ -218,42 +211,38 @@ OFCondition DcmQueryRetrieveSCP::dispatch(T_ASC_Association *assoc, OFBool corre
 
 OFCondition DcmQueryRetrieveSCP::handleAssociation(T_ASC_Association * assoc, OFBool correctUIDPadding)
 {
-    OFCondition           cond = EC_Normal;
+    OFCondition         cond = EC_Normal;
     DIC_NODENAME        peerHostName;
     DIC_AE              peerAETitle;
     DIC_AE              myAETitle;
+    OFString            temp_str;
 
     ASC_getPresentationAddresses(assoc->params, peerHostName, NULL);
     ASC_getAPTitles(assoc->params, peerAETitle, myAETitle, NULL);
 
- /* now do the real work */
+    /* now do the real work */
     cond = dispatch(assoc, correctUIDPadding);
 
- /* clean up on association termination */
+    /* clean up on association termination */
     if (cond == DUL_PEERREQUESTEDRELEASE) {
-        if (options_.verbose_)
-            printf("Association Release\n");
+        DCMQRDB_INFO("Association Release");
         cond = ASC_acknowledgeRelease(assoc);
         ASC_dropSCPAssociation(assoc);
     } else if (cond == DUL_PEERABORTEDASSOCIATION) {
-        if (options_.verbose_)
-            printf("Association Aborted\n");
+        DCMQRDB_INFO("Association Aborted");
     } else {
-        DcmQueryRetrieveOptions::errmsg("DIMSE Failure (aborting association):\n");
-        DimseCondition::dump(cond);
-    /* some kind of error so abort the association */
+        DCMQRDB_ERROR("DIMSE Failure (aborting association): " << DimseCondition::dump(temp_str, cond));
+        /* some kind of error so abort the association */
         cond = ASC_abortAssociation(assoc);
     }
 
     cond = ASC_dropAssociation(assoc);
     if (cond.bad()) {
-        fprintf(stderr, "Cannot Drop Association:\n");
-        DimseCondition::dump(cond);
+        DCMQRDB_ERROR("Cannot Drop Association: " << DimseCondition::dump(temp_str, cond));
     }
     cond = ASC_destroyAssociation(&assoc);
     if (cond.bad()) {
-        fprintf(stderr, "Cannot Destroy Association:\n");
-        DimseCondition::dump(cond);
+        DCMQRDB_ERROR("Cannot Destroy Association: " << DimseCondition::dump(temp_str, cond));
     }
 
     return cond;
@@ -265,17 +254,14 @@ OFCondition DcmQueryRetrieveSCP::echoSCP(T_ASC_Association * assoc, T_DIMSE_C_Ec
 {
     OFCondition cond = EC_Normal;
 
-    if (options_.verbose_) {
-        printf("Received Echo SCP RQ: MsgID %d\n",
-                req->MessageID);
-    }
+    DCMQRDB_INFO("Received Echo SCP RQ: MsgID " << req->MessageID);
     /* we send an echo response back */
     cond = DIMSE_sendEchoResponse(assoc, presId,
         req, STATUS_Success, NULL);
 
     if (cond.bad()) {
-        DcmQueryRetrieveOptions::errmsg("echoSCP: Echo Response Failed:");
-        DimseCondition::dump(cond);
+        OFString temp_str;
+        DCMQRDB_ERROR("echoSCP: Echo Response Failed: " << DimseCondition::dump(temp_str, cond));
     }
     return cond;
 }
@@ -294,16 +280,13 @@ OFCondition DcmQueryRetrieveSCP::findSCP(T_ASC_Association * assoc, T_DIMSE_C_Fi
     ASC_getAPTitles(assoc->params, NULL, aeTitle, NULL);
     context.setOurAETitle(aeTitle);
 
-    if (options_.verbose_) {
-        printf("Received Find SCP: ");
-        DIMSE_printCFindRQ(stdout, request);
-    }
+    OFString temp_str;
+    DCMQRDB_INFO("Received Find SCP:" << OFendl << DIMSE_dumpMessage(temp_str, *request, DIMSE_INCOMING));
 
     cond = DIMSE_findProvider(assoc, presID, request,
         findCallback, &context, options_.blockMode_, options_.dimse_timeout_);
     if (cond.bad()) {
-        DcmQueryRetrieveOptions::errmsg("Find SCP Failed:");
-        DimseCondition::dump(cond);
+        DCMQRDB_ERROR("Find SCP Failed: " << DimseCondition::dump(temp_str, cond));
     }
     return cond;
 }
@@ -320,16 +303,13 @@ OFCondition DcmQueryRetrieveSCP::getSCP(T_ASC_Association * assoc, T_DIMSE_C_Get
     ASC_getAPTitles(assoc->params, NULL, aeTitle, NULL);
     context.setOurAETitle(aeTitle);
 
-    if (options_.verbose_) {
-        printf("Received Get SCP: ");
-        DIMSE_printCGetRQ(stdout, request);
-    }
+    OFString temp_str;
+    DCMQRDB_INFO("Received Get SCP:" << OFendl << DIMSE_dumpMessage(temp_str, *request, DIMSE_INCOMING));
 
     cond = DIMSE_getProvider(assoc, presID, request,
         getCallback, &context, options_.blockMode_, options_.dimse_timeout_);
     if (cond.bad()) {
-        DcmQueryRetrieveOptions::errmsg("Get SCP Failed:");
-        DimseCondition::dump(cond);
+        DCMQRDB_ERROR("Get SCP Failed: " << DimseCondition::dump(temp_str, cond));
     }
     return cond;
 }
@@ -346,16 +326,13 @@ OFCondition DcmQueryRetrieveSCP::moveSCP(T_ASC_Association * assoc, T_DIMSE_C_Mo
     ASC_getAPTitles(assoc->params, NULL, aeTitle, NULL);
     context.setOurAETitle(aeTitle);
 
-    if (options_.verbose_) {
-        printf("Received Move SCP: ");
-        DIMSE_printCMoveRQ(stdout, request);
-    }
+    OFString temp_str;
+    DCMQRDB_INFO("Received Move SCP:" << OFendl << DIMSE_dumpMessage(temp_str, *request, DIMSE_INCOMING));
 
     cond = DIMSE_moveProvider(assoc, presID, request,
         moveCallback, &context, options_.blockMode_, options_.dimse_timeout_);
     if (cond.bad()) {
-        DcmQueryRetrieveOptions::errmsg("Move SCP Failed:");
-        DimseCondition::dump(cond);
+        DCMQRDB_ERROR("Move SCP Failed: " << DimseCondition::dump(temp_str, cond));
     }
     return cond;
 }
@@ -373,10 +350,8 @@ OFCondition DcmQueryRetrieveSCP::storeSCP(T_ASC_Association * assoc, T_DIMSE_C_S
 
     DcmQueryRetrieveStoreContext context(dbHandle, options_, STATUS_Success, &dcmff, correctUIDPadding);
 
-    if (options_.verbose_) {
-        printf("Received Store SCP: ");
-        DIMSE_printCStoreRQ(stdout, request);
-    }
+    OFString temp_str;
+    DCMQRDB_INFO("Received Store SCP:" << OFendl << DIMSE_dumpMessage(temp_str, *request, DIMSE_INCOMING));
 
     if (!dcmIsaStorageSOPClassUID(request->AffectedSOPClassUID)) {
         /* callback will send back sop class not supported status */
@@ -391,7 +366,7 @@ OFCondition DcmQueryRetrieveSCP::storeSCP(T_ASC_Association * assoc, T_DIMSE_C_S
             request->AffectedSOPInstanceUID,
             imageFileName);
         if (dbcond.bad()) {
-            DcmQueryRetrieveOptions::errmsg("storeSCP: Database: makeNewStoreFileName Failed");
+            DCMQRDB_ERROR("storeSCP: Database: makeNewStoreFileName Failed");
             /* must still receive data */
             strcpy(imageFileName, NULL_DEVICE_NAME);
             /* callback will send back out of resources status */
@@ -408,7 +383,7 @@ OFCondition DcmQueryRetrieveSCP::storeSCP(T_ASC_Association * assoc, T_DIMSE_C_S
 #endif
     if (lockfd < 0)
     {
-        DcmQueryRetrieveOptions::errmsg("storeSCP: file locking failed, cannot create file");
+        DCMQRDB_ERROR("storeSCP: file locking failed, cannot create file");
 
         /* must still receive data */
         strcpy(imageFileName, NULL_DEVICE_NAME);
@@ -422,6 +397,13 @@ OFCondition DcmQueryRetrieveSCP::storeSCP(T_ASC_Association * assoc, T_DIMSE_C_S
 
     context.setFileName(imageFileName);
 
+    // store SourceApplicationEntityTitle in metaheader
+    if (assoc && assoc->params)
+    {
+      const char *aet = assoc->params->DULparams.callingAPTitle;
+      if (aet) dcmff.getMetaInfo()->putAndInsertString(DCM_SourceApplicationEntityTitle, aet);
+    }
+
     DcmDataset *dset = dcmff.getDataset();
 
     /* we must still retrieve the data set even if some error has occured */
@@ -437,15 +419,14 @@ OFCondition DcmQueryRetrieveSCP::storeSCP(T_ASC_Association * assoc, T_DIMSE_C_S
     }
 
     if (cond.bad()) {
-        DcmQueryRetrieveOptions::errmsg("Store SCP Failed:");
-        DimseCondition::dump(cond);
+        DCMQRDB_ERROR("Store SCP Failed: " << DimseCondition::dump(temp_str, cond));
     }
     if (!options_.ignoreStoreData_ && (cond.bad() || (context.getStatus() != STATUS_Success)))
     {
       /* remove file */
       if (strcmp(imageFileName, NULL_DEVICE_NAME) != 0) // don't try to delete /dev/null
       {
-        if (options_.verbose_) fprintf(stderr, "Store SCP: Deleting Image File: %s\n", imageFileName);
+        DCMQRDB_INFO("Store SCP: Deleting Image File: %s" << imageFileName);
         unlink(imageFileName);
       }
       dbHandle.pruneInvalidRecords();
@@ -472,11 +453,10 @@ void DcmQueryRetrieveSCP::refuseAnyStorageContexts(T_ASC_Association * assoc)
     T_ASC_PresentationContextID pid;
 
     for (i = 0; i < numberOfAllDcmStorageSOPClassUIDs; i++) {
-        pid = ASC_findAcceptedPresentationContextID(assoc, dcmAllStorageSOPClassUIDs[i]);
-        if (pid != 0) {
-            /* refuse */
-            ASC_refusePresentationContext(assoc->params, pid, ASC_P_USERREJECTION);
-        }
+        do {
+          pid = ASC_findAcceptedPresentationContextID(assoc, dcmAllStorageSOPClassUIDs[i]);
+          if (pid != 0) ASC_refusePresentationContext(assoc->params, pid, ASC_P_USERREJECTION);
+        } while (pid != 0); // repeat as long as we find presentation contexts for this SOP class - there might be multiple ones.
     }
 }
 
@@ -485,36 +465,34 @@ OFCondition DcmQueryRetrieveSCP::refuseAssociation(T_ASC_Association ** assoc, C
 {
     OFCondition cond = EC_Normal;
     T_ASC_RejectParameters rej;
+    OFString temp_str;
 
-    if (options_.verbose_)
+    const char *reason_string;
+    switch (reason)
     {
-      printf("Refusing Association (");
-      switch (reason)
-      {
-        case CTN_TooManyAssociations:
-            printf("TooManyAssociations");
-            break;
-        case CTN_CannotFork:
-            printf("CannotFork");
-            break;
-        case CTN_BadAppContext:
-            printf("BadAppContext");
-            break;
-        case CTN_BadAEPeer:
-            printf("BadAEPeer");
-            break;
-        case CTN_BadAEService:
-            printf("BadAEService");
-            break;
-        case CTN_NoReason:
-            printf("NoReason");
-            break;
-        default:
-            printf("???");
-            break;
-      }
-      printf(")\n");
+      case CTN_TooManyAssociations:
+          reason_string = "TooManyAssociations";
+          break;
+      case CTN_CannotFork:
+          reason_string = "CannotFork";
+          break;
+      case CTN_BadAppContext:
+          reason_string = "BadAppContext";
+          break;
+      case CTN_BadAEPeer:
+          reason_string = "BadAEPeer";
+          break;
+      case CTN_BadAEService:
+          reason_string = "BadAEService";
+          break;
+      case CTN_NoReason:
+          reason_string = "NoReason";
+        break;
+      default:
+          reason_string = "???";
+          break;
     }
+    DCMQRDB_INFO("Refusing Association (" << reason_string << ")");
 
     switch (reason)
     {
@@ -555,21 +533,18 @@ OFCondition DcmQueryRetrieveSCP::refuseAssociation(T_ASC_Association ** assoc, C
 
     if (cond.bad())
     {
-      fprintf(stderr, "Association Reject Failed:\n");
-      DimseCondition::dump(cond);
+      DCMQRDB_ERROR("Association Reject Failed: " << DimseCondition::dump(temp_str, cond));
     }
 
     cond = ASC_dropAssociation(*assoc);
     if (cond.bad())
     {
-      fprintf(stderr, "Cannot Drop Association:\n");
-      DimseCondition::dump(cond);
+      DCMQRDB_ERROR("Cannot Drop Association: " << DimseCondition::dump(temp_str, cond));
     }
     cond = ASC_destroyAssociation(assoc);
     if (cond.bad())
     {
-      fprintf(stderr, "Cannot Destroy Association:\n");
-      DimseCondition::dump(cond);
+      DCMQRDB_ERROR("Cannot Destroy Association: " << DimseCondition::dump(temp_str, cond));
     }
 
     return cond;
@@ -581,14 +556,15 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
     OFCondition cond = EC_Normal;
     int i;
     T_ASC_PresentationContextID movepid, findpid;
+    OFString temp_str;
     struct { const char *moveSyntax, *findSyntax; } queryRetrievePairs[] =
     {
-    { UID_MOVEPatientRootQueryRetrieveInformationModel,
-      UID_FINDPatientRootQueryRetrieveInformationModel },
-    { UID_MOVEStudyRootQueryRetrieveInformationModel,
-      UID_FINDStudyRootQueryRetrieveInformationModel },
-    { UID_MOVEPatientStudyOnlyQueryRetrieveInformationModel,
-      UID_FINDPatientStudyOnlyQueryRetrieveInformationModel}
+      { UID_MOVEPatientRootQueryRetrieveInformationModel,
+        UID_FINDPatientRootQueryRetrieveInformationModel },
+      { UID_MOVEStudyRootQueryRetrieveInformationModel,
+        UID_FINDStudyRootQueryRetrieveInformationModel },
+      { UID_RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel,
+        UID_RETIRED_FINDPatientStudyOnlyQueryRetrieveInformationModel }
     };
 
     DIC_AE calledAETitle;
@@ -659,6 +635,46 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
         transferSyntaxes[3] = UID_LittleEndianImplicitTransferSyntax;
         numTransferSyntaxes = 4;
         break;
+      case EXS_JPEGLSLossless:
+        /* we prefer JPEG-LS Lossless */
+        transferSyntaxes[0] = UID_JPEGLSLosslessTransferSyntax;
+        transferSyntaxes[1] = UID_LittleEndianExplicitTransferSyntax;
+        transferSyntaxes[2] = UID_BigEndianExplicitTransferSyntax;
+        transferSyntaxes[3] = UID_LittleEndianImplicitTransferSyntax;
+        numTransferSyntaxes = 4;
+        break;
+      case EXS_JPEGLSLossy:
+        /* we prefer JPEG-LS Lossy */
+        transferSyntaxes[0] = UID_JPEGLSLossyTransferSyntax;
+        transferSyntaxes[1] = UID_LittleEndianExplicitTransferSyntax;
+        transferSyntaxes[2] = UID_BigEndianExplicitTransferSyntax;
+        transferSyntaxes[3] = UID_LittleEndianImplicitTransferSyntax;
+        numTransferSyntaxes = 4;
+        break;
+      case EXS_MPEG2MainProfileAtMainLevel:
+        /* we prefer MPEG2 MP@ML */
+        transferSyntaxes[0] = UID_MPEG2MainProfileAtMainLevelTransferSyntax;
+        transferSyntaxes[1] = UID_LittleEndianExplicitTransferSyntax;
+        transferSyntaxes[2] = UID_BigEndianExplicitTransferSyntax;
+        transferSyntaxes[3] = UID_LittleEndianImplicitTransferSyntax;
+        numTransferSyntaxes = 4;
+        break;
+      case EXS_MPEG2MainProfileAtHighLevel:
+        /* we prefer MPEG2 MP@HL */
+        transferSyntaxes[0] = UID_MPEG2MainProfileAtHighLevelTransferSyntax;
+        transferSyntaxes[1] = UID_LittleEndianExplicitTransferSyntax;
+        transferSyntaxes[2] = UID_BigEndianExplicitTransferSyntax;
+        transferSyntaxes[3] = UID_LittleEndianImplicitTransferSyntax;
+        numTransferSyntaxes = 4;
+        break;
+      case EXS_RLELossless:
+        /* we prefer RLE Lossless */
+        transferSyntaxes[0] = UID_RLELosslessTransferSyntax;
+        transferSyntaxes[1] = UID_LittleEndianExplicitTransferSyntax;
+        transferSyntaxes[2] = UID_BigEndianExplicitTransferSyntax;
+        transferSyntaxes[3] = UID_LittleEndianImplicitTransferSyntax;
+        numTransferSyntaxes = 4;
+        break;
 #ifdef WITH_ZLIB
       case EXS_DeflatedLittleEndianExplicit:
         /* we prefer deflated transmission */
@@ -669,14 +685,6 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
         numTransferSyntaxes = 4;
         break;
 #endif
-      case EXS_RLELossless:
-        /* we prefer RLE Lossless */
-        transferSyntaxes[0] = UID_RLELosslessTransferSyntax;
-        transferSyntaxes[1] = UID_LittleEndianExplicitTransferSyntax;
-        transferSyntaxes[2] = UID_BigEndianExplicitTransferSyntax;
-        transferSyntaxes[3] = UID_LittleEndianImplicitTransferSyntax;
-        numTransferSyntaxes = 4;
-        break;
 #endif
       default:
         /* We prefer explicit transfer syntaxes.
@@ -703,9 +711,9 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
         UID_MOVEPatientRootQueryRetrieveInformationModel,
         UID_GETPatientRootQueryRetrieveInformationModel,
 #ifndef NO_PATIENTSTUDYONLY_SUPPORT
-        UID_FINDPatientStudyOnlyQueryRetrieveInformationModel,
-        UID_MOVEPatientStudyOnlyQueryRetrieveInformationModel,
-        UID_GETPatientStudyOnlyQueryRetrieveInformationModel,
+        UID_RETIRED_FINDPatientStudyOnlyQueryRetrieveInformationModel,
+        UID_RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel,
+        UID_RETIRED_GETPatientStudyOnlyQueryRetrieveInformationModel,
 #endif
         UID_FINDStudyRootQueryRetrieveInformationModel,
         UID_MOVEStudyRootQueryRetrieveInformationModel,
@@ -716,7 +724,7 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
     const int numberOfNonStorageSyntaxes = DIM_OF(nonStorageSyntaxes);
     const char *selectedNonStorageSyntaxes[DIM_OF(nonStorageSyntaxes)];
     int numberOfSelectedNonStorageSyntaxes = 0;
-    for (i=0; i<numberOfNonStorageSyntaxes; i++)
+    for (i = 0; i < numberOfNonStorageSyntaxes; i++)
     {
         if (0 == strcmp(nonStorageSyntaxes[i], UID_FINDPatientRootQueryRetrieveInformationModel))
         {
@@ -730,15 +738,15 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
         {
           if (options_.supportPatientRoot_ && (! options_.disableGetSupport_)) selectedNonStorageSyntaxes[numberOfSelectedNonStorageSyntaxes++] = nonStorageSyntaxes[i];
         }
-        else if (0 == strcmp(nonStorageSyntaxes[i], UID_FINDPatientStudyOnlyQueryRetrieveInformationModel))
+        else if (0 == strcmp(nonStorageSyntaxes[i], UID_RETIRED_FINDPatientStudyOnlyQueryRetrieveInformationModel))
         {
           if (options_.supportPatientStudyOnly_) selectedNonStorageSyntaxes[numberOfSelectedNonStorageSyntaxes++] = nonStorageSyntaxes[i];
         }
-        else if (0 == strcmp(nonStorageSyntaxes[i], UID_MOVEPatientStudyOnlyQueryRetrieveInformationModel))
+        else if (0 == strcmp(nonStorageSyntaxes[i], UID_RETIRED_MOVEPatientStudyOnlyQueryRetrieveInformationModel))
         {
           if (options_.supportPatientStudyOnly_) selectedNonStorageSyntaxes[numberOfSelectedNonStorageSyntaxes++] = nonStorageSyntaxes[i];
         }
-        else if (0 == strcmp(nonStorageSyntaxes[i], UID_GETPatientStudyOnlyQueryRetrieveInformationModel))
+        else if (0 == strcmp(nonStorageSyntaxes[i], UID_RETIRED_GETPatientStudyOnlyQueryRetrieveInformationModel))
         {
           if (options_.supportPatientStudyOnly_ && (! options_.disableGetSupport_)) selectedNonStorageSyntaxes[numberOfSelectedNonStorageSyntaxes++] = nonStorageSyntaxes[i];
         }
@@ -768,8 +776,7 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
     (const char**)selectedNonStorageSyntaxes, numberOfSelectedNonStorageSyntaxes,
     (const char**)transferSyntaxes, numTransferSyntaxes);
     if (cond.bad()) {
-    DcmQueryRetrieveOptions::errmsg("Cannot accept presentation contexts:");
-    DimseCondition::dump(cond);
+        DCMQRDB_ERROR("Cannot accept presentation contexts: " << DimseCondition::dump(temp_str, cond));
     }
 
     /*  accept any of the storage syntaxes */
@@ -781,15 +788,14 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
         dcmAllStorageSOPClassUIDs, numberOfAllDcmStorageSOPClassUIDs,
         (const char**)transferSyntaxes, DIM_OF(transferSyntaxes));
       if (cond.bad()) {
-        DcmQueryRetrieveOptions::errmsg("Cannot accept presentation contexts:");
-        DimseCondition::dump(cond);
+        DCMQRDB_ERROR("Cannot accept presentation contexts: " << DimseCondition::dump(temp_str, cond));
       }
     } else {
       /* accept storage syntaxes with proposed role */
       T_ASC_PresentationContext pc;
       T_ASC_SC_ROLE role;
       int npc = ASC_countPresentationContexts(assoc->params);
-      for (i=0; i<npc; i++)
+      for (i = 0; i < npc; i++)
       {
         ASC_getPresentationContext(assoc->params, i, &pc);
         if (dcmIsaStorageSOPClassUID(pc.abstractSyntax))
@@ -806,9 +812,9 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
           ** syntax.  Accepting a transfer syntax will override previously
           ** accepted transfer syntaxes.
           */
-          for (int k=numTransferSyntaxes-1; k>=0; k--)
+          for (int k = numTransferSyntaxes - 1; k >= 0; k--)
           {
-            for (int j=0; j < (int)pc.transferSyntaxCount; j++)
+            for (int j = 0; j < (int)pc.transferSyntaxCount; j++)
             {
               /* if the transfer syntax was proposed then we can accept it
                * appears in our supported list of transfer syntaxes
@@ -830,9 +836,7 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
      */
     if (0 != ASC_findAcceptedPresentationContextID(assoc, UID_PrivateShutdownSOPClass))
     {
-      if (options_.verbose_) {
-        printf("Shutting down server ... (negotiated private \"shut down\" SOP class)\n");
-      }
+      DCMQRDB_INFO("Shutting down server ... (negotiated private \"shut down\" SOP class)");
       refuseAssociation(&assoc, CTN_NoReason);
       return ASC_SHUTDOWNAPPLICATION;
     }
@@ -851,21 +855,21 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
      * accepting a context for MOVE if a context for FIND is also present.
      */
 
-    for (i=0; i<(int)DIM_OF(queryRetrievePairs); i++) {
+    for (i = 0; i < (int)DIM_OF(queryRetrievePairs); i++) {
         movepid = ASC_findAcceptedPresentationContextID(assoc,
         queryRetrievePairs[i].moveSyntax);
         if (movepid != 0) {
-        findpid = ASC_findAcceptedPresentationContextID(assoc,
-            queryRetrievePairs[i].findSyntax);
-        if (findpid == 0) {
-        if (options_.requireFindForMove_) {
-            /* refuse the move */
-            ASC_refusePresentationContext(assoc->params,
-                movepid, ASC_P_USERREJECTION);
+          findpid = ASC_findAcceptedPresentationContextID(assoc,
+              queryRetrievePairs[i].findSyntax);
+          if (findpid == 0) {
+            if (options_.requireFindForMove_) {
+              /* refuse the move */
+              ASC_refusePresentationContext(assoc->params,
+                  movepid, ASC_P_USERREJECTION);
             } else {
-            DcmQueryRetrieveOptions::errmsg("WARNING: Move PresCtx but no Find (accepting for now)");
-        }
-        }
+              DCMQRDB_ERROR("Move Presentation Context but no Find (accepting for now)");
+            }
+          }
         }
     }
 
@@ -894,6 +898,7 @@ OFCondition DcmQueryRetrieveSCP::negotiateAssociation(T_ASC_Association * assoc)
 OFCondition DcmQueryRetrieveSCP::waitForAssociation(T_ASC_Network * theNet)
 {
     OFCondition cond = EC_Normal;
+    OFString temp_str;
 #ifdef HAVE_FORK
     int                 pid;
 #endif
@@ -918,39 +923,23 @@ OFCondition DcmQueryRetrieveSCP::waitForAssociation(T_ASC_Network * theNet)
         cond = ASC_receiveAssociation(theNet, &assoc, (int)options_.maxPDU_);
         if (cond.bad())
         {
-          if (options_.verbose_)
-          {
-            DcmQueryRetrieveOptions::errmsg("Failed to receive association:");
-            DimseCondition::dump(cond);
-          }
+          DCMQRDB_INFO("Failed to receive association: " << DimseCondition::dump(temp_str, cond));
           go_cleanup = OFTrue;
         }
     } else return EC_Normal;
 
     if (! go_cleanup)
     {
-        if (options_.verbose_)
-        {
-            time_t t = time(NULL);
-            printf("Association Received (%s:%s -> %s) %s",
-               assoc->params->DULparams.callingPresentationAddress,
-               assoc->params->DULparams.callingAPTitle,
-               assoc->params->DULparams.calledAPTitle,
-               ctime(&t));
-        }
+        time_t t = time(NULL);
+        DCMQRDB_INFO("Association Received (" << assoc->params->DULparams.callingPresentationAddress
+                << ":" << assoc->params->DULparams.callingAPTitle << " -> "
+                << assoc->params->DULparams.calledAPTitle << ") " << ctime(&t));
 
-        if (options_.debug_)
-        {
-          printf("Parameters:\n");
-          ASC_dumpParameters(assoc->params, COUT);
-        }
+        DCMQRDB_DEBUG("Parameters:" << OFendl << ASC_dumpParameters(temp_str, assoc->params, ASC_ASSOC_RQ));
 
         if (options_.refuse_)
         {
-            if (options_.verbose_)
-            {
-                printf("Refusing Association (forced via command line)\n");
-            }
+            DCMQRDB_INFO("Refusing Association (forced via command line)");
             cond = refuseAssociation(&assoc, CTN_NoReason);
             go_cleanup = OFTrue;
         }
@@ -963,10 +952,7 @@ OFCondition DcmQueryRetrieveSCP::waitForAssociation(T_ASC_Network * theNet)
         if (cond.bad() || strcmp(buf, DICOM_STDAPPLICATIONCONTEXT) != 0)
         {
             /* reject: the application context name is not supported */
-            if (options_.verbose_)
-            {
-                DcmQueryRetrieveOptions::errmsg("Bad AppContextName: %s", buf);
-            }
+            DCMQRDB_INFO("Bad AppContextName: " << buf);
             cond = refuseAssociation(&assoc, CTN_BadAppContext);
             go_cleanup = OFTrue;
         }
@@ -979,10 +965,7 @@ OFCondition DcmQueryRetrieveSCP::waitForAssociation(T_ASC_Network * theNet)
         strlen(assoc->params->theirImplementationClassUID) == 0)
         {
             /* reject: no implementation Class UID provided */
-            if (options_.verbose_)
-            {
-                DcmQueryRetrieveOptions::errmsg("No implementation Class UID provided");
-            }
+            DCMQRDB_INFO("No implementation Class UID provided");
             cond = refuseAssociation(&assoc, CTN_NoReason);
             go_cleanup = OFTrue;
         }
@@ -1021,23 +1004,17 @@ OFCondition DcmQueryRetrieveSCP::waitForAssociation(T_ASC_Network * theNet)
         cond = ASC_acknowledgeAssociation(assoc);
         if (cond.bad())
         {
-            DimseCondition::dump(cond);
+            DCMQRDB_ERROR(DimseCondition::dump(temp_str, cond));
             go_cleanup = OFTrue;
         }
     }
 
     if (! go_cleanup)
     {
-
-        if (options_.verbose_)
-        {
-            printf("Association Acknowledged (Max Send PDV: %lu)\n",
-                   assoc->sendPDVLength);
-            if (ASC_countAcceptedPresentationContexts(assoc->params) == 0)
-                printf("    (but no valid presentation contexts)\n");
-            if (options_.debug_)
-                ASC_dumpParameters(assoc->params, COUT);
-        }
+        DCMQRDB_INFO("Association Acknowledged (Max Send PDV: " << assoc->sendPDVLength << ")");
+        if (ASC_countAcceptedPresentationContexts(assoc->params) == 0)
+            DCMQRDB_INFO("    (but no valid presentation contexts)");
+        DCMQRDB_DEBUG(ASC_dumpParameters(temp_str, assoc->params, ASC_ASSOC_AC));
 
         if (options_.singleProcess_)
         {
@@ -1051,8 +1028,9 @@ OFCondition DcmQueryRetrieveSCP::waitForAssociation(T_ASC_Network * theNet)
             pid = (int)(fork());
             if (pid < 0)
             {
-                DcmQueryRetrieveOptions::errmsg("Cannot create association sub-process: %s",
-                   strerror(errno));
+                char errBuf[256];
+                DCMQRDB_ERROR("Cannot create association sub-process: "
+                   << OFStandard::strerror(errno, errBuf, sizeof(errBuf)));
                 cond = refuseAssociation(&assoc, CTN_CannotFork);
                 go_cleanup = OFTrue;
             }
@@ -1080,14 +1058,12 @@ OFCondition DcmQueryRetrieveSCP::waitForAssociation(T_ASC_Network * theNet)
         cond = ASC_dropAssociation(assoc);
         if (cond.bad())
         {
-            DcmQueryRetrieveOptions::errmsg("Cannot Drop Association:");
-            DimseCondition::dump(cond);
+            DCMQRDB_ERROR("Cannot Drop Association: " << DimseCondition::dump(temp_str, cond));
         }
         cond = ASC_destroyAssociation(&assoc);
         if (cond.bad())
         {
-            DcmQueryRetrieveOptions::errmsg("Cannot Destroy Association:");
-            DimseCondition::dump(cond);
+            DCMQRDB_ERROR("Cannot Destroy Association: " << DimseCondition::dump(temp_str, cond));
         }
     }
 
@@ -1096,26 +1072,63 @@ OFCondition DcmQueryRetrieveSCP::waitForAssociation(T_ASC_Network * theNet)
 }
 
 
-void DcmQueryRetrieveSCP::cleanChildren(OFBool verbose)
+void DcmQueryRetrieveSCP::cleanChildren()
 {
-  processtable_.cleanChildren(verbose);
+  processtable_.cleanChildren();
 }
 
 
 void DcmQueryRetrieveSCP::setDatabaseFlags(
   OFBool dbCheckFindIdentifier,
-  OFBool dbCheckMoveIdentifier,
-  OFBool dbDebug)
+  OFBool dbCheckMoveIdentifier)
 {
   dbCheckFindIdentifier_ = dbCheckFindIdentifier;
   dbCheckMoveIdentifier_ = dbCheckMoveIdentifier;
-  dbDebug_ = dbDebug;
 }
 
 
 /*
  * CVS Log
  * $Log: dcmqrsrv.cc,v $
+ * Revision 1.12  2010-10-14 13:14:36  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.11  2010-09-24 13:34:17  joergr
+ * Compared names of SOP Class UIDs with 2009 edition of the DICOM standard. The
+ * resulting name changes are mainly caused by the fact that the corresponding
+ * SOP Class is now retired.
+ *
+ * Revision 1.10  2010-09-09 16:54:32  joergr
+ * Further code clean-up and minor changes to log messages.
+ *
+ * Revision 1.9  2010-09-09 15:00:03  joergr
+ * Made log messages more consistent. Replaced '\n' by OFendl where appropriate.
+ *
+ * Revision 1.8  2010-09-02 12:13:00  joergr
+ * Added support for "MPEG2 Main Profile @ High Level" transfer syntax.
+ *
+ * Revision 1.7  2010-06-03 10:34:57  joergr
+ * Replaced calls to strerror() by new helper function OFStandard::strerror()
+ * which results in using the thread safe version of strerror() if available.
+ *
+ * Revision 1.6  2009-11-24 10:10:42  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.5  2009-08-21 09:54:11  joergr
+ * Replaced tabs by spaces and updated copyright date.
+ *
+ * Revision 1.4  2009-08-05 14:54:54  meichel
+ * Fixed bug that caused dcmqrscp to accept image transmissions to read-only
+ *   storage areas when multiple presentation contexts were proposed for a
+ *   single SOP class.
+ *
+ * Revision 1.3  2009-02-06 15:25:43  joergr
+ * Added support for JPEG-LS and MPEG2 transfer syntaxes.
+ *
+ * Revision 1.2  2006/06/23 10:24:43  meichel
+ * All Store SCPs in DCMTK now store the source application entity title in the
+ *   metaheader, both in normal and in bit-preserving mode.
+ *
  * Revision 1.1  2005/12/16 12:41:35  joergr
  * Renamed file to avoid naming conflicts when linking on SunOS 5.5.1 with
  * Sun CC 2.0.1.
