@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmsign
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DcmSignature
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:17 $
- *  CVS/RCS Revision: $Revision: 1.3 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:38 $
+ *  CVS/RCS Revision: $Revision: 1.6 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -41,6 +37,7 @@
 #include "dcmtk/dcmdata/dcvrat.h"
 #include "dcmtk/dcmdata/dcvrcs.h"
 #include "dcmtk/dcmdata/dcvrdt.h"
+#include "dcmtk/dcmdata/dcvrui.h"
 #include "dcmtk/dcmdata/dcvrobow.h"
 #include "dcmtk/dcmdata/dcvrus.h"
 #include "dcmtk/dcmdata/dcuid.h"
@@ -362,8 +359,8 @@ OFCondition DcmSignature::createSignature(
       // Digital Signature Date/Time
       if (result.good())
       {
-      	OFString aString;
-      	currentDateTime(aString);
+        OFString aString;
+        currentDateTime(aString);
         DcmDateTime *elemDT = new DcmDateTime(DCM_DigitalSignatureDateTime);
         if (elemDT)
         {
@@ -467,7 +464,7 @@ OFCondition DcmSignature::createSignature(
 
       if (result.good())
       {
-      	result = signatureSq->append(seqItem);
+        result = signatureSq->append(seqItem);
         if (result.bad())
         {
           delete seqItem;
@@ -531,7 +528,7 @@ OFCondition DcmSignature::createSignature(
       // Data Elements Signed
       if (result.good())
       {
-      	result = macItem->insert(tagListOut, OFTrue);
+        result = macItem->insert(tagListOut, OFTrue);
         if (result.good())
         {
           tagListOut = NULL; // make sure we don't delete tagListOut later
@@ -540,7 +537,7 @@ OFCondition DcmSignature::createSignature(
 
       if (result.good())
       {
-      	result = macParametersSq->append(macItem);
+        result = macParametersSq->append(macItem);
         if (result.bad())
         {
           delete macItem;
@@ -699,6 +696,7 @@ OFCondition DcmSignature::verifyCurrent()
     } else result = SI_EC_VerificationFailed_NoCertificate;
   }
   
+  delete signature;
   delete tagList;
   delete mac;
   return result;
@@ -745,8 +743,8 @@ OFCondition DcmSignature::getCurrentMacXferSyntaxName(OFString& str)
       DcmXfer xf(uid);
       if (xf.getXfer() == EXS_Unknown) str=uid; else 
       {
-      	str="=";
-      	str.append(xf.getXferName());
+        str = "=";
+        str.append(xf.getXferName());
       }
     } else result = SI_EC_VerificationFailed_NoMAC;
   } else result = SI_EC_VerificationFailed_NoMAC;
@@ -827,6 +825,15 @@ int dcmsign_cc_dummy_to_keep_linker_from_moaning = 0;
 
 /*
  *  $Log: dcsignat.cc,v $
+ *  Revision 1.6  2010-10-14 13:14:38  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.5  2010-03-01 09:08:50  uli
+ *  Removed some unnecessary include directives in the headers.
+ *
+ *  Revision 1.4  2009-04-29 12:21:42  joergr
+ *  Fixed memory leak in method verifyCurrent().
+ *
  *  Revision 1.3  2005/12/08 15:47:17  meichel
  *  Changed include path schema for all DCMTK header files
  *
@@ -880,4 +887,3 @@ int dcmsign_cc_dummy_to_keep_linker_from_moaning = 0;
  *
  *
  */
-
