@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmsign
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: SiPrivateKey
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:27 $
- *  CVS/RCS Revision: $Revision: 1.6 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:38 $
+ *  CVS/RCS Revision: $Revision: 1.8 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -40,6 +36,9 @@
 #include "dcmtk/dcmsign/sidsa.h"
 #include "dcmtk/dcmsign/sicert.h"
 
+#define INCLUDE_CSTRING
+#include "dcmtk/ofstd/ofstdinc.h"
+
 BEGIN_EXTERN_C
 #include <openssl/evp.h>
 #include <openssl/x509.h>
@@ -192,7 +191,13 @@ int siprivat_cc_dummy_to_keep_linker_from_moaning = 0;
 
 /*
  *  $Log: siprivat.cc,v $
- *  Revision 1.6  2005/12/08 15:47:27  meichel
+ *  Revision 1.8  2010-10-14 13:14:38  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.7  2010-06-25 09:15:19  uli
+ *  Fixed issues with compiling with HAVE_STD_STRING.
+ *
+ *  Revision 1.6  2005-12-08 15:47:27  meichel
  *  Changed include path schema for all DCMTK header files
  *
  *  Revision 1.5  2002/12/16 12:57:52  meichel
