@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose: Renders the contents of a DICOM structured reporting file in
  *           HTML format
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:33 $
- *  CVS/RCS Revision: $Revision: 1.23 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-21 09:10:08 $
+ *  CVS/RCS Revision: $Revision: 1.37 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,7 +31,6 @@
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #include "dcmtk/dcmsr/dsrdoc.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofconapp.h"
@@ -47,6 +42,8 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dsr2html"
 
+static OFLogger dsr2htmlLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -54,21 +51,20 @@ static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
 // ********************************************
 
 
-static OFCondition renderFile(ostream &out,
+static OFCondition renderFile(STD_NAMESPACE ostream &out,
                               const char *ifname,
                               const char *cssName,
                               const char *defaultCharset,
                               const E_FileReadMode readMode,
                               const E_TransferSyntax xfer,
                               const size_t readFlags,
-                              const size_t renderFlags,
-                              const OFBool debugMode)
+                              const size_t renderFlags)
 {
     OFCondition result = EC_Normal;
 
     if ((ifname == NULL) || (strlen(ifname) == 0))
     {
-        CERR << OFFIS_CONSOLE_APPLICATION << ": invalid filename: <empty string>" << endl;
+        OFLOG_FATAL(dsr2htmlLogger, OFFIS_CONSOLE_APPLICATION << ": invalid filename: <empty string>");
         return EC_IllegalParameter;
     }
 
@@ -81,8 +77,8 @@ static OFCondition renderFile(ostream &out,
             result = dfile->loadFile(ifname, xfer);
         if (result.bad())
         {
-            CERR << OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
-                 << ") reading file: "<< ifname << endl;
+            OFLOG_FATAL(dsr2htmlLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
+                << ") reading file: " << ifname);
         }
     } else
         result = EC_MemoryExhausted;
@@ -90,45 +86,50 @@ static OFCondition renderFile(ostream &out,
     if (result.good())
     {
         result = EC_CorruptedData;
+        DcmDataset *dset = dfile->getDataset();
         DSRDocument *dsrdoc = new DSRDocument();
         if (dsrdoc != NULL)
         {
-            if (debugMode)
-                dsrdoc->setLogStream(&ofConsole);
-            result = dsrdoc->read(*dfile->getDataset(), readFlags);
+            result = dsrdoc->read(*dset, readFlags);
             if (result.good())
             {
                 // check extended character set
                 const char *charset = dsrdoc->getSpecificCharacterSet();
-                if ((charset == NULL || strlen(charset) == 0) && dsrdoc->containsExtendedCharacters())
+                if ((charset == NULL || strlen(charset) == 0) && dset->containsExtendedCharacters())
                 {
-                  // we have an unspecified extended character set
-                  if (defaultCharset == NULL)
-                  {
-                    /* the dataset contains non-ASCII characters that really should not be there */
-                    CERR << OFFIS_CONSOLE_APPLICATION << ": error: (0008,0005) Specific Character Set absent but extended characters used in file: "<< ifname << endl;
-                    result = EC_IllegalCall;
-                  }
-                  else
-                  {
-                    OFString charset(defaultCharset);
-                    if (charset == "latin-1") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin1);
-                    else if (charset == "latin-2") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin2);
-                    else if (charset == "latin-3") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin3);
-                    else if (charset == "latin-4") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin4);
-                    else if (charset == "latin-5") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin5);
-                    else if (charset == "cyrillic") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Cyrillic);
-                    else if (charset == "arabic") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Arabic);
-                    else if (charset == "greek") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Greek);
-                    else if (charset == "hebrew") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Hebrew);
-                  }
+                    // we have an unspecified extended character set
+                    if (defaultCharset == NULL)
+                    {
+                        /* the dataset contains non-ASCII characters that really should not be there */
+                        OFLOG_FATAL(dsr2htmlLogger, OFFIS_CONSOLE_APPLICATION << ": (0008,0005) Specific Character Set absent "
+                            << "but extended characters used in file: " << ifname);
+                        result = EC_IllegalCall;
+                    } else {
+                        OFString charsetStr(defaultCharset);
+                        if (charsetStr == "latin-1")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin1);
+                        else if (charsetStr == "latin-2")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin2);
+                        else if (charsetStr == "latin-3")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin3);
+                        else if (charsetStr == "latin-4")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin4);
+                        else if (charsetStr == "latin-5")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin5);
+                        else if (charsetStr == "cyrillic")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Cyrillic);
+                        else if (charsetStr == "arabic")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Arabic);
+                        else if (charsetStr == "greek")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Greek);
+                        else if (charsetStr == "hebrew")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Hebrew);
+                    }
                 }
                 if (result.good()) result = dsrdoc->renderHTML(out, renderFlags, cssName);
-            }
-            else
-            {
-                CERR << OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
-                     << ") parsing file: "<< ifname << endl;
+            } else {
+                OFLOG_FATAL(dsr2htmlLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
+                    << ") parsing file: " << ifname);
             }
         }
         delete dsrdoc;
@@ -140,12 +141,11 @@ static OFCondition renderFile(ostream &out,
 
 
 #define SHORTCOL 3
-#define LONGCOL 21
+#define LONGCOL 22
 
 
 int main(int argc, char *argv[])
 {
-    int opt_debugMode = 0;
     size_t opt_readFlags = 0;
     size_t opt_renderFlags = DSRTypes::HF_renderDcmtkFootnote;
     const char *opt_cssName = NULL;
@@ -153,100 +153,96 @@ int main(int argc, char *argv[])
     E_FileReadMode opt_readMode = ERM_autoDetect;
     E_TransferSyntax opt_ixfer = EXS_Unknown;
 
-    SetDebugLevel(( 0 ));
-
-    OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, "Render DICOM SR file and data set to HTML", rcsid);
+    OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, "Render DICOM SR file and data set to HTML/XHTML", rcsid);
     OFCommandLine cmd;
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
     cmd.setParamColumn(LONGCOL + SHORTCOL + 4);
 
     cmd.addParam("dsrfile-in",   "DICOM SR input filename to be rendered", OFCmdParam::PM_Mandatory);
-    cmd.addParam("htmlfile-out", "HTML output filename (default: stdout)", OFCmdParam::PM_Optional);
+    cmd.addParam("htmlfile-out", "HTML/XHTML output filename (default: stdout)", OFCmdParam::PM_Optional);
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-      cmd.addOption("--help",                  "-h",     "print this help text and exit");
-      cmd.addOption("--version",                         "print version information and exit", OFTrue /* exclusive */);
-      cmd.addOption("--debug",                 "-d",     "debug mode, print debug information");
-      cmd.addOption("--verbose-debug",         "-dd",    "verbose debug mode, print more details");
+      cmd.addOption("--help",                   "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+      cmd.addOption("--version",                          "print version information and exit", OFCommandLine::AF_Exclusive);
+      OFLog::addOptions(cmd);
 
     cmd.addGroup("input options:");
       cmd.addSubGroup("input file format:");
-        cmd.addOption("--read-file",           "+f",     "read file format or data set (default)");
-        cmd.addOption("--read-file-only",      "+fo",    "read file format only");
-        cmd.addOption("--read-dataset",        "-f",     "read data set without file meta information");
+        cmd.addOption("--read-file",            "+f",     "read file format or data set (default)");
+        cmd.addOption("--read-file-only",       "+fo",    "read file format only");
+        cmd.addOption("--read-dataset",         "-f",     "read data set without file meta information");
       cmd.addSubGroup("input transfer syntax:");
-        cmd.addOption("--read-xfer-auto",      "-t=",    "use TS recognition (default)");
-        cmd.addOption("--read-xfer-detect",    "-td",    "ignore TS specified in the file meta header");
-        cmd.addOption("--read-xfer-little",    "-te",    "read with explicit VR little endian TS");
-        cmd.addOption("--read-xfer-big",       "-tb",    "read with explicit VR big endian TS");
-        cmd.addOption("--read-xfer-implicit",  "-ti",    "read with implicit VR little endian TS");
+        cmd.addOption("--read-xfer-auto",       "-t=",    "use TS recognition (default)");
+        cmd.addOption("--read-xfer-detect",     "-td",    "ignore TS specified in the file meta header");
+        cmd.addOption("--read-xfer-little",     "-te",    "read with explicit VR little endian TS");
+        cmd.addOption("--read-xfer-big",        "-tb",    "read with explicit VR big endian TS");
+        cmd.addOption("--read-xfer-implicit",   "-ti",    "read with implicit VR little endian TS");
 
     cmd.addGroup("parsing options:");
       cmd.addSubGroup("additional information:");
-        cmd.addOption("--processing-details",  "-Ip",    "show currently processed content item");
+        cmd.addOption("--processing-details",   "-Ip",    "show currently processed content item");
       cmd.addSubGroup("error handling:");
-        cmd.addOption("--ignore-constraints",  "-Ec",    "ignore relationship content constraints");
-        cmd.addOption("--ignore-item-errors",  "-Ee",    "do not abort on content item errors, just warn\n(e.g. missing value type specific attributes)");
-        cmd.addOption("--skip-invalid-items",  "-Ei",    "skip invalid content items (incl. sub-tree)");
+        cmd.addOption("--unknown-relationship", "-Er",    "accept unknown/missing relationship type");
+        cmd.addOption("--ignore-constraints",   "-Ec",    "ignore relationship content constraints");
+        cmd.addOption("--ignore-item-errors",   "-Ee",    "do not abort on content item errors, just warn\n(e.g. missing value type specific attributes)");
+        cmd.addOption("--skip-invalid-items",   "-Ei",    "skip invalid content items (incl. sub-tree)");
       cmd.addSubGroup("character set:");
-        cmd.addOption("--charset-require",     "+Cr",    "require declaration of ext. charset (default)");
-        cmd.addOption("--charset-assume",      "+Ca", 1, "charset: string constant (latin-1 to -5,",
-                                                         "greek, cyrillic, arabic, hebrew)\n"
-                                                         "assume charset if undeclared ext. charset found");
+        cmd.addOption("--charset-require",      "+Cr",    "require declaration of ext. charset (default)");
+        cmd.addOption("--charset-assume",       "+Ca", 1, "[c]harset: string constant (latin-1 to -5,",
+                                                          "greek, cyrillic, arabic, hebrew)\n"
+                                                          "assume c if undeclared extended charset found");
     cmd.addGroup("output options:");
-      cmd.addSubGroup("HTML compatibility:");
-        cmd.addOption("--html-3.2",            "+H3",    "use only HTML version 3.2 compatible features");
-        cmd.addOption("--html-4.0",            "+H4",    "allow all HTML version 4.0 features (default)");
-        cmd.addOption("--add-document-type",   "+Hd",    "add reference to SGML document type definition");
-      cmd.addSubGroup("cascading style sheet (CSS), only with HTML 4.0:");
-        cmd.addOption("--css-reference",       "+Sr", 1, "URL : string",
-                                                         "add reference to specified CSS to HTML page");
-        cmd.addOption("--css-file",            "+Sf", 1, "filename : string",
-                                                         "embed content of specified CSS into HTML page");
+      cmd.addSubGroup("HTML/XHTML compatibility:");
+        cmd.addOption("--html-3.2",             "+H3",    "use only HTML version 3.2 compatible features");
+        cmd.addOption("--html-4.0",             "+H4",    "allow all HTML version 4.01 features (default)");
+        cmd.addOption("--xhtml-1.1",            "+X1",    "comply with XHTML version 1.1 specification");
+        cmd.addOption("--add-document-type",    "+Hd",    "add reference to SGML document type definition");
+      cmd.addSubGroup("cascading style sheet (CSS), not with HTML 3.2:");
+        cmd.addOption("--css-reference",        "+Sr", 1, "URL: string",
+                                                          "add reference to specified CSS to document");
+        cmd.addOption("--css-file",             "+Sf", 1, "[f]ilename: string",
+                                                          "embed content of specified CSS into document");
       cmd.addSubGroup("general rendering:");
-        cmd.addOption("--expand-inline",       "+Ri",    "expand short content items inline (default)");
-        cmd.addOption("--never-expand-inline", "-Ri",    "never expand content items inline");
-        cmd.addOption("--render-full-data",    "+Rd",    "render full data of content items");
+        cmd.addOption("--expand-inline",        "+Ri",    "expand short content items inline (default)");
+        cmd.addOption("--never-expand-inline",  "-Ri",    "never expand content items inline");
+        cmd.addOption("--always-expand-inline", "+Ra",    "always expand content items inline");
+        cmd.addOption("--render-full-data",     "+Rd",    "render full data of content items");
+        cmd.addOption("--section-title-inline", "+Rt",    "render section titles inline, not separately");
       cmd.addSubGroup("document rendering:");
-        cmd.addOption("--document-type-title", "+Dt",    "use document type as document title (default)");
-        cmd.addOption("--patient-info-title",  "+Dp",    "use patient information as document title");
-        cmd.addOption("--no-document-header",  "-Dh",    "do not render general document information");
+        cmd.addOption("--document-type-title",  "+Dt",    "use document type as document title (default)");
+        cmd.addOption("--patient-info-title",   "+Dp",    "use patient information as document title");
+        cmd.addOption("--no-document-header",   "-Dh",    "do not render general document information");
       cmd.addSubGroup("code rendering:");
-        cmd.addOption("--render-inline-codes", "+Ci",    "render codes in continuous text blocks");
-        cmd.addOption("--concept-name-codes",  "+Cn",    "render code of concept names");
-        cmd.addOption("--numeric-unit-codes",  "+Cu",    "render code of numeric measurement units");
-        cmd.addOption("--code-value-unit",     "+Cv",    "use code value as measurement unit (default)");
-        cmd.addOption("--code-meaning-unit",   "+Cm",    "use code meaning as measurement unit");
-        cmd.addOption("--render-all-codes",    "+Ca",    "render all codes (implies +Ci, +Cn and +Cu)");
+        cmd.addOption("--render-inline-codes",  "+Ci",    "render codes in continuous text blocks");
+        cmd.addOption("--concept-name-codes",   "+Cn",    "render code of concept names");
+        cmd.addOption("--numeric-unit-codes",   "+Cu",    "render code of numeric measurement units");
+        cmd.addOption("--code-value-unit",      "+Cv",    "use code value as measurement unit (default)");
+        cmd.addOption("--code-meaning-unit",    "+Cm",    "use code meaning as measurement unit");
+        cmd.addOption("--render-all-codes",     "+Cc",    "render all codes (implies +Ci, +Cn and +Cu)");
+        cmd.addOption("--code-details-tooltip", "+Ct",    "render code details as a tooltip (implies +Cc)");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
         /* check exclusive options first */
-        if (cmd.getParamCount() == 0)
+        if (cmd.hasExclusiveOption())
         {
-          if (cmd.findOption("--version"))
-          {
-              app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-              CERR << endl << "External libraries used:";
+            if (cmd.findOption("--version"))
+            {
+                app.printHeader(OFTrue /*print host identifier*/);
+                COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-              CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+                COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-              CERR << " none" << endl;
+                COUT << " none" << OFendl;
 #endif
-              return 0;
-           }
+                return 0;
+            }
         }
 
         /* general options */
-        if (cmd.findOption("--debug"))
-            opt_debugMode = 2;
-        if (cmd.findOption("--verbose-debug"))
-        {
-            opt_debugMode = 5;
-            opt_readFlags |= DSRTypes::RF_verboseDebugMode;
-        }
+        OFLog::configureFromCommandLine(cmd, app);
 
         /* input options */
         cmd.beginOptionBlock();
@@ -278,7 +274,12 @@ int main(int argc, char *argv[])
         cmd.endOptionBlock();
 
         if (cmd.findOption("--processing-details"))
+        {
+            app.checkDependence("--processing-details", "verbose mode", dsr2htmlLogger.isEnabledFor(OFLogger::INFO_LOG_LEVEL));
             opt_readFlags |= DSRTypes::RF_showCurrentlyProcessedItem;
+        }
+        if (cmd.findOption("--unknown-relationship"))
+            opt_readFlags |= DSRTypes::RF_acceptUnknownRelationshipType;
         if (cmd.findOption("--ignore-constraints"))
             opt_readFlags |= DSRTypes::RF_ignoreRelationshipConstraints;
         if (cmd.findOption("--ignore-item-errors"))
@@ -308,11 +309,11 @@ int main(int argc, char *argv[])
         /* HTML compatibility */
         cmd.beginOptionBlock();
         if (cmd.findOption("--html-3.2"))
-            opt_renderFlags |= DSRTypes::HF_version32Compatibility;
+            opt_renderFlags = (opt_renderFlags & ~DSRTypes::HF_XHTML11Compatibility) | DSRTypes::HF_HTML32Compatibility;
         if (cmd.findOption("--html-4.0"))
-        {
-            /* default */
-        }
+            opt_renderFlags = (opt_renderFlags & ~(DSRTypes::HF_XHTML11Compatibility | DSRTypes::HF_HTML32Compatibility));
+        if (cmd.findOption("--xhtml-1.1"))
+            opt_renderFlags = (opt_renderFlags & ~DSRTypes::HF_HTML32Compatibility) | DSRTypes::HF_XHTML11Compatibility | DSRTypes::HF_addDocumentTypeReference;
         cmd.endOptionBlock();
 
         if (cmd.findOption("--add-document-type"))
@@ -322,13 +323,13 @@ int main(int argc, char *argv[])
         cmd.beginOptionBlock();
         if (cmd.findOption("--css-reference"))
         {
-          	app.checkDependence("--css-reference", "--html-4.0", !(opt_renderFlags & DSRTypes::HF_version32Compatibility));
+            app.checkConflict("--css-reference", "--html-3.2", (opt_renderFlags & DSRTypes::HF_HTML32Compatibility) > 0);
             opt_renderFlags &= ~DSRTypes::HF_copyStyleSheetContent;
             app.checkValue(cmd.getValue(opt_cssName));
         }
         if (cmd.findOption("--css-file"))
         {
-          	app.checkDependence("--css-file", "--html-4.0", !(opt_renderFlags & DSRTypes::HF_version32Compatibility));
+            app.checkConflict("--css-file", "--html-3.2", (opt_renderFlags & DSRTypes::HF_HTML32Compatibility) > 0);
             opt_renderFlags |= DSRTypes::HF_copyStyleSheetContent;
             app.checkValue(cmd.getValue(opt_cssName));
         }
@@ -342,11 +343,16 @@ int main(int argc, char *argv[])
         }
         if (cmd.findOption("--never-expand-inline"))
             opt_renderFlags |= DSRTypes::HF_neverExpandChildrenInline;
+        if (cmd.findOption("--always-expand-inline"))
+            opt_renderFlags |= DSRTypes::HF_alwaysExpandChildrenInline;
         cmd.endOptionBlock();
 
         if (cmd.findOption("--render-full-data"))
             opt_renderFlags |= DSRTypes::HF_renderFullData;
 
+        if (cmd.findOption("--section-title-inline"))
+            opt_renderFlags |= DSRTypes::HF_renderSectionTitlesInline;
+
         /* document rendering */
         cmd.beginOptionBlock();
         if (cmd.findOption("--document-type-title"))
@@ -373,16 +379,21 @@ int main(int argc, char *argv[])
             opt_renderFlags |= DSRTypes::HF_useCodeMeaningAsUnit;
         if (cmd.findOption("--render-all-codes"))
             opt_renderFlags |= DSRTypes::HF_renderAllCodes;
+        if (cmd.findOption("--code-details-tooltip"))
+        {
+            app.checkConflict("--code-details-tooltip", "--html-3.2", (opt_renderFlags & DSRTypes::HF_HTML32Compatibility) > 0);
+            opt_renderFlags |= DSRTypes::HF_useCodeDetailsTooltip;
+        }
     }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(dsr2htmlLogger, rcsid << OFendl);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dsr2htmlLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     int result = 0;
@@ -392,15 +403,15 @@ int main(int argc, char *argv[])
     {
         const char *ofname = NULL;
         cmd.getParam(2, ofname);
-        ofstream stream(ofname);
+        STD_NAMESPACE ofstream stream(ofname);
         if (stream.good())
         {
-            if (renderFile(stream, ifname, opt_cssName, opt_defaultCharset, opt_readMode, opt_ixfer, opt_readFlags, opt_renderFlags, opt_debugMode != 0).bad())
+            if (renderFile(stream, ifname, opt_cssName, opt_defaultCharset, opt_readMode, opt_ixfer, opt_readFlags, opt_renderFlags).bad())
                 result = 2;
         } else
             result = 1;
     } else {
-        if (renderFile(COUT, ifname, opt_cssName, opt_defaultCharset, opt_readMode, opt_ixfer, opt_readFlags, opt_renderFlags, opt_debugMode != 0).bad())
+        if (renderFile(COUT, ifname, opt_cssName, opt_defaultCharset, opt_readMode, opt_ixfer, opt_readFlags, opt_renderFlags).bad())
             result = 3;
     }
 
@@ -411,6 +422,57 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dsr2html.cc,v $
+ * Revision 1.37  2010-10-21 09:10:08  joergr
+ * Renamed variable to avoid warning reported by gcc with additional flags.
+ *
+ * Revision 1.36  2010-10-14 13:13:51  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.35  2009-10-30 10:08:34  joergr
+ * Option --processing-details now requires verbose mode.
+ *
+ * Revision 1.34  2009-10-14 10:51:56  joergr
+ * Fixed minor issues in log output. Also updated copyright date (if required).
+ *
+ * Revision 1.33  2009-10-13 14:57:49  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.32  2009-04-21 14:13:27  joergr
+ * Fixed minor inconsistencies in manpage / syntax usage.
+ *
+ * Revision 1.31  2008-09-25 14:14:21  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.30  2008-05-20 13:46:39  joergr
+ * Modified code to avoid warning message on MSVC compiler (implicit type
+ * conversion).
+ *
+ * Revision 1.29  2008-05-19 09:41:07  joergr
+ * Added new command line options that enables reading of SR documents with
+ * unknown/missing relationship type(s).
+ *
+ * Revision 1.28  2007/11/15 16:25:07  joergr
+ * Added support for output in XHTML 1.1 format.
+ *
+ * Revision 1.27  2006/08/15 16:40:02  meichel
+ * Updated the code in module dcmsr to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.26  2006/07/27 14:52:00  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
+ * Revision 1.25  2006/07/25 13:33:30  joergr
+ * Added new command line options --always-expand-inline, --section-title-inline
+ * and --code-details-tooltip (according to new optional HTML rendering flags).
+ * Changed short option of --render-all-codes from +Ca to +Cc in order to avoid
+ * conflicts with option --charset-assume.
+ *
+ * Revision 1.24  2006/05/11 09:13:45  joergr
+ * Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  * Revision 1.23  2005/12/08 15:47:33  meichel
  * Changed include path schema for all DCMTK header files
  *
