@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose: Convert the contents of a DICOM structured reporting file to
  *           XML format
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:34 $
- *  CVS/RCS Revision: $Revision: 1.28 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-21 09:10:08 $
+ *  CVS/RCS Revision: $Revision: 1.42 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,11 +31,10 @@
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #include "dcmtk/dcmsr/dsrdoc.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofconapp.h"
-#include "dcmtk/dcmdata/dcuid.h"       /* for dcmtk version name */
+#include "dcmtk/dcmdata/dcuid.h"      /* for dcmtk version name */
 
 #ifdef WITH_ZLIB
 #include <zlib.h>        /* for zlibVersion() */
@@ -47,6 +42,8 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dsr2xml"
 
+static OFLogger dsr2xmlLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -54,84 +51,66 @@ static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
 // ********************************************
 
 
-static OFCondition writeFile(ostream &out,
+static OFCondition writeFile(STD_NAMESPACE ostream &out,
                              const char *ifname,
-                             const E_FileReadMode readMode,
-                             const E_TransferSyntax xfer,
+                             DcmDataset *dset,
                              const size_t readFlags,
                              const size_t writeFlags,
                              const char *defaultCharset,
-                             const OFBool debugMode)
+                             const OFBool checkAllStrings)
 {
-    OFCondition result = EC_Normal;
-
-    if ((ifname == NULL) || (strlen(ifname) == 0))
+    OFCondition result = EC_IllegalParameter;
+    if ((ifname != NULL) && (dset != NULL))
     {
-        CERR << OFFIS_CONSOLE_APPLICATION << ": invalid filename: <empty string>" << endl;
-        return EC_IllegalParameter;
-    }
-
-    DcmFileFormat *dfile = new DcmFileFormat();
-    if (dfile != NULL)
-    {
-        if (readMode == ERM_dataset)
-            result = dfile->getDataset()->loadFile(ifname, xfer);
-        else
-            result = dfile->loadFile(ifname, xfer);
-        if (result.bad())
-        {
-            CERR << OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
-                 << ") reading file: "<< ifname << endl;
-        }
-    } else
-        result = EC_MemoryExhausted;
-
-    if (result.good())
-    {
-        result = EC_CorruptedData;
         DSRDocument *dsrdoc = new DSRDocument();
         if (dsrdoc != NULL)
         {
-            if (debugMode)
-                dsrdoc->setLogStream(&ofConsole);
-            result = dsrdoc->read(*dfile->getDataset(), readFlags);
+            result = dsrdoc->read(*dset, readFlags);
             if (result.good())
             {
                 // check extended character set
-
                 const char *charset = dsrdoc->getSpecificCharacterSet();
-                if ((charset == NULL || strlen(charset) == 0) && dsrdoc->containsExtendedCharacters())
+                if ((charset == NULL || strlen(charset) == 0) && dset->containsExtendedCharacters(checkAllStrings))
                 {
-                  // we have an unspecified extended character set
-                  if (defaultCharset == NULL)
-                  {
-                    /* the dataset contains non-ASCII characters that really should not be there */
-                    CERR << OFFIS_CONSOLE_APPLICATION << ": error: (0008,0005) Specific Character Set absent "
-                         << "but extended characters used in file: " << ifname << endl;
-                    result = EC_IllegalCall;
-                  } else  {
-                    OFString charset(defaultCharset);
-                    if (charset == "latin-1") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin1);
-                    else if (charset == "latin-2") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin2);
-                    else if (charset == "latin-3") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin3);
-                    else if (charset == "latin-4") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin4);
-                    else if (charset == "latin-5") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin5);
-                    else if (charset == "cyrillic") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Cyrillic);
-                    else if (charset == "arabic") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Arabic);
-                    else if (charset == "greek") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Greek);
-                    else if (charset == "hebrew") dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Hebrew);
-                  }
+                    // we have an unspecified extended character set
+                    if (defaultCharset == NULL)
+                    {
+                      /* the dataset contains non-ASCII characters that really should not be there */
+                      OFLOG_FATAL(dsr2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": error: (0008,0005) Specific Character Set absent "
+                          << "but extended characters used in file: " << ifname);
+                      result = EC_IllegalCall;
+                    } else {
+                        OFString charsetStr(defaultCharset);
+                        if (charsetStr == "latin-1")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin1);
+                        else if (charsetStr == "latin-2")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin2);
+                        else if (charsetStr == "latin-3")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin3);
+                        else if (charsetStr == "latin-4")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin4);
+                        else if (charsetStr == "latin-5")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Latin5);
+                        else if (charsetStr == "cyrillic")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Cyrillic);
+                        else if (charsetStr == "arabic")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Arabic);
+                        else if (charsetStr == "greek")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Greek);
+                        else if (charsetStr == "hebrew")
+                            dsrdoc->setSpecificCharacterSetType(DSRTypes::CS_Hebrew);
+                    }
                 }
-                if (result.good()) result = dsrdoc->writeXML(out, writeFlags);
+                if (result.good())
+                    result = dsrdoc->writeXML(out, writeFlags);
             } else {
-                CERR << OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
-                     << ") parsing file: "<< ifname << endl;
+                OFLOG_FATAL(dsr2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
+                    << ") parsing file: " << ifname);
             }
-        }
+        } else
+            result = EC_MemoryExhausted;
         delete dsrdoc;
     }
-    delete dfile;
-
     return result;
 }
 
@@ -142,91 +121,83 @@ static OFCondition writeFile(ostream &out,
 
 int main(int argc, char *argv[])
 {
-    int opt_debugMode = 0;
     size_t opt_readFlags = 0;
     size_t opt_writeFlags = 0;
     const char *opt_defaultCharset = NULL;
     E_FileReadMode opt_readMode = ERM_autoDetect;
     E_TransferSyntax opt_ixfer = EXS_Unknown;
-
-    SetDebugLevel(( 0 ));
+    OFBool opt_checkAllStrings = OFFalse;
 
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, "Convert DICOM SR file and data set to XML", rcsid);
     OFCommandLine cmd;
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
     cmd.setParamColumn(LONGCOL + SHORTCOL + 4);
 
-    cmd.addParam("dsrfile-in",   "DICOM SR input filename to be converted", OFCmdParam::PM_Mandatory);
-    cmd.addParam("xmlfile-out",  "XML output filename (default: stdout)", OFCmdParam::PM_Optional);
+    cmd.addParam("dsrfile-in",  "DICOM SR input filename to be converted", OFCmdParam::PM_Mandatory);
+    cmd.addParam("xmlfile-out", "XML output filename (default: stdout)", OFCmdParam::PM_Optional);
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-      cmd.addOption("--help",                  "-h",  "print this help text and exit");
-      cmd.addOption("--version",                      "print version information and exit", OFTrue /* exclusive */);
-      cmd.addOption("--debug",                 "-d",  "debug mode, print debug information");
-      cmd.addOption("--verbose-debug",         "-dd", "verbose debug mode, print more details");
+      cmd.addOption("--help",                   "-h",     "print this help text and exit", OFCommandLine::AF_Exclusive);
+      cmd.addOption("--version",                          "print version information and exit", OFCommandLine::AF_Exclusive);
+      OFLog::addOptions(cmd);
 
     cmd.addGroup("input options:");
       cmd.addSubGroup("input file format:");
-        cmd.addOption("--read-file",            "+f",  "read file format or data set (default)");
-        cmd.addOption("--read-file-only",       "+fo", "read file format only");
-        cmd.addOption("--read-dataset",         "-f",  "read data set without file meta information");
+        cmd.addOption("--read-file",            "+f",     "read file format or data set (default)");
+        cmd.addOption("--read-file-only",       "+fo",    "read file format only");
+        cmd.addOption("--read-dataset",         "-f",     "read data set without file meta information");
       cmd.addSubGroup("input transfer syntax:");
-        cmd.addOption("--read-xfer-auto",       "-t=", "use TS recognition (default)");
-        cmd.addOption("--read-xfer-detect",     "-td", "ignore TS specified in the file meta header");
-        cmd.addOption("--read-xfer-little",     "-te", "read with explicit VR little endian TS");
-        cmd.addOption("--read-xfer-big",        "-tb", "read with explicit VR big endian TS");
-        cmd.addOption("--read-xfer-implicit",   "-ti", "read with implicit VR little endian TS");
+        cmd.addOption("--read-xfer-auto",       "-t=",    "use TS recognition (default)");
+        cmd.addOption("--read-xfer-detect",     "-td",    "ignore TS specified in the file meta header");
+        cmd.addOption("--read-xfer-little",     "-te",    "read with explicit VR little endian TS");
+        cmd.addOption("--read-xfer-big",        "-tb",    "read with explicit VR big endian TS");
+        cmd.addOption("--read-xfer-implicit",   "-ti",    "read with implicit VR little endian TS");
 
     cmd.addGroup("processing options:");
       cmd.addSubGroup("character set:");
-        cmd.addOption("--charset-require",     "+Cr",    "require declaration of ext. charset (default)");
-        cmd.addOption("--charset-assume",      "+Ca", 1, "charset: string constant (latin-1 to -5,",
-                                                         "greek, cyrillic, arabic, hebrew)\n"
-                                                         "assume charset if undeclared ext. charset found");
+        cmd.addOption("--charset-require",      "+Cr",    "require declaration of ext. charset (default)");
+        cmd.addOption("--charset-assume",       "+Ca", 1, "[c]harset: string constant (latin-1 to -5,",
+                                                          "greek, cyrillic, arabic, hebrew)\n"
+                                                          "assume charset c if no extended charset found");
+        cmd.addOption("--charset-check-all",    "+Cc",    "check all data elements with string values\n(default: only PN, LO, LT, SH, ST and UT)");
     cmd.addGroup("output options:");
       cmd.addSubGroup("encoding:");
-        cmd.addOption("--attr-all",             "+Ea", "encode everything as XML attribute\n(shortcut for +Ec, +Er, +Ev and +Et)");
-        cmd.addOption("--attr-code",            "+Ec", "encode code value, coding scheme designator\nand coding scheme version as XML attribute");
-        cmd.addOption("--attr-relationship",    "+Er", "encode relationship type as XML attribute");
-        cmd.addOption("--attr-value-type",      "+Ev", "encode value type as XML attribute");
-        cmd.addOption("--attr-template-id",     "+Et", "encode template id as XML attribute");
-        cmd.addOption("--template-envelope",    "+Ee", "template element encloses content items\n(requires +Wt, implies +Et)");
+        cmd.addOption("--attr-all",             "+Ea",    "encode everything as XML attribute\n(shortcut for +Ec, +Er, +Ev and +Et)");
+        cmd.addOption("--attr-code",            "+Ec",    "encode code value, coding scheme designator\nand coding scheme version as XML attribute");
+        cmd.addOption("--attr-relationship",    "+Er",    "encode relationship type as XML attribute");
+        cmd.addOption("--attr-value-type",      "+Ev",    "encode value type as XML attribute");
+        cmd.addOption("--attr-template-id",     "+Et",    "encode template id as XML attribute");
+        cmd.addOption("--template-envelope",    "+Ee",    "template element encloses content items\n(requires +Wt, implies +Et)");
       cmd.addSubGroup("XML structure:");
-        cmd.addOption("--add-schema-reference", "+Xs", "add reference to XML Schema \"" DCMSR_XML_XSD_FILE "\"\n(not with +Ea, +Ec, +Er, +Ev, +Et, +Ee, +We)");
-        cmd.addOption("--use-xml-namespace",    "+Xn", "add XML namespace declaration to root element");
+        cmd.addOption("--add-schema-reference", "+Xs",    "add reference to XML Schema \"" DCMSR_XML_XSD_FILE "\"\n(not with +Ea, +Ec, +Er, +Ev, +Et, +Ee, +We)");
+        cmd.addOption("--use-xml-namespace",    "+Xn",    "add XML namespace declaration to root element");
       cmd.addSubGroup("writing:");
-        cmd.addOption("--write-empty-tags",     "+We", "write all tags even if their value is empty");
-        cmd.addOption("--write-item-id",        "+Wi", "always write item identifier");
-        cmd.addOption("--write-template-id",    "+Wt", "write template identification information");
+        cmd.addOption("--write-empty-tags",     "+We",    "write all tags even if their value is empty");
+        cmd.addOption("--write-item-id",        "+Wi",    "always write item identifier");
+        cmd.addOption("--write-template-id",    "+Wt",    "write template identification information");
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
         /* check exclusive options first */
-        if (cmd.getParamCount() == 0)
+        if (cmd.hasExclusiveOption())
         {
-          if (cmd.findOption("--version"))
-          {
-              app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-              CERR << endl << "External libraries used:";
+            if (cmd.findOption("--version"))
+            {
+                app.printHeader(OFTrue /*print host identifier*/);
+                COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-              CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+                COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-              CERR << " none" << endl;
+                COUT << " none" << OFendl;
 #endif
-              return 0;
-           }
+                return 0;
+            }
         }
 
         /* general options */
-        if (cmd.findOption("--debug"))
-            opt_debugMode = 2;
-        if (cmd.findOption("--verbose-debug"))
-        {
-            opt_debugMode = 5;
-            opt_readFlags |= DSRTypes::RF_verboseDebugMode;
-        }
+        OFLog::configureFromCommandLine(cmd, app);
 
         /* input options */
         cmd.beginOptionBlock();
@@ -259,21 +230,21 @@ int main(int argc, char *argv[])
 
         cmd.beginOptionBlock();
         if (cmd.findOption("--charset-require"))
-        {
-           opt_defaultCharset = NULL;
-        }
+            opt_defaultCharset = NULL;
         if (cmd.findOption("--charset-assume"))
         {
-          app.checkValue(cmd.getValue(opt_defaultCharset));
-          OFString charset(opt_defaultCharset);
-          if (charset != "latin-1" && charset != "latin-2" && charset != "latin-3" &&
-              charset != "latin-4" && charset != "latin-5" && charset != "cyrillic" &&
-              charset != "arabic" && charset != "greek" && charset != "hebrew")
-          {
-            app.printError("unknown value for --charset-assume. known values are latin-1 to -5, cyrillic, arabic, greek, hebrew.");
-          }
+            app.checkValue(cmd.getValue(opt_defaultCharset));
+            OFString charset(opt_defaultCharset);
+            if (charset != "latin-1" && charset != "latin-2" && charset != "latin-3" &&
+                charset != "latin-4" && charset != "latin-5" && charset != "cyrillic" &&
+                charset != "arabic" && charset != "greek" && charset != "hebrew")
+            {
+                app.printError("unknown value for --charset-assume. known values are latin-1 to -5, cyrillic, arabic, greek, hebrew.");
+            }
         }
         cmd.endOptionBlock();
+        if (cmd.findOption("--charset-check-all"))
+            opt_checkAllStrings = OFTrue;
 
         /* output options */
         if (cmd.findOption("--attr-all"))
@@ -316,34 +287,53 @@ int main(int argc, char *argv[])
             app.checkDependence("--template-envelope", "--write-template-id", (opt_writeFlags & DSRTypes::XF_writeTemplateIdentification) > 0);
     }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(dsr2xmlLogger, rcsid << OFendl);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dsr2xmlLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     int result = 0;
+    /* first parameter is treated as the input filename */
     const char *ifname = NULL;
     cmd.getParam(1, ifname);
-    if (cmd.getParamCount() == 2)
+    /* check input file */
+    if ((ifname != NULL) && (strlen(ifname) > 0))
     {
-        const char *ofname = NULL;
-        cmd.getParam(2, ofname);
-        ofstream stream(ofname);
-        if (stream.good())
+        /* read DICOM file or data set */
+        DcmFileFormat dfile;
+        OFCondition status = dfile.loadFile(ifname, opt_ixfer);
+        if (status.good())
         {
-            if (writeFile(stream, ifname, opt_readMode, opt_ixfer, opt_readFlags, opt_writeFlags, opt_defaultCharset, opt_debugMode != 0).bad())
-                result = 2;
-        } else
-            result = 1;
-    } else {
-        if (writeFile(COUT, ifname, opt_readMode, opt_ixfer, opt_readFlags, opt_writeFlags, opt_defaultCharset, opt_debugMode != 0).bad())
-            result = 3;
-    }
+            DcmDataset *dset = dfile.getDataset();
+            /* if second parameter is present, it is treated as the output filename ("stdout" otherwise) */
+            if (cmd.getParamCount() == 2)
+            {
+                const char *ofname = NULL;
+                cmd.getParam(2, ofname);
+                STD_NAMESPACE ofstream stream(ofname);
+                if (stream.good())
+                {
+                    /* write content in XML format to file */
+                    if (writeFile(stream, ifname, dset, opt_readFlags, opt_writeFlags, opt_defaultCharset, opt_checkAllStrings).bad())
+                        result = 2;
+                } else
+                    result = 1;
+            } else {
+                /* write content in XML format to standard output */
+                if (writeFile(COUT, ifname, dset, opt_readFlags, opt_writeFlags, opt_defaultCharset, opt_checkAllStrings).bad())
+                    result = 3;
+            }
+        } else {
+            OFLOG_FATAL(dsr2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << status.text()
+                << ") reading file: " << ifname);
+        }
+    } else
+        OFLOG_FATAL(dsr2xmlLogger, OFFIS_CONSOLE_APPLICATION << ": invalid filename: <empty string>");
 
     return result;
 }
@@ -352,6 +342,55 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dsr2xml.cc,v $
+ * Revision 1.42  2010-10-21 09:10:08  joergr
+ * Renamed variable to avoid warning reported by gcc with additional flags.
+ *
+ * Revision 1.41  2010-10-14 13:13:51  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.40  2009-10-14 10:51:56  joergr
+ * Fixed minor issues in log output. Also updated copyright date (if required).
+ *
+ * Revision 1.39  2009-10-13 14:57:49  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.38  2009-04-21 14:13:27  joergr
+ * Fixed minor inconsistencies in manpage / syntax usage.
+ *
+ * Revision 1.37  2008-09-25 14:14:21  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.36  2008-01-23 15:13:26  joergr
+ * Restructured code in order to avoid empty output file in case the input file
+ * could not be read.
+ *
+ * Revision 1.35  2007/11/15 16:22:42  joergr
+ * Fixed coding style to be more consistent.
+ *
+ * Revision 1.34  2006/12/13 14:16:15  joergr
+ * Added new command line option that allows to check all data elements with
+ * string values for extended characters, not only those affected by Specific
+ * CharacterSet (0008,0005).
+ *
+ * Revision 1.33  2006/08/15 16:40:02  meichel
+ * Updated the code in module dcmsr to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.32  2006/07/27 14:52:00  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
+ * Revision 1.31  2006/07/25 13:32:01  joergr
+ * Fixed minor layout and formatting issues.
+ *
+ * Revision 1.30  2006/05/11 09:13:45  joergr
+ * Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
+ * Revision 1.29  2006/02/23 12:49:43  joergr
+ * Fixed layout and formatting issues.
+ *
  * Revision 1.28  2005/12/08 15:47:34  meichel
  * Changed include path schema for all DCMTK header files
  *
