@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: List the contents of a dicom structured reporting file
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:35 $
- *  CVS/RCS Revision: $Revision: 1.23 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:13:52 $
+ *  CVS/RCS Revision: $Revision: 1.34 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -34,7 +30,6 @@
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
 #include "dcmtk/dcmsr/dsrdoc.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/ofstd/ofconapp.h"
@@ -46,6 +41,8 @@
 
 #define OFFIS_CONSOLE_APPLICATION "dsrdump"
 
+static OFLogger dsrdumpLogger = OFLog::getLogger("dcmtk.apps." OFFIS_CONSOLE_APPLICATION);
+
 static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
   OFFIS_DCMTK_VERSION " " OFFIS_DCMTK_RELEASEDATE " $";
 
@@ -53,19 +50,18 @@ static char rcsid[] = "$dcmtk: " OFFIS_CONSOLE_APPLICATION " v"
 // ********************************************
 
 
-static OFCondition dumpFile(ostream &out,
+static OFCondition dumpFile(STD_NAMESPACE ostream &out,
                             const char *ifname,
                             const E_FileReadMode readMode,
                             const E_TransferSyntax xfer,
                             const size_t readFlags,
-                            const size_t printFlags,
-                            const OFBool debugMode)
+                            const size_t printFlags)
 {
     OFCondition result = EC_Normal;
 
     if ((ifname == NULL) || (strlen(ifname) == 0))
     {
-        CERR << OFFIS_CONSOLE_APPLICATION << ": invalid filename: <empty string>" << endl;
+        OFLOG_FATAL(dsrdumpLogger, OFFIS_CONSOLE_APPLICATION << ": invalid filename: <empty string>");
         return EC_IllegalParameter;
     }
 
@@ -78,8 +74,8 @@ static OFCondition dumpFile(ostream &out,
             result = dfile->loadFile(ifname, xfer);
         if (result.bad())
         {
-            CERR << OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
-                 << ") reading file: "<< ifname << endl;
+            OFLOG_FATAL(dsrdumpLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
+                << ") reading file: " << ifname);
         }
     } else
         result = EC_MemoryExhausted;
@@ -90,18 +86,16 @@ static OFCondition dumpFile(ostream &out,
         DSRDocument *dsrdoc = new DSRDocument();
         if (dsrdoc != NULL)
         {
-            if (debugMode)
-                dsrdoc->setLogStream(&ofConsole);
             result = dsrdoc->read(*dfile->getDataset(), readFlags);
             if (result.good())
             {
                 result = dsrdoc->print(out, printFlags);
-                out << endl;
+                out << OFendl;
             }
             else
             {
-                CERR << OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
-                     << ") parsing file: "<< ifname << endl;
+                OFLOG_FATAL(dsrdumpLogger, OFFIS_CONSOLE_APPLICATION << ": error (" << result.text()
+                    << ") parsing file: " << ifname);
             }
         }
         delete dsrdoc;
@@ -113,20 +107,17 @@ static OFCondition dumpFile(ostream &out,
 
 
 #define SHORTCOL 3
-#define LONGCOL 21
+#define LONGCOL 22
 
 
 int main(int argc, char *argv[])
 {
-    int opt_debugMode = 0;
     size_t opt_readFlags = 0;
     size_t opt_printFlags = DSRTypes::PF_shortenLongItemValues;
     OFBool opt_printFilename = OFFalse;
     E_FileReadMode opt_readMode = ERM_autoDetect;
     E_TransferSyntax opt_ixfer = EXS_Unknown;
 
-    SetDebugLevel(( 0 ));
-
     OFConsoleApplication app(OFFIS_CONSOLE_APPLICATION, "Dump DICOM SR file and data set", rcsid);
     OFCommandLine cmd;
     cmd.setOptionColumns(LONGCOL, SHORTCOL);
@@ -135,10 +126,9 @@ int main(int argc, char *argv[])
     cmd.addParam("dsrfile-in", "DICOM SR input filename to be dumped", OFCmdParam::PM_MultiMandatory);
 
     cmd.addGroup("general options:", LONGCOL, SHORTCOL + 2);
-      cmd.addOption("--help",                   "-h",  "print this help text and exit");
-      cmd.addOption("--version",                       "print version information and exit", OFTrue /* exclusive */);
-      cmd.addOption("--debug",                  "-d",  "debug mode, print debug information");
-      cmd.addOption("--verbose-debug",          "-dd", "verbose debug mode, print more details");
+      cmd.addOption("--help",                   "-h",  "print this help text and exit", OFCommandLine::AF_Exclusive);
+      cmd.addOption("--version",                       "print version information and exit", OFCommandLine::AF_Exclusive);
+      OFLog::addOptions(cmd);
 
     cmd.addGroup("input options:");
       cmd.addSubGroup("input file format:");
@@ -156,6 +146,7 @@ int main(int argc, char *argv[])
       cmd.addSubGroup("additional information:");
         cmd.addOption("--processing-details",   "-Ip", "show currently processed content item");
       cmd.addSubGroup("error handling:");
+        cmd.addOption("--unknown-relationship", "-Er", "accept unknown/missing relationship type");
         cmd.addOption("--ignore-constraints",   "-Ec", "ignore relationship content constraints");
         cmd.addOption("--ignore-item-errors",   "-Ee", "do not abort on content item errors, just warn\n(e.g. missing value type specific attributes)");
         cmd.addOption("--skip-invalid-items",   "-Ei", "skip invalid content items (incl. sub-tree)");
@@ -174,32 +165,26 @@ int main(int argc, char *argv[])
 
     /* evaluate command line */
     prepareCmdLineArgs(argc, argv, OFFIS_CONSOLE_APPLICATION);
-    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::ExpandWildcards))
+    if (app.parseCommandLine(cmd, argc, argv, OFCommandLine::PF_ExpandWildcards))
     {
         /* check exclusive options first */
-        if (cmd.getParamCount() == 0)
+        if (cmd.hasExclusiveOption())
         {
-          if (cmd.findOption("--version"))
-          {
-              app.printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-              CERR << endl << "External libraries used:";
+            if (cmd.findOption("--version"))
+            {
+                app.printHeader(OFTrue /*print host identifier*/);
+                COUT << OFendl << "External libraries used:";
 #ifdef WITH_ZLIB
-              CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+                COUT << OFendl << "- ZLIB, Version " << zlibVersion() << OFendl;
 #else
-              CERR << " none" << endl;
+                COUT << " none" << OFendl;
 #endif
-              return 0;
-           }
+                return 0;
+            }
         }
 
         /* options */
-        if (cmd.findOption("--debug"))
-            opt_debugMode = 2;
-        if (cmd.findOption("--verbose-debug"))
-        {
-            opt_debugMode = 5;
-            opt_readFlags |= DSRTypes::RF_verboseDebugMode;
-        }
+        OFLog::configureFromCommandLine(cmd, app);
 
         cmd.beginOptionBlock();
         if (cmd.findOption("--read-file")) opt_readMode = ERM_autoDetect;
@@ -230,7 +215,12 @@ int main(int argc, char *argv[])
         cmd.endOptionBlock();
 
         if (cmd.findOption("--processing-details"))
+        {
+            app.checkDependence("--processing-details", "verbose mode", dsrdumpLogger.isEnabledFor(OFLogger::INFO_LOG_LEVEL));
             opt_readFlags |= DSRTypes::RF_showCurrentlyProcessedItem;
+        }
+        if (cmd.findOption("--unknown-relationship"))
+            opt_readFlags |= DSRTypes::RF_acceptUnknownRelationshipType;
         if (cmd.findOption("--ignore-constraints"))
             opt_readFlags |= DSRTypes::RF_ignoreRelationshipConstraints;
         if (cmd.findOption("--ignore-item-errors"))
@@ -265,14 +255,14 @@ int main(int argc, char *argv[])
             opt_printFlags |= DSRTypes::PF_printTemplateIdentification;
     }
 
-    SetDebugLevel((opt_debugMode));
+    /* print resource identifier */
+    OFLOG_DEBUG(dsrdumpLogger, rcsid << OFendl);
 
     /* make sure data dictionary is loaded */
     if (!dcmDataDict.isDictionaryLoaded())
     {
-        CERR << "Warning: no data dictionary loaded, "
-             << "check environment variable: "
-             << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+        OFLOG_WARN(dsrdumpLogger, "no data dictionary loaded, check environment variable: "
+            << DCM_DICT_ENVIRONMENT_VARIABLE);
     }
 
     int errorCount = 0;
@@ -283,10 +273,11 @@ int main(int argc, char *argv[])
         cmd.getParam(i, current);
         if (opt_printFilename)
         {
-            COUT << OFString(79, '-') << endl;
-            COUT << OFFIS_CONSOLE_APPLICATION << " (" << i << "/" << count << "): " << current << endl << endl;
+            if (i > 1)
+                COUT << OFString(79, '-') << OFendl;
+            COUT << OFFIS_CONSOLE_APPLICATION << " (" << i << "/" << count << "): " << current << OFendl << OFendl;
         }
-        if (dumpFile(COUT, current, opt_readMode, opt_ixfer, opt_readFlags, opt_printFlags, opt_debugMode != 0).bad())
+        if (dumpFile(COUT, current, opt_readMode, opt_ixfer, opt_readFlags, opt_printFlags).bad())
             errorCount++;
     }
 
@@ -300,6 +291,45 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log:
  * $Log: dsrdump.cc,v $
+ * Revision 1.34  2010-10-14 13:13:52  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.33  2009-11-03 09:13:54  joergr
+ * Switched to old behavior: Output input filename to COUT and not to the log
+ * stream.
+ *
+ * Revision 1.32  2009-10-30 10:08:34  joergr
+ * Option --processing-details now requires verbose mode.
+ *
+ * Revision 1.31  2009-10-14 10:51:56  joergr
+ * Fixed minor issues in log output. Also updated copyright date (if required).
+ *
+ * Revision 1.30  2009-10-13 14:57:50  uli
+ * Switched to logging mechanism provided by the "new" oflog module.
+ *
+ * Revision 1.29  2008-09-25 14:14:21  joergr
+ * Added support for printing the expanded command line arguments.
+ * Always output the resource identifier of the command line tool in debug mode.
+ *
+ * Revision 1.28  2008-05-19 09:41:07  joergr
+ * Added new command line options that enables reading of SR documents with
+ * unknown/missing relationship type(s).
+ *
+ * Revision 1.27  2007/11/15 16:22:42  joergr
+ * Fixed coding style to be more consistent.
+ *
+ * Revision 1.26  2006/08/15 16:40:02  meichel
+ * Updated the code in module dcmsr to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.25  2006/07/27 14:52:00  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ *
+ * Revision 1.24  2006/07/25 13:31:40  joergr
+ * Fixed minor layout and formatting issues.
+ *
  * Revision 1.23  2005/12/08 15:47:35  meichel
  * Changed include path schema for all DCMTK header files
  *
