@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmsr
  *
@@ -23,9 +19,9 @@
  *    classes: DSRSOPInstanceReferenceList
  *             - InstanceStruct, SeriesStruct, StudyStruct
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 16:05:18 $
- *  CVS/RCS Revision: $Revision: 1.9 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:16:33 $
+ *  CVS/RCS Revision: $Revision: 1.15 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -40,7 +36,6 @@
 
 #include "dcmtk/ofstd/oflist.h"
 #include "dcmtk/ofstd/ofstring.h"
-#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/ofstd/ofcond.h"
 
 #include "dcmtk/dcmdata/dcitem.h"
@@ -98,19 +93,15 @@ class DSRSOPInstanceReferenceList
 
         /** read instance level attributes from dataset
          ** @param  dataset    DICOM dataset from which the list should be read
-         *  @param  logStream  pointer to error/warning output stream (output disabled if NULL)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition read(DcmItem &dataset,
-                         OFConsole *logStream);
+        OFCondition read(DcmItem &dataset);
 
         /** write series and instance level attributes to dataset
          ** @param  dataset    DICOM dataset to which the list should be written
-         *  @param  logStream  pointer to error/warning output stream (output disabled if NULL)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition write(DcmItem &dataset,
-                          OFConsole *logStream) const;
+        OFCondition write(DcmItem &dataset) const;
 
         /** read series and instance level attributes from XML document
          ** @param  doc     document containing the XML file content
@@ -125,7 +116,7 @@ class DSRSOPInstanceReferenceList
          *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition writeXML(ostream &stream,
+        OFCondition writeXML(STD_NAMESPACE ostream &stream,
                              const size_t flags = 0) const;
 
         /** set cursor to the specified instance (if existent)
@@ -161,12 +152,6 @@ class DSRSOPInstanceReferenceList
          */
         OFCondition removeItem();
 
-        /** check if this object contains non-ASCII characters in one of the
-         *  strings affected by SpecificCharacterSet in DICOM
-         *  @return true if node contains non-ASCII characters, false otherwise
-         */
-        OFBool containsExtendedCharacters();
-
         /// series instance UID (VR=UI, VM=1)
         const OFString SeriesUID;
         /// optional: retrieve application entity title (VR=AE, VM=1-n)
@@ -202,19 +187,15 @@ class DSRSOPInstanceReferenceList
 
         /** read series and instance level from dataset
          ** @param  dataset    DICOM dataset from which the list should be read
-         *  @param  logStream  pointer to error/warning output stream (output disabled if NULL)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition read(DcmItem &dataset,
-                         OFConsole *logStream);
+        OFCondition read(DcmItem &dataset);
 
         /** write study, series and instance level attributes to dataset
          ** @param  dataset    DICOM dataset to which the list should be written
-         *  @param  logStream  pointer to error/warning output stream (output disabled if NULL)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition write(DcmItem &dataset,
-                          OFConsole *logStream) const;
+        OFCondition write(DcmItem &dataset) const;
 
         /** read study, series and instance level attributes from XML document
          ** @param  doc     document containing the XML file content
@@ -229,7 +210,7 @@ class DSRSOPInstanceReferenceList
          *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
          ** @return status, EC_Normal if successful, an error code otherwise
          */
-        OFCondition writeXML(ostream &stream,
+        OFCondition writeXML(STD_NAMESPACE ostream &stream,
                              const size_t flags = 0) const;
 
         /** set cursor to the specified series entry (if existent)
@@ -280,12 +261,6 @@ class DSRSOPInstanceReferenceList
          */
         void removeIncompleteItems();
 
-        /** check if this object contains non-ASCII characters in one of the
-         *  strings affected by SpecificCharacterSet in DICOM
-         *  @return true if node contains non-ASCII characters, false otherwise
-         */
-        OFBool containsExtendedCharacters();
-
         /// study instance UID (VR=UI, VM=1)
         const OFString StudyUID;
 
@@ -325,20 +300,16 @@ class DSRSOPInstanceReferenceList
      *  i.e. the structure might look different when written back to a dataset.  However,
      *  the content is identical and this way of storing information saves storage space.
      ** @param  dataset    DICOM dataset from which the data should be read
-     *  @param  logStream  pointer to error/warning output stream (output disabled if NULL)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition read(DcmItem &dataset,
-                     OFConsole *logStream);
+    OFCondition read(DcmItem &dataset);
 
     /** write list of referenced SOP instances.
      *  Does nothing if list is empty.
      ** @param  dataset    DICOM dataset to which the data should be written
-     *  @param  logStream  pointer to error/warning output stream (output disabled if NULL)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition write(DcmItem &dataset,
-                      OFConsole *logStream) const;
+    OFCondition write(DcmItem &dataset) const;
 
     /** read list of references from XML document.
      *  The hierarchical structure is automatically reorganized in a way that each study,
@@ -359,7 +330,7 @@ class DSRSOPInstanceReferenceList
      *  @param  flags   optional flag used to customize the output (see DSRTypes::XF_xxx)
      ** @return status, EC_Normal if successful, an error code otherwise
      */
-    OFCondition writeXML(ostream &stream,
+    OFCondition writeXML(STD_NAMESPACE ostream &stream,
                          const size_t flags = 0) const;
 
     /** add the specified item to the list of references.
@@ -510,11 +481,6 @@ class DSRSOPInstanceReferenceList
      */
     OFCondition setStorageMediaFileSetUID(const OFString &value);
 
-    /** check if this object contains non-ASCII characters in one of the
-     *  strings affected by SpecificCharacterSet in DICOM
-     *  @return true if node contains non-ASCII characters, false otherwise
-     */
-    OFBool containsExtendedCharacters();
 
   protected:
 
@@ -571,6 +537,25 @@ class DSRSOPInstanceReferenceList
 /*
  *  CVS/RCS Log:
  *  $Log: dsrsoprf.h,v $
+ *  Revision 1.15  2010-10-14 13:16:33  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.14  2010-02-22 11:39:55  uli
+ *  Remove some unneeded includes.
+ *
+ *  Revision 1.13  2009-10-13 14:57:50  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.12  2007-11-15 16:33:19  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.11  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.10  2006/05/11 09:18:21  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  *  Revision 1.9  2005/12/08 16:05:18  meichel
  *  Changed include path schema for all DCMTK header files
  *
