@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2003, OFFIS
+ *  Copyright (C) 2003-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRChestCadSRConstraintChecker
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:38 $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:40 $
+ *  CVS/RCS Revision: $Revision: 1.8 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -89,8 +85,8 @@ OFBool DSRChestCadSRConstraintChecker::checkContentRelationship(const E_ValueTyp
     else if ((relationshipType == RT_hasObsContext) && !byReference && ((sourceValueType == VT_Container) ||
         (sourceValueType == VT_Text) || (sourceValueType == VT_Code) || (sourceValueType == VT_Num)))
     {
-        result = (targetValueType == VT_Text)   || (targetValueType == VT_Code)  || (targetValueType == VT_Num)  ||
-                 (targetValueType == VT_Date)   || (targetValueType == VT_Time) || (targetValueType == VT_PName) ||
+        result = (targetValueType == VT_Text) || (targetValueType == VT_Code) || (targetValueType == VT_Num) ||
+                 (targetValueType == VT_Date) || (targetValueType == VT_Time) || (targetValueType == VT_PName) ||
                  (targetValueType == VT_UIDRef) || (targetValueType == VT_Composite);
     }
     /* row 3 of the table */
@@ -101,8 +97,8 @@ OFBool DSRChestCadSRConstraintChecker::checkContentRelationship(const E_ValueTyp
                  (targetValueType == VT_Date) || (targetValueType == VT_Time);
     }
     /* row 4 of the table */
-    else if ((relationshipType == RT_hasConceptMod) && !byReference &&
-        ((sourceValueType == VT_Container) || (sourceValueType == VT_Code) || (sourceValueType == VT_Composite)))
+    else if ((relationshipType == RT_hasConceptMod) && !byReference && ((sourceValueType == VT_Container) ||
+        (sourceValueType == VT_Code) || (sourceValueType == VT_Composite) || (sourceValueType == VT_Num)))
     {
         result = (targetValueType == VT_Text) || (targetValueType == VT_Code);
     }
@@ -111,17 +107,18 @@ OFBool DSRChestCadSRConstraintChecker::checkContentRelationship(const E_ValueTyp
         ((sourceValueType == VT_Text) || (sourceValueType == VT_Code) || (sourceValueType == VT_Num)))
     {
         /* by-reference allowed */
-        result = (targetValueType == VT_Text)   || (targetValueType == VT_Code)  || (targetValueType == VT_Num)      ||
-                 (targetValueType == VT_Date)   || (targetValueType == VT_Image) || (targetValueType == VT_Waveform) ||
-                 (targetValueType == VT_SCoord) || (targetValueType == VT_TCoord);
+        result = (targetValueType == VT_Container) || (targetValueType == VT_Text) || (targetValueType == VT_Code) ||
+                 (targetValueType == VT_Num) || (targetValueType == VT_Date) || (targetValueType == VT_Image) ||
+                 (targetValueType == VT_Waveform) || (targetValueType == VT_SCoord) || (targetValueType == VT_TCoord) ||
+                 (targetValueType == VT_UIDRef);
     }
     /* row 6 of the table */
     else if ((relationshipType == RT_inferredFrom) && ((sourceValueType == VT_Code) || (sourceValueType == VT_Num)))
     {
         /* by-reference allowed */
-        result = (targetValueType == VT_Code)     || (targetValueType == VT_Num)    || (targetValueType == VT_Image)  ||
+        result = (targetValueType == VT_Code) || (targetValueType == VT_Num) || (targetValueType == VT_Image) ||
                  (targetValueType == VT_Waveform) || (targetValueType == VT_SCoord) || (targetValueType == VT_TCoord) ||
-                 (targetValueType == VT_Container);
+                 (targetValueType == VT_Container) || (targetValueType == VT_Text);
     }
     /* row 7 of the table */
     else if ((relationshipType == RT_selectedFrom) && (sourceValueType == VT_SCoord))
@@ -142,6 +139,18 @@ OFBool DSRChestCadSRConstraintChecker::checkContentRelationship(const E_ValueTyp
 /*
  *  CVS/RCS Log:
  *  $Log: dsrchecc.cc,v $
+ *  Revision 1.8  2010-10-14 13:14:40  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.7  2010-06-09 16:35:12  joergr
+ *  Removed references to CP 767.
+ *
+ *  Revision 1.6  2009-08-07 08:36:36  joergr
+ *  Added missing relationship content constraint introduced with DICOM 2007.
+ *
+ *  Revision 1.5  2007-11-30 16:54:28  joergr
+ *  Updated relationship content constraints according to CP 767.
+ *
  *  Revision 1.4  2005/12/08 15:47:38  meichel
  *  Changed include path schema for all DCMTK header files
  *
