@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2003, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -23,8 +19,8 @@
  *    classes: DSRCodeTreeNode
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2003/09/15 14:13:42 $
- *  CVS/RCS Revision: $Revision: 1.18 $
+ *  Update Date:      $Date: 2010-10-14 13:14:40 $
+ *  CVS/RCS Revision: $Revision: 1.26 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,11 +28,11 @@
  */
 
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
-#include "dsrtypes.h"
-#include "dsrcodtn.h"
-#include "dsrxmld.h"
+#include "dcmtk/dcmsr/dsrtypes.h"
+#include "dcmtk/dcmsr/dsrcodtn.h"
+#include "dcmtk/dcmsr/dsrxmld.h"
 
 
 DSRCodeTreeNode::DSRCodeTreeNode(const E_RelationshipType relationshipType)
@@ -65,7 +61,7 @@ OFBool DSRCodeTreeNode::isValid() const
 }
 
 
-OFCondition DSRCodeTreeNode::print(ostream &stream,
+OFCondition DSRCodeTreeNode::print(STD_NAMESPACE ostream &stream,
                                    const size_t flags) const
 {
     OFCondition result = DSRDocumentTreeNode::print(stream, flags);
@@ -99,60 +95,68 @@ OFCondition DSRCodeTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRCodeTreeNode::writeXML(ostream &stream,
-                                      const size_t flags,
-                                      OFConsole *logStream) const
+OFCondition DSRCodeTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                      const size_t flags) const
 {
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags);
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
     if (flags & DSRTypes::XF_codeComponentsAsAttribute)
     {
         stream << "<value";     // bracket ">" is closed in next the writeXML() routine
-        DSRCodedEntryValue::writeXML(stream, flags, logStream);
-        stream << "</value>" << endl;
+        DSRCodedEntryValue::writeXML(stream, flags);
+        stream << "</value>" << OFendl;
     } else
-        DSRCodedEntryValue::writeXML(stream, flags, logStream);
+        DSRCodedEntryValue::writeXML(stream, flags);
     writeXMLItemEnd(stream, flags);
     return result;
 }
 
 
-OFCondition DSRCodeTreeNode::readContentItem(DcmItem &dataset,
-                                             OFConsole *logStream)
+OFCondition DSRCodeTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read ConceptCodeSequence */
-    return DSRCodedEntryValue::readSequence(dataset, DCM_ConceptCodeSequence, "1" /*type*/, logStream);
+    return DSRCodedEntryValue::readSequence(dataset, DCM_ConceptCodeSequence, "1" /*type*/);
 }
 
 
-OFCondition DSRCodeTreeNode::writeContentItem(DcmItem &dataset,
-                                              OFConsole *logStream) const
+OFCondition DSRCodeTreeNode::writeContentItem(DcmItem &dataset) const
 {
     /* write ConceptCodeSequence */
-    return DSRCodedEntryValue::writeSequence(dataset, DCM_ConceptCodeSequence, logStream);
+    return DSRCodedEntryValue::writeSequence(dataset, DCM_ConceptCodeSequence);
 }
 
 
-OFCondition DSRCodeTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                   ostream & /*annexStream*/,
+OFCondition DSRCodeTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                   STD_NAMESPACE ostream & /*annexStream*/,
                                                    const size_t /*nestingLevel*/,
                                                    size_t & /*annexNumber*/,
-                                                   const size_t flags,
-                                                   OFConsole *logStream) const
+                                                   const size_t flags) const
 {
     /* render ConceptName */
-    OFCondition result = renderHTMLConceptName(docStream, flags, logStream);
+    OFCondition result = renderHTMLConceptName(docStream, flags);
     /* render Code */
     if (result.good())
     {
         const OFBool fullCode = (flags & DSRTypes::HF_renderInlineCodes) || (flags & DSRTypes::HF_renderItemsSeparately);
-        if (!fullCode)
-            docStream << "<u>";
-        result = DSRCodedEntryValue::renderHTML(docStream, flags, logStream, fullCode);
-        if (!fullCode)
-            docStream << "</u>";
-        docStream << endl;
+        if (!fullCode || (flags & DSRTypes::HF_useCodeDetailsTooltip))
+        {
+            if (flags & DSRTypes::HF_XHTML11Compatibility)
+                docStream << "<span class=\"code\">";
+            else if (flags & DSRTypes::HF_HTML32Compatibility)
+                docStream << "<u>";
+            else /* HTML 4.01 */
+                docStream << "<span class=\"under\">";
+        }
+        result = DSRCodedEntryValue::renderHTML(docStream, flags, fullCode);
+        if (!fullCode || (flags & DSRTypes::HF_useCodeDetailsTooltip))
+        {
+            if (flags & DSRTypes::HF_HTML32Compatibility)
+                docStream << "</u>";
+            else
+                docStream << "</span>";
+        }
+        docStream << OFendl;
     }
     return result;
 }
@@ -161,6 +165,36 @@ OFCondition DSRCodeTreeNode::renderHTMLContentItem(ostream &docStream,
 /*
  *  CVS/RCS Log:
  *  $Log: dsrcodtn.cc,v $
+ *  Revision 1.26  2010-10-14 13:14:40  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.25  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.24  2007-11-15 16:45:26  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *  Enhanced support for output in valid HTML 3.2 format. Migrated support for
+ *  standard HTML from version 4.0 to 4.01 (strict).
+ *
+ *  Revision 1.23  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.22  2006/07/25 13:35:18  joergr
+ *  Added new optional flags for the HTML rendering of SR documents:
+ *  HF_alwaysExpandChildrenInline, HF_useCodeDetailsTooltip and
+ *  HF_renderSectionTitlesInline.
+ *
+ *  Revision 1.21  2006/05/11 09:16:49  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
+ *  Revision 1.20  2005/12/08 15:47:40  meichel
+ *  Changed include path schema for all DCMTK header files
+ *
+ *  Revision 1.19  2004/11/22 16:39:12  meichel
+ *  Added method that checks if the SR document contains non-ASCII characters
+ *    in any of the strings affected by SpecificCharacterSet.
+ *
  *  Revision 1.18  2003/09/15 14:13:42  joergr
  *  Introduced new class to facilitate checking of SR IOD relationship content
  *  constraints. Replaced old implementation distributed over numerous classes.
