@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRCodedEntryValue
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:41 $
- *  CVS/RCS Revision: $Revision: 1.20 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:40 $
+ *  CVS/RCS Revision: $Revision: 1.27 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -130,7 +126,7 @@ OFBool DSRCodedEntryValue::isEmpty() const
 }
 
 
-void DSRCodedEntryValue::print(ostream &stream,
+void DSRCodedEntryValue::print(STD_NAMESPACE ostream &stream,
                                const OFBool printCodeValue,
                                const OFBool printInvalid) const
 {
@@ -154,25 +150,23 @@ void DSRCodedEntryValue::print(ostream &stream,
 
 
 OFCondition DSRCodedEntryValue::readItem(DcmItem &dataset,
-                                         OFConsole *logStream,
                                          const char *moduleName)
 {
     /* read BasicCodedEntryAttributes only */
-    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_CodeValue, CodeValue, "1", "1", logStream, moduleName);
+    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_CodeValue, CodeValue, "1", "1", moduleName);
     if (result.good())
-        result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_CodingSchemeDesignator, CodingSchemeDesignator, "1", "1", logStream, moduleName);
+        result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_CodingSchemeDesignator, CodingSchemeDesignator, "1", "1", moduleName);
     if (result.good())                                             /* conditional (type 1C) */
-        DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_CodingSchemeVersion, CodingSchemeVersion, "1", "1C", logStream, moduleName);
+        DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_CodingSchemeVersion, CodingSchemeVersion, "1", "1C", moduleName);
     if (result.good())
-        result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_CodeMeaning, CodeMeaning, "1", "1", logStream, moduleName);
+        result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_CodeMeaning, CodeMeaning, "1", "1", moduleName);
     /* tbd: might add check for correct code */
 
     return result;
 }
 
 
-OFCondition DSRCodedEntryValue::writeItem(DcmItem &dataset,
-                                          OFConsole * /*logStream*/) const
+OFCondition DSRCodedEntryValue::writeItem(DcmItem &dataset) const
 {
     /* write BasicCodedEntryAttributes only */
     OFCondition result = DSRTypes::putStringValueToDataset(dataset, DCM_CodeValue, CodeValue);
@@ -188,20 +182,19 @@ OFCondition DSRCodedEntryValue::writeItem(DcmItem &dataset,
 
 OFCondition DSRCodedEntryValue::readSequence(DcmItem &dataset,
                                              const DcmTagKey &tagKey,
-                                             const OFString &type,
-                                             OFConsole *logStream)
+                                             const OFString &type)
 {
     /* read CodeSequence */
     DcmSequenceOfItems dseq(tagKey);
-    OFCondition result = DSRTypes::getSequenceFromDataset(dataset, dseq);
-    DSRTypes::checkElementValue(dseq, "1", type, logStream, result, "content item");
+    OFCondition result = DSRTypes::getElementFromDataset(dataset, dseq);
+    DSRTypes::checkElementValue(dseq, "1", type, result, "content item");
     if (result.good())
     {
         DcmItem *ditem = dseq.getItem(0);
         if (ditem != NULL)
         {
             /* read Code */
-            result = readItem(*ditem, logStream, DcmTag(tagKey).getTagName());
+            result = readItem(*ditem, DcmTag(tagKey).getTagName());
         } else
             result = SR_EC_InvalidDocumentTree;
     }
@@ -210,8 +203,7 @@ OFCondition DSRCodedEntryValue::readSequence(DcmItem &dataset,
 
 
 OFCondition DSRCodedEntryValue::writeSequence(DcmItem &dataset,
-                                              const DcmTagKey &tagKey,
-                                              OFConsole *logStream) const
+                                              const DcmTagKey &tagKey) const
 {
     OFCondition result = EC_MemoryExhausted;
     /* write CodeSequence */
@@ -228,7 +220,7 @@ OFCondition DSRCodedEntryValue::writeSequence(DcmItem &dataset,
             {
                 /* write Code */
                 if (isValid())
-                    result = writeItem(*ditem, logStream);
+                    result = writeItem(*ditem);
                 if (result.good())
                     dseq->insert(ditem);
                 else
@@ -284,54 +276,69 @@ OFCondition DSRCodedEntryValue::readXML(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRCodedEntryValue::writeXML(ostream &stream,
-                                         const size_t flags,
-                                         OFConsole * /*logStream*/) const
+OFCondition DSRCodedEntryValue::writeXML(STD_NAMESPACE ostream &stream,
+                                         const size_t flags) const
 {
     OFString tmpString;
     if (flags & DSRTypes::XF_codeComponentsAsAttribute)
     {
-        stream << " codValue=\"" << DSRTypes::convertToMarkupString(CodeValue, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/) << "\"";
-        stream << " codScheme=\"" << DSRTypes::convertToMarkupString(CodingSchemeDesignator, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/) << "\"";
+        stream << " codValue=\"" << DSRTypes::convertToXMLString(CodeValue, tmpString) << "\"";
+        stream << " codScheme=\"" << DSRTypes::convertToXMLString(CodingSchemeDesignator, tmpString) << "\"";
         if (!CodingSchemeVersion.empty() || (flags & DSRTypes::XF_writeEmptyTags))
-            stream << " codVersion=\"" << DSRTypes::convertToMarkupString(CodingSchemeVersion, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/) << "\"";
+            stream << " codVersion=\"" << DSRTypes::convertToXMLString(CodingSchemeVersion, tmpString) << "\"";
         stream << ">";      // close open bracket from calling routine
-        stream << DSRTypes::convertToMarkupString(CodeMeaning, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/);
+        stream << DSRTypes::convertToXMLString(CodeMeaning, tmpString);
     } else {
         DSRTypes::writeStringValueToXML(stream, CodeValue, "value", (flags & DSRTypes::XF_writeEmptyTags) > 0);
-        stream << "<scheme>" << endl;
+        stream << "<scheme>" << OFendl;
         DSRTypes::writeStringValueToXML(stream, CodingSchemeDesignator, "designator", (flags & DSRTypes::XF_writeEmptyTags) > 0);
         DSRTypes::writeStringValueToXML(stream, CodingSchemeVersion, "version", (flags & DSRTypes::XF_writeEmptyTags) > 0);
-        stream << "</scheme>" << endl;
+        stream << "</scheme>" << OFendl;
         DSRTypes::writeStringValueToXML(stream, CodeMeaning, "meaning", (flags & DSRTypes::XF_writeEmptyTags) > 0);
     }
     return EC_Normal;
 }
 
 
-OFCondition DSRCodedEntryValue::renderHTML(ostream &stream,
+OFCondition DSRCodedEntryValue::renderHTML(STD_NAMESPACE ostream &stream,
                                            const size_t flags,
-                                           OFConsole * /*logStream*/,
                                            const OFBool fullCode,
                                            const OFBool valueFirst) const
 {
     OFString htmlString;
-    const OFBool convertNonASCII = (flags & DSRTypes::HF_convertNonASCIICharacters) > 0;
-    if (valueFirst)
-        stream << DSRTypes::convertToMarkupString(CodeValue, htmlString, convertNonASCII);
-    else
-        stream << DSRTypes::convertToMarkupString(CodeMeaning, htmlString, convertNonASCII);
-    if (fullCode)
+    if (flags & DSRTypes::HF_useCodeDetailsTooltip)
     {
-        stream << " (";
-        if (!valueFirst)
-            stream << DSRTypes::convertToMarkupString(CodeValue, htmlString, convertNonASCII) << ", ";
-        stream << DSRTypes::convertToMarkupString(CodingSchemeDesignator, htmlString, convertNonASCII);
+        /* render code details as a tooltip */
+        stream << "<span title=\"(";
+        stream << DSRTypes::convertToHTMLString(CodeValue, htmlString, flags) << ", ";
+        stream << DSRTypes::convertToHTMLString(CodingSchemeDesignator, htmlString, flags);
         if (!CodingSchemeVersion.empty())
-            stream << " [" << DSRTypes::convertToMarkupString(CodingSchemeVersion, htmlString, convertNonASCII) << "]";
+            stream << " [" << DSRTypes::convertToHTMLString(CodingSchemeVersion, htmlString, flags) << "]";
+        stream << ", &quot;" << DSRTypes::convertToHTMLString(CodeMeaning, htmlString, flags) << "&quot;)\">";
+        /* render value */
         if (valueFirst)
-            stream << ", " << DSRTypes::convertToMarkupString(CodeMeaning, htmlString, convertNonASCII);
-        stream << ")";
+            stream << DSRTypes::convertToHTMLString(CodeValue, htmlString, flags);
+        else
+            stream << DSRTypes::convertToHTMLString(CodeMeaning, htmlString, flags);
+        stream << "</span>";
+    } else {
+        /* render code in a conventional manner */
+        if (valueFirst)
+            stream << DSRTypes::convertToHTMLString(CodeValue, htmlString, flags);
+        else
+            stream << DSRTypes::convertToHTMLString(CodeMeaning, htmlString, flags);
+        if (fullCode)
+        {
+            stream << " (";
+            if (!valueFirst)
+                stream << DSRTypes::convertToHTMLString(CodeValue, htmlString, flags) << ", ";
+            stream << DSRTypes::convertToHTMLString(CodingSchemeDesignator, htmlString, flags);
+            if (!CodingSchemeVersion.empty())
+                stream << " [" << DSRTypes::convertToHTMLString(CodingSchemeVersion, htmlString, flags) << "]";
+            if (valueFirst)
+                stream << ", &quot;" << DSRTypes::convertToHTMLString(CodeMeaning, htmlString, flags) << "&quot;";
+            stream << ")";
+        }
     }
     return EC_Normal;
 }
@@ -387,18 +394,35 @@ OFBool DSRCodedEntryValue::checkCode(const OFString &codeValue,
 }
 
 
-OFBool DSRCodedEntryValue::valueContainsExtendedCharacters() const
-{
-  return DSRTypes::stringContainsExtendedCharacters(CodeValue)
-    || DSRTypes::stringContainsExtendedCharacters(CodingSchemeDesignator)
-    || DSRTypes::stringContainsExtendedCharacters(CodingSchemeVersion)
-    || DSRTypes::stringContainsExtendedCharacters(CodeMeaning);
-}
-
-
 /*
  *  CVS/RCS Log:
  *  $Log: dsrcodvl.cc,v $
+ *  Revision 1.27  2010-10-14 13:14:40  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.26  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.25  2008-07-17 12:00:09  joergr
+ *  Replaced call to getSequenceFromDataset() by getElementFromDataset().
+ *
+ *  Revision 1.24  2007-11-15 16:45:26  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *  Enhanced support for output in valid HTML 3.2 format. Migrated support for
+ *  standard HTML from version 4.0 to 4.01 (strict).
+ *
+ *  Revision 1.23  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.22  2006/07/25 13:35:46  joergr
+ *  Added new optional flags for the HTML rendering of SR documents:
+ *  HF_alwaysExpandChildrenInline, HF_useCodeDetailsTooltip and
+ *  HF_renderSectionTitlesInline.
+ *
+ *  Revision 1.21  2006/05/11 09:16:49  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  *  Revision 1.20  2005/12/08 15:47:41  meichel
  *  Changed include path schema for all DCMTK header files
  *
