@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRCompositeReferenceValue
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:44 $
- *  CVS/RCS Revision: $Revision: 1.15 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.20 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -97,7 +93,7 @@ OFBool DSRCompositeReferenceValue::isEmpty() const
 }
 
 
-OFCondition DSRCompositeReferenceValue::print(ostream &stream,
+OFCondition DSRCompositeReferenceValue::print(STD_NAMESPACE ostream &stream,
                                               const size_t flags) const
 {
     const char *className = dcmFindNameOfUID(SOPClassUID.c_str());
@@ -131,9 +127,8 @@ OFCondition DSRCompositeReferenceValue::readXML(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRCompositeReferenceValue::writeXML(ostream &stream,
-                                                 const size_t flags,
-                                                 OFConsole * /* logStream */) const
+OFCondition DSRCompositeReferenceValue::writeXML(STD_NAMESPACE ostream &stream,
+                                                 const size_t flags) const
 {
     if ((flags & DSRTypes::XF_writeEmptyTags) || !isEmpty())
     {
@@ -142,27 +137,25 @@ OFCondition DSRCompositeReferenceValue::writeXML(ostream &stream,
         const char *sopClass = dcmFindNameOfUID(SOPClassUID.c_str());
         if (sopClass != NULL)
             stream << sopClass;
-        stream << "</sopclass>" << endl;
-        stream << "<instance uid=\"" << SOPInstanceUID << "\"/>" << endl;
+        stream << "</sopclass>" << OFendl;
+        stream << "<instance uid=\"" << SOPInstanceUID << "\"/>" << OFendl;
     }
     return EC_Normal;
 }
 
 
-OFCondition DSRCompositeReferenceValue::readItem(DcmItem &dataset,
-                                                 OFConsole *logStream)
+OFCondition DSRCompositeReferenceValue::readItem(DcmItem &dataset)
 {
     /* read ReferencedSOPClassUID */
-    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_ReferencedSOPClassUID, SOPClassUID, "1", "1", logStream, "ReferencedSOPSequence");
+    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_ReferencedSOPClassUID, SOPClassUID, "1", "1", "ReferencedSOPSequence");
     /* read ReferencedSOPInstanceUID */
     if (result.good())
-        result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_ReferencedSOPInstanceUID, SOPInstanceUID, "1", "1", logStream, "ReferencedSOPSequence");
+        result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_ReferencedSOPInstanceUID, SOPInstanceUID, "1", "1", "ReferencedSOPSequence");
     return result;
 }
 
 
-OFCondition DSRCompositeReferenceValue::writeItem(DcmItem &dataset,
-                                                  OFConsole * /*logStream */) const
+OFCondition DSRCompositeReferenceValue::writeItem(DcmItem &dataset) const
 {
     /* write ReferencedSOPClassUID */
     OFCondition result = DSRTypes::putStringValueToDataset(dataset, DCM_ReferencedSOPClassUID, SOPClassUID);
@@ -174,19 +167,18 @@ OFCondition DSRCompositeReferenceValue::writeItem(DcmItem &dataset,
 
 
 OFCondition DSRCompositeReferenceValue::readSequence(DcmItem &dataset,
-                                                     const OFString &type,
-                                                     OFConsole *logStream)
+                                                     const OFString &type)
 {
     /* read ReferencedSOPSequence */
     DcmSequenceOfItems dseq(DCM_ReferencedSOPSequence);
-    OFCondition result = DSRTypes::getSequenceFromDataset(dataset, dseq);
-    DSRTypes::checkElementValue(dseq, "1", type, logStream, result, "content item");
+    OFCondition result = DSRTypes::getElementFromDataset(dataset, dseq);
+    DSRTypes::checkElementValue(dseq, "1", type, result, "content item");
     if (result.good())
     {
         /* read first item */
         DcmItem *ditem = dseq.getItem(0);
         if (ditem != NULL)
-            result = readItem(*ditem, logStream);
+            result = readItem(*ditem);
         else
             result = SR_EC_InvalidDocumentTree;
     }
@@ -194,8 +186,7 @@ OFCondition DSRCompositeReferenceValue::readSequence(DcmItem &dataset,
 }
 
 
-OFCondition DSRCompositeReferenceValue::writeSequence(DcmItem &dataset,
-                                                      OFConsole *logStream) const
+OFCondition DSRCompositeReferenceValue::writeSequence(DcmItem &dataset) const
 {
     OFCondition result = EC_MemoryExhausted;
     /* write ReferencedSOPSequence */
@@ -206,7 +197,7 @@ OFCondition DSRCompositeReferenceValue::writeSequence(DcmItem &dataset,
         if (ditem != NULL)
         {
             /* write item */
-            result = writeItem(*ditem, logStream);
+            result = writeItem(*ditem);
             if (result.good())
                 dseq->insert(ditem);
             else
@@ -223,11 +214,10 @@ OFCondition DSRCompositeReferenceValue::writeSequence(DcmItem &dataset,
 }
 
 
-OFCondition DSRCompositeReferenceValue::renderHTML(ostream &docStream,
-                                                   ostream & /*annexStream*/,
+OFCondition DSRCompositeReferenceValue::renderHTML(STD_NAMESPACE ostream &docStream,
+                                                   STD_NAMESPACE ostream & /*annexStream*/,
                                                    size_t & /*annexNumber*/,
-                                                   const size_t /*flags*/,
-                                                   OFConsole * /*logStream*/) const
+                                                   const size_t /*flags*/) const
 {
     /* render reference */
     docStream << "<a href=\"" << HTML_HYPERLINK_PREFIX_FOR_CGI;
@@ -309,6 +299,22 @@ OFBool DSRCompositeReferenceValue::checkSOPInstanceUID(const OFString &sopInstan
 /*
  *  CVS/RCS Log:
  *  $Log: dsrcomvl.cc,v $
+ *  Revision 1.20  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.19  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.18  2008-07-17 12:00:09  joergr
+ *  Replaced call to getSequenceFromDataset() by getElementFromDataset().
+ *
+ *  Revision 1.17  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.16  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.15  2005/12/08 15:47:44  meichel
  *  Changed include path schema for all DCMTK header files
  *
