@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2003, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -23,8 +19,8 @@
  *    classes: DSRContainerTreeNode
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2003/09/15 14:13:42 $
- *  CVS/RCS Revision: $Revision: 1.23 $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.28 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -32,11 +28,11 @@
  */
 
 
-#include "osconfig.h"    /* make sure OS specific configuration is included first */
+#include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 
-#include "dsrtypes.h"
-#include "dsrcontn.h"
-#include "dsrxmld.h"
+#include "dcmtk/dcmsr/dsrtypes.h"
+#include "dcmtk/dcmsr/dsrcontn.h"
+#include "dcmtk/dcmsr/dsrxmld.h"
 
 
 DSRContainerTreeNode::DSRContainerTreeNode(const E_RelationshipType relationshipType,
@@ -72,7 +68,7 @@ OFBool DSRContainerTreeNode::isShort(const size_t /*flags*/) const
 }
 
 
-OFCondition DSRContainerTreeNode::print(ostream &stream,
+OFCondition DSRContainerTreeNode::print(STD_NAMESPACE ostream &stream,
                                         const size_t flags) const
 {
     OFCondition result = DSRDocumentTreeNode::print(stream, flags);
@@ -82,19 +78,18 @@ OFCondition DSRContainerTreeNode::print(ostream &stream,
 }
 
 
-OFCondition DSRContainerTreeNode::readContentItem(DcmItem &dataset,
-                                                  OFConsole *logStream)
+OFCondition DSRContainerTreeNode::readContentItem(DcmItem &dataset)
 {
     OFString tmpString;
     /* read ContinuityOfContent */
-    OFCondition result = getAndCheckStringValueFromDataset(dataset, DCM_ContinuityOfContent, tmpString, "1", "1", logStream, "CONTAINER content item");
+    OFCondition result = getAndCheckStringValueFromDataset(dataset, DCM_ContinuityOfContent, tmpString, "1", "1", "CONTAINER content item");
     if (result.good())
     {
         ContinuityOfContent = enumeratedValueToContinuityOfContent(tmpString);
         /* check ContinuityOfContent value */
         if (ContinuityOfContent == COC_invalid)
         {
-            printUnknownValueWarningMessage(logStream, "ContinuityOfContent value", tmpString.c_str());
+            printUnknownValueWarningMessage("ContinuityOfContent value", tmpString.c_str());
             result = SR_EC_InvalidValue;
         }
     }
@@ -102,8 +97,7 @@ OFCondition DSRContainerTreeNode::readContentItem(DcmItem &dataset,
 }
 
 
-OFCondition DSRContainerTreeNode::writeContentItem(DcmItem &dataset,
-                                                   OFConsole * /*logStream*/) const
+OFCondition DSRContainerTreeNode::writeContentItem(DcmItem &dataset) const
 {
     /* write ContinuityOfContent */
     return putStringValueToDataset(dataset, DCM_ContinuityOfContent, continuityOfContentToEnumeratedValue(ContinuityOfContent));
@@ -121,7 +115,7 @@ OFCondition DSRContainerTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
         ContinuityOfContent = enumeratedValueToContinuityOfContent(doc.getStringFromAttribute(cursor, tmpString, "flag"));
         if (ContinuityOfContent == COC_invalid)
         {
-            printUnknownValueWarningMessage(doc.getLogStream(), "CONTAINER flag", tmpString.c_str());
+            printUnknownValueWarningMessage("CONTAINER flag", tmpString.c_str());
             result = SR_EC_InvalidValue;
         } else
             result = EC_Normal;
@@ -130,26 +124,24 @@ OFCondition DSRContainerTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRContainerTreeNode::writeXML(ostream &stream,
-                                           const size_t flags,
-                                           OFConsole *logStream) const
+OFCondition DSRContainerTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                           const size_t flags) const
 {
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags, OFFalse /*closingBracket*/);
     stream << " flag=\"" << continuityOfContentToEnumeratedValue(ContinuityOfContent) << "\"";
-    stream << ">" << endl;
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
+    stream << ">" << OFendl;
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
     writeXMLItemEnd(stream, flags);
     return result;
 }
 
 
-OFCondition DSRContainerTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                        ostream & /*annexStream*/,
+OFCondition DSRContainerTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                        STD_NAMESPACE ostream & /*annexStream*/,
                                                         const size_t nestingLevel,
                                                         size_t & /*annexNumber*/,
-                                                        const size_t flags,
-                                                        OFConsole *logStream) const
+                                                        const size_t flags) const
 {
     /* section heading (optional) */
     if (nestingLevel > 0)
@@ -159,41 +151,50 @@ OFCondition DSRContainerTreeNode::renderHTMLContentItem(ostream &docStream,
         {
             const size_t section = (nestingLevel > 6) ? 6 : nestingLevel;
             docStream << "<h" << section << ">";
-            getConceptName().renderHTML(docStream, flags, logStream, (flags & HF_renderConceptNameCodes) && getConceptName().isValid() /*fullCode*/);
-            docStream << "</h" << section << ">" << endl;
+            getConceptName().renderHTML(docStream, flags, (flags & HF_renderConceptNameCodes) && getConceptName().isValid() /*fullCode*/);
+            docStream << "</h" << section << ">" << OFendl;
         }
         /* render optional observation datetime */
         if (!getObservationDateTime().empty())
         {
             OFString tmpString;
-            docStream << "<small>(observed: " << dicomToReadableDateTime(getObservationDateTime(), tmpString) << ")</small>" << endl;
+            docStream << "<p>" << OFendl;
+            if (flags & HF_XHTML11Compatibility)
+                docStream << "<span class=\"observe\">";
+            else
+                docStream << "<small>";
+            docStream << "(observed: " << dicomToReadableDateTime(getObservationDateTime(), tmpString) << ")";
+            if (flags & HF_XHTML11Compatibility)
+                docStream << "</span>" << OFendl;
+            else
+                docStream << "</small>" << OFendl;
+            docStream << "</p>" << OFendl;
         }
     }
     return EC_Normal;
 }
 
 
-OFCondition DSRContainerTreeNode::renderHTML(ostream &docStream,
-                                             ostream &annexStream,
+OFCondition DSRContainerTreeNode::renderHTML(STD_NAMESPACE ostream &docStream,
+                                             STD_NAMESPACE ostream &annexStream,
                                              const size_t nestingLevel,
                                              size_t &annexNumber,
-                                             const size_t flags,
-                                             OFConsole *logStream) const
+                                             const size_t flags) const
 {
     /* check for validity */
     if (!isValid())
-        printInvalidContentItemMessage(logStream, "Rendering", this);
+        printInvalidContentItemMessage("Rendering", this);
     /* render content item */
-    OFCondition result = renderHTMLContentItem(docStream, annexStream, nestingLevel, annexNumber, flags, logStream);
+    OFCondition result = renderHTMLContentItem(docStream, annexStream, nestingLevel, annexNumber, flags);
     if (result.good())
     {
         /* section body: render child nodes */
         if (ContinuityOfContent == COC_Continuous)
-            result = renderHTMLChildNodes(docStream, annexStream, nestingLevel, annexNumber, flags & ~HF_renderItemsSeparately, logStream);
+            result = renderHTMLChildNodes(docStream, annexStream, nestingLevel, annexNumber, flags & ~HF_renderItemsSeparately);
         else  // might be invalid
-            result = renderHTMLChildNodes(docStream, annexStream, nestingLevel, annexNumber, flags | HF_renderItemsSeparately, logStream);
+            result = renderHTMLChildNodes(docStream, annexStream, nestingLevel, annexNumber, flags | HF_renderItemsSeparately);
     } else
-        printContentItemErrorMessage(logStream, "Rendering", result, this);
+        printContentItemErrorMessage("Rendering", result, this);
     return result;
 }
 
@@ -213,6 +214,24 @@ OFCondition DSRContainerTreeNode::setContinuityOfContent(const E_ContinuityOfCon
 /*
  *  CVS/RCS Log:
  *  $Log: dsrcontn.cc,v $
+ *  Revision 1.28  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.27  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.26  2007-11-15 16:45:26  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *  Enhanced support for output in valid HTML 3.2 format. Migrated support for
+ *  standard HTML from version 4.0 to 4.01 (strict).
+ *
+ *  Revision 1.25  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.24  2005/12/08 15:47:45  meichel
+ *  Changed include path schema for all DCMTK header files
+ *
  *  Revision 1.23  2003/09/15 14:13:42  joergr
  *  Introduced new class to facilitate checking of SR IOD relationship content
  *  constraints. Replaced old implementation distributed over numerous classes.
