@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2003-2005, OFFIS
+ *  Copyright (C) 2003-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRCodingSchemeIdentificationList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:46 $
- *  CVS/RCS Revision: $Revision: 1.7 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -57,7 +53,7 @@ DSRCodingSchemeIdentificationList::~DSRCodingSchemeIdentificationList()
 void DSRCodingSchemeIdentificationList::clear()
 {
     Iterator = ItemList.begin();
-    const OFListConstIterator(ItemStruct *) last = ItemList.end();
+    const OFListIterator(ItemStruct *) last = ItemList.end();
     /* delete all items and free memory */
     while (Iterator != last)
     {
@@ -82,13 +78,12 @@ size_t DSRCodingSchemeIdentificationList::getNumberOfItems() const
 }
 
 
-OFCondition DSRCodingSchemeIdentificationList::read(DcmItem &dataset,
-                                                    OFConsole *logStream)
+OFCondition DSRCodingSchemeIdentificationList::read(DcmItem &dataset)
 {
     /* first, check whether sequence is present and non-empty */
     DcmSequenceOfItems sequence(DCM_CodingSchemeIdentificationSequence);
-    OFCondition result = getSequenceFromDataset(dataset, sequence);
-    checkElementValue(sequence, "1-n", "3", logStream, result);
+    OFCondition result = getElementFromDataset(dataset, sequence);
+    checkElementValue(sequence, "1-n", "3", result, "SOPCommonModule");
     if (result.good())
     {
         ItemStruct *item = NULL;
@@ -100,18 +95,18 @@ OFCondition DSRCodingSchemeIdentificationList::read(DcmItem &dataset,
             if (ditem != NULL)
             {
                 /* get the coding scheme designator */
-                if (getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeDesignator, codingSchemeDesignator, "1", "1", logStream).good())
+                if (getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeDesignator, codingSchemeDesignator, "1", "1", "CodingSchemeIdentificationSequence").good())
                 {
                     /* add new item to the list */
-                    if (addItem(codingSchemeDesignator, item, logStream).good())
+                    if (addItem(codingSchemeDesignator, item).good())
                     {
                         /* read additional information */
-                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeRegistry, item->CodingSchemeRegistry, "1", "1C", logStream);
-                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeUID, item->CodingSchemeUID, "1", "1C", logStream);
-                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeExternalID, item->CodingSchemeExternalID, "", "2C", logStream);
-                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeName, item->CodingSchemeName, "1", "3", logStream);
-                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeVersion, item->CodingSchemeVersion, "1", "3", logStream);
-                        getAndCheckStringValueFromDataset(*ditem, DCM_ResponsibleOrganization, item->ResponsibleOrganization, "1", "3", logStream);
+                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeRegistry, item->CodingSchemeRegistry, "1", "1C", "CodingSchemeIdentificationSequence");
+                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeUID, item->CodingSchemeUID, "1", "1C", "CodingSchemeIdentificationSequence");
+                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeExternalID, item->CodingSchemeExternalID, "1", "2C", "CodingSchemeIdentificationSequence");
+                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeName, item->CodingSchemeName, "1", "3", "CodingSchemeIdentificationSequence");
+                        getAndCheckStringValueFromDataset(*ditem, DCM_CodingSchemeVersion, item->CodingSchemeVersion, "1", "3", "CodingSchemeIdentificationSequence");
+                        getAndCheckStringValueFromDataset(*ditem, DCM_ResponsibleOrganization, item->ResponsibleOrganization, "1", "3", "CodingSchemeIdentificationSequence");
                     }
                 }
             }
@@ -121,8 +116,7 @@ OFCondition DSRCodingSchemeIdentificationList::read(DcmItem &dataset,
 }
 
 
-OFCondition DSRCodingSchemeIdentificationList::write(DcmItem &dataset,
-                                                     OFConsole *logStream) const
+OFCondition DSRCodingSchemeIdentificationList::write(DcmItem &dataset) const
 {
     OFCondition result = EC_Normal;
     /* iterate over all list items */
@@ -147,10 +141,8 @@ OFCondition DSRCodingSchemeIdentificationList::write(DcmItem &dataset,
                     putStringValueToDataset(*ditem, DCM_CodingSchemeExternalID, item->CodingSchemeExternalID, OFFalse /*allowEmpty*/);
                 else if (!item->CodingSchemeExternalID.empty())
                 {
-                    OFString message = "both CodingSchemeUID and CodingSchemeExternalID present for \"";
-                    message += item->CodingSchemeDesignator;
-                    message += "\", the latter will be ignored";
-                    printWarningMessage(logStream, message.c_str());
+                    DCMSR_WARN("Both CodingSchemeUID and CodingSchemeExternalID present for \""
+                        << item->CodingSchemeDesignator << "\", the latter will be ignored");
                 }
                 putStringValueToDataset(*ditem, DCM_CodingSchemeName, item->CodingSchemeName, OFFalse /*allowEmpty*/);
                 putStringValueToDataset(*ditem, DCM_CodingSchemeVersion, item->CodingSchemeVersion, OFFalse /*allowEmpty*/);
@@ -179,7 +171,7 @@ OFCondition DSRCodingSchemeIdentificationList::readXML(const DSRXMLDocument &doc
             /* retrieve coding scheme designator */
             if (!doc.getStringFromAttribute(cursor, codingSchemeDesignator, "designator", OFTrue /*encoding*/).empty())
             {
-                result = addItem(codingSchemeDesignator, item, doc.getLogStream());
+                result = addItem(codingSchemeDesignator, item);
                 if (result.good())
                 {
                     DSRXMLCursor childCursor = cursor.getChild();
@@ -207,7 +199,7 @@ OFCondition DSRCodingSchemeIdentificationList::readXML(const DSRXMLDocument &doc
 }
 
 
-OFCondition DSRCodingSchemeIdentificationList::writeXML(ostream &stream,
+OFCondition DSRCodingSchemeIdentificationList::writeXML(STD_NAMESPACE ostream &stream,
                                                         const size_t flags) const
 {
     OFString tmpString;
@@ -220,14 +212,14 @@ OFCondition DSRCodingSchemeIdentificationList::writeXML(ostream &stream,
         /* check whether list item really exists */
         if (item != NULL)
         {
-            stream << "<scheme designator=\"" << convertToMarkupString(item->CodingSchemeDesignator, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/) << "\">" << endl;
-            writeStringValueToXML(stream, convertToMarkupString(item->CodingSchemeRegistry, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/), "registry", (flags & DSRTypes::XF_writeEmptyTags) > 0);
+            stream << "<scheme designator=\"" << convertToXMLString(item->CodingSchemeDesignator, tmpString) << "\">" << OFendl;
+            writeStringValueToXML(stream, convertToXMLString(item->CodingSchemeRegistry, tmpString), "registry", (flags & DSRTypes::XF_writeEmptyTags) > 0);
             writeStringValueToXML(stream, item->CodingSchemeUID, "uid", (flags & DSRTypes::XF_writeEmptyTags) > 0);
-            writeStringValueToXML(stream, convertToMarkupString(item->CodingSchemeExternalID, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/), "identifier", (flags & DSRTypes::XF_writeEmptyTags) > 0);
-            writeStringValueToXML(stream, convertToMarkupString(item->CodingSchemeName, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/), "name", (flags & DSRTypes::XF_writeEmptyTags) > 0);
-            writeStringValueToXML(stream, convertToMarkupString(item->CodingSchemeVersion, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/), "version", (flags & DSRTypes::XF_writeEmptyTags) > 0);
-            writeStringValueToXML(stream, convertToMarkupString(item->ResponsibleOrganization, tmpString, OFFalse /*convertNonASCII*/, OFFalse /*newlineAllowed*/, OFTrue /*xmlMode*/), "organization", (flags & DSRTypes::XF_writeEmptyTags) > 0);
-            stream << "</scheme>" << endl;
+            writeStringValueToXML(stream, convertToXMLString(item->CodingSchemeExternalID, tmpString), "identifier", (flags & DSRTypes::XF_writeEmptyTags) > 0);
+            writeStringValueToXML(stream, convertToXMLString(item->CodingSchemeName, tmpString), "name", (flags & DSRTypes::XF_writeEmptyTags) > 0);
+            writeStringValueToXML(stream, convertToXMLString(item->CodingSchemeVersion, tmpString), "version", (flags & DSRTypes::XF_writeEmptyTags) > 0);
+            writeStringValueToXML(stream, convertToXMLString(item->ResponsibleOrganization, tmpString), "organization", (flags & DSRTypes::XF_writeEmptyTags) > 0);
+            stream << "</scheme>" << OFendl;
         }
         ++iter;
     }
@@ -255,8 +247,7 @@ OFCondition DSRCodingSchemeIdentificationList::addPrivateDcmtkCodingScheme()
 
 
 OFCondition DSRCodingSchemeIdentificationList::addItem(const OFString &codingSchemeDesignator,
-                                                       ItemStruct *&item,
-                                                       OFConsole *logStream)
+                                                       ItemStruct *&item)
 {
     OFCondition result = EC_IllegalParameter;
     /* check parameter first */
@@ -280,10 +271,8 @@ OFCondition DSRCodingSchemeIdentificationList::addItem(const OFString &codingSch
                 result = EC_MemoryExhausted;
             }
         } else {
-            OFString message = "CodingSchemeDesignator \"";
-            message += codingSchemeDesignator;
-            message += "\" already exists in CodingSchemeIdentificationSequence ... overwriting";
-            printWarningMessage(logStream, message.c_str());
+            DCMSR_WARN("CodingSchemeDesignator \"" << codingSchemeDesignator
+                << "\" already exists in CodingSchemeIdentificationSequence ... overwriting");
             /* gotoItem() was successful, set item pointer */
             item = OFstatic_cast(ItemStruct *, *Iterator);
         }
@@ -337,7 +326,7 @@ OFCondition DSRCodingSchemeIdentificationList::gotoItem(const OFString &codingSc
         result = SR_EC_CodingSchemeNotFound;
         /* start with first item */
         Iterator = ItemList.begin();
-        const OFListConstIterator(ItemStruct *) last = ItemList.end();
+        const OFListIterator(ItemStruct *) last = ItemList.end();
         /* search for given item */
         while ((Iterator != last) && result.bad())
         {
@@ -385,7 +374,9 @@ DSRCodingSchemeIdentificationList::ItemStruct *DSRCodingSchemeIdentificationList
 {
     ItemStruct *item = NULL;
     /* check whether current item is valid */
-    if (Iterator != ItemList.end())
+    OFListConstIterator(ItemStruct *) it = Iterator;
+
+    if (it != ItemList.end())
         item = OFstatic_cast(ItemStruct *, *Iterator);
     return item;
 }
@@ -572,33 +563,41 @@ OFCondition DSRCodingSchemeIdentificationList::setResponsibleOrganization(const
 }
 
 
-OFBool DSRCodingSchemeIdentificationList::ItemStruct::containsExtendedCharacters()
-{
-  return DSRTypes::stringContainsExtendedCharacters(CodingSchemeDesignator) 
-    || DSRTypes::stringContainsExtendedCharacters(CodingSchemeRegistry) 
-    || DSRTypes::stringContainsExtendedCharacters(CodingSchemeExternalID) 
-    || DSRTypes::stringContainsExtendedCharacters(CodingSchemeName) 
-    || DSRTypes::stringContainsExtendedCharacters(CodingSchemeVersion) 
-    || DSRTypes::stringContainsExtendedCharacters(ResponsibleOrganization);
-}
-
-
-OFBool DSRCodingSchemeIdentificationList::containsExtendedCharacters()
-{
-    OFListIterator(ItemStruct *) iter = ItemList.begin();
-    OFListIterator(ItemStruct *) last = ItemList.end();
-    while (iter != last)
-    {
-      if (*iter && (*iter)->containsExtendedCharacters()) return OFTrue;
-      ++iter;
-    }
-    return OFFalse;
-}
-
-
 /*
  *  CVS/RCS Log:
  *  $Log: dsrcsidl.cc,v $
+ *  Revision 1.17  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.16  2010-09-29 08:32:26  joergr
+ *  Used more specific "moduleName" for getAndCheckElementFromDataset() and
+ *  checkElementValue().
+ *
+ *  Revision 1.15  2009-10-14 10:49:32  joergr
+ *  Fixed minor issues in log output. Also updated copyright date (if required).
+ *
+ *  Revision 1.14  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.13  2009-09-04 13:53:09  meichel
+ *  Minor const iterator related changes needed to compile with VC6 with HAVE_STL
+ *
+ *  Revision 1.12  2008-07-17 12:00:09  joergr
+ *  Replaced call to getSequenceFromDataset() by getElementFromDataset().
+ *
+ *  Revision 1.11  2008-04-29 13:59:21  joergr
+ *  Harmonized capitalization of warning messages.
+ *
+ *  Revision 1.10  2007/11/15 16:45:42  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *
+ *  Revision 1.9  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.8  2006/05/11 09:16:49  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  *  Revision 1.7  2005/12/08 15:47:46  meichel
  *  Changed include path schema for all DCMTK header files
  *
