@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRDocumentTree
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:50 $
- *  CVS/RCS Revision: $Revision: 1.26 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.36 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -44,7 +40,6 @@
 DSRDocumentTree::DSRDocumentTree(const E_DocumentType documentType)
   : DSRTree(),
     DocumentType(DT_invalid),
-    LogStream(NULL),
     CurrentContentItem(),
     ConstraintChecker(NULL)
 {
@@ -82,13 +77,7 @@ OFBool DSRDocumentTree::isValid() const
 }
 
 
-void DSRDocumentTree::setLogStream(OFConsole *stream)
-{
-    LogStream = stream;
-}
-
-
-OFCondition DSRDocumentTree::print(ostream &stream,
+OFCondition DSRDocumentTree::print(STD_NAMESPACE ostream &stream,
                                    const size_t flags)
 {
     OFCondition result = EC_Normal;
@@ -96,7 +85,7 @@ OFCondition DSRDocumentTree::print(ostream &stream,
     if (cursor.isValid())
     {
         /* check and update by-reference relationships (if applicable) */
-        checkByReferenceRelationships(OFTrue /*updateString*/,  OFFalse /*updateNodeID*/);
+        checkByReferenceRelationships(CM_updatePositionString);
         OFString tmpString;
         size_t level = 0;
         const DSRDocumentTreeNode *node = NULL;
@@ -129,7 +118,7 @@ OFCondition DSRDocumentTree::print(ostream &stream,
                             stream << "  # TID " << templateIdentifier << " (" << mappingResource << ")";
                     }
                 }
-                stream << endl;
+                stream << OFendl;
             } else
                 result = SR_EC_InvalidDocumentTree;
         } while (result.good() && cursor.iterate());
@@ -147,20 +136,27 @@ OFCondition DSRDocumentTree::read(DcmItem &dataset,
     if (result.good())
     {
         if (ConstraintChecker == NULL)
-            printWarningMessage(LogStream, "Check for relationship content constraints not yet supported");
+            DCMSR_WARN("Check for relationship content constraints not yet supported");
         else if (ConstraintChecker->isTemplateSupportRequired())
-            printWarningMessage(LogStream, "Check for template constraints not yet supported");
-        if ((LogStream != NULL) && (flags & RF_showCurrentlyProcessedItem))
-        {
-            LogStream->lockCerr() << "Processing content item 1" << endl;
-            LogStream->unlockCerr();
-        }
+            DCMSR_WARN("Check for template constraints not yet supported");
+        if (flags & RF_showCurrentlyProcessedItem)
+            DCMSR_INFO("Processing content item 1");
         /* first try to read value type */
         OFString tmpString;
-        if (getAndCheckStringValueFromDataset(dataset, DCM_ValueType, tmpString, "1", "1", LogStream).good())
+        if (getAndCheckStringValueFromDataset(dataset, DCM_ValueType, tmpString, "1", "1").good() ||
+            (flags & RF_ignoreContentItemErrors))
         {
             /* root node should always be a container */
-            if (definedTermToValueType(tmpString) == VT_Container)
+            if (definedTermToValueType(tmpString) != VT_Container)
+            {
+                if (flags & RF_ignoreContentItemErrors)
+                    DCMSR_WARN("Root content item should always be a CONTAINER");
+                else {
+                    DCMSR_ERROR("Root content item should always be a CONTAINER");
+                    result = SR_EC_InvalidDocumentTree;
+                }
+            }
+            if (result.good())
             {
                 /* ... then create corresponding document tree node */
                 DSRDocumentTreeNode *node = new DSRContainerTreeNode(RT_isRoot);
@@ -170,19 +166,16 @@ OFCondition DSRDocumentTree::read(DcmItem &dataset,
                     if (addNode(node))
                     {
                         /* ... and let the node read the rest of the document */
-                        result = node->read(dataset, ConstraintChecker, flags, LogStream);
+                        result = node->read(dataset, ConstraintChecker, flags);
                         /* check and update by-reference relationships (if applicable) */
-                        checkByReferenceRelationships(OFFalse /*updateString*/, OFTrue /*updateNodeID*/);
+                        checkByReferenceRelationships(CM_updateNodeID, flags);
                     } else
                         result = SR_EC_InvalidDocumentTree;
                 } else
                     result = EC_MemoryExhausted;
-            } else {
-                printErrorMessage(LogStream, "Root content item should always be a CONTAINER");
-                result = SR_EC_InvalidDocumentTree;
             }
         } else {
-            printErrorMessage(LogStream, "ValueType attribute for root content item is missing");
+            DCMSR_ERROR("ValueType attribute for root content item is missing");
             result = SR_EC_MandatoryAttributeMissing;
         }
     }
@@ -196,9 +189,9 @@ OFCondition DSRDocumentTree::readXML(const DSRXMLDocument &doc,
 {
     OFCondition result = SR_EC_CorruptedXMLStructure;
     if (ConstraintChecker == NULL)
-        printWarningMessage(LogStream, "Check for relationship content constraints not yet supported");
+        DCMSR_WARN("Check for relationship content constraints not yet supported");
     else if (ConstraintChecker->isTemplateSupportRequired())
-        printWarningMessage(LogStream, "Check for template constraints not yet supported");
+        DCMSR_WARN("Check for template constraints not yet supported");
     /* we assume that 'cursor' points to the "content" element */
     if (cursor.valid())
     {
@@ -234,18 +227,18 @@ OFCondition DSRDocumentTree::readXML(const DSRXMLDocument &doc,
                     {
                         /* set template identification (if any) */
                         if (node->setTemplateIdentification(templateIdentifier, mappingResource).bad())
-                            printWarningMessage(LogStream, "Root content item has invalid/incomplete template identification");
+                            DCMSR_WARN("Root content item has invalid/incomplete template identification");
                     }
                     /* ... and let the node read the rest of the document */
                     result = node->readXML(doc, cursor, DocumentType, flags);
                     /* check and update by-reference relationships (if applicable) */
-                    checkByReferenceRelationships(OFTrue /*updateString*/,  OFFalse /*updateNodeID*/);
+                    checkByReferenceRelationships(CM_updatePositionString);
                 } else
                     result = SR_EC_InvalidDocumentTree;
             } else
                 result = EC_MemoryExhausted;
         } else {
-            printErrorMessage(LogStream, "Root content item should always be a CONTAINER");
+            DCMSR_ERROR("Root content item should always be a CONTAINER");
             result = SR_EC_InvalidDocumentTree;
         }
     }
@@ -264,16 +257,16 @@ OFCondition DSRDocumentTree::write(DcmItem &dataset,
         if (node != NULL)
         {
             /* check and update by-reference relationships (if applicable) */
-            checkByReferenceRelationships(OFTrue /*updateString*/,  OFFalse /*updateNodeID*/);
+            checkByReferenceRelationships(CM_updatePositionString);
             /* start writing from root node */
-            result = node->write(dataset, markedItems, LogStream);
+            result = node->write(dataset, markedItems);
         }
     }
     return result;
 }
 
 
-OFCondition DSRDocumentTree::writeXML(ostream &stream,
+OFCondition DSRDocumentTree::writeXML(STD_NAMESPACE ostream &stream,
                                       const size_t flags)
 {
     OFCondition result = SR_EC_InvalidDocumentTree;
@@ -285,17 +278,17 @@ OFCondition DSRDocumentTree::writeXML(ostream &stream,
         if (node != NULL)
         {
             /* check by-reference relationships (if applicable) */
-            checkByReferenceRelationships(OFFalse /*updateString*/,  OFFalse /*updateNodeID*/);
+            checkByReferenceRelationships(CM_resetReferenceTargetFlag);
             /* start writing from root node */
-            result = node->writeXML(stream, flags, LogStream);
+            result = node->writeXML(stream, flags);
         }
     }
     return result;
 }
 
 
-OFCondition DSRDocumentTree::renderHTML(ostream &docStream,
-                                        ostream &annexStream,
+OFCondition DSRDocumentTree::renderHTML(STD_NAMESPACE ostream &docStream,
+                                        STD_NAMESPACE ostream &annexStream,
                                         const size_t flags)
 {
     OFCondition result = SR_EC_InvalidDocumentTree;
@@ -307,10 +300,10 @@ OFCondition DSRDocumentTree::renderHTML(ostream &docStream,
         if (node != NULL)
         {
             /* check by-reference relationships (if applicable) */
-            checkByReferenceRelationships(OFFalse /*updateString*/,  OFFalse /*updateNodeID*/);
+            checkByReferenceRelationships(CM_resetReferenceTargetFlag);
             size_t annexNumber = 1;
             /* start rendering from root node */
-            result = node->renderHTML(docStream, annexStream, 1 /*nestingLevel*/, annexNumber, flags & ~HF_internalUseOnly, LogStream);
+            result = node->renderHTML(docStream, annexStream, 1 /*nestingLevel*/, annexNumber, flags & ~HF_internalUseOnly);
         }
     }
     return result;
@@ -542,17 +535,21 @@ size_t DSRDocumentTree::removeNode()
 }
 
 
-OFCondition DSRDocumentTree::checkByReferenceRelationships(const OFBool updateString,
-                                                           const OFBool updateNodeID)
+OFCondition DSRDocumentTree::checkByReferenceRelationships(const size_t mode,
+                                                           const size_t flags)
 {
     OFCondition result = EC_IllegalParameter;
-    /* the flags are mutually exclusive */
-    if (!(updateString && updateNodeID))
+    /* the update flags are mutually exclusive */
+    if (!((mode & CM_updatePositionString) && (mode & CM_updateNodeID)))
     {
         result = EC_Normal;
         /* by-reference relationships are only allowed for particular IODs */
         if ((ConstraintChecker != NULL) && ConstraintChecker->isByReferenceAllowed())
         {
+            /* specify for all content items not to be the target of a by-reference relationship */
+            if (mode & CM_resetReferenceTargetFlag)
+                resetReferenceTargetFlag();
+            /* start at the root of the document tree */
             DSRTreeNodeCursor cursor(getRoot());
             if (cursor.isValid())
             {
@@ -567,9 +564,14 @@ OFCondition DSRDocumentTree::checkByReferenceRelationships(const OFBool updateSt
                             size_t refNodeID = 0;
                             /* type cast to directly access member variables of by-reference class */
                             DSRByReferenceTreeNode *refNode = OFconst_cast(DSRByReferenceTreeNode *, OFstatic_cast(const DSRByReferenceTreeNode *, node));
+                            if (flags & RF_showCurrentlyProcessedItem)
+                            {
+                                OFString posString;
+                                DCMSR_WARN("Updating by-reference relationship in content item " << cursor.getPosition(posString));
+                            }
                             /* start searching from root node (be careful with large trees, might be improved later on) */
                             DSRTreeNodeCursor refCursor(getRoot());
-                            if (updateNodeID)
+                            if (mode & CM_updateNodeID)
                             {
                                 /* update node ID */
                                 refNodeID = refCursor.gotoNode(refNode->ReferencedContentItem);
@@ -581,13 +583,14 @@ OFCondition DSRDocumentTree::checkByReferenceRelationships(const OFBool updateSt
                             } else {
                                 /* ReferenceNodeID contains a valid value */
                                 refNodeID = refCursor.gotoNode(refNode->ReferencedNodeID);
-                                if (updateString)
+                                if (mode & CM_updatePositionString)
                                 {
                                     /* update position string */
                                     if (refNodeID > 0)
                                         refCursor.getPosition(refNode->ReferencedContentItem);
                                     else
                                         refNode->ReferencedContentItem.clear();
+                                    /* tbd: check for valid reference could be more strict */
                                     refNode->ValidReference = checkForValidUIDFormat(refNode->ReferencedContentItem);
                                 } else if (refNodeID == 0)
                                     refNode->ValidReference = OFFalse;
@@ -607,27 +610,35 @@ OFCondition DSRDocumentTree::checkByReferenceRelationships(const OFBool updateSt
                                         DSRDocumentTreeNode *targetNode = OFstatic_cast(DSRDocumentTreeNode *, refCursor.getNode());
                                         if ((parentNode != NULL) && (targetNode != NULL))
                                         {
-                                            /* tbd: need to reset flag to OFFalse!? */
+                                            /* specify that this content item is target of an by-reference relationship */
                                             targetNode->setReferenceTarget();
-                                            /* check whether relationship is valid */
-                                            if ((ConstraintChecker != NULL) && !ConstraintChecker->checkContentRelationship(parentNode->getValueType(),
-                                                refNode->getRelationshipType(), targetNode->getValueType(), OFTrue /*byReference*/))
+                                            /* do we really need to check the constraints? */
+                                            E_RelationshipType relationshipType = refNode->getRelationshipType();
+                                            if (!(flags & RF_ignoreRelationshipConstraints) &&
+                                                (!(flags & RF_acceptUnknownRelationshipType) || (relationshipType != RT_unknown)))
                                             {
-                                                OFString message = "Invalid by-reference relationship between item \"";
-                                                message += posString;
-                                                message += "\" and \"";
-                                                message += refNode->ReferencedContentItem;
-                                                message += "\"";
-                                                printWarningMessage(LogStream, message.c_str());
+                                                /* check whether relationship is valid */
+                                                if ((ConstraintChecker != NULL) && !ConstraintChecker->checkContentRelationship(parentNode->getValueType(),
+                                                    relationshipType, targetNode->getValueType(), OFTrue /*byReference*/))
+                                                {
+                                                    DCMSR_WARN("Invalid by-reference relationship between item \"" << posString
+                                                        << "\" and \"" << refNode->ReferencedContentItem << "\"");
+                                                }
                                             }
                                         } else
-                                            printWarningMessage(LogStream, "Corrupted data structures while checking by-reference relationships");
+                                            DCMSR_WARN("Corrupted data structures while checking by-reference relationships");
                                     } else
-                                        printWarningMessage(LogStream, "By-reference relationship to ancestor content item (loop check)");
+                                        DCMSR_WARN("By-reference relationship to ancestor content item (loop check)");
                                 } else
-                                    printWarningMessage(LogStream, "Source and target content item of by-reference relationship are identical");
-                            } else
-                                printWarningMessage(LogStream, "Target content item of by-reference relationship does not exist");
+                                    DCMSR_WARN("Source and target content item of by-reference relationship are identical");
+                            } else {
+                                if (mode & CM_updateNodeID)
+                                {
+                                    DCMSR_WARN("Target content item of by-reference relationship ("
+                                        << refNode->ReferencedContentItem << ") does not exist");
+                                } else
+                                    DCMSR_WARN("Target content item of by-reference relationship does not exist");
+                            }
                         }
                     } else
                         result = SR_EC_InvalidDocumentTree;
@@ -639,26 +650,63 @@ OFCondition DSRDocumentTree::checkByReferenceRelationships(const OFBool updateSt
 }
 
 
-OFBool DSRDocumentTree::containsExtendedCharacters()
+void DSRDocumentTree::resetReferenceTargetFlag()
 {
-  DSRTreeNodeCursor cursor(getRoot());
-  if (cursor.isValid())
-  {
-      const DSRDocumentTreeNode *node = NULL;
-      /* iterate over all nodes */
-      do
-      {
-          node = OFstatic_cast(DSRDocumentTreeNode *, cursor.getNode());
-          if (node && node->containsExtendedCharacters()) return OFTrue;
-      } while (cursor.iterate());
-  }
-  return OFFalse;
+    DSRTreeNodeCursor cursor(getRoot());
+    if (cursor.isValid())
+    {
+        DSRDocumentTreeNode *node = NULL;
+        /* iterate over all nodes */
+        do {
+            node = OFstatic_cast(DSRDocumentTreeNode *, cursor.getNode());
+            if (node != NULL)
+                node->setReferenceTarget(OFFalse);
+        } while (cursor.iterate());
+    }
 }
 
 
 /*
  *  CVS/RCS Log:
  *  $Log: dsrdoctr.cc,v $
+ *  Revision 1.36  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.35  2009-10-30 10:08:55  joergr
+ *  Output processing details in verbose mode and not as a warning message.
+ *
+ *  Revision 1.34  2009-10-14 09:28:06  joergr
+ *  Slightly modified output of some log messages (avoid creation of temporary
+ *  strings).
+ *
+ *  Revision 1.33  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.32  2008-05-19 09:54:41  joergr
+ *  Added new flag that enables reading of SR documents with unknown/missing
+ *  relationship type(s).
+ *  Reset flag for all content items whether they are target of a by-reference
+ *  relationship (required for an reproducible behavior).
+ *  Changed parameters of checkByReferenceRelationships() method.
+ *
+ *  Revision 1.31  2007/11/15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.30  2007/05/11 14:48:55  joergr
+ *  Enhanced debug output when detecting by-reference relationships to non-
+ *  existing content items.
+ *
+ *  Revision 1.29  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.28  2006/07/25 13:41:52  joergr
+ *  Enhanced robustness of reading methods by accepting SR documents where the
+ *  value type of the root content item is absent or not "CONTAINER".
+ *
+ *  Revision 1.27  2006/05/11 09:16:49  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  *  Revision 1.26  2005/12/08 15:47:50  meichel
  *  Changed include path schema for all DCMTK header files
  *
