@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRDateTimeTreeNode
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:51 $
- *  CVS/RCS Revision: $Revision: 1.20 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.24 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -73,7 +69,7 @@ OFBool DSRDateTimeTreeNode::isValid() const
 }
 
 
-OFCondition DSRDateTimeTreeNode::print(ostream &stream,
+OFCondition DSRDateTimeTreeNode::print(STD_NAMESPACE ostream &stream,
                                        const size_t flags) const
 {
     OFCondition result = DSRDocumentTreeNode::print(stream, flags);
@@ -86,14 +82,13 @@ OFCondition DSRDateTimeTreeNode::print(ostream &stream,
 }
 
 
-OFCondition DSRDateTimeTreeNode::writeXML(ostream &stream,
-                                          const size_t flags,
-                                          OFConsole *logStream) const
+OFCondition DSRDateTimeTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                          const size_t flags) const
 {
     OFString tmpString;
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags);
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
     /* output time in ISO 8601 format */
     DcmDateTime::getISOFormattedDateTimeFromString(getValue(), tmpString, OFTrue /*seconds*/, OFFalse /*fraction*/,
         OFFalse /*timeZone*/, OFFalse /*createMissingPart*/, "T" /*dateTimeSeparator*/);
@@ -103,19 +98,17 @@ OFCondition DSRDateTimeTreeNode::writeXML(ostream &stream,
 }
 
 
-OFCondition DSRDateTimeTreeNode::readContentItem(DcmItem &dataset,
-                                                 OFConsole *logStream)
+OFCondition DSRDateTimeTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read DateTime */
-    return DSRStringValue::read(dataset, DCM_DateTime, logStream);
+    return DSRStringValue::read(dataset, DCM_DateTime);
 }
 
 
-OFCondition DSRDateTimeTreeNode::writeContentItem(DcmItem &dataset,
-                                                  OFConsole *logStream) const
+OFCondition DSRDateTimeTreeNode::writeContentItem(DcmItem &dataset) const
 {
     /* write DateTime */
-    return DSRStringValue::write(dataset, DCM_DateTime, logStream);
+    return DSRStringValue::write(dataset, DCM_DateTime);
 }
 
 
@@ -155,25 +148,36 @@ OFString &DSRDateTimeTreeNode::getValueFromXMLNodeContent(const DSRXMLDocument &
 }
 
 
-OFCondition DSRDateTimeTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                       ostream & /*annexStream*/,
+OFCondition DSRDateTimeTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                       STD_NAMESPACE ostream & /*annexStream*/,
                                                        const size_t /*nestingLevel*/,
                                                        size_t & /*annexNumber*/,
-                                                       const size_t flags,
-                                                       OFConsole *logStream) const
+                                                       const size_t flags) const
 {
     /* render ConceptName */
-    OFCondition result = renderHTMLConceptName(docStream, flags, logStream);
+    OFCondition result = renderHTMLConceptName(docStream, flags);
     /* render DateTime */
     if (result.good())
     {
         OFString htmlString;
         if (!(flags & DSRTypes::HF_renderItemsSeparately))
-            docStream << "<u>";
+        {
+            if (flags & DSRTypes::HF_XHTML11Compatibility)
+                docStream << "<span class=\"datetime\">";
+            else if (flags & DSRTypes::HF_HTML32Compatibility)
+                docStream << "<u>";
+            else /* HTML 4.01 */
+                docStream << "<span class=\"under\">";
+        }
         docStream << dicomToReadableDateTime(getValue(), htmlString);
         if (!(flags & DSRTypes::HF_renderItemsSeparately))
-            docStream << "</u>";
-        docStream << endl;
+        {
+            if (flags & DSRTypes::HF_HTML32Compatibility)
+                docStream << "</u>";
+            else
+                docStream << "</span>";
+        }
+        docStream << OFendl;
     }
     return result;
 }
@@ -182,6 +186,21 @@ OFCondition DSRDateTimeTreeNode::renderHTMLContentItem(ostream &docStream,
 /*
  *  CVS/RCS Log:
  *  $Log: dsrdtitn.cc,v $
+ *  Revision 1.24  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.23  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.22  2007-11-15 16:45:26  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *  Enhanced support for output in valid HTML 3.2 format. Migrated support for
+ *  standard HTML from version 4.0 to 4.01 (strict).
+ *
+ *  Revision 1.21  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.20  2005/12/08 15:47:51  meichel
  *  Changed include path schema for all DCMTK header files
  *
