@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRImageFrameList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:53 $
- *  CVS/RCS Revision: $Revision: 1.14 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.19 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -67,7 +63,7 @@ DSRImageFrameList &DSRImageFrameList::operator=(const DSRImageFrameList &lst)
 }
 
 
-OFCondition DSRImageFrameList::print(ostream &stream,
+OFCondition DSRImageFrameList::print(STD_NAMESPACE ostream &stream,
                                      const size_t flags,
                                      const char separator) const
 {
@@ -92,8 +88,7 @@ OFCondition DSRImageFrameList::print(ostream &stream,
 }
 
 
-OFCondition DSRImageFrameList::read(DcmItem &dataset,
-                                    OFConsole * /*logStream*/)
+OFCondition DSRImageFrameList::read(DcmItem &dataset)
 {
     /* get integer string from dataset */
     DcmIntegerString delem(DCM_ReferencedFrameNumber);
@@ -115,8 +110,7 @@ OFCondition DSRImageFrameList::read(DcmItem &dataset,
 }
 
 
-OFCondition DSRImageFrameList::write(DcmItem &dataset,
-                                     OFConsole * /*logStream*/) const
+OFCondition DSRImageFrameList::write(DcmItem &dataset) const
 {
     OFCondition result = EC_Normal;
     /* fill string with values from list */
@@ -141,7 +135,7 @@ OFCondition DSRImageFrameList::write(DcmItem &dataset,
     result = delem.putOFStringArray(tmpString);
     /* add to dataset */
     if (result.good())
-        result = DSRTypes::addElementToDataset(result, dataset, new DcmIntegerString(delem));
+        result = DSRTypes::addElementToDataset(result, dataset, new DcmIntegerString(delem), "1-n", "1", "IMAGE content item");
     return result;
 }
 
@@ -181,6 +175,22 @@ OFCondition DSRImageFrameList::putString(const char *stringValue)
 /*
  *  CVS/RCS Log:
  *  $Log: dsrimgfr.cc,v $
+ *  Revision 1.19  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.18  2010-09-29 15:16:50  joergr
+ *  Enhanced checking and reporting of standard violations in write() methods.
+ *
+ *  Revision 1.17  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.16  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.15  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.14  2005/12/08 15:47:53  meichel
  *  Changed include path schema for all DCMTK header files
  *
