@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRImageReferenceValue
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:55 $
- *  CVS/RCS Revision: $Revision: 1.17 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.22 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -127,7 +123,7 @@ OFBool DSRImageReferenceValue::isShort(const size_t flags) const
 }
 
 
-OFCondition DSRImageReferenceValue::print(ostream &stream,
+OFCondition DSRImageReferenceValue::print(STD_NAMESPACE ostream &stream,
                                           const size_t flags) const
 {
     const char *modality = dcmSOPClassUIDToModality(SOPClassUID.c_str());
@@ -184,69 +180,65 @@ OFCondition DSRImageReferenceValue::readXML(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRImageReferenceValue::writeXML(ostream &stream,
-                                             const size_t flags,
-                                             OFConsole *logStream) const
+OFCondition DSRImageReferenceValue::writeXML(STD_NAMESPACE ostream &stream,
+                                             const size_t flags) const
 {
-    OFCondition result = DSRCompositeReferenceValue::writeXML(stream, flags, logStream);
+    OFCondition result = DSRCompositeReferenceValue::writeXML(stream, flags);
     if ((flags & DSRTypes::XF_writeEmptyTags) || !FrameList.isEmpty())
     {
         stream << "<frames>";
         FrameList.print(stream);
-        stream << "</frames>" << endl;
+        stream << "</frames>" << OFendl;
     }
     if ((flags & DSRTypes::XF_writeEmptyTags) || PresentationState.isValid())
     {
-        stream << "<pstate>" << endl;
+        stream << "<pstate>" << OFendl;
         if (PresentationState.isValid())
-            PresentationState.writeXML(stream, flags, logStream);
-        stream << "</pstate>" << endl;
+            PresentationState.writeXML(stream, flags);
+        stream << "</pstate>" << OFendl;
     }
     return result;
 }
 
 
-OFCondition DSRImageReferenceValue::readItem(DcmItem &dataset,
-                                             OFConsole *logStream)
+OFCondition DSRImageReferenceValue::readItem(DcmItem &dataset)
 {
     /* read ReferencedSOPClassUID and ReferencedSOPInstanceUID */
-    OFCondition result = DSRCompositeReferenceValue::readItem(dataset, logStream);
+    OFCondition result = DSRCompositeReferenceValue::readItem(dataset);
     /* read ReferencedFrameNumber (conditional) */
     if (result.good())
-        FrameList.read(dataset, logStream);
+        FrameList.read(dataset);
     /* read ReferencedSOPSequence (Presentation State, optional) */
     if (result.good())
-        PresentationState.readSequence(dataset, "3" /*type*/, logStream);
+        PresentationState.readSequence(dataset, "3" /*type*/);
     return result;
 }
 
 
-OFCondition DSRImageReferenceValue::writeItem(DcmItem &dataset,
-                                              OFConsole *logStream) const
+OFCondition DSRImageReferenceValue::writeItem(DcmItem &dataset) const
 {
     /* write ReferencedSOPClassUID and ReferencedSOPInstanceUID */
-    OFCondition result = DSRCompositeReferenceValue::writeItem(dataset, logStream);
+    OFCondition result = DSRCompositeReferenceValue::writeItem(dataset);
     /* write ReferencedFrameNumber (conditional) */
     if (result.good())
     {
         if (!FrameList.isEmpty())
-            result = FrameList.write(dataset, logStream);
+            result = FrameList.write(dataset);
     }
     /* write ReferencedSOPSequence (Presentation State, optional) */
     if (result.good())
     {
         if (PresentationState.isValid())
-            result = PresentationState.writeSequence(dataset, logStream);
+            result = PresentationState.writeSequence(dataset);
     }
     return result;
 }
 
 
-OFCondition DSRImageReferenceValue::renderHTML(ostream &docStream,
-                                               ostream &annexStream,
+OFCondition DSRImageReferenceValue::renderHTML(STD_NAMESPACE ostream &docStream,
+                                               STD_NAMESPACE ostream &annexStream,
                                                size_t &annexNumber,
-                                               const size_t flags,
-                                               OFConsole * /*logStream*/) const
+                                               const size_t flags) const
 {
     /* reference: image */
     docStream << "<a href=\"" << HTML_HYPERLINK_PREFIX_FOR_CGI;
@@ -254,13 +246,13 @@ OFCondition DSRImageReferenceValue::renderHTML(ostream &docStream,
     /* reference: pstate */
     if (PresentationState.isValid())
     {
-        docStream << "&pstate=" << PresentationState.getSOPClassUID();
+        docStream << "&amp;pstate=" << PresentationState.getSOPClassUID();
         docStream << "+" << PresentationState.getSOPInstanceUID();
     }
     /* reference: frames */
     if (!FrameList.isEmpty())
     {
-        docStream << "&frames=";
+        docStream << "&amp;frames=";
         FrameList.print(docStream, 0 /*flags*/, '+');
     }
     docStream << "\">";
@@ -277,20 +269,23 @@ OFCondition DSRImageReferenceValue::renderHTML(ostream &docStream,
     docStream << "</a>";
     if (!isShort(flags))
     {
+        const char *lineBreak = (flags & DSRTypes::HF_renderSectionTitlesInline) ? " " :
+                                (flags & DSRTypes::HF_XHTML11Compatibility) ? "<br />" : "<br>";
         if (flags & DSRTypes::HF_currentlyInsideAnnex)
         {
-            docStream << endl << "<p>" << endl;
+            docStream << OFendl << "<p>" << OFendl;
             /* render frame list (= print)*/
-            docStream << "<b>Referenced Frame Number:</b><br>";
+            docStream << "<b>Referenced Frame Number:</b>" << lineBreak;
             FrameList.print(docStream);
             docStream << "</p>";
         } else {
-            DSRTypes::createHTMLAnnexEntry(docStream, annexStream, "for more details see", annexNumber);
-            annexStream << "<p>" << endl;
+            docStream << " ";
+            DSRTypes::createHTMLAnnexEntry(docStream, annexStream, "for more details see", annexNumber, flags);
+            annexStream << "<p>" << OFendl;
             /* render frame list (= print)*/
-            annexStream << "<b>Referenced Frame Number:</b><br>";
+            annexStream << "<b>Referenced Frame Number:</b>" << lineBreak;
             FrameList.print(annexStream);
-            annexStream << "</p>" << endl;
+            annexStream << "</p>" << OFendl;
         }
     }
     return EC_Normal;
@@ -359,6 +354,26 @@ OFBool DSRImageReferenceValue::checkPresentationState(const DSRCompositeReferenc
 /*
  *  CVS/RCS Log:
  *  $Log: dsrimgvl.cc,v $
+ *  Revision 1.22  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.21  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.20  2007-11-15 16:45:26  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *  Enhanced support for output in valid HTML 3.2 format. Migrated support for
+ *  standard HTML from version 4.0 to 4.01 (strict).
+ *
+ *  Revision 1.19  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.18  2006/07/25 13:37:48  joergr
+ *  Added new optional flags for the HTML rendering of SR documents:
+ *  HF_alwaysExpandChildrenInline, HF_useCodeDetailsTooltip and
+ *  HF_renderSectionTitlesInline.
+ *
  *  Revision 1.17  2005/12/08 15:47:55  meichel
  *  Changed include path schema for all DCMTK header files
  *
