@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2003-2005, OFFIS
+ *  Copyright (C) 2003-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRMammographyCadSRConstraintChecker
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:47:58 $
- *  CVS/RCS Revision: $Revision: 1.5 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.12 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -82,49 +78,47 @@ OFBool DSRMammographyCadSRConstraintChecker::checkContentRelationship(const E_Va
     /* row 1 of the table */
     if ((relationshipType == RT_contains) && !byReference && (sourceValueType == VT_Container))
     {
-        result = (targetValueType == VT_Code)  || (targetValueType == VT_Num) || (targetValueType == VT_SCoord) ||
-                 (targetValueType == VT_Image) || (targetValueType == VT_Container);
+        result = (targetValueType == VT_Code) || (targetValueType == VT_Num) || (targetValueType == VT_SCoord) ||
+                 (targetValueType == VT_Image) || (targetValueType == VT_Container) ||
+                 (targetValueType == VT_Text) || (targetValueType == VT_Date);
     }
     /* row 2 of the table */
     else if ((relationshipType == RT_hasObsContext) && !byReference && ((sourceValueType == VT_Container) ||
         (sourceValueType == VT_Text) || (sourceValueType == VT_Code) || (sourceValueType == VT_Num)))
     {
-        result = (targetValueType == VT_Text) || (targetValueType == VT_Code) || (targetValueType == VT_Num)   ||
+        result = (targetValueType == VT_Text) || (targetValueType == VT_Code) || (targetValueType == VT_Num) ||
                  (targetValueType == VT_Date) || (targetValueType == VT_Time) || (targetValueType == VT_PName) ||
-                 (targetValueType == VT_Composite);
+                 (targetValueType == VT_UIDRef) || (targetValueType == VT_Composite);
     }
     /* row 3 of the table */
     else if ((relationshipType == RT_hasAcqContext) && !byReference && (sourceValueType == VT_Image))
     {
         result = (targetValueType == VT_Text) || (targetValueType == VT_Code) || (targetValueType == VT_Date) ||
-                 (targetValueType == VT_Time) || (targetValueType == VT_Num /* see CP 545 */);
+                 (targetValueType == VT_Time) || (targetValueType == VT_Num);
     }
     /* row 4 of the table */
     else if ((relationshipType == RT_hasConceptMod) && !byReference &&
-        ((sourceValueType == VT_Container) || (sourceValueType == VT_Code)))
+        ((sourceValueType == VT_Container) || (sourceValueType == VT_Code) ||
+        (sourceValueType == VT_Num) || (sourceValueType == VT_Composite)))
     {
         result = (targetValueType == VT_Text) || (targetValueType == VT_Code);
     }
     /* row 5 the table */
-    else if ((relationshipType == RT_hasProperties) && !byReference &&
-        ((sourceValueType == VT_Text) || (sourceValueType == VT_Code)))
+    else if ((relationshipType == RT_hasProperties) &&
+        ((sourceValueType == VT_Text) || (sourceValueType == VT_Code) || (sourceValueType == VT_Num)))
     {
-        result = (targetValueType == VT_Text) || (targetValueType == VT_Code)  || (targetValueType == VT_Num) ||
-                 (targetValueType == VT_Date) || (targetValueType == VT_Image) || (targetValueType == VT_SCoord);
-    }
-    else if ((relationshipType == RT_hasProperties) && byReference && (sourceValueType == VT_Code))
-    {
-        /* WORKAROUND: allow by-reference relationship since it is needed for some Mammography CAD
-         * SR templates (PS 3.16); however, this conflicts with the definitions in PS 3.3-2004.
-         */
-        result = (targetValueType == VT_Image);
+        /* by-reference allowed */
+        result = (targetValueType == VT_Container) || (targetValueType == VT_Text) || (targetValueType == VT_Code) ||
+                 (targetValueType == VT_Num) || (targetValueType == VT_Date) || (targetValueType == VT_Image) ||
+                 (targetValueType == VT_SCoord) || (targetValueType == VT_UIDRef);
     }
     /* row 6 of the table */
     else if ((relationshipType == RT_inferredFrom) && ((sourceValueType == VT_Code) || (sourceValueType == VT_Num)))
     {
         /* by-reference allowed */
         result = (targetValueType == VT_Code) || (targetValueType == VT_Num) || (targetValueType == VT_SCoord) ||
-                 (targetValueType == VT_Container);
+                 (targetValueType == VT_Container) || (targetValueType == VT_Text) ||
+                 (targetValueType == VT_Image);
     }
     /* row 7 of the table */
     else if ((relationshipType == RT_selectedFrom) && (sourceValueType == VT_SCoord))
@@ -139,6 +133,29 @@ OFBool DSRMammographyCadSRConstraintChecker::checkContentRelationship(const E_Va
 /*
  *  CVS/RCS Log:
  *  $Log: dsrmamcc.cc,v $
+ *  Revision 1.12  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.11  2010-06-09 16:35:12  joergr
+ *  Removed references to CP 767.
+ *
+ *  Revision 1.10  2009-08-07 08:36:36  joergr
+ *  Added missing relationship content constraint introduced with DICOM 2007.
+ *
+ *  Revision 1.9  2007-11-30 16:57:50  joergr
+ *  Updated relationship content constraints according to CP 767.
+ *
+ *  Revision 1.8  2007/11/15 16:57:31  joergr
+ *  Removed preliminary patch for TID 4023 (since not yet approved). Documented
+ *  modification required for CP 492 (has already been added by the last commit).
+ *
+ *  Revision 1.7  2007/11/15 16:45:42  joergr
+ *  Added support for output in XHTML 1.1 format. -> incorrect log entry
+ *
+ *  Revision 1.6  2006/03/24 11:11:45  joergr
+ *  Added full support for CP 545, i.e. allow by-reference HAS PROPERTIES
+ *  relationships.
+ *
  *  Revision 1.5  2005/12/08 15:47:58  meichel
  *  Changed include path schema for all DCMTK header files
  *
