@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRPNameTreeNode
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:01 $
- *  CVS/RCS Revision: $Revision: 1.22 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.27 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -73,7 +69,7 @@ OFBool DSRPNameTreeNode::isValid() const
 }
 
 
-OFCondition DSRPNameTreeNode::print(ostream &stream,
+OFCondition DSRPNameTreeNode::print(STD_NAMESPACE ostream &stream,
                                     const size_t flags) const
 {
     OFCondition result = DSRDocumentTreeNode::print(stream, flags);
@@ -86,36 +82,33 @@ OFCondition DSRPNameTreeNode::print(ostream &stream,
 }
 
 
-OFCondition DSRPNameTreeNode::writeXML(ostream &stream,
-                                       const size_t flags,
-                                       OFConsole *logStream) const
+OFCondition DSRPNameTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                       const size_t flags) const
 {
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags);
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
     if (!getValue().empty() || (flags & XF_writeEmptyTags))
     {
         OFString tmpString;
-        stream << "<value>" << endl << dicomToXMLPersonName(getValue(), tmpString) << endl << "</value>" << endl;
+        stream << "<value>" << OFendl << dicomToXMLPersonName(getValue(), tmpString) << OFendl << "</value>" << OFendl;
     }
     writeXMLItemEnd(stream, flags);
     return result;
 }
 
 
-OFCondition DSRPNameTreeNode::readContentItem(DcmItem &dataset,
-                                              OFConsole *logStream)
+OFCondition DSRPNameTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read PName */
-    return DSRStringValue::read(dataset, DCM_PersonName, logStream);
+    return DSRStringValue::read(dataset, DCM_PersonName);
 }
 
 
-OFCondition DSRPNameTreeNode::writeContentItem(DcmItem &dataset,
-                                               OFConsole *logStream) const
+OFCondition DSRPNameTreeNode::writeContentItem(DcmItem &dataset) const
 {
     /* write PName */
-    return DSRStringValue::write(dataset, DCM_PersonName, logStream);
+    return DSRStringValue::write(dataset, DCM_PersonName);
 }
 
 
@@ -168,39 +161,62 @@ OFString &DSRPNameTreeNode::getValueFromXMLNodeContent(const DSRXMLDocument &doc
 }
 
 
-OFCondition DSRPNameTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                    ostream & /*annexStream*/,
+OFCondition DSRPNameTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                    STD_NAMESPACE ostream & /*annexStream*/,
                                                     const size_t /*nestingLevel*/,
                                                     size_t & /*annexNumber*/,
-                                                    const size_t flags,
-                                                    OFConsole *logStream) const
+                                                    const size_t flags) const
 {
     /* render ConceptName */
-    OFCondition result = renderHTMLConceptName(docStream, flags, logStream);
+    OFCondition result = renderHTMLConceptName(docStream, flags);
     /* render PName */
     if (result.good())
     {
         OFString tmpString, htmlString;
         if (!(flags & DSRTypes::HF_renderItemsSeparately))
-            docStream << "<u>";
-        docStream << convertToMarkupString(dicomToReadablePersonName(getValue(), tmpString), htmlString, (flags & HF_convertNonASCIICharacters) > 0);
+        {
+            if (flags & DSRTypes::HF_XHTML11Compatibility)
+                docStream << "<span class=\"pname\">";
+            else if (flags & DSRTypes::HF_HTML32Compatibility)
+                docStream << "<u>";
+            else /* HTML 4.01 */
+                docStream << "<span class=\"under\">";
+        }
+        docStream << convertToHTMLString(dicomToReadablePersonName(getValue(), tmpString), htmlString, flags);
         if (!(flags & DSRTypes::HF_renderItemsSeparately))
-            docStream << "</u>";
-        docStream << endl;
+        {
+            if (flags & DSRTypes::HF_HTML32Compatibility)
+                docStream << "</u>";
+            else
+                docStream << "</span>";
+        }
+        docStream << OFendl;
     }
     return result;
 }
 
 
-OFBool DSRPNameTreeNode::containsExtendedCharacters() const
-{
-  return DSRDocumentTreeNode::containsExtendedCharacters() || valueContainsExtendedCharacters();
-}
-
-
 /*
  *  CVS/RCS Log:
  *  $Log: dsrpnmtn.cc,v $
+ *  Revision 1.27  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.26  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.25  2007-11-15 16:45:26  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *  Enhanced support for output in valid HTML 3.2 format. Migrated support for
+ *  standard HTML from version 4.0 to 4.01 (strict).
+ *
+ *  Revision 1.24  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.23  2006/05/11 09:16:49  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  *  Revision 1.22  2005/12/08 15:48:01  meichel
  *  Changed include path schema for all DCMTK header files
  *
