@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRByReferenceTreeNode
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:03 $
- *  CVS/RCS Revision: $Revision: 1.15 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.21 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -79,7 +75,7 @@ OFBool DSRByReferenceTreeNode::isValid() const
 }
 
 
-OFCondition DSRByReferenceTreeNode::print(ostream &stream,
+OFCondition DSRByReferenceTreeNode::print(STD_NAMESPACE ostream &stream,
                                           const size_t /*flags*/) const
 {
     stream << relationshipTypeToReadableName(getRelationshipType()) << " " << ReferencedContentItem;
@@ -87,29 +83,27 @@ OFCondition DSRByReferenceTreeNode::print(ostream &stream,
 }
 
 
-OFCondition DSRByReferenceTreeNode::writeXML(ostream &stream,
-                                             const size_t flags,
-                                             OFConsole *logStream) const
+OFCondition DSRByReferenceTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                             const size_t flags) const
 {
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags, OFFalse /*closingBracket*/);
-    stream << " ref=\"" << ReferencedNodeID << "\">" << endl;
+    stream << " ref=\"" << ReferencedNodeID << "\">" << OFendl;
     /* basically, there should be no child content items but ... */
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
     writeXMLItemEnd(stream, flags);
     return result;
 }
 
 
-OFCondition DSRByReferenceTreeNode::readContentItem(DcmItem &dataset,
-                                                    OFConsole *logStream)
+OFCondition DSRByReferenceTreeNode::readContentItem(DcmItem &dataset)
 {
     DcmUnsignedLong delem(DCM_ReferencedContentItemIdentifier);
     /* clear before reading */
     ReferencedContentItem.clear();
     ReferencedNodeID = 0;
     /* read ReferencedContentItemIdentifier */
-    OFCondition result = getAndCheckElementFromDataset(dataset, delem, "1-n", "1C", logStream);
+    OFCondition result = getAndCheckElementFromDataset(dataset, delem, "1-n", "1C", "by-reference relationship");
     if (result.good())
     {
         /* create reference string from unsigned long values */
@@ -128,8 +122,7 @@ OFCondition DSRByReferenceTreeNode::readContentItem(DcmItem &dataset,
 }
 
 
-OFCondition DSRByReferenceTreeNode::writeContentItem(DcmItem &dataset,
-                                                     OFConsole * /*logStream*/) const
+OFCondition DSRByReferenceTreeNode::writeContentItem(DcmItem &dataset) const
 {
     OFCondition result = SR_EC_InvalidValue;
     /* only write references with valid format */
@@ -154,7 +147,7 @@ OFCondition DSRByReferenceTreeNode::writeContentItem(DcmItem &dataset,
             i++;
         } while (posEnd != OFString_npos);
         /* write ReferencedContentItemIdentifier */
-        addElementToDataset(result, dataset, new DcmUnsignedLong(delem));
+        addElementToDataset(result, dataset, new DcmUnsignedLong(delem), "1-n", "1", "by-reference relationship");
     }
     return result;
 }
@@ -180,15 +173,14 @@ OFCondition DSRByReferenceTreeNode::readXMLContentItem(const DSRXMLDocument &doc
 }
 
 
-OFCondition DSRByReferenceTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                          ostream & /*annexStream*/,
+OFCondition DSRByReferenceTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                          STD_NAMESPACE ostream & /*annexStream*/,
                                                           const size_t /*nestingLevel*/,
                                                           size_t & /*annexNumber*/,
-                                                          const size_t /*flags*/,
-                                                          OFConsole * /*logStream*/) const
+                                                          const size_t /*flags*/) const
 {
     /* render reference string */
-    docStream << "Content Item <a href=\"#content_item_" << ReferencedNodeID << "\">by-reference</a>" << endl;
+    docStream << "Content Item <a href=\"#content_item_" << ReferencedNodeID << "\">by-reference</a>" << OFendl;
     return EC_Normal;
 }
 
@@ -218,6 +210,26 @@ OFCondition DSRByReferenceTreeNode::setTemplateIdentification(const OFString & /
 /*
  *  CVS/RCS Log:
  *  $Log: dsrreftn.cc,v $
+ *  Revision 1.21  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.20  2010-09-29 15:16:50  joergr
+ *  Enhanced checking and reporting of standard violations in write() methods.
+ *
+ *  Revision 1.19  2010-09-29 08:32:26  joergr
+ *  Used more specific "moduleName" for getAndCheckElementFromDataset() and
+ *  checkElementValue().
+ *
+ *  Revision 1.18  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.17  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.16  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.15  2005/12/08 15:48:03  meichel
  *  Changed include path schema for all DCMTK header files
  *
