@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRSpatialCoordinatesValue
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:06 $
- *  CVS/RCS Revision: $Revision: 1.16 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:41 $
+ *  CVS/RCS Revision: $Revision: 1.22 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -91,7 +87,7 @@ OFBool DSRSpatialCoordinatesValue::isShort(const size_t flags) const
 }
 
 
-OFCondition DSRSpatialCoordinatesValue::print(ostream &stream,
+OFCondition DSRSpatialCoordinatesValue::print(STD_NAMESPACE ostream &stream,
                                               const size_t flags) const
 {
     /* GraphicType */
@@ -126,44 +122,41 @@ OFCondition DSRSpatialCoordinatesValue::readXML(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRSpatialCoordinatesValue::writeXML(ostream &stream,
-                                                 const size_t flags,
-                                                 OFConsole * /*logStream*/) const
+OFCondition DSRSpatialCoordinatesValue::writeXML(STD_NAMESPACE ostream &stream,
+                                                 const size_t flags) const
 {
     /* GraphicType is written in TreeNode class */
     if ((flags & DSRTypes::XF_writeEmptyTags) || !GraphicDataList.isEmpty())
     {
         stream << "<data>";
         GraphicDataList.print(stream);
-        stream << "</data>" << endl;
+        stream << "</data>" << OFendl;
     }
     return EC_Normal;
 }
 
 
-OFCondition DSRSpatialCoordinatesValue::read(DcmItem &dataset,
-                                             OFConsole *logStream)
+OFCondition DSRSpatialCoordinatesValue::read(DcmItem &dataset)
 {
     /* read GraphicType */
     OFString tmpString;
-    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_GraphicType, tmpString, "1", "1", logStream, "SCOORD content item");
+    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_GraphicType, tmpString, "1", "1", "SCOORD content item");
     if (result.good())
     {
         GraphicType = DSRTypes::enumeratedValueToGraphicType(tmpString);
         /* check GraphicType */
         if (GraphicType == DSRTypes::GT_invalid)
-            DSRTypes::printUnknownValueWarningMessage(logStream, "GraphicType", tmpString.c_str());
+            DSRTypes::printUnknownValueWarningMessage("GraphicType", tmpString.c_str());
         /* read GraphicData */
-        result = GraphicDataList.read(dataset, logStream);
+        result = GraphicDataList.read(dataset);
         /* check GraphicData and report warnings if any */
-        checkData(GraphicType, GraphicDataList, logStream);
+        checkData(GraphicType, GraphicDataList);
     }
     return result;
 }
 
 
-OFCondition DSRSpatialCoordinatesValue::write(DcmItem &dataset,
-                                              OFConsole *logStream) const
+OFCondition DSRSpatialCoordinatesValue::write(DcmItem &dataset) const
 {
     /* write GraphicType */
     OFCondition result = DSRTypes::putStringValueToDataset(dataset, DCM_GraphicType, DSRTypes::graphicTypeToEnumeratedValue(GraphicType));
@@ -171,39 +164,40 @@ OFCondition DSRSpatialCoordinatesValue::write(DcmItem &dataset,
     if (result.good())
     {
         if (!GraphicDataList.isEmpty())
-            result = GraphicDataList.write(dataset, logStream);
+            result = GraphicDataList.write(dataset);
     }
     /* check GraphicData and report warnings if any */
-    checkData(GraphicType, GraphicDataList, logStream);
+    checkData(GraphicType, GraphicDataList);
     return result;
 }
 
 
-OFCondition DSRSpatialCoordinatesValue::renderHTML(ostream &docStream,
-                                                   ostream &annexStream,
+OFCondition DSRSpatialCoordinatesValue::renderHTML(STD_NAMESPACE ostream &docStream,
+                                                   STD_NAMESPACE ostream &annexStream,
                                                    size_t &annexNumber,
-                                                   const size_t flags,
-                                                   OFConsole * /*logStream*/) const
+                                                   const size_t flags) const
 {
     /* render GraphicType */
     docStream << DSRTypes::graphicTypeToReadableName(GraphicType);
     /* render GraphicData */
     if (!isShort(flags))
     {
+        const char *lineBreak = (flags & DSRTypes::HF_renderSectionTitlesInline) ? " " :
+                                (flags & DSRTypes::HF_XHTML11Compatibility) ? "<br />" : "<br>";
         if (flags & DSRTypes::HF_currentlyInsideAnnex)
         {
-            docStream << endl << "<p>" << endl;
+            docStream << OFendl << "<p>" << OFendl;
             /* render graphic data list (= print)*/
-            docStream << "<b>Graphic Data:</b><br>";
+            docStream << "<b>Graphic Data:</b>" << lineBreak;
             GraphicDataList.print(docStream);
             docStream << "</p>";
         } else {
-            DSRTypes::createHTMLAnnexEntry(docStream, annexStream, "for more details see", annexNumber);
-            annexStream << "<p>" << endl;
+            DSRTypes::createHTMLAnnexEntry(docStream, annexStream, "for more details see", annexNumber, flags);
+            annexStream << "<p>" << OFendl;
             /* render graphic data list (= print)*/
-            annexStream << "<b>Graphic Data:</b><br>";
+            annexStream << "<b>Graphic Data:</b>" << lineBreak;
             GraphicDataList.print(annexStream);
-            annexStream << "</p>" << endl;
+            annexStream << "</p>" << OFendl;
         }
     }
     return EC_Normal;
@@ -243,14 +237,13 @@ OFCondition DSRSpatialCoordinatesValue::setValue(const DSRSpatialCoordinatesValu
 
 
 OFBool DSRSpatialCoordinatesValue::checkData(const DSRTypes::E_GraphicType graphicType,
-                                             const DSRGraphicDataList &graphicDataList,
-                                             OFConsole *logStream) const
+                                             const DSRGraphicDataList &graphicDataList) const
 {
     OFBool result = OFFalse;
     if (graphicType == DSRTypes::GT_invalid)
-        DSRTypes::printWarningMessage(logStream, "Invalid GraphicType for SCOORD content item");
+        DCMSR_WARN("Invalid GraphicType for SCOORD content item");
     else if (graphicDataList.isEmpty())
-        DSRTypes::printWarningMessage(logStream, "No GraphicData for SCOORD content item");
+        DCMSR_WARN("No GraphicData for SCOORD content item");
     else
     {
         const size_t count = graphicDataList.getNumberOfItems();
@@ -258,38 +251,38 @@ OFBool DSRSpatialCoordinatesValue::checkData(const DSRTypes::E_GraphicType graph
         {
             case DSRTypes::GT_Point:
                 if (count > 1)
-                    DSRTypes::printWarningMessage(logStream, "GraphicData has too many entries, only a single entry expected");
+                    DCMSR_WARN("GraphicData has too many entries, only a single entry expected");
                 result = OFTrue;
                 break;
             case DSRTypes::GT_Multipoint:
                 if (count < 1)
-                    DSRTypes::printWarningMessage(logStream, "GraphicData has too few entries, at least one entry expected");
+                    DCMSR_WARN("GraphicData has too few entries, at least one entry expected");
                 result = OFTrue;
                 break;
             case DSRTypes::GT_Polyline:
 /*              // not required any more according to CP-233
-                if (!(graphicDataList.getItem(1) == graphicDataList.getItem(count)))
-                    DSRTypes::printWarningMessage(logStream, "First and last entry in GraphicData are not equal (POLYLINE)");
+                if (graphicDataList.getItem(1) != graphicDataList.getItem(count))
+                    DCMSR_WARN("First and last entry in GraphicData are not equal (POLYLINE)");
 */
                 result = OFTrue;
                 break;
             case DSRTypes::GT_Circle:
                 if (count < 2)
-                    DSRTypes::printWarningMessage(logStream, "GraphicData has too few entries, exactly two entries expected");
+                    DCMSR_WARN("GraphicData has too few entries, exactly two entries expected");
                 else
                 {
                     if (count > 2)
-                        DSRTypes::printWarningMessage(logStream, "GraphicData has too many entries, exactly two entries expected");
+                        DCMSR_WARN("GraphicData has too many entries, exactly two entries expected");
                     result = OFTrue;
                 }
                 break;
             case DSRTypes::GT_Ellipse:
                 if (count < 4)
-                    DSRTypes::printWarningMessage(logStream, "GraphicData has too few entries, exactly four entries expected");
+                    DCMSR_WARN("GraphicData has too few entries, exactly four entries expected");
                 else
                 {
                     if (count > 4)
-                        DSRTypes::printWarningMessage(logStream, "GraphicData has too many entries, exactly four entries expected");
+                        DCMSR_WARN("GraphicData has too many entries, exactly four entries expected");
                     result = OFTrue;
                 }
                 break;
@@ -305,6 +298,27 @@ OFBool DSRSpatialCoordinatesValue::checkData(const DSRTypes::E_GraphicType graph
 /*
  *  CVS/RCS Log:
  *  $Log: dsrscovl.cc,v $
+ *  Revision 1.22  2010-10-14 13:14:41  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.21  2010-09-28 14:03:41  joergr
+ *  Updated comment on the requirements for POLYLINE according to CP-233.
+ *
+ *  Revision 1.20  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.19  2007-11-15 16:45:42  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *
+ *  Revision 1.18  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.17  2006/07/25 13:37:48  joergr
+ *  Added new optional flags for the HTML rendering of SR documents:
+ *  HF_alwaysExpandChildrenInline, HF_useCodeDetailsTooltip and
+ *  HF_renderSectionTitlesInline.
+ *
  *  Revision 1.16  2005/12/08 15:48:06  meichel
  *  Changed include path schema for all DCMTK header files
  *
