@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2005, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -24,8 +20,8 @@
  *             - InstanceStruct, SeriesStruct, StudyStruct
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2005/12/15 16:53:48 $
- *  CVS/RCS Revision: $Revision: 1.10 $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.19 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -70,7 +66,7 @@ DSRSOPInstanceReferenceList::SeriesStruct::SeriesStruct(const OFString &seriesUI
 DSRSOPInstanceReferenceList::SeriesStruct::~SeriesStruct()
 {
     Iterator = InstanceList.begin();
-    const OFListConstIterator(InstanceStruct *) last = InstanceList.end();
+    const OFListIterator(InstanceStruct *) last = InstanceList.end();
     /* delete all items and free memory */
     while (Iterator != last)
     {
@@ -86,17 +82,16 @@ size_t DSRSOPInstanceReferenceList::SeriesStruct::getNumberOfInstances() const
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::SeriesStruct::read(DcmItem &dataset,
-                                                            OFConsole *logStream)
+OFCondition DSRSOPInstanceReferenceList::SeriesStruct::read(DcmItem &dataset)
 {
     /* first, read optional attributes on series level */
-    getAndCheckStringValueFromDataset(dataset, DCM_RetrieveAETitle, RetrieveAETitle, "1-n", "3", logStream);
-    getAndCheckStringValueFromDataset(dataset, DCM_StorageMediaFileSetID, StorageMediaFileSetID, "1", "3", logStream);
-    getAndCheckStringValueFromDataset(dataset, DCM_StorageMediaFileSetUID, StorageMediaFileSetUID, "1", "3", logStream);
+    getAndCheckStringValueFromDataset(dataset, DCM_RetrieveAETitle, RetrieveAETitle, "1-n", "3", "ReferencedSeriesSequence");
+    getAndCheckStringValueFromDataset(dataset, DCM_StorageMediaFileSetID, StorageMediaFileSetID, "1", "3", "ReferencedSeriesSequence");
+    getAndCheckStringValueFromDataset(dataset, DCM_StorageMediaFileSetUID, StorageMediaFileSetUID, "1", "3", "ReferencedSeriesSequence");
     /* then, check whether sequence is present and non-empty */
     DcmSequenceOfItems sequence(DCM_ReferencedSOPSequence);
-    OFCondition result = getSequenceFromDataset(dataset, sequence);
-    checkElementValue(sequence, "1-n", "1", logStream, result);
+    OFCondition result = getElementFromDataset(dataset, sequence);
+    checkElementValue(sequence, "1-n", "1", result);
     if (result.good())
     {
         /* iterate over all sequence items */
@@ -107,8 +102,8 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::read(DcmItem &dataset,
             {
                 /* get the SOP class and SOP instance UID */
                 OFString sopClassUID, instanceUID;
-                if (getAndCheckStringValueFromDataset(*item, DCM_ReferencedSOPClassUID, sopClassUID, "1", "1", logStream).good() &&
-                    getAndCheckStringValueFromDataset(*item, DCM_ReferencedSOPInstanceUID, instanceUID, "1", "1", logStream).good())
+                if (getAndCheckStringValueFromDataset(*item, DCM_ReferencedSOPClassUID, sopClassUID, "1", "1", "ReferencedSOPSequence").good() &&
+                    getAndCheckStringValueFromDataset(*item, DCM_ReferencedSOPInstanceUID, instanceUID, "1", "1", "ReferencedSOPSequence").good())
                 {
                     /* check whether instance item already exists */
                     InstanceStruct *instance = gotoInstance(instanceUID);
@@ -128,10 +123,7 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::read(DcmItem &dataset,
                         }
                     } else {
                         /* report a warning message and ignore this entry */
-                        OFString message = "SOP Instance \"";
-                        message += instanceUID;
-                        message += "\" already exists in reference list ... ignoring";
-                        DSRTypes::printWarningMessage(logStream, message.c_str());
+                        DCMSR_WARN("SOP Instance \"" << instanceUID << "\" already exists in reference list ... ignoring");
                     }
                 }
             }
@@ -141,8 +133,7 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::read(DcmItem &dataset,
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::SeriesStruct::write(DcmItem &dataset,
-                                                             OFConsole * /*logStream*/) const
+OFCondition DSRSOPInstanceReferenceList::SeriesStruct::write(DcmItem &dataset) const
 {
     OFCondition result = EC_Normal;
     /* store the series level attributes */
@@ -223,10 +214,7 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::readXML(const DSRXMLDocum
                         }
                     } else {
                         /* report a warning message and ignore this entry */
-                        OFString message = "SOP Instance \"";
-                        message += instanceUID;
-                        message += "\" already exists in reference list ... ignoring";
-                        DSRTypes::printWarningMessage(doc.getLogStream(), message.c_str());
+                        DCMSR_WARN("SOP Instance \"" << instanceUID << "\" already exists in reference list ... ignoring");
                     }
                 }
                 /* proceed with next node */
@@ -235,29 +223,24 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::readXML(const DSRXMLDocum
         } while (cursor.valid());
         /* report a warning message if no "value" element found */
         if (result.bad())
-        {
-            OFString message = "Series \"";
-            message += SeriesUID;
-            message += "\" empty in reference list ... ignoring";
-            DSRTypes::printWarningMessage(doc.getLogStream(), message.c_str());
-        }
+            DCMSR_WARN("Series \"" << SeriesUID << "\" empty in reference list ... ignoring");
     }
     return result;
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::SeriesStruct::writeXML(ostream &stream,
+OFCondition DSRSOPInstanceReferenceList::SeriesStruct::writeXML(STD_NAMESPACE ostream &stream,
                                                                 const size_t flags) const
 {
     /* write the series level attributes */
-    stream << "<series uid=\"" << SeriesUID << "\">" << endl;
+    stream << "<series uid=\"" << SeriesUID << "\">" << OFendl;
     writeStringValueToXML(stream, RetrieveAETitle, "aetitle", (flags & XF_writeEmptyTags) > 0);
     if ((flags & XF_writeEmptyTags) || !StorageMediaFileSetUID.empty() || !StorageMediaFileSetID.empty())
     {
         stream << "<fileset";
         if (!StorageMediaFileSetUID.empty())
             stream << " uid=\"" << StorageMediaFileSetUID << "\"";
-        stream << ">" << StorageMediaFileSetID << "</fileset>" << endl;
+        stream << ">" << StorageMediaFileSetID << "</fileset>" << OFendl;
     }
     /* iterate over all list items */
     OFListConstIterator(InstanceStruct *) iter = InstanceList.begin();
@@ -269,19 +252,19 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::writeXML(ostream &stream,
         if (instance != NULL)
         {
             /* write instance level */
-            stream << "<value>" << endl;
+            stream << "<value>" << OFendl;
             stream << "<sopclass uid=\"" << instance->SOPClassUID << "\">";
             /* retrieve name of SOP class */
             const char *sopClass = dcmFindNameOfUID(instance->SOPClassUID.c_str());
             if (sopClass != NULL)
                 stream << sopClass;
-            stream << "</sopclass>" << endl;
-            stream << "<instance uid=\"" << instance->InstanceUID << "\"/>" << endl;
-            stream << "</value>" << endl;
+            stream << "</sopclass>" << OFendl;
+            stream << "<instance uid=\"" << instance->InstanceUID << "\"/>" << OFendl;
+            stream << "</value>" << OFendl;
         }
         iter++;
     }
-    stream << "</series>" << endl;
+    stream << "</series>" << OFendl;
     return EC_Normal;
 }
 
@@ -296,7 +279,7 @@ DSRSOPInstanceReferenceList::InstanceStruct *DSRSOPInstanceReferenceList::Series
     {
         /* start with the first list item */
         Iterator = InstanceList.begin();
-        const OFListConstIterator(InstanceStruct *) last = InstanceList.end();
+        const OFListIterator(InstanceStruct *) last = InstanceList.end();
         /* search for given SOP instance UID */
         while ((Iterator != last) && ((*Iterator == NULL) || ((*Iterator)->InstanceUID != instanceUID)))
             Iterator++;
@@ -384,12 +367,6 @@ OFCondition DSRSOPInstanceReferenceList::SeriesStruct::removeItem()
 }
 
 
-OFBool DSRSOPInstanceReferenceList::SeriesStruct::containsExtendedCharacters()
-{
-  return DSRTypes::stringContainsExtendedCharacters(StorageMediaFileSetID);
-}
-
-
 // --- DSRSOPInstanceReferenceList::StudyStruct ---
 
 
@@ -406,7 +383,7 @@ DSRSOPInstanceReferenceList::StudyStruct::StudyStruct(const OFString &studyUID)
 DSRSOPInstanceReferenceList::StudyStruct::~StudyStruct()
 {
     Iterator = SeriesList.begin();
-    const OFListConstIterator(SeriesStruct *) last = SeriesList.end();
+    const OFListIterator(SeriesStruct *) last = SeriesList.end();
     /* delete all items and free memory */
     while (Iterator != last)
     {
@@ -433,13 +410,12 @@ size_t DSRSOPInstanceReferenceList::StudyStruct::getNumberOfInstances() const
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::StudyStruct::read(DcmItem &dataset,
-                                                           OFConsole *logStream)
+OFCondition DSRSOPInstanceReferenceList::StudyStruct::read(DcmItem &dataset)
 {
     /* first, check whether sequence is present and non-empty */
     DcmSequenceOfItems sequence(DCM_ReferencedSeriesSequence);
-    OFCondition result = getSequenceFromDataset(dataset, sequence);
-    checkElementValue(sequence, "1-n", "1", logStream, result);
+    OFCondition result = getElementFromDataset(dataset, sequence);
+    checkElementValue(sequence, "1-n", "1", result);
     if (result.good())
     {
         /* iterate over all sequence items */
@@ -450,7 +426,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::read(DcmItem &dataset,
             {
                 /* get the series instance UID */
                 OFString seriesUID;
-                if (getAndCheckStringValueFromDataset(*item, DCM_SeriesInstanceUID, seriesUID, "1", "1", logStream).good())
+                if (getAndCheckStringValueFromDataset(*item, DCM_SeriesInstanceUID, seriesUID, "1", "1", "ReferencedSeriesSequence").good())
                 {
                     /* check whether series item already exists,
                        because the internal structure is organized in a strictly hierarchical manner  */
@@ -473,7 +449,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::read(DcmItem &dataset,
                         /* set cursor to new position */
                         Iterator = --SeriesList.end();
                         /* read further attributes on series level and the instance level */
-                        result = series->read(*item, logStream);
+                        result = series->read(*item);
                     }
                 }
             }
@@ -483,8 +459,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::read(DcmItem &dataset,
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::StudyStruct::write(DcmItem &dataset,
-                                                            OFConsole *logStream) const
+OFCondition DSRSOPInstanceReferenceList::StudyStruct::write(DcmItem &dataset) const
 {
     OFCondition result = EC_Normal;
     /* store the study level attributes */
@@ -503,7 +478,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::write(DcmItem &dataset,
             result = dataset.findOrCreateSequenceItem(DCM_ReferencedSeriesSequence, item, -2 /*append new*/);
             /* write series and instance level */
             if (result.good())
-                result = series->write(*item, logStream);
+                result = series->write(*item);
         }
         iter++;
     }
@@ -555,23 +530,18 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::readXML(const DSRXMLDocume
         }
         /* report a warning message if no "value" element found */
         if (result.bad())
-        {
-            OFString message = "Study \"";
-            message += StudyUID;
-            message += "\" empty in reference list ... ignoring";
-            DSRTypes::printWarningMessage(doc.getLogStream(), message.c_str());
-        }
+            DCMSR_WARN("Study \"" << StudyUID << "\" empty in reference list ... ignoring");
     }
     return result;
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::StudyStruct::writeXML(ostream &stream,
+OFCondition DSRSOPInstanceReferenceList::StudyStruct::writeXML(STD_NAMESPACE ostream &stream,
                                                                const size_t flags) const
 {
     OFCondition result = EC_Normal;
     /* write the study level attributes */
-    stream << "<study uid=\"" << StudyUID << "\">" << endl;
+    stream << "<study uid=\"" << StudyUID << "\">" << OFendl;
     /* iterate over all list items */
     OFListConstIterator(SeriesStruct *) iter = SeriesList.begin();
     const OFListConstIterator(SeriesStruct *) last = SeriesList.end();
@@ -586,7 +556,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::writeXML(ostream &stream,
         }
         iter++;
     }
-    stream << "</study>" << endl;
+    stream << "</study>" << OFendl;
     return result;
 }
 
@@ -601,7 +571,7 @@ DSRSOPInstanceReferenceList::SeriesStruct *DSRSOPInstanceReferenceList::StudyStr
     {
         /* start with the first list item */
         Iterator = SeriesList.begin();
-        const OFListConstIterator(SeriesStruct *) last = SeriesList.end();
+        const OFListIterator(SeriesStruct *) last = SeriesList.end();
         /* search for given series UID */
         while ((Iterator != last) && ((*Iterator == NULL) || (OFstatic_cast(SeriesStruct *, *Iterator)->SeriesUID != seriesUID)))
             Iterator++;
@@ -618,7 +588,7 @@ DSRSOPInstanceReferenceList::InstanceStruct *DSRSOPInstanceReferenceList::StudyS
     InstanceStruct *instance = NULL;
     /* start with the first list item */
     Iterator = SeriesList.begin();
-    const OFListConstIterator(SeriesStruct *) last = SeriesList.end();
+    const OFListIterator(SeriesStruct *) last = SeriesList.end();
     /* search for given series UID */
     while ((Iterator != last) && (instance == NULL))
     {
@@ -735,7 +705,7 @@ OFCondition DSRSOPInstanceReferenceList::StudyStruct::removeItem()
 void DSRSOPInstanceReferenceList::StudyStruct::removeIncompleteItems()
 {
     Iterator = SeriesList.begin();
-    const OFListConstIterator(SeriesStruct *) last = SeriesList.end();
+    const OFListIterator(SeriesStruct *) last = SeriesList.end();
     /* for all series in the list */
     while (Iterator != last)
     {
@@ -757,19 +727,6 @@ void DSRSOPInstanceReferenceList::StudyStruct::removeIncompleteItems()
 }
 
 
-OFBool DSRSOPInstanceReferenceList::StudyStruct::containsExtendedCharacters()
-{
-    OFListIterator(SeriesStruct *) iter = SeriesList.begin();
-    OFListIterator(SeriesStruct *) last = SeriesList.end();
-    while (iter != last)
-    {
-      if (*iter && OFstatic_cast(SeriesStruct *, *iter)->containsExtendedCharacters()) return OFTrue;
-      ++iter;
-    }
-    return OFFalse;
-}
-
-
 // --- DSRSOPInstanceReferenceList ---
 
 DSRSOPInstanceReferenceList::DSRSOPInstanceReferenceList(const DcmTagKey &sequence)
@@ -792,7 +749,7 @@ DSRSOPInstanceReferenceList::~DSRSOPInstanceReferenceList()
 void DSRSOPInstanceReferenceList::clear()
 {
     Iterator = StudyList.begin();
-    const OFListConstIterator(StudyStruct *) last = StudyList.end();
+    const OFListIterator(StudyStruct *) last = StudyList.end();
     /* delete all items and free memory */
     while (Iterator != last)
     {
@@ -828,15 +785,15 @@ size_t DSRSOPInstanceReferenceList::getNumberOfInstances() const
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::read(DcmItem &dataset,
-                                              OFConsole *logStream)
+OFCondition DSRSOPInstanceReferenceList::read(DcmItem &dataset)
 {
     /* first, check whether sequence is present and non-empty */
     DcmSequenceOfItems sequence(SequenceTag);
-    OFCondition result = getSequenceFromDataset(dataset, sequence);
-    checkElementValue(sequence, "1-n", "1C", logStream, result);
+    OFCondition result = getElementFromDataset(dataset, sequence);
+    checkElementValue(sequence, "1-n", "1C", result);
     if (result.good())
     {
+        OFString sequenceName = DcmTag(SequenceTag).getTagName();
         /* iterate over all sequence items */
         for (unsigned long i = 0; i < sequence.card(); i++)
         {
@@ -845,7 +802,7 @@ OFCondition DSRSOPInstanceReferenceList::read(DcmItem &dataset,
             {
                 /* get the study instance UID */
                 OFString studyUID;
-                if (getAndCheckStringValueFromDataset(*item, DCM_StudyInstanceUID, studyUID, "1", "1", logStream).good())
+                if (getAndCheckStringValueFromDataset(*item, DCM_StudyInstanceUID, studyUID, "1", "1", sequenceName.c_str()).good())
                 {
                     /* check whether study item already exists,
                        because the internal structure is organized in a strictly hierarchical manner  */
@@ -868,7 +825,7 @@ OFCondition DSRSOPInstanceReferenceList::read(DcmItem &dataset,
                         /* set cursor to new position */
                         Iterator = --StudyList.end();
                         /* read attributes on series and instance level */
-                        result = study->read(*item, logStream);
+                        result = study->read(*item);
                     }
                 }
             }
@@ -880,8 +837,7 @@ OFCondition DSRSOPInstanceReferenceList::read(DcmItem &dataset,
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::write(DcmItem &dataset,
-                                               OFConsole *logStream) const
+OFCondition DSRSOPInstanceReferenceList::write(DcmItem &dataset) const
 {
     OFCondition result = EC_Normal;
     /* iterate over all list items */
@@ -898,7 +854,7 @@ OFCondition DSRSOPInstanceReferenceList::write(DcmItem &dataset,
             result = dataset.findOrCreateSequenceItem(SequenceTag, item, -2 /*append new*/);
             /* write study, series and instance level */
             if (result.good())
-                result = study->write(*item, logStream);
+                result = study->write(*item);
         }
         iter++;
     }
@@ -957,7 +913,7 @@ OFCondition DSRSOPInstanceReferenceList::readXML(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRSOPInstanceReferenceList::writeXML(ostream &stream,
+OFCondition DSRSOPInstanceReferenceList::writeXML(STD_NAMESPACE ostream &stream,
                                                   const size_t flags) const
 {
     OFCondition result = EC_Normal;
@@ -989,7 +945,7 @@ DSRSOPInstanceReferenceList::StudyStruct *DSRSOPInstanceReferenceList::gotoStudy
     {
         /* start with the first list item */
         Iterator = StudyList.begin();
-        const OFListConstIterator(StudyStruct *) last = StudyList.end();
+        const OFListIterator(StudyStruct *) last = StudyList.end();
         /* search for given study UID */
         while ((Iterator != last) && ((*Iterator == NULL) || (OFstatic_cast(StudyStruct *, *Iterator)->StudyUID != studyUID)))
             Iterator++;
@@ -1098,7 +1054,7 @@ OFCondition DSRSOPInstanceReferenceList::removeItem(const OFString &studyUID,
 void DSRSOPInstanceReferenceList::removeIncompleteItems()
 {
     Iterator = StudyList.begin();
-    const OFListConstIterator(StudyStruct *) last = StudyList.end();
+    const OFListIterator(StudyStruct *) last = StudyList.end();
     /* for all studies in the list */
     while (Iterator != last)
     {
@@ -1133,7 +1089,7 @@ OFCondition DSRSOPInstanceReferenceList::gotoItem(const OFString &sopClassUID,
         result = SR_EC_SOPInstanceNotFound;
         /* start with first study */
         Iterator = StudyList.begin();
-        const OFListConstIterator(StudyStruct *) last = StudyList.end();
+        const OFListIterator(StudyStruct *) last = StudyList.end();
         /* iterate over all studies */
         while ((Iterator != last) && result.bad())
         {
@@ -1238,7 +1194,8 @@ DSRSOPInstanceReferenceList::StudyStruct *DSRSOPInstanceReferenceList::getCurren
 {
     StudyStruct *study = NULL;
     /* check whether current study is valid */
-    if (Iterator != StudyList.end())
+    OFListConstIterator(StudyStruct *) it = Iterator;
+    if (it != StudyList.end())
         study = OFstatic_cast(StudyStruct *, *Iterator);
     return study;
 }
@@ -1402,22 +1359,38 @@ OFCondition DSRSOPInstanceReferenceList::setStorageMediaFileSetUID(const OFStrin
 }
 
 
-OFBool DSRSOPInstanceReferenceList::containsExtendedCharacters()
-{
-    OFListIterator(StudyStruct *) iter = StudyList.begin();
-    OFListIterator(StudyStruct *) last = StudyList.end();
-    while (iter != last)
-    {
-      if (*iter && OFstatic_cast(StudyStruct *, *iter)->containsExtendedCharacters()) return OFTrue;
-      ++iter;
-    }
-    return OFFalse;
-}
-
-
 /*
  *  CVS/RCS Log:
  *  $Log: dsrsoprf.cc,v $
+ *  Revision 1.19  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.18  2010-09-29 08:32:26  joergr
+ *  Used more specific "moduleName" for getAndCheckElementFromDataset() and
+ *  checkElementValue().
+ *
+ *  Revision 1.17  2009-10-14 10:49:32  joergr
+ *  Fixed minor issues in log output. Also updated copyright date (if required).
+ *
+ *  Revision 1.16  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.15  2009-09-04 13:53:10  meichel
+ *  Minor const iterator related changes needed to compile with VC6 with HAVE_STL
+ *
+ *  Revision 1.14  2008-07-17 12:00:09  joergr
+ *  Replaced call to getSequenceFromDataset() by getElementFromDataset().
+ *
+ *  Revision 1.13  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.12  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.11  2006/05/11 09:16:49  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  *  Revision 1.10  2005/12/15 16:53:48  joergr
  *  Added explicit type cast, required for Sun CC 2.0.1 on Solaris.
  *
