@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRStringValue
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:09 $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.18 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -84,7 +80,7 @@ OFBool DSRStringValue::isValid() const
 }
 
 
-void DSRStringValue::print(ostream &stream,
+void DSRStringValue::print(STD_NAMESPACE ostream &stream,
                            const size_t maxLength) const
 {
     OFString printString;
@@ -96,17 +92,15 @@ void DSRStringValue::print(ostream &stream,
 
 
 OFCondition DSRStringValue::read(DcmItem &dataset,
-                                 const DcmTagKey &tagKey,
-                                 OFConsole *logStream)
+                                 const DcmTagKey &tagKey)
 {
     /* tbd: check value */
-    return DSRTypes::getAndCheckStringValueFromDataset(dataset, tagKey, Value, "1", "1", logStream, "content item");
+    return DSRTypes::getAndCheckStringValueFromDataset(dataset, tagKey, Value, "1", "1", "content item");
 }
 
 
 OFCondition DSRStringValue::write(DcmItem &dataset,
-                                  const DcmTagKey &tagKey,
-                                  OFConsole * /*logStream*/) const
+                                  const DcmTagKey &tagKey) const
 {
     /* write Value */
     return DSRTypes::putStringValueToDataset(dataset, tagKey, Value);
@@ -129,16 +123,27 @@ OFCondition DSRStringValue::readXML(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRStringValue::renderHTML(ostream &docStream,
-                                       const size_t flags,
-                                       OFConsole * /*logStream*/) const
+OFCondition DSRStringValue::renderHTML(STD_NAMESPACE ostream &docStream,
+                                       const size_t flags) const
 {
     OFString htmlString;
     if (!(flags & DSRTypes::HF_renderItemsSeparately))
-        docStream << "<u>";
-    docStream << DSRTypes::convertToMarkupString(Value, htmlString, (flags & DSRTypes::HF_convertNonASCIICharacters) > 0);
+    {
+        if (flags & DSRTypes::HF_XHTML11Compatibility)
+            docStream << "<span class=\"under\">";
+        else if (flags & DSRTypes::HF_HTML32Compatibility)
+            docStream << "<u>";
+        else /* HTML 4.01 */
+            docStream << "<span class=\"under\">";
+    }
+    docStream << DSRTypes::convertToHTMLString(Value, htmlString, flags);
     if (!(flags & DSRTypes::HF_renderItemsSeparately))
-        docStream << "</u>";
+    {
+        if (flags & DSRTypes::HF_HTML32Compatibility)
+            docStream << "</u>";
+        else
+            docStream << "</span>";
+    }
     return EC_Normal;
 }
 
@@ -160,14 +165,28 @@ OFBool DSRStringValue::checkValue(const OFString &stringValue) const
     return !stringValue.empty();
 }
 
-OFBool DSRStringValue::valueContainsExtendedCharacters() const
-{
-  return DSRTypes::stringContainsExtendedCharacters(Value);
-}
 
 /*
  *  CVS/RCS Log:
  *  $Log: dsrstrvl.cc,v $
+ *  Revision 1.18  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.17  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.16  2007-11-15 16:45:26  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *  Enhanced support for output in valid HTML 3.2 format. Migrated support for
+ *  standard HTML from version 4.0 to 4.01 (strict).
+ *
+ *  Revision 1.15  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.14  2006/05/11 09:16:49  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  *  Revision 1.13  2005/12/08 15:48:09  meichel
  *  Changed include path schema for all DCMTK header files
  *
