@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRReferencedDatetimeList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:10 $
- *  CVS/RCS Revision: $Revision: 1.11 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -65,7 +61,7 @@ DSRReferencedDatetimeList &DSRReferencedDatetimeList::operator=(const DSRReferen
 }
 
 
-OFCondition DSRReferencedDatetimeList::print(ostream &stream,
+OFCondition DSRReferencedDatetimeList::print(STD_NAMESPACE ostream &stream,
                                              const size_t flags,
                                              const char separator) const
 {
@@ -90,12 +86,11 @@ OFCondition DSRReferencedDatetimeList::print(ostream &stream,
 }
 
 
-OFCondition DSRReferencedDatetimeList::read(DcmItem &dataset,
-                                            OFConsole *logStream)
+OFCondition DSRReferencedDatetimeList::read(DcmItem &dataset)
 {
     /* get string array from dataset */
-    DcmDateTime delem(DCM_ReferencedDatetime);
-    OFCondition result = DSRTypes::getAndCheckElementFromDataset(dataset, delem, "1-n", "1C", logStream, "TCOORD content item");
+    DcmDateTime delem(DCM_ReferencedDateTime);
+    OFCondition result = DSRTypes::getAndCheckElementFromDataset(dataset, delem, "1-n", "1C", "TCOORD content item");
     if (result.good())
     {
         /* clear internal list */
@@ -113,8 +108,7 @@ OFCondition DSRReferencedDatetimeList::read(DcmItem &dataset,
 }
 
 
-OFCondition DSRReferencedDatetimeList::write(DcmItem &dataset,
-                                             OFConsole * /*logStream*/) const
+OFCondition DSRReferencedDatetimeList::write(DcmItem &dataset) const
 {
     OFCondition result = EC_Normal;
     /* fill string with values from list */
@@ -129,11 +123,11 @@ OFCondition DSRReferencedDatetimeList::write(DcmItem &dataset,
         iterator++;
     }
     /* set decimal string */
-    DcmDateTime delem(DCM_ReferencedDatetime);
+    DcmDateTime delem(DCM_ReferencedDateTime);
     result = delem.putOFStringArray(tmpString);
     /* add to dataset */
     if (result.good())
-        result = DSRTypes::addElementToDataset(result, dataset, new DcmDateTime(delem));
+        result = DSRTypes::addElementToDataset(result, dataset, new DcmDateTime(delem), "1-n", "1", "TCOORD content item");
     return result;
 }
 
@@ -171,6 +165,25 @@ OFCondition DSRReferencedDatetimeList::putString(const char *stringValue)
 /*
  *  CVS/RCS Log:
  *  $Log: dsrtcodt.cc,v $
+ *  Revision 1.17  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.16  2010-09-29 15:16:51  joergr
+ *  Enhanced checking and reporting of standard violations in write() methods.
+ *
+ *  Revision 1.15  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.14  2008-04-30 12:38:43  meichel
+ *  Fixed compile errors due to changes in attribute tag names
+ *
+ *  Revision 1.13  2007/11/15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.12  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.11  2005/12/08 15:48:10  meichel
  *  Changed include path schema for all DCMTK header files
  *
