@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRReferencedSamplePositionList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:11 $
- *  CVS/RCS Revision: $Revision: 1.12 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -68,7 +64,7 @@ DSRReferencedSamplePositionList &DSRReferencedSamplePositionList::operator=(cons
 }
 
 
-OFCondition DSRReferencedSamplePositionList::print(ostream &stream,
+OFCondition DSRReferencedSamplePositionList::print(STD_NAMESPACE ostream &stream,
                                                    const size_t flags,
                                                    const char separator) const
 {
@@ -93,12 +89,11 @@ OFCondition DSRReferencedSamplePositionList::print(ostream &stream,
 }
 
 
-OFCondition DSRReferencedSamplePositionList::read(DcmItem &dataset,
-                                                  OFConsole *logStream)
+OFCondition DSRReferencedSamplePositionList::read(DcmItem &dataset)
 {
     /* get element from dataset */
     DcmUnsignedLong delem(DCM_ReferencedSamplePositions);
-    OFCondition result = DSRTypes::getAndCheckElementFromDataset(dataset, delem, "1-n", "1C", logStream, "TCOORD content item");
+    OFCondition result = DSRTypes::getAndCheckElementFromDataset(dataset, delem, "1-n", "1C", "TCOORD content item");
     if (result.good())
     {
         /* clear internal list */
@@ -116,8 +111,7 @@ OFCondition DSRReferencedSamplePositionList::read(DcmItem &dataset,
 }
 
 
-OFCondition DSRReferencedSamplePositionList::write(DcmItem &dataset,
-                                                   OFConsole * /*logStream*/) const
+OFCondition DSRReferencedSamplePositionList::write(DcmItem &dataset) const
 {
     OFCondition result = EC_Normal;
     unsigned long i = 0;
@@ -133,7 +127,7 @@ OFCondition DSRReferencedSamplePositionList::write(DcmItem &dataset,
     }
     /* add to dataset */
     if (result.good())
-        result = DSRTypes::addElementToDataset(result, dataset, new DcmUnsignedLong(delem));
+        result = DSRTypes::addElementToDataset(result, dataset, new DcmUnsignedLong(delem), "1-n", "1", "TCOORD content item");
     return result;
 }
 
@@ -173,6 +167,22 @@ OFCondition DSRReferencedSamplePositionList::putString(const char *stringValue)
 /*
  *  CVS/RCS Log:
  *  $Log: dsrtcosp.cc,v $
+ *  Revision 1.17  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.16  2010-09-29 15:16:51  joergr
+ *  Enhanced checking and reporting of standard violations in write() methods.
+ *
+ *  Revision 1.15  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.14  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.13  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.12  2005/12/08 15:48:11  meichel
  *  Changed include path schema for all DCMTK header files
  *
