@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRTCoordTreeNode
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:12 $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -70,7 +66,7 @@ OFBool DSRTCoordTreeNode::isShort(const size_t flags) const
 }
 
 
-OFCondition DSRTCoordTreeNode::print(ostream &stream,
+OFCondition DSRTCoordTreeNode::print(STD_NAMESPACE ostream &stream,
                                      const size_t flags) const
 {
     OFCondition result = DSRDocumentTreeNode::print(stream, flags);
@@ -83,34 +79,31 @@ OFCondition DSRTCoordTreeNode::print(ostream &stream,
 }
 
 
-OFCondition DSRTCoordTreeNode::writeXML(ostream &stream,
-                                        const size_t flags,
-                                        OFConsole *logStream) const
+OFCondition DSRTCoordTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                        const size_t flags) const
 {
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags, OFFalse /*closingBracket*/);
     stream << " type=\"" << temporalRangeTypeToEnumeratedValue(getTemporalRangeType()) << "\"";
-    stream << ">" << endl;
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
-    DSRTemporalCoordinatesValue::writeXML(stream, flags, logStream);
+    stream << ">" << OFendl;
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
+    DSRTemporalCoordinatesValue::writeXML(stream, flags);
     writeXMLItemEnd(stream, flags);
     return result;
 }
 
 
-OFCondition DSRTCoordTreeNode::readContentItem(DcmItem &dataset,
-                                               OFConsole *logStream)
+OFCondition DSRTCoordTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read TemporalCoordinates */
-    return DSRTemporalCoordinatesValue::read(dataset, logStream);
+    return DSRTemporalCoordinatesValue::read(dataset);
 }
 
 
-OFCondition DSRTCoordTreeNode::writeContentItem(DcmItem &dataset,
-                                                OFConsole *logStream) const
+OFCondition DSRTCoordTreeNode::writeContentItem(DcmItem &dataset) const
 {
     /* write TemporalCoordinates */
-    return DSRTemporalCoordinatesValue::write(dataset, logStream);
+    return DSRTemporalCoordinatesValue::write(dataset);
 }
 
 
@@ -128,26 +121,25 @@ OFCondition DSRTCoordTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
             /* proceed reading the temporal coordinates */
             result = DSRTemporalCoordinatesValue::readXML(doc, cursor);
         } else
-            printUnknownValueWarningMessage(doc.getLogStream(), "TCOORD type", tmpString.c_str());
+            printUnknownValueWarningMessage("TCOORD type", tmpString.c_str());
     }
     return result;
 }
 
 
-OFCondition DSRTCoordTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                     ostream &annexStream,
+OFCondition DSRTCoordTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                     STD_NAMESPACE ostream &annexStream,
                                                      const size_t /*nestingLevel*/,
                                                      size_t &annexNumber,
-                                                     const size_t flags,
-                                                     OFConsole *logStream) const
+                                                     const size_t flags) const
 {
     /* render ConceptName */
-    OFCondition result = renderHTMLConceptName(docStream, flags, logStream);
+    OFCondition result = renderHTMLConceptName(docStream, flags);
     /* render TemporalCoordinates */
     if (result.good())
     {
-        result = DSRTemporalCoordinatesValue::renderHTML(docStream, annexStream, annexNumber, flags, logStream);
-        docStream << endl;
+        result = DSRTemporalCoordinatesValue::renderHTML(docStream, annexStream, annexNumber, flags);
+        docStream << OFendl;
     }
     return result;
 }
@@ -156,6 +148,19 @@ OFCondition DSRTCoordTreeNode::renderHTMLContentItem(ostream &docStream,
 /*
  *  CVS/RCS Log:
  *  $Log: dsrtcotn.cc,v $
+ *  Revision 1.17  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.16  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.15  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.14  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.13  2005/12/08 15:48:12  meichel
  *  Changed include path schema for all DCMTK header files
  *
