@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRTemporalCoordinatesValue
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:14 $
- *  CVS/RCS Revision: $Revision: 1.12 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -102,7 +98,7 @@ OFBool DSRTemporalCoordinatesValue::isShort(const size_t flags) const
 }
 
 
-OFCondition DSRTemporalCoordinatesValue::print(ostream &stream,
+OFCondition DSRTemporalCoordinatesValue::print(STD_NAMESPACE ostream &stream,
                                                const size_t flags) const
 {
     /* TemporalRangeType */
@@ -149,7 +145,7 @@ OFCondition DSRTemporalCoordinatesValue::readXML(const DSRXMLDocument &doc,
                 /* put value to the datetime list (tbd: convert from ISO 8601 format?) */
                 result = DatetimeList.putString(doc.getStringFromNodeContent(cursor, tmpString).c_str());
             } else {
-                DSRTypes::printUnknownValueWarningMessage(doc.getLogStream(), "TCOORD data type", typeString.c_str());
+                DSRTypes::printUnknownValueWarningMessage("TCOORD data type", typeString.c_str());
                 result = SR_EC_InvalidValue;
             }
         }
@@ -158,9 +154,8 @@ OFCondition DSRTemporalCoordinatesValue::readXML(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRTemporalCoordinatesValue::writeXML(ostream &stream,
-                                                  const size_t flags,
-                                                  OFConsole * /*logStream*/) const
+OFCondition DSRTemporalCoordinatesValue::writeXML(STD_NAMESPACE ostream &stream,
+                                                  const size_t flags) const
 {
     /* TemporalRangeType is written in TreeNode class */
     if ((flags & DSRTypes::XF_writeEmptyTags) || !SamplePositionList.isEmpty() ||
@@ -182,38 +177,36 @@ OFCondition DSRTemporalCoordinatesValue::writeXML(ostream &stream,
             stream << "DATETIME\">";
             DatetimeList.print(stream);
         }
-        stream << "</data>" << endl;
+        stream << "</data>" << OFendl;
     }
     return EC_Normal;
 }
 
 
-OFCondition DSRTemporalCoordinatesValue::read(DcmItem &dataset,
-                                              OFConsole *logStream)
+OFCondition DSRTemporalCoordinatesValue::read(DcmItem &dataset)
 {
     /* read TemporalRangeType */
     OFString tmpString;
-    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_TemporalRangeType, tmpString, "1", "1", logStream, "TCOORD content item");
+    OFCondition result = DSRTypes::getAndCheckStringValueFromDataset(dataset, DCM_TemporalRangeType, tmpString, "1", "1", "TCOORD content item");
     if (result.good())
     {
         TemporalRangeType = DSRTypes::enumeratedValueToTemporalRangeType(tmpString);
         /* check TemporalRangeType */
         if (TemporalRangeType == DSRTypes::TRT_invalid)
-            DSRTypes::printUnknownValueWarningMessage(logStream, "TemporalRangeType", tmpString.c_str());
+            DSRTypes::printUnknownValueWarningMessage("TemporalRangeType", tmpString.c_str());
         /* first read data (all three lists) */
-        SamplePositionList.read(dataset, logStream);
-        TimeOffsetList.read(dataset, logStream);
-        DatetimeList.read(dataset, logStream);
+        SamplePositionList.read(dataset);
+        TimeOffsetList.read(dataset);
+        DatetimeList.read(dataset);
         /* then check data and report warnings if any */
-        if (!checkData(TemporalRangeType, SamplePositionList, TimeOffsetList, DatetimeList, logStream))
+        if (!checkData(TemporalRangeType, SamplePositionList, TimeOffsetList, DatetimeList))
             result = SR_EC_InvalidValue;
     }
     return result;
 }
 
 
-OFCondition DSRTemporalCoordinatesValue::write(DcmItem &dataset,
-                                               OFConsole *logStream) const
+OFCondition DSRTemporalCoordinatesValue::write(DcmItem &dataset) const
 {
     /* write TemporalRangeType */
     OFCondition result = DSRTypes::putStringValueToDataset(dataset, DCM_TemporalRangeType, DSRTypes::temporalRangeTypeToEnumeratedValue(TemporalRangeType));
@@ -221,65 +214,66 @@ OFCondition DSRTemporalCoordinatesValue::write(DcmItem &dataset,
     {
         /* write data (only one list) */
         if (!SamplePositionList.isEmpty())
-            SamplePositionList.write(dataset, logStream);
+            SamplePositionList.write(dataset);
         else if (!TimeOffsetList.isEmpty())
-            TimeOffsetList.write(dataset, logStream);
+            TimeOffsetList.write(dataset);
         else
-            DatetimeList.write(dataset, logStream);
+            DatetimeList.write(dataset);
     }
     /* check data and report warnings if any */
-    checkData(TemporalRangeType, SamplePositionList, TimeOffsetList, DatetimeList, logStream);
+    checkData(TemporalRangeType, SamplePositionList, TimeOffsetList, DatetimeList);
     return result;
 }
 
 
-OFCondition DSRTemporalCoordinatesValue::renderHTML(ostream &docStream,
-                                                    ostream &annexStream,
+OFCondition DSRTemporalCoordinatesValue::renderHTML(STD_NAMESPACE ostream &docStream,
+                                                    STD_NAMESPACE ostream &annexStream,
                                                     size_t &annexNumber,
-                                                    const size_t flags,
-                                                    OFConsole * /*logStream*/) const
+                                                    const size_t flags) const
 {
     /* render TemporalRangeType */
     docStream << DSRTypes::temporalRangeTypeToReadableName(TemporalRangeType);
     /* render data */
     if (!isShort(flags))
     {
+        const char *lineBreak = (flags & DSRTypes::HF_renderSectionTitlesInline) ? " " :
+                                (flags & DSRTypes::HF_XHTML11Compatibility) ? "<br />" : "<br>";
         if (flags & DSRTypes::HF_currentlyInsideAnnex)
         {
-            docStream << endl << "<p>" << endl;
+            docStream << OFendl << "<p>" << OFendl;
             /* render data list (= print)*/
             if (!SamplePositionList.isEmpty())
             {
-                docStream << "<b>Reference Sample Positions:</b><br>";
+                docStream << "<b>Reference Sample Positions:</b>" << lineBreak;
                 SamplePositionList.print(docStream);
             }
             else if (!TimeOffsetList.isEmpty())
             {
-                docStream << "<b>Referenced Time Offsets:</b><br>";
+                docStream << "<b>Referenced Time Offsets:</b>" << lineBreak;
                 TimeOffsetList.print(docStream);
             } else {
-                docStream << "<b>Referenced Datetime:</b><br>";
+                docStream << "<b>Referenced Datetime:</b>" << lineBreak;
                 DatetimeList.print(docStream);
             }
             docStream << "</p>";
         } else {
-            DSRTypes::createHTMLAnnexEntry(docStream, annexStream, "for more details see", annexNumber);
-            annexStream << "<p>" << endl;
+            DSRTypes::createHTMLAnnexEntry(docStream, annexStream, "for more details see", annexNumber, flags);
+            annexStream << "<p>" << OFendl;
             /* render data list (= print)*/
             if (!SamplePositionList.isEmpty())
             {
-                annexStream << "<b>Reference Sample Positions:</b><br>";
+                annexStream << "<b>Reference Sample Positions:</b>" << lineBreak;
                 SamplePositionList.print(annexStream);
             }
             else if (!TimeOffsetList.isEmpty())
             {
-                annexStream << "<b>Referenced Time Offsets:</b><br>";
+                annexStream << "<b>Referenced Time Offsets:</b>" << lineBreak;
                 TimeOffsetList.print(annexStream);
             } else {
-                annexStream << "<b>Referenced Datetime:</b><br>";
+                annexStream << "<b>Referenced Datetime:</b>" << lineBreak;
                 DatetimeList.print(annexStream);
             }
-            annexStream << "</p>" << endl;
+            annexStream << "</p>" << OFendl;
         }
     }
     return EC_Normal;
@@ -324,26 +318,25 @@ OFCondition DSRTemporalCoordinatesValue::setTemporalRangeType(const DSRTypes::E_
 OFBool DSRTemporalCoordinatesValue::checkData(const DSRTypes::E_TemporalRangeType temporalRangeType,
                                               const DSRReferencedSamplePositionList &samplePositionList,
                                               const DSRReferencedTimeOffsetList &timeOffsetList,
-                                              const DSRReferencedDatetimeList &datetimeList,
-                                              OFConsole *logStream) const
+                                              const DSRReferencedDatetimeList &datetimeList) const
 {
     OFBool result = OFTrue;
     if (temporalRangeType == DSRTypes::TRT_invalid)
-        DSRTypes::printWarningMessage(logStream, "Invalid TemporalRangeType for TCOORD content item");
+        DCMSR_WARN("Invalid TemporalRangeType for TCOORD content item");
     const OFBool list1 = !samplePositionList.isEmpty();
     const OFBool list2 = !timeOffsetList.isEmpty();
     const OFBool list3 = !datetimeList.isEmpty();
     if (list1 && list2 && list3)
-        DSRTypes::printWarningMessage(logStream, "ReferencedSamplePositions/TimeOffsets/Datetime present in TCOORD content item");
+        DCMSR_WARN("ReferencedSamplePositions/TimeOffsets/Datetime present in TCOORD content item");
     else if (list1 && list2)
-        DSRTypes::printWarningMessage(logStream, "ReferencedSamplePositions/TimeOffsets present in TCOORD content item");
+        DCMSR_WARN("ReferencedSamplePositions/TimeOffsets present in TCOORD content item");
     else if (list1 && list3)
-        DSRTypes::printWarningMessage(logStream, "ReferencedSamplePositions/Datetime present in TCOORD content item");
+        DCMSR_WARN("ReferencedSamplePositions/Datetime present in TCOORD content item");
     else if (list2 && list3)
-        DSRTypes::printWarningMessage(logStream, "ReferencedTimeOffsets/Datetime present in TCOORD content item");
+        DCMSR_WARN("ReferencedTimeOffsets/Datetime present in TCOORD content item");
     else if (!list1 && !list2 && !list3)
     {
-        DSRTypes::printWarningMessage(logStream, "ReferencedSamplePositions/TimeOffsets/Datetime empty in TCOORD content item");
+        DCMSR_WARN("ReferencedSamplePositions/TimeOffsets/Datetime empty in TCOORD content item");
         /* invalid: all lists are empty (type 1C) */
         result= OFFalse;
     }
@@ -354,6 +347,24 @@ OFBool DSRTemporalCoordinatesValue::checkData(const DSRTypes::E_TemporalRangeTyp
 /*
  *  CVS/RCS Log:
  *  $Log: dsrtcovl.cc,v $
+ *  Revision 1.17  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.16  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.15  2007-11-15 16:45:42  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *
+ *  Revision 1.14  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.13  2006/07/25 13:37:48  joergr
+ *  Added new optional flags for the HTML rendering of SR documents:
+ *  HF_alwaysExpandChildrenInline, HF_useCodeDetailsTooltip and
+ *  HF_renderSectionTitlesInline.
+ *
  *  Revision 1.12  2005/12/08 15:48:14  meichel
  *  Changed include path schema for all DCMTK header files
  *
