@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRTextTreeNode
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:15 $
- *  CVS/RCS Revision: $Revision: 1.22 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.27 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -80,7 +76,7 @@ OFBool DSRTextTreeNode::isShort(const size_t /*flags*/) const
 }
 
 
-OFCondition DSRTextTreeNode::print(ostream &stream,
+OFCondition DSRTextTreeNode::print(STD_NAMESPACE ostream &stream,
                                    const size_t flags) const
 {
     OFCondition result = DSRDocumentTreeNode::print(stream, flags);
@@ -96,32 +92,29 @@ OFCondition DSRTextTreeNode::print(ostream &stream,
 }
 
 
-OFCondition DSRTextTreeNode::writeXML(ostream &stream,
-                                      const size_t flags,
-                                      OFConsole *logStream) const
+OFCondition DSRTextTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                      const size_t flags) const
 {
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags);
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
     writeStringValueToXML(stream, getValue(), "value", (flags & XF_writeEmptyTags) > 0);
     writeXMLItemEnd(stream, flags);
     return result;
 }
 
 
-OFCondition DSRTextTreeNode::readContentItem(DcmItem &dataset,
-                                             OFConsole *logStream)
+OFCondition DSRTextTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read TextValue */
-    return DSRStringValue::read(dataset, DCM_TextValue, logStream);
+    return DSRStringValue::read(dataset, DCM_TextValue);
 }
 
 
-OFCondition DSRTextTreeNode::writeContentItem(DcmItem &dataset,
-                                              OFConsole *logStream) const
+OFCondition DSRTextTreeNode::writeContentItem(DcmItem &dataset) const
 {
     /* write TextValue */
-    return DSRStringValue::write(dataset, DCM_TextValue, logStream);
+    return DSRStringValue::write(dataset, DCM_TextValue);
 }
 
 
@@ -133,34 +126,43 @@ OFCondition DSRTextTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRTextTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                   ostream & /*annexStream*/,
+OFCondition DSRTextTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                   STD_NAMESPACE ostream & /*annexStream*/,
                                                    const size_t /*nestingLevel*/,
                                                    size_t & /*annexNumber*/,
-                                                   const size_t flags,
-                                                   OFConsole *logStream) const
+                                                   const size_t flags) const
 {
     OFString htmlString;
     /* render ConceptName */
-    OFCondition result = renderHTMLConceptName(docStream, flags, logStream);
+    OFCondition result = renderHTMLConceptName(docStream, flags);
     /* render TextValue */
     if (flags & HF_renderItemInline)
-        docStream << "\"" << convertToMarkupString(getValue(), htmlString, (flags & HF_convertNonASCIICharacters) > 0) << "\"" << endl;
+        docStream << "\"" << convertToHTMLString(getValue(), htmlString, flags) << "\"" << OFendl;
     else
-        docStream << convertToMarkupString(getValue(), htmlString, (flags & HF_convertNonASCIICharacters) > 0, OFTrue /*newlineAllowed*/) << endl;
+        docStream << convertToHTMLString(getValue(), htmlString, flags, OFTrue /*newlineAllowed*/) << OFendl;
     return result;
 }
 
 
-OFBool DSRTextTreeNode::containsExtendedCharacters() const
-{
-  return DSRDocumentTreeNode::containsExtendedCharacters() || valueContainsExtendedCharacters();
-}
-
-
 /*
  *  CVS/RCS Log:
  *  $Log: dsrtextn.cc,v $
+ *  Revision 1.27  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.26  2009-10-13 14:57:51  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.25  2007-11-15 16:45:42  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *
+ *  Revision 1.24  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.23  2006/05/11 09:16:49  joergr
+ *  Moved containsExtendedCharacters() from dcmsr to dcmdata module.
+ *
  *  Revision 1.22  2005/12/08 15:48:15  meichel
  *  Changed include path schema for all DCMTK header files
  *
