@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRUIDRefTreeNode
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:20 $
- *  CVS/RCS Revision: $Revision: 1.18 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.22 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -73,7 +69,7 @@ OFBool DSRUIDRefTreeNode::isValid() const
 }
 
 
-OFCondition DSRUIDRefTreeNode::print(ostream &stream,
+OFCondition DSRUIDRefTreeNode::print(STD_NAMESPACE ostream &stream,
                                      const size_t flags) const
 {
     OFCondition result = DSRDocumentTreeNode::print(stream, flags);
@@ -86,32 +82,29 @@ OFCondition DSRUIDRefTreeNode::print(ostream &stream,
 }
 
 
-OFCondition DSRUIDRefTreeNode::writeXML(ostream &stream,
-                                        const size_t flags,
-                                        OFConsole *logStream) const
+OFCondition DSRUIDRefTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                        const size_t flags) const
 {
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags);
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
     writeStringValueToXML(stream, getValue(), "value", (flags & XF_writeEmptyTags) > 0);
     writeXMLItemEnd(stream, flags);
     return result;
 }
 
 
-OFCondition DSRUIDRefTreeNode::readContentItem(DcmItem &dataset,
-                                               OFConsole *logStream)
+OFCondition DSRUIDRefTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read UID */
-    return DSRStringValue::read(dataset, DCM_UID, logStream);
+    return DSRStringValue::read(dataset, DCM_UID);
 }
 
 
-OFCondition DSRUIDRefTreeNode::writeContentItem(DcmItem &dataset,
-                                                OFConsole *logStream) const
+OFCondition DSRUIDRefTreeNode::writeContentItem(DcmItem &dataset) const
 {
     /* write UID */
-    return DSRStringValue::write(dataset, DCM_UID, logStream);
+    return DSRStringValue::write(dataset, DCM_UID);
 }
 
 
@@ -123,20 +116,19 @@ OFCondition DSRUIDRefTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRUIDRefTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                     ostream & /*annexStream*/,
+OFCondition DSRUIDRefTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                     STD_NAMESPACE ostream & /*annexStream*/,
                                                      const size_t /*nestingLevel*/,
                                                      size_t & /*annexNumber*/,
-                                                     const size_t flags,
-                                                     OFConsole *logStream) const
+                                                     const size_t flags) const
 {
     /* render ConceptName */
-    OFCondition result = renderHTMLConceptName(docStream, flags, logStream);
+    OFCondition result = renderHTMLConceptName(docStream, flags);
     /* render UID */
     if (result.good())
     {
-        result = DSRStringValue::renderHTML(docStream, flags, logStream);
-        docStream << endl;
+        result = DSRStringValue::renderHTML(docStream, flags);
+        docStream << OFendl;
     }
     return result;
 }
@@ -145,6 +137,19 @@ OFCondition DSRUIDRefTreeNode::renderHTMLContentItem(ostream &docStream,
 /*
  *  CVS/RCS Log:
  *  $Log: dsruidtn.cc,v $
+ *  Revision 1.22  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.21  2009-10-13 14:57:52  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.20  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.19  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.18  2005/12/08 15:48:20  meichel
  *  Changed include path schema for all DCMTK header files
  *
