@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRWaveformChannelList
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:21 $
- *  CVS/RCS Revision: $Revision: 1.21 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.26 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -74,7 +70,7 @@ DSRWaveformChannelList &DSRWaveformChannelList::operator=(const DSRWaveformChann
 }
 
 
-OFCondition DSRWaveformChannelList::print(ostream &stream,
+OFCondition DSRWaveformChannelList::print(STD_NAMESPACE ostream &stream,
                                           const size_t flags,
                                           const char pairSeparator,
                                           const char itemSeparator) const
@@ -99,12 +95,11 @@ OFCondition DSRWaveformChannelList::print(ostream &stream,
 }
 
 
-OFCondition DSRWaveformChannelList::read(DcmItem &dataset,
-                                         OFConsole *logStream)
+OFCondition DSRWaveformChannelList::read(DcmItem &dataset)
 {
     /* get integer string from dataset */
     DcmUnsignedShort delem(DCM_ReferencedWaveformChannels);
-    OFCondition result = DSRTypes::getAndCheckElementFromDataset(dataset, delem, "2-2n", "1C", logStream, "WAVEFORM content item");
+    OFCondition result = DSRTypes::getAndCheckElementFromDataset(dataset, delem, "2-2n", "1C", "WAVEFORM content item");
     if (result.good())
     {
         /* clear internal list */
@@ -129,8 +124,7 @@ OFCondition DSRWaveformChannelList::read(DcmItem &dataset,
 }
 
 
-OFCondition DSRWaveformChannelList::write(DcmItem &dataset,
-                                          OFConsole * /*logStream*/) const
+OFCondition DSRWaveformChannelList::write(DcmItem &dataset) const
 {
     OFCondition result = EC_Normal;
     /* fill string with values from list */
@@ -147,7 +141,7 @@ OFCondition DSRWaveformChannelList::write(DcmItem &dataset,
     }
     /* add to dataset */
     if (result.good())
-        result = DSRTypes::addElementToDataset(result, dataset, new DcmUnsignedShort(delem));
+        result = DSRTypes::addElementToDataset(result, dataset, new DcmUnsignedShort(delem), "2-2n", "1", "WAVEFORM content item");
     return result;
 }
 
@@ -210,6 +204,22 @@ OFCondition DSRWaveformChannelList::putString(const char *stringValue)
 /*
  *  CVS/RCS Log:
  *  $Log: dsrwavch.cc,v $
+ *  Revision 1.26  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.25  2010-09-29 15:16:51  joergr
+ *  Enhanced checking and reporting of standard violations in write() methods.
+ *
+ *  Revision 1.24  2009-10-13 14:57:52  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.23  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.22  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.21  2005/12/08 15:48:21  meichel
  *  Changed include path schema for all DCMTK header files
  *
