@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRWaveformTreeNode
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:22 $
- *  CVS/RCS Revision: $Revision: 1.17 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.21 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -70,7 +66,7 @@ OFBool DSRWaveformTreeNode::isShort(const size_t flags) const
 }
 
 
-OFCondition DSRWaveformTreeNode::print(ostream &stream,
+OFCondition DSRWaveformTreeNode::print(STD_NAMESPACE ostream &stream,
                                        const size_t flags) const
 {
     OFCondition result = DSRDocumentTreeNode::print(stream, flags);
@@ -83,34 +79,31 @@ OFCondition DSRWaveformTreeNode::print(ostream &stream,
 }
 
 
-OFCondition DSRWaveformTreeNode::writeXML(ostream &stream,
-                                          const size_t flags,
-                                          OFConsole *logStream) const
+OFCondition DSRWaveformTreeNode::writeXML(STD_NAMESPACE ostream &stream,
+                                          const size_t flags) const
 {
     OFCondition result = EC_Normal;
     writeXMLItemStart(stream, flags);
-    result = DSRDocumentTreeNode::writeXML(stream, flags, logStream);
-    stream << "<value>" << endl;
-    DSRWaveformReferenceValue::writeXML(stream, flags, logStream);
-    stream << "</value>" << endl;
+    result = DSRDocumentTreeNode::writeXML(stream, flags);
+    stream << "<value>" << OFendl;
+    DSRWaveformReferenceValue::writeXML(stream, flags);
+    stream << "</value>" << OFendl;
     writeXMLItemEnd(stream, flags);
     return result;
 }
 
 
-OFCondition DSRWaveformTreeNode::readContentItem(DcmItem &dataset,
-                                                 OFConsole *logStream)
+OFCondition DSRWaveformTreeNode::readContentItem(DcmItem &dataset)
 {
     /* read ReferencedSOPSequence */
-    return DSRWaveformReferenceValue::readSequence(dataset, "1" /*type*/, logStream);
+    return DSRWaveformReferenceValue::readSequence(dataset, "1" /*type*/);
 }
 
 
-OFCondition DSRWaveformTreeNode::writeContentItem(DcmItem &dataset,
-                                                  OFConsole *logStream) const
+OFCondition DSRWaveformTreeNode::writeContentItem(DcmItem &dataset) const
 {
     /* write ReferencedSOPSequence */
-    return DSRWaveformReferenceValue::writeSequence(dataset, logStream);
+    return DSRWaveformReferenceValue::writeSequence(dataset);
 }
 
 
@@ -122,20 +115,19 @@ OFCondition DSRWaveformTreeNode::readXMLContentItem(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRWaveformTreeNode::renderHTMLContentItem(ostream &docStream,
-                                                       ostream &annexStream,
+OFCondition DSRWaveformTreeNode::renderHTMLContentItem(STD_NAMESPACE ostream &docStream,
+                                                       STD_NAMESPACE ostream &annexStream,
                                                        const size_t /*nestingLevel*/,
                                                        size_t &annexNumber,
-                                                       const size_t flags,
-                                                       OFConsole *logStream) const
+                                                       const size_t flags) const
 {
     /* render ConceptName */
-    OFCondition result = renderHTMLConceptName(docStream, flags, logStream);
+    OFCondition result = renderHTMLConceptName(docStream, flags);
     /* render Reference */
     if (result.good())
     {
-        result = DSRWaveformReferenceValue::renderHTML(docStream, annexStream, annexNumber, flags, logStream);
-        docStream << endl;
+        result = DSRWaveformReferenceValue::renderHTML(docStream, annexStream, annexNumber, flags);
+        docStream << OFendl;
     }
     return result;
 }
@@ -144,6 +136,19 @@ OFCondition DSRWaveformTreeNode::renderHTMLContentItem(ostream &docStream,
 /*
  *  CVS/RCS Log:
  *  $Log: dsrwavtn.cc,v $
+ *  Revision 1.21  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.20  2009-10-13 14:57:52  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.19  2007-11-15 16:43:43  joergr
+ *  Fixed coding style to be more consistent.
+ *
+ *  Revision 1.18  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.17  2005/12/08 15:48:22  meichel
  *  Changed include path schema for all DCMTK header files
  *
