@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRWaveformReferenceValue
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:23 $
- *  CVS/RCS Revision: $Revision: 1.16 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:42 $
+ *  CVS/RCS Revision: $Revision: 1.21 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -90,7 +86,7 @@ OFBool DSRWaveformReferenceValue::isShort(const size_t flags) const
 }
 
 
-OFCondition DSRWaveformReferenceValue::print(ostream &stream,
+OFCondition DSRWaveformReferenceValue::print(STD_NAMESPACE ostream &stream,
                                              const size_t flags) const
 {
     const char *className = dcmFindNameOfUID(SOPClassUID.c_str());
@@ -133,60 +129,56 @@ OFCondition DSRWaveformReferenceValue::readXML(const DSRXMLDocument &doc,
 }
 
 
-OFCondition DSRWaveformReferenceValue::writeXML(ostream &stream,
-                                                const size_t flags,
-                                                OFConsole *logStream) const
+OFCondition DSRWaveformReferenceValue::writeXML(STD_NAMESPACE ostream &stream,
+                                                const size_t flags) const
 {
-    OFCondition result = DSRCompositeReferenceValue::writeXML(stream, flags, logStream);
+    OFCondition result = DSRCompositeReferenceValue::writeXML(stream, flags);
     if ((flags & DSRTypes::XF_writeEmptyTags) || !ChannelList.isEmpty())
     {
         stream << "<channels>";
         ChannelList.print(stream);
-        stream << "</channels>" << endl;
+        stream << "</channels>" << OFendl;
     }
     return result;
 }
 
 
-OFCondition DSRWaveformReferenceValue::readItem(DcmItem &dataset,
-                                                OFConsole *logStream)
+OFCondition DSRWaveformReferenceValue::readItem(DcmItem &dataset)
 {
     /* read ReferencedSOPClassUID and ReferencedSOPInstanceUID */
-    OFCondition result = DSRCompositeReferenceValue::readItem(dataset, logStream);
+    OFCondition result = DSRCompositeReferenceValue::readItem(dataset);
     /* read ReferencedWaveformChannels (conditional) */
     if (result.good())
-        ChannelList.read(dataset, logStream);
+        ChannelList.read(dataset);
     return result;
 }
 
 
-OFCondition DSRWaveformReferenceValue::writeItem(DcmItem &dataset,
-                                                 OFConsole *logStream) const
+OFCondition DSRWaveformReferenceValue::writeItem(DcmItem &dataset) const
 {
     /* write ReferencedSOPClassUID and ReferencedSOPInstanceUID */
-    OFCondition result = DSRCompositeReferenceValue::writeItem(dataset, logStream);
+    OFCondition result = DSRCompositeReferenceValue::writeItem(dataset);
     /* write ReferencedWaveformChannels (conditional) */
     if (result.good())
     {
         if (!ChannelList.isEmpty())
-            result = ChannelList.write(dataset, logStream);
+            result = ChannelList.write(dataset);
     }
     return result;
 }
 
 
-OFCondition DSRWaveformReferenceValue::renderHTML(ostream &docStream,
-                                                  ostream &annexStream,
+OFCondition DSRWaveformReferenceValue::renderHTML(STD_NAMESPACE ostream &docStream,
+                                                  STD_NAMESPACE ostream &annexStream,
                                                   size_t &annexNumber,
-                                                  const size_t flags,
-                                                  OFConsole * /*logStream*/) const
+                                                  const size_t flags) const
 {
     /* render reference */
     docStream << "<a href=\"" << HTML_HYPERLINK_PREFIX_FOR_CGI;
     docStream << "?waveform=" << SOPClassUID << "+" << SOPInstanceUID;
     if (!ChannelList.isEmpty())
     {
-        docStream << "&channels=";
+        docStream << "&amp;channels=";
         ChannelList.print(docStream, 0 /*flags*/, '+', '+');
     }
     docStream << "\">";
@@ -199,20 +191,23 @@ OFCondition DSRWaveformReferenceValue::renderHTML(ostream &docStream,
     /* render (optional) channel list */
     if (!isShort(flags))
     {
+        const char *lineBreak = (flags & DSRTypes::HF_renderSectionTitlesInline) ? " " :
+                                (flags & DSRTypes::HF_XHTML11Compatibility) ? "<br />" : "<br>";
         if (flags & DSRTypes::HF_currentlyInsideAnnex)
         {
-            docStream  << endl << "<p>" << endl;
+            docStream  << OFendl << "<p>" << OFendl;
             /* render channel list (= print)*/
-            docStream << "<b>Referenced Waveform Channels:</b><br>";
+            docStream << "<b>Referenced Waveform Channels:</b>" << lineBreak;
             ChannelList.print(docStream);
             docStream << "</p>";
         } else {
-            DSRTypes::createHTMLAnnexEntry(docStream, annexStream, "for more details see", annexNumber);
-            annexStream << "<p>" << endl;
+            docStream << " ";
+            DSRTypes::createHTMLAnnexEntry(docStream, annexStream, "for more details see", annexNumber, flags);
+            annexStream << "<p>" << OFendl;
             /* render channel list (= print)*/
-            annexStream << "<b>Referenced Waveform Channels:</b><br>";
+            annexStream << "<b>Referenced Waveform Channels:</b>" << lineBreak;
             ChannelList.print(annexStream);
-            annexStream << "</p>" << endl;
+            annexStream << "</p>" << OFendl;
         }
     }
     return EC_Normal;
@@ -268,6 +263,26 @@ OFBool DSRWaveformReferenceValue::checkSOPClassUID(const OFString &sopClassUID)
 /*
  *  CVS/RCS Log:
  *  $Log: dsrwavvl.cc,v $
+ *  Revision 1.21  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.20  2009-10-13 14:57:52  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.19  2007-11-15 16:45:26  joergr
+ *  Added support for output in XHTML 1.1 format.
+ *  Enhanced support for output in valid HTML 3.2 format. Migrated support for
+ *  standard HTML from version 4.0 to 4.01 (strict).
+ *
+ *  Revision 1.18  2006/08/15 16:40:03  meichel
+ *  Updated the code in module dcmsr to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
+ *  Revision 1.17  2006/07/25 13:37:48  joergr
+ *  Added new optional flags for the HTML rendering of SR documents:
+ *  HF_alwaysExpandChildrenInline, HF_useCodeDetailsTooltip and
+ *  HF_renderSectionTitlesInline.
+ *
  *  Revision 1.16  2005/12/08 15:48:23  meichel
  *  Changed include path schema for all DCMTK header files
  *
