@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2003-2005, OFFIS
+ *  Copyright (C) 2003-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmsr
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DSRXMLDocument
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/16 15:46:43 $
- *  CVS/RCS Revision: $Revision: 1.11 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-12-15 13:59:58 $
+ *  CVS/RCS Revision: $Revision: 1.19 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -40,29 +36,72 @@
 #include "dcmtk/ofstd/ofstdinc.h"
 
 #ifdef WITH_LIBXML
-#include <libxml/xmlschemas.h>
+#include <libxml/xmlversion.h>
 
 #ifdef LIBXML_SCHEMAS_ENABLED
-#ifdef HAVE_VPRINTF
-// function required to avoid issue with 'std' namespace
-extern "C" void errorFunction(void *ctx, const char *msg, ...)
+#include <libxml/xmlschemas.h>
+#endif /* LIBXML_SCHEMAS_ENABLED */
+
+// This function is also used in xml2dcm, try to stay in sync!
+extern "C" void errorFunction(void * ctx, const char *msg, ...)
 {
+    OFString &buffer = *OFstatic_cast(OFString*, ctx);
+    OFLogger xmlLogger = OFLog::getLogger("dcmtk.dcmsr.libxml");
+
+    if (!xmlLogger.isEnabledFor(OFLogger::DEBUG_LOG_LEVEL))
+        return;
+
+#if defined(HAVE_VSNPRINTF) && defined(HAVE_PROTOTYPE_VSNPRINTF)
+    // libxml calls us multiple times for one line of log output which would
+    // result in garbled output. To avoid this, we buffer the output in a local
+    // string in the caller which we get through our 'ctx' parameter. Then, we
+    // output this string on one go when we receive a newline.
+    va_list ap;
+    char buf[1024];
+
+    va_start(ap, msg);
+#ifdef HAVE_PROTOTYPE_STD__VSNPRINTF
+    std::vsnprintf(buf, 1024, msg, ap);
+#else
+    vsnprintf(buf, 1024, msg, ap);
+#endif
+    va_end(ap);
+
+    // Since we can't do anything about a too small buffer for vsnprintf(), we
+    // ignore it. But we do make sure the buffer is null-terminated!
+    buf[1023] = '\0';
+    buffer += buf;
+
+    // If there is a full line in the buffer...
+    size_t pos = buffer.find('\n');
+    while (pos != OFString_npos)
+    {
+        // ..output it and remove it from the buffer
+        OFLOG_DEBUG(xmlLogger, buffer.substr(0, pos));
+        buffer.erase(0, pos + 1);
+
+        pos = buffer.find('\n');
+    }
+#elif defined(HAVE_VPRINTF)
+    // No vsnprint, but at least vfprintf. Output the messages directly to stderr.
     va_list ap;
     va_start(ap, msg);
 #ifdef HAVE_PROTOTYPE_STD__VFPRINTF
-    std::vfprintf(OFstatic_cast(FILE *, ctx), msg, ap);
+    std::vfprintf(stderr, msg, ap);
 #else
-    vfprintf(OFstatic_cast(FILE *, ctx), msg, ap);
+    vfprintf(stderr, msg, ap);
 #endif
     va_end(ap);
-}
+#else
+    // We can only show the most basic part of the message, this will look bad :(
+    printf("%s", msg);
 #endif
-#endif /* LIBXML_SCHEMAS_ENABLED */
 
-// 'libxml' shall be quiet in non-debug mode
-extern "C" void noErrorFunction(void * /*ctx*/, const char * /*msg*/, ...)
-{
-    /* do nothing */
+#ifndef HAVE_VSNPRINTF
+    // Only the vsnprintf() branch above uses 'buffer' which means the compiler
+    // would warn about an unused variable if HAVE_VSNPRINTF is undefined.
+    buffer += "";
+#endif
 }
 
 #endif /* WITH_LIBXML */
@@ -73,8 +112,7 @@ extern "C" void noErrorFunction(void * /*ctx*/, const char * /*msg*/, ...)
 
 DSRXMLDocument::DSRXMLDocument()
   : Document(NULL),
-    EncodingHandler(NULL),
-    LogStream(NULL)
+    EncodingHandler(NULL)
 {
 }
 
@@ -103,39 +141,23 @@ OFBool DSRXMLDocument::valid() const
 }
 
 
-OFConsole *DSRXMLDocument::getLogStream() const
-{
-    return LogStream;
-}
-
-
-void DSRXMLDocument::setLogStream(OFConsole *stream)
-{
-    LogStream = stream;
-}
-
-
 #ifdef WITH_LIBXML
 OFCondition DSRXMLDocument::read(const OFString &filename,
                                  const size_t flags)
 {
     OFCondition result = SR_EC_InvalidDocument;
+    /* temporary buffer needed for errorFunction - more detailed explanation there */
+    OFString tmpErrorString;
     /* first remove any possibly existing document from memory */
     clear();
     /* substitute default entities (XML mnenonics) */
     xmlSubstituteEntitiesDefault(1);
-    if (flags & XF_enableLibxmlErrorOutput)
-    {
-        /* add line number to debug messages */
-        xmlLineNumbersDefault(1);
-        /* enable libxml warnings and error messages */
-        xmlGetWarningsDefaultValue = 1;
-        initGenericErrorDefaultFunc(NULL);
-    } else {
-        /* disable libxml warnings and error messages */
-        xmlGetWarningsDefaultValue = 0;
-        xmlSetGenericErrorFunc(NULL, noErrorFunction);
-    }
+    /* add line number to debug messages */
+    xmlLineNumbersDefault(1);
+    /* enable libxml warnings and error messages */
+    xmlGetWarningsDefaultValue = 1;
+    xmlSetGenericErrorFunc(&tmpErrorString, errorFunction);
+
     xmlGenericError(xmlGenericErrorContext, "--- libxml parsing ------\n");
     /* build an XML tree from the given file */
     Document = xmlParseFile(filename.c_str());
@@ -150,31 +172,13 @@ OFCondition DSRXMLDocument::read(const OFString &filename,
 #if 1
             /* create context for Schema validation */
             xmlSchemaParserCtxtPtr context = xmlSchemaNewParserCtxt(DCMSR_XML_XSD_FILE);
-            if (flags & XF_enableLibxmlErrorOutput)
-            {
-#ifdef HAVE_VPRINTF
-                xmlSchemaSetParserErrors(context, errorFunction, errorFunction, stderr);
-#else
-                xmlSchemaSetParserErrors(context, OFreinterpret_cast(xmlSchemaValidityErrorFunc, fprintf),
-                                                  OFreinterpret_cast(xmlSchemaValidityWarningFunc, fprintf), stderr);
-#endif
-            } else
-                xmlSchemaSetParserErrors(context, NULL, NULL, NULL);
+            xmlSchemaSetParserErrors(context, errorFunction, errorFunction, &tmpErrorString);
             /* parse Schema file */
             xmlSchemaPtr schema = xmlSchemaParse(context);
             if (schema != NULL)
             {
                 xmlSchemaValidCtxtPtr validCtx = xmlSchemaNewValidCtxt(schema);
-                if (flags & XF_enableLibxmlErrorOutput)
-                {
-#ifdef HAVE_VPRINTF
-                    xmlSchemaSetValidErrors(validCtx, errorFunction, errorFunction, stderr);
-#else
-                    xmlSchemaSetValidErrors(validCtx, OFreinterpret_cast(xmlSchemaValidityErrorFunc, fprintf),
-                                                      OFreinterpret_cast(xmlSchemaValidityWarningFunc, fprintf), stderr);
-#endif
-                } else
-                    xmlSchemaSetValidErrors(validCtx, NULL, NULL, NULL);
+                xmlSchemaSetValidErrors(validCtx, errorFunction, errorFunction, &tmpErrorString);
                 /* validate the document */
                 isValid = (xmlSchemaValidateDoc(validCtx, Document) == 0);
                 xmlSchemaFreeValidCtxt(validCtx);
@@ -187,16 +191,7 @@ OFCondition DSRXMLDocument::read(const OFString &filename,
 
             /* create context for Schema validation */
             xmlSchemaValidCtxtPtr context = xmlSchemaNewValidCtxt(NULL);
-            if (flags & XF_enableLibxmlErrorOutput)
-            {
-#ifdef HAVE_VPRINTF
-                xmlSchemaSetValidErrors(context, errorFunction, errorFunction, stderr);
-#else
-                xmlSchemaSetValidErrors(context, OFreinterpret_cast(xmlSchemaValidityErrorFunc, fprintf),
-                                                 OFreinterpret_cast(xmlSchemaValidityWarningFunc, fprintf), stderr);
-#endif
-            } else
-                xmlSchemaSetValidErrors(context, NULL, NULL, NULL);
+            xmlSchemaSetValidErrors(context, errorFunction, errorFunction, &tmpErrorString);
             /* validate the document */
             isValid = (xmlSchemaValidateDoc(context, Document) == 0);
 #endif
@@ -215,17 +210,22 @@ OFCondition DSRXMLDocument::read(const OFString &filename,
             {
                 result = EC_Normal;
             } else
-                printErrorMessage(LogStream, "Document has wrong type, dcmsr namespace not found");
+                DCMSR_ERROR("Document has wrong type, dcmsr namespace not found");
         } else {
             if (isValid)
-                printErrorMessage(LogStream, "Document is empty");
+                DCMSR_ERROR("Document is empty");
             else
-                printErrorMessage(LogStream, "Document does not validate");
+                DCMSR_ERROR("Document does not validate");
         }
     } else {
         xmlGenericError(xmlGenericErrorContext, "-------------------------\n");
-        printErrorMessage(LogStream, "Could not parse document");
+        DCMSR_ERROR("Could not parse document");
     }
+
+    /* Reset to default function because we used a local string as context for
+     * the error function.
+     */
+    xmlSetGenericErrorFunc(NULL, NULL);
     return result;
 }
 #else /* WITH_LIBXML */
@@ -306,11 +306,8 @@ DSRXMLCursor DSRXMLDocument::getNamedNode(const DSRXMLCursor &cursor,
             if (required)
             {
                 OFString tmpString;
-                OFString message = "Document of the wrong type, '";
-                message += name;
-                message += "' expected at ";
-                message += getFullNodePath(cursor, tmpString, OFFalse /*omitCurrent*/);
-                DSRTypes::printErrorMessage(LogStream, message.c_str());
+                DCMSR_ERROR("Document of the wrong type, '" << name
+                    << "' expected at " << getFullNodePath(cursor, tmpString, OFFalse /*omitCurrent*/));
             }
         } else {
             /* return new node position */
@@ -366,20 +363,13 @@ OFCondition DSRXMLDocument::checkNode(const DSRXMLCursor &cursor,
             /* check whether node has expected name */
             if (xmlStrcmp(cursor.Node->name, OFreinterpret_cast(const xmlChar *, name)) != 0)
             {
-                OFString message = "Document of the wrong type, was '";
-                message += OFreinterpret_cast(const char *, cursor.Node->name);
-                message += "', '";
-                message += name;
-                message += "' expected";
-                DSRTypes::printErrorMessage(LogStream, message.c_str());
+                DCMSR_ERROR("Document of the wrong type, was '" << OFreinterpret_cast(const char *, cursor.Node->name)
+                    << "', '" << name << "' expected");
                 result = SR_EC_InvalidDocument;
             } else
                 result = EC_Normal;
         } else {
-            OFString message = "Document of the wrong type, '";
-            message += name;
-            message += "' expected";
-            DSRTypes::printErrorMessage(LogStream, message.c_str());
+            DCMSR_ERROR("Document of the wrong type, '" << name << "' expected");
             result = EC_IllegalParameter;
         }
     }
@@ -612,13 +602,13 @@ OFString &DSRXMLDocument::getFullNodePath(const DSRXMLCursor &cursor,
         OFString tmpString;
         xmlNodePtr current = cursor.Node;
         if (!omitCurrent)
-            stringValue = OFreinterpret_cast(const char *, current->name);
+            stringValue = OFSTRING_GUARD(OFreinterpret_cast(const char *, current->name));
         /* follow path to parent nodes */
         while (current->parent != NULL)
         {
             current = current->parent;
             tmpString = stringValue;
-            stringValue = OFreinterpret_cast(const char *, current->name);
+            stringValue = OFSTRING_GUARD(OFreinterpret_cast(const char *, current->name));
             if (!tmpString.empty())
             {
                 stringValue += '/';
@@ -702,12 +692,7 @@ DSRTypes::E_RelationshipType DSRXMLDocument::getRelationshipTypeFromNode(const D
 void DSRXMLDocument::printUnexpectedNodeWarning(const DSRXMLCursor &cursor) const
 {
     OFString tmpString;
-    /* create message string */
-    OFString message = "Unexpected node '";
-    message += getFullNodePath(cursor, tmpString);
-    message += "', skipping";
-    /* print warning message */
-    printWarningMessage(LogStream, message.c_str());
+    DCMSR_WARN("Unexpected node '" << getFullNodePath(cursor, tmpString) << "', skipping");
 }
 
 
@@ -718,11 +703,7 @@ void DSRXMLDocument::printMissingAttributeError(const DSRXMLCursor &cursor,
     if (name != NULL)
     {
         OFString tmpString;
-        OFString message = "XML attribute '";
-        message += name;
-        message += "' missing/empty in ";
-        message += getFullNodePath(cursor, tmpString);
-        printErrorMessage(LogStream, message.c_str());
+        DCMSR_ERROR("XML attribute '" << name << "' missing/empty in " << getFullNodePath(cursor, tmpString));
     }
 }
 
@@ -734,12 +715,7 @@ void DSRXMLDocument::printGeneralNodeError(const DSRXMLCursor &cursor,
     if (result.bad())
     {
         OFString tmpString;
-        OFString message = "Parsing node ";
-        message += getFullNodePath(cursor, tmpString);
-        message += " (";
-        message += result.text();
-        message += ")";
-        printErrorMessage(LogStream, message.c_str());
+        DCMSR_ERROR("Parsing node " << getFullNodePath(cursor, tmpString) << " (" << result.text() << ")");
     }
 }
 
@@ -747,6 +723,31 @@ void DSRXMLDocument::printGeneralNodeError(const DSRXMLCursor &cursor,
 /*
  *  CVS/RCS Log:
  *  $Log: dsrxmld.cc,v $
+ *  Revision 1.19  2010-12-15 13:59:58  uli
+ *  Fixed a problem with a missing prototype for vsnprintf on HP-UX.
+ *
+ *  Revision 1.18  2010-10-14 13:14:42  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.17  2010-09-28 13:21:40  joergr
+ *  Made sure that no NULL pointer is passed to the OFString constructor.
+ *
+ *  Revision 1.16  2010-06-15 14:34:51  uli
+ *  Don't fail to compile if libxml does not support schemas.
+ *
+ *  Revision 1.15  2009-10-28 08:42:40  uli
+ *  Use a local variable for buffering libxml error messages instead of a
+ *  static one.
+ *
+ *  Revision 1.14  2009-10-14 10:49:33  joergr
+ *  Fixed minor issues in log output. Also updated copyright date (if required).
+ *
+ *  Revision 1.13  2009-10-13 14:57:52  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.12  2008-04-25 15:37:20  joergr
+ *  Include header file for XML Schemas only if Schema support is enabled.
+ *
  *  Revision 1.11  2005/12/16 15:46:43  meichel
  *  Declared libxml2 callback functions as extern "C"
  *
