@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmnet
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DcmTLSTransportLayer
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:28 $
- *  CVS/RCS Revision: $Revision: 1.11 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:46 $
+ *  CVS/RCS Revision: $Revision: 1.19 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -50,10 +46,17 @@ END_EXTERN_C
 #include "dcmtk/dcmtls/tlslayer.h"
 #include "dcmtk/dcmtls/tlstrans.h"
 #include "dcmtk/dcmnet/dicom.h"
-#include "dcmtk/ofstd/ofconsol.h"    /* for ofConsole */
 
 extern "C" int DcmTLSTransportLayer_certificateValidationCallback(int ok, X509_STORE_CTX *storeContext);
 
+OFLogger DCM_dcmtlsGetLogger()
+{
+    // We don't just use a global variable, because constructors of globals are
+    // executed in random order. This guarantees that the OFLogger is constructed
+    // before first use.
+    static OFLogger DCM_dcmtlsLogger = OFLog::getLogger("dcmtk.dcmtls");
+    return DCM_dcmtlsLogger;
+}
 
 int DcmTLSTransportLayer_certificateValidationCallback(int ok, X509_STORE_CTX * /* storeContext */)
 {
@@ -74,7 +77,7 @@ extern "C" int DcmTLSTransportLayer_passwordCallback(char *buf, int size, int rw
 int DcmTLSTransportLayer_passwordCallback(char *buf, int size, int /* rwflag */, void *userdata)
 {
   if (userdata == NULL) return -1;
-  OFString *password = (OFString *)userdata;
+  OFString *password = OFreinterpret_cast(OFString *, userdata);
   int passwordSize = password->length();
   if (passwordSize > size) passwordSize = size;
   strncpy(buf, password->c_str(), passwordSize);
@@ -154,13 +157,13 @@ unsigned long DcmTLSTransportLayer::getNumberOfCipherSuites()
 const char *DcmTLSTransportLayer::getTLSCipherSuiteName(unsigned long idx)
 {
   if (idx < sizeof(cipherSuiteList)/sizeof(DcmCipherSuiteList)) return cipherSuiteList[idx].TLSname;
-  return NULL;  
+  return NULL;
 }
 
 const char *DcmTLSTransportLayer::getOpenSSLCipherSuiteName(unsigned long idx)
 {
   if (idx < sizeof(cipherSuiteList)/sizeof(DcmCipherSuiteList)) return cipherSuiteList[idx].openSSLName;
-  return NULL;  
+  return NULL;
 }
 
 const char *DcmTLSTransportLayer::findOpenSSLCipherSuiteName(const char *tlsCipherSuiteName)
@@ -188,28 +191,21 @@ DcmTLSTransportLayer::DcmTLSTransportLayer(int networkRole, const char *randFile
    SSLeay_add_all_algorithms();
    seedPRNG(randFile);
 
-   SSL_METHOD *method = NULL;
-   switch (networkRole)
+   if (networkRole == DICOM_APPLICATION_ACCEPTOR)
    {
-     case DICOM_APPLICATION_ACCEPTOR: 
-       method = TLSv1_server_method();
-       break;
-     case DICOM_APPLICATION_REQUESTOR:
-       method = TLSv1_client_method();
-       break;
-     default:
-       method = TLSv1_method();
-       break;
+     transportLayerContext = SSL_CTX_new(TLSv1_server_method());
+   } else if (networkRole == DICOM_APPLICATION_REQUESTOR) {
+     transportLayerContext = SSL_CTX_new(TLSv1_client_method());
+   } else {
+     transportLayerContext = SSL_CTX_new(TLSv1_method());
    }
-   transportLayerContext = SSL_CTX_new(method);
 
 #ifdef DEBUG
    if (transportLayerContext == NULL)
    {
       const char *result = ERR_reason_error_string(ERR_peek_error());
       if (result == NULL) result = "unknown error in SSL_CTX_new()";
-      ofConsole.lockCerr() << "error: unable to create TLS transport layer: " << result << endl;
-      ofConsole.unlockCerr();      
+      DCMTLS_ERROR("unable to create TLS transport layer: " << result);
    }
 #endif
 
@@ -349,7 +345,7 @@ DcmTransportLayerStatus DcmTLSTransportLayer::addTrustedCertificateDir(const cha
   } else return TCS_illegalCall;
   return TCS_ok;
 }
-      
+
 DcmTransportConnection *DcmTLSTransportLayer::createConnection(int openSocket, OFBool useSecureLayer)
 {
   if (useSecureLayer)
@@ -370,7 +366,7 @@ DcmTransportConnection *DcmTLSTransportLayer::createConnection(int openSocket, O
 
 void DcmTLSTransportLayer::seedPRNG(const char *randFile)
 {
-#ifdef WINDOWS
+#ifdef _WIN32
   RAND_screen();
 #endif
   if (randFile)
@@ -380,18 +376,17 @@ void DcmTLSTransportLayer::seedPRNG(const char *randFile)
       RAND_load_file(randFile ,-1);
     }
   }
-  if (RAND_status()) canWriteRandseed = OFTrue; 
+  if (RAND_status()) canWriteRandseed = OFTrue;
   else
   {
     /* warn user */
-    ofConsole.lockCerr() << "Warning: PRNG for TLS not seeded with sufficient random data." << endl;
-    ofConsole.unlockCerr();    
+    DCMTLS_WARN("PRNG for TLS not seeded with sufficient random data.");
   }
 }
 
 void DcmTLSTransportLayer::addPRNGseed(void *buf, size_t bufSize)
 {
-  RAND_seed(buf,(int) bufSize);
+  RAND_seed(buf,OFstatic_cast(int, bufSize));
 }
 
 OFBool DcmTLSTransportLayer::writeRandomSeed(const char *randFile)
@@ -403,7 +398,7 @@ OFBool DcmTLSTransportLayer::writeRandomSeed(const char *randFile)
   return OFFalse;
 }
 
-void DcmTLSTransportLayer::printX509Certificate(ostream &out, X509 *peerCertificate)
+OFString DcmTLSTransportLayer::dumpX509Certificate(X509 *peerCertificate)
 {
   if (peerCertificate)
   {
@@ -425,7 +420,7 @@ void DcmTLSTransportLayer::printX509Certificate(ostream &out, X509 *peerCertific
     {
       ASN1_UTCTIME_print(certValidNotBeforeBIO, X509_get_notBefore(peerCertificate));
       BIO_write(certValidNotBeforeBIO,"\0",1);
-      BIO_get_mem_data(certValidNotBeforeBIO, (char *)(&bufptr));
+      BIO_get_mem_data(certValidNotBeforeBIO, OFreinterpret_cast(char *, &bufptr));
       if (bufptr) certValidNotBefore = bufptr;
       BIO_free(certValidNotBeforeBIO);
     }
@@ -435,7 +430,7 @@ void DcmTLSTransportLayer::printX509Certificate(ostream &out, X509 *peerCertific
     {
       ASN1_UTCTIME_print(certValidNotAfterBIO, X509_get_notAfter(peerCertificate));
       BIO_write(certValidNotAfterBIO,"\0",1);
-      BIO_get_mem_data(certValidNotAfterBIO, (char *)(&bufptr));
+      BIO_get_mem_data(certValidNotAfterBIO, OFreinterpret_cast(char *, &bufptr));
       if (bufptr) certValidNotAfter = bufptr;
       BIO_free(certValidNotAfterBIO);
     }
@@ -461,21 +456,24 @@ void DcmTLSTransportLayer::printX509Certificate(ostream &out, X509 *peerCertific
       }
       certPubKeyBits = EVP_PKEY_bits(pubkey);
       EVP_PKEY_free(pubkey);
-    } 
-    out << "X.509v" << certVersion << " Certificate" << endl
-         << "  Subject      : " << certSubjectName << endl
-         << "  Issued by    : " << certIssuerName << endl
-         << "  Serial no.   : " << certSerialNumber << endl
-         << "  Validity     : not before " << certValidNotBefore << ", not after " << certValidNotAfter << endl
-         << "  Public key   : " << certPubKeyType << ", " << certPubKeyBits << " bits" << endl;
+    }
+    OFOStringStream out;
+    out << "X.509v" << certVersion << " Certificate" << OFendl
+         << "  Subject      : " << certSubjectName << OFendl
+         << "  Issued by    : " << certIssuerName << OFendl
+         << "  Serial no.   : " << certSerialNumber << OFendl
+         << "  Validity     : not before " << certValidNotBefore << ", not after " << certValidNotAfter << OFendl
+         << "  Public key   : " << certPubKeyType << ", " << certPubKeyBits << " bits" << OFendl << OFStringStream_ends;
+    OFSTRINGSTREAM_GETOFSTRING(out, ret)
+    return ret;
   } else {
-    out << "No X.509 Certificate." << endl;
+    return "No X.509 Certificate.";
   }
 }
 
 #else  /* WITH_OPENSSL */
 
-/* make sure that the object file is not completely empty if compiled 
+/* make sure that the object file is not completely empty if compiled
  * without OpenSSL because some linkers might fail otherwise.
  */
 void tlslayer_dummy_function()
@@ -487,6 +485,32 @@ void tlslayer_dummy_function()
 
 /*
  *  $Log: tlslayer.cc,v $
+ *  Revision 1.19  2010-10-14 13:14:46  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.18  2010-08-05 08:38:11  uli
+ *  Fixed some warnings from -Wold-style-cast.
+ *
+ *  Revision 1.17  2010-06-02 12:32:58  joergr
+ *  Appended missing OFStringStream_ends to the end of output streams because
+ *  this is required when OFOStringStream is mapped to ostrstream.
+ *
+ *  Revision 1.16  2010-02-22 11:39:55  uli
+ *  Remove some unneeded includes.
+ *
+ *  Revision 1.15  2009-12-18 13:15:45  joergr
+ *  Fixed issue with beta version of OpenSSL 1.0 (const declaration changed).
+ *
+ *  Revision 1.14  2009-11-18 12:11:19  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.13  2009-01-30 13:53:53  joergr
+ *  Replaced checking of macro WINDOWS by _WIN32.
+ *
+ *  Revision 1.12  2006/08/15 16:02:56  meichel
+ *  Updated the code in module dcmtls to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.11  2005/12/08 15:48:28  meichel
  *  Changed include path schema for all DCMTK header files
  *
@@ -527,4 +551,3 @@ void tlslayer_dummy_function()
  *
  *
  */
-
