@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module: dcmtls
  *
@@ -22,9 +18,9 @@
  *  Purpose:
  *    classes: DcmTLSConnection
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:29 $
- *  CVS/RCS Revision: $Revision: 1.10 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:46 $
+ *  CVS/RCS Revision: $Revision: 1.18 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -67,7 +63,6 @@ END_EXTERN_C
 #include "dcmtk/ofstd/ofbmanip.h"
 #include "dcmtk/dcmtls/tlstrans.h"
 #include "dcmtk/dcmtls/tlslayer.h"
-#include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/dcmnet/dcompat.h"    /* to make sure we have a select prototype */
 
 
@@ -80,7 +75,7 @@ DcmTLSConnection::DcmTLSConnection(int openSocket, SSL *newTLSConnection)
 
 DcmTLSConnection::~DcmTLSConnection()
 {
-  if (tlsConnection) SSL_free(tlsConnection);
+  close();
 }
 
 DcmTransportLayerStatus DcmTLSConnection::serverSideHandshake()
@@ -117,6 +112,7 @@ DcmTransportLayerStatus DcmTLSConnection::serverSideHandshake()
 
 DcmTransportLayerStatus DcmTLSConnection::clientSideHandshake()
 {
+  DCMTLS_TRACE("Starting TLS client handshake");
   if (tlsConnection == NULL) return TCS_noConnection;
   lastError = 0;
   DcmTransportLayerStatus result = TCS_ok;
@@ -147,7 +143,7 @@ DcmTransportLayerStatus DcmTLSConnection::renegotiate(const char *newSuite)
   if (tlsConnection == NULL) return TCS_noConnection;
   if (newSuite == NULL) return TCS_illegalCall;
   DcmTransportLayerStatus result = TCS_ok;
-  
+
   switch (SSL_get_error(tlsConnection, SSL_set_cipher_list(tlsConnection, newSuite)))
   {
     case SSL_ERROR_NONE:
@@ -194,27 +190,36 @@ DcmTransportLayerStatus DcmTLSConnection::renegotiate(const char *newSuite)
 
 ssize_t DcmTLSConnection::read(void *buf, size_t nbyte)
 {
-  if (tlsConnection) return SSL_read(tlsConnection, (char*)buf, nbyte);
+  if (tlsConnection) return SSL_read(tlsConnection, OFreinterpret_cast(char*, buf), nbyte);
   errno = EIO; /* IO Error */
   return -1;
 }
 
 ssize_t DcmTLSConnection::write(void *buf, size_t nbyte)
 {
-  if (tlsConnection) return SSL_write(tlsConnection, (char*)buf, nbyte);
+  if (tlsConnection) return SSL_write(tlsConnection, OFreinterpret_cast(char*, buf), nbyte);
   errno = EIO; /* IO Error */
   return -1;
 }
 
 void DcmTLSConnection::close()
 {
-  if (tlsConnection) SSL_shutdown(tlsConnection);
+  if (tlsConnection != NULL)
+  {
+    SSL_shutdown(tlsConnection);
+    SSL_free(tlsConnection);
+    tlsConnection = NULL;
+  }
+  if (getSocket()!=-1)
+  {
 #ifdef HAVE_WINSOCK_H
-  (void) shutdown(getSocket(),  1 /* SD_SEND */);
-  (void) closesocket(getSocket());
+    (void) shutdown(getSocket(),  1 /* SD_SEND */);
+    (void) closesocket(getSocket());
 #else
-  (void) ::close(getSocket());
+    (void) ::close(getSocket());
 #endif
+    setSocket(-1);
+  }
 }
 
 unsigned long DcmTLSConnection::getPeerCertificateLength()
@@ -225,7 +230,8 @@ unsigned long DcmTLSConnection::getPeerCertificateLength()
     X509 *peerCert = SSL_get_peer_certificate(tlsConnection);
     if (peerCert)
     {
-      result = (unsigned long) i2d_X509(peerCert, NULL);
+      result = OFstatic_cast(unsigned long, i2d_X509(peerCert, NULL));
+      X509_free(peerCert);
     }
   }
   return result;
@@ -239,12 +245,13 @@ unsigned long DcmTLSConnection::getPeerCertificate(void *buf, unsigned long bufL
     X509 *peerCert = SSL_get_peer_certificate(tlsConnection);
     if (peerCert)
     {
-      unsigned long certSize = (unsigned long) i2d_X509(peerCert, NULL);
+      unsigned long certSize = OFstatic_cast(unsigned long, i2d_X509(peerCert, NULL));
       if (certSize <= bufLen)
       {
-      	unsigned char *p = (unsigned char *)buf;
-        result = (unsigned long) i2d_X509(peerCert, &p);
+        unsigned char *p = OFreinterpret_cast(unsigned char *, buf);
+        result = OFstatic_cast(unsigned long, i2d_X509(peerCert, &p));
       }
+      X509_free(peerCert);
     }
   }
   return result;
@@ -286,16 +293,30 @@ OFBool DcmTLSConnection::isTransparentConnection()
   return OFFalse;
 }
 
-void DcmTLSConnection::dumpConnectionParameters(ostream &out)
+OFString& DcmTLSConnection::dumpConnectionParameters(OFString& str)
 {
-  out << "Transport connection: TLS/SSL over TCP/IP" << endl
-      << "  Protocol: " << SSL_get_version(tlsConnection) << endl 
-      << "  Ciphersuite: " << SSL_CIPHER_get_name(SSL_get_current_cipher(tlsConnection))
-      << ", version: " << SSL_CIPHER_get_version(SSL_get_current_cipher(tlsConnection))
-      << ", encryption: " << SSL_CIPHER_get_bits(SSL_get_current_cipher(tlsConnection), NULL) << " bits" << endl;
-  DcmTLSTransportLayer::printX509Certificate(out, SSL_get_peer_certificate(tlsConnection));
-  // out << "Certificate verification: " << X509_verify_cert_error_string(SSL_get_verify_result(tlsConnection)) << endl;
-  return;
+  if (tlsConnection == NULL)
+  {
+    // This should never happen (famous last words)
+    str = "Transport connection: TLS/SSL over TCP/IP\n  Error: No Connection\n";
+    return str;
+  }
+
+  X509 *peerCert = SSL_get_peer_certificate(tlsConnection);
+  OFOStringStream stream;
+  stream << "Transport connection: TLS/SSL over TCP/IP" << OFendl
+         << "  Protocol: " << SSL_get_version(tlsConnection) << OFendl
+         << "  Ciphersuite: " << SSL_CIPHER_get_name(SSL_get_current_cipher(tlsConnection))
+         << ", version: " << SSL_CIPHER_get_version(SSL_get_current_cipher(tlsConnection))
+         << ", encryption: " << SSL_CIPHER_get_bits(SSL_get_current_cipher(tlsConnection), NULL) << " bits" << OFendl
+         << DcmTLSTransportLayer::dumpX509Certificate(peerCert) << OFendl;
+  // out << "Certificate verification: " << X509_verify_cert_error_string(SSL_get_verify_result(tlsConnection)) << OFendl;
+  X509_free(peerCert);
+  stream << OFStringStream_ends;
+  OFSTRINGSTREAM_GETSTR(stream, res)
+  str = res;
+  OFSTRINGSTREAM_FREESTR(res)
+  return str;
 }
 
 const char *DcmTLSConnection::errorString(DcmTransportLayerStatus code)
@@ -313,7 +334,7 @@ const char *DcmTLSConnection::errorString(DcmTransportLayerStatus code)
       {
         const char *result = ERR_reason_error_string(lastError);
         if (result) return result;
-      } 
+      }
       return "unspecified TLS error";
       /* break; */
     case TCS_illegalCall:
@@ -328,7 +349,7 @@ const char *DcmTLSConnection::errorString(DcmTransportLayerStatus code)
 
 #else  /* WITH_OPENSSL */
 
-/* make sure that the object file is not completely empty if compiled 
+/* make sure that the object file is not completely empty if compiled
  * without OpenSSL because some linkers might fail otherwise.
  */
 void tlstrans_dummy_function()
@@ -342,6 +363,32 @@ void tlstrans_dummy_function()
 
 /*
  *  $Log: tlstrans.cc,v $
+ *  Revision 1.18  2010-10-14 13:14:46  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.17  2010-08-24 10:06:04  uli
+ *  Fixed some resource leaks in dcmtls (FDs and memory was leaked).
+ *
+ *  Revision 1.16  2010-08-05 08:38:11  uli
+ *  Fixed some warnings from -Wold-style-cast.
+ *
+ *  Revision 1.15  2010-06-02 12:32:58  joergr
+ *  Appended missing OFStringStream_ends to the end of output streams because
+ *  this is required when OFOStringStream is mapped to ostrstream.
+ *
+ *  Revision 1.14  2010-04-29 16:18:51  onken
+ *  Added debug message noting the initiation of a TLS client handshake.
+ *
+ *  Revision 1.13  2010-02-22 11:39:55  uli
+ *  Remove some unneeded includes.
+ *
+ *  Revision 1.12  2009-11-18 12:11:19  uli
+ *  Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *  Revision 1.11  2006-08-15 16:02:56  meichel
+ *  Updated the code in module dcmtls to correctly compile when
+ *    all standard C++ classes remain in namespace std.
+ *
  *  Revision 1.10  2005/12/08 15:48:29  meichel
  *  Changed include path schema for all DCMTK header files
  *
