@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmwlm
  *
@@ -22,10 +18,9 @@
  *  Purpose: Class representing a console engine for basic worklist
  *           management service class providers based on the file system.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:30 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmwlm/apps/wlcefs.cc,v $
- *  CVS/RCS Revision: $Revision: 1.10 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-11-01 13:37:32 $
+ *  CVS/RCS Revision: $Revision: 1.29 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -35,6 +30,7 @@
 // ----------------------------------------------------------------------------
 
 #include "dcmtk/config/osconfig.h"
+
 #include "dcmtk/dcmnet/dicom.h"
 #include "dcmtk/ofstd/ofcmdln.h"
 #include "dcmtk/dcmwlm/wltypdef.h"
@@ -43,7 +39,6 @@
 #include "dcmtk/dcmnet/assoc.h"
 #include "dcmtk/dcmdata/cmdlnarg.h"
 #include "dcmtk/dcmnet/dimse.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/dcvrat.h"
 #include "dcmtk/dcmdata/dcvrlo.h"
 #include "dcmtk/dcmwlm/wlds.h"
@@ -63,6 +58,8 @@
 #define SHORTCOL 4
 #define LONGCOL 21
 
+static OFLogger wlmscpfsLogger = OFLog::getLogger("dcmtk.apps.wlmscpfs");
+
 // ----------------------------------------------------------------------------
 
 WlmConsoleEngineFileSystem::WlmConsoleEngineFileSystem( int argc, char *argv[], const char *applicationName, WlmDataSource *dataSourcev )
@@ -77,13 +74,14 @@ WlmConsoleEngineFileSystem::WlmConsoleEngineFileSystem( int argc, char *argv[],
 //                dataSourcev     - [in] Pointer to the dataSource object.
 // Return Value : none.
   : opt_returnedCharacterSet( RETURN_NO_CHARACTER_SET ),
-    opt_dfPath( NULL ), opt_port( 0 ), opt_refuseAssociation( OFFalse ),
+    opt_dfPath( "" ), opt_port( 0 ), opt_refuseAssociation( OFFalse ),
     opt_rejectWithoutImplementationUID( OFFalse ), opt_sleepAfterFind( 0 ), opt_sleepDuringFind( 0 ),
     opt_maxPDU( ASC_DEFAULTMAXPDU ), opt_networkTransferSyntax( EXS_Unknown ),
-    opt_verbose( OFFalse ), opt_debug( OFFalse ), opt_failInvalidQuery( OFTrue ), opt_singleProcess( OFTrue ),
-    opt_maxAssociations( 50 ), opt_noSequenceExpansion( OFFalse ), opt_enableRejectionOfIncompleteWlFiles( OFTrue ),
-    opt_blockMode(DIMSE_BLOCKING), opt_dimse_timeout(0), opt_acse_timeout(30),
-    app( NULL ), cmd( NULL ), dataSource( dataSourcev )
+    opt_failInvalidQuery( OFTrue ), opt_singleProcess( OFTrue ),
+    opt_forkedChild( OFFalse ), opt_maxAssociations( 50 ), opt_noSequenceExpansion( OFFalse ),
+    opt_enableRejectionOfIncompleteWlFiles( OFTrue ), opt_blockMode(DIMSE_BLOCKING),
+    opt_dimse_timeout(0), opt_acse_timeout(30), app( NULL ), cmd( NULL ), command_argc( argc ),
+    command_argv(argv), dataSource( dataSourcev )
 {
   // Initialize application identification string.
   sprintf( rcsid, "$dcmtk: %s v%s %s $", applicationName, OFFIS_DCMTK_VERSION, OFFIS_DCMTK_RELEASEDATE );
@@ -91,7 +89,8 @@ WlmConsoleEngineFileSystem::WlmConsoleEngineFileSystem( int argc, char *argv[],
   // Initialize starting values for variables pertaining to program options.
   opt_dfPath = "/home/www/wlist";
 
-#ifdef HAVE_FORK
+  // default: spawn new process for each incoming connection (fork()-OS or WIN32)
+#if defined(HAVE_FORK) || defined(_WIN32)
   opt_singleProcess = OFFalse;
 #else
   opt_singleProcess = OFTrue;
@@ -103,131 +102,150 @@ WlmConsoleEngineFileSystem::WlmConsoleEngineFileSystem( int argc, char *argv[],
 
   cmd = new OFCommandLine();
 
-  cmd->setParamColumn(LONGCOL+SHORTCOL+4);
+  cmd->setParamColumn(LONGCOL + SHORTCOL + 4);
   cmd->addParam("port", "tcp/ip port number to listen on");
 
   cmd->setOptionColumns(LONGCOL, SHORTCOL);
-  cmd->addGroup("general options:", LONGCOL, SHORTCOL+2);
-    cmd->addOption("--help",                      "-h",        "print this help text and exit");
-    cmd->addOption("--version",                                "print version information and exit", OFTrue /* exclusive */);
-    cmd->addOption("--verbose",                   "-v",        "verbose mode, print processing details");
-    cmd->addOption("--debug",                     "-d",        "debug mode, print debug information");
-#ifdef HAVE_FORK
-    cmd->addOption("--single-process",            "-s",        "single process mode");
-#endif
-    cmd->addOption("--no-sq-expansion",           "-nse",        "disable expansion of empty sequences\nin C-FIND request messages");
-    OFString opt5 = "path to worklist data files\n(default: ";
-    opt5 += opt_dfPath;
-    opt5 += ")";
-    cmd->addOption("--data-files-path",           "-dfp",    1, "[p]ath: string", opt5.c_str() );
-    cmd->addOption("--enable-file-reject",        "-efr",       "enable rejection of incomplete worklist-files\n(default)");
-    cmd->addOption("--disable-file-reject",       "-dfr",       "disable rejection of incomplete worklist-files");
+  cmd->addGroup("general options:", LONGCOL, SHORTCOL + 2);
+    cmd->addOption("--help",                  "-h",      "print this help text and exit", OFCommandLine::AF_Exclusive);
+    cmd->addOption("--version",                          "print version information and exit", OFCommandLine::AF_Exclusive);
+    OFLog::addOptions(*cmd);
 
-  cmd->addGroup("returned character set options:", LONGCOL, SHORTCOL+2);
-    cmd->addOption("--return-no-char-set",        "-cs0",       "return no specific character set (default)");
-    cmd->addOption("--return-iso-ir-100",         "-cs1",       "return specific character set ISO IR 100");
+#if defined(HAVE_FORK) || defined(_WIN32)
+  cmd->addGroup("multi-process options:", LONGCOL, SHORTCOL + 2);
+    cmd->addOption("--single-process",        "-s",      "single process mode");
+    cmd->addOption("--fork",                             "fork child process for each association (def.)");
+#ifdef _WIN32
+    cmd->addOption("--forked-child",                     "process is forked child, internal use only", OFCommandLine::AF_Internal);
+#endif
+#endif
+
+  cmd->addGroup("input options:");
+    cmd->addSubGroup("general:");
+      OFString opt5 = "[p]ath: string (default: ";
+      opt5 += opt_dfPath;
+      opt5 += ")";
+      cmd->addOption("--data-files-path",     "-dfp", 1, opt5.c_str(), "path to worklist data files" );
+    cmd->addSubGroup("handling of worklist files:");
+      cmd->addOption("--enable-file-reject",  "-efr",    "enable rejection of incomplete worklist files\n(default)");
+      cmd->addOption("--disable-file-reject", "-dfr",    "disable rejection of incomplete worklist files");
+
+  cmd->addGroup("processing options:");
+    cmd->addSubGroup("returned character set:");
+      cmd->addOption("--return-no-char-set",  "-cs0",    "return no specific character set (default)");
+      cmd->addOption("--return-iso-ir-100",   "-cs1",    "return specific character set ISO IR 100");
+      cmd->addOption("--keep-char-set",       "-csk",    "return character set provided in file");
+    cmd->addSubGroup("other processing options:");
+      cmd->addOption("--no-sq-expansion",     "-nse",    "disable expansion of empty sequences in C-FIND\nrequest messages");
 
   cmd->addGroup("network options:");
     cmd->addSubGroup("preferred network transfer syntaxes:");
-      cmd->addOption("--prefer-uncompr",        "+x=",       "prefer explicit VR local byte order (default)");
-      cmd->addOption("--prefer-little",         "+xe",       "prefer explicit VR little endian TS");
-      cmd->addOption("--prefer-big",            "+xb",       "prefer explicit VR big endian TS");
-      cmd->addOption("--implicit",              "+xi",       "accept implicit VR little endian TS only");
+      cmd->addOption("--prefer-uncompr",      "+x=",     "prefer explicit VR local byte order (default)");
+      cmd->addOption("--prefer-little",       "+xe",     "prefer explicit VR little endian TS");
+      cmd->addOption("--prefer-big",          "+xb",     "prefer explicit VR big endian TS");
+      cmd->addOption("--implicit",            "+xi",     "accept implicit VR little endian TS only");
 
 #ifdef WITH_TCPWRAPPER
-    cmd->addSubGroup("network host access control (tcp wrapper) options:");
-      cmd->addOption("--access-full",            "-ac",       "accept connections from any host (default)");
-      cmd->addOption("--access-control",         "+ac",       "enforce host access control rules");
+    cmd->addSubGroup("network host access control (tcp wrapper):");
+      cmd->addOption("--access-full",         "-ac",     "accept connections from any host (default)");
+      cmd->addOption("--access-control",      "+ac",     "enforce host access control rules");
 #endif
 
+    cmd->addSubGroup("post-1993 value representations:");
+      cmd->addOption("--enable-new-vr",       "+u",      "enable support for new VRs (UN/UT) (default)");
+      cmd->addOption("--disable-new-vr",      "-u",      "disable support for new VRs, convert to OB");
+
     cmd->addSubGroup("other network options:");
-      cmd->addOption("--acse-timeout",           "-ta", 1, "[s]econds: integer (default: 30)", "timeout for ACSE messages");
-      cmd->addOption("--dimse-timeout",          "-td", 1, "[s]econds: integer (default: unlimited)", "timeout for DIMSE messages");
+      cmd->addOption("--acse-timeout",        "-ta",  1, "[s]econds: integer (default: 30)", "timeout for ACSE messages");
+      cmd->addOption("--dimse-timeout",       "-td",  1, "[s]econds: integer (default: unlimited)", "timeout for DIMSE messages");
 
       OFString opt6 = "[a]ssocs: integer (default: ";
-      sprintf(tempstr, "%ld", (long)opt_maxAssociations);
+      sprintf(tempstr, "%ld", OFstatic_cast(long, opt_maxAssociations));
       opt6 += tempstr;
       opt6 += ")";
-      cmd->addOption("--max-associations",                1, opt6.c_str(), "limit maximum number of parallel associations");
-      cmd->addOption("--refuse",                             "refuse association");
-      cmd->addOption("--reject",                             "reject association if no implement. class UID");
-      cmd->addOption("--no-fail",                            "don't fail on an invalid query");
-      cmd->addOption("--sleep-after",                     1, "[s]econds: integer", "sleep s seconds after find (default: 0)");
-      cmd->addOption("--sleep-during",                    1, "[s]econds: integer", "sleep s seconds during find (default: 0)");
+      cmd->addOption("--max-associations",            1, opt6.c_str(), "limit maximum number of parallel associations");
+      cmd->addOption("--refuse",                         "refuse association");
+      cmd->addOption("--reject",                         "reject association if no implement. class UID");
+      cmd->addOption("--no-fail",                        "don't fail on an invalid query");
+      cmd->addOption("--sleep-after",                 1, "[s]econds: integer", "sleep s seconds after find (default: 0)");
+      cmd->addOption("--sleep-during",                1, "[s]econds: integer", "sleep s seconds during find (default: 0)");
       OFString opt3 = "set max receive pdu to n bytes (default: ";
-      sprintf(tempstr, "%ld", (long)ASC_DEFAULTMAXPDU);
+      sprintf(tempstr, "%ld", OFstatic_cast(long, ASC_DEFAULTMAXPDU));
       opt3 += tempstr;
       opt3 += ")";
-      OFString opt4 = "[n]umber of bytes: integer [";
-      sprintf(tempstr, "%ld", (long)ASC_MINIMUMPDUSIZE);
+      OFString opt4 = "[n]umber of bytes: integer (";
+      sprintf(tempstr, "%ld", OFstatic_cast(long, ASC_MINIMUMPDUSIZE));
       opt4 += tempstr;
       opt4 += "..";
-      sprintf(tempstr, "%ld", (long)ASC_MAXIMUMPDUSIZE);
+      sprintf(tempstr, "%ld", OFstatic_cast(long, ASC_MAXIMUMPDUSIZE));
       opt4 += tempstr;
-      opt4 += "]";
-      cmd->addOption("--max-pdu",                "-pdu",   1,  opt4.c_str(), opt3.c_str());
-      cmd->addOption("--disable-host-lookup",    "-dhl",      "disable hostname lookup");
-    cmd->addSubGroup("group length encoding (when sending C-FIND response data):");
-      cmd->addOption("--group-length-recalc",    "+g=",       "recalculate group lengths if present (default)");
-      cmd->addOption("--group-length-create",    "+g",        "always write with group length elements");
-      cmd->addOption("--group-length-remove",    "-g",        "always write without group length elements");
-    cmd->addSubGroup("length encoding in sequences and items (when sending C-FIND response data):");
-      cmd->addOption("--length-explicit",        "+e",        "write with explicit lengths (default)");
-      cmd->addOption("--length-undefined",       "-e",        "write with undefined lengths");
-
-  cmd->addGroup("encoding options:");
-    cmd->addSubGroup("post-1993 value representations:");
-      cmd->addOption("--enable-new-vr",          "+u",        "enable support for new VRs (UN/UT) (default)");
-      cmd->addOption("--disable-new-vr",         "-u",        "disable support for new VRs, convert to OB");
+      opt4 += ")";
+      cmd->addOption("--max-pdu",             "-pdu", 1, opt4.c_str(), opt3.c_str());
+      cmd->addOption("--disable-host-lookup", "-dhl",    "disable hostname lookup");
 
   // Evaluate command line.
   prepareCmdLineArgs( argc, argv, applicationName );
-  if( app->parseCommandLine( *cmd, argc, argv, OFCommandLine::ExpandWildcards ) )
+  if( app->parseCommandLine( *cmd, argc, argv, OFCommandLine::PF_ExpandWildcards ) )
   {
     /* check exclusive options first */
-    if (cmd->getParamCount() == 0)
+    if (cmd->hasExclusiveOption())
     {
       if (cmd->findOption("--version"))
       {
-        app->printHeader(OFTrue /*print host identifier*/);          // uses ofConsole.lockCerr()
-        CERR << endl << "External libraries used:";
-#ifdef WITH_ZLIB
-        CERR << endl << "- ZLIB, Version " << zlibVersion() << endl;
+        app->printHeader(OFTrue /*print host identifier*/);
+        ofConsole.lockCout() << OFendl << "External libraries used:";
+#if !defined(WITH_ZLIB) && !defined(WITH_TCPWRAPPER)
+        ofConsole.getCout() << " none" << OFendl;
 #else
-        CERR << " none" << endl;
+        ofConsole.getCout() << OFendl;
 #endif
+#ifdef WITH_ZLIB
+        ofConsole.getCout() << "- ZLIB, Version " << zlibVersion() << OFendl;
+#endif
+#ifdef WITH_TCPWRAPPER
+        ofConsole.getCout() << "- LIBWRAP" << OFendl;
+#endif
+        ofConsole.unlockCout();
         exit(0);
       }
     }
     /* command line parameters and options */
     app->checkParam(cmd->getParamAndCheckMinMax(1, opt_port, 1, 65535));
-    if( cmd->findOption("--verbose") ) opt_verbose = OFTrue;
-    if( cmd->findOption("--debug") )
-    {
-      opt_debug = OFTrue;
-      DUL_Debug(OFTrue);
-      DIMSE_debug(OFTrue);
-      SetDebugLevel(3);
-    }
-#ifdef HAVE_FORK
-    if( cmd->findOption("--single-process") ) opt_singleProcess = OFTrue;
+
+    OFLog::configureFromCommandLine(*cmd, *app);
+
+#if defined(HAVE_FORK) || defined(_WIN32)
+    cmd->beginOptionBlock();
+    if (cmd->findOption("--single-process")) opt_singleProcess = OFTrue;
+    if (cmd->findOption("--fork")) opt_singleProcess = OFFalse;
+    cmd->endOptionBlock();
+#ifdef _WIN32
+    if (cmd->findOption("--forked-child")) opt_forkedChild = OFTrue;
 #endif
-    if( cmd->findOption("--no-sq-expansion") ) opt_noSequenceExpansion = OFTrue;
+#endif
+
     if( cmd->findOption("--data-files-path") ) app->checkValue(cmd->getValue(opt_dfPath));
+
     cmd->beginOptionBlock();
-    if( cmd->findOption("--enable-file-reject") )  opt_enableRejectionOfIncompleteWlFiles = OFTrue;
-    if( cmd->findOption("--disable-file-reject") )  opt_enableRejectionOfIncompleteWlFiles = OFFalse;
+    if( cmd->findOption("--enable-file-reject") ) opt_enableRejectionOfIncompleteWlFiles = OFTrue;
+    if( cmd->findOption("--disable-file-reject") ) opt_enableRejectionOfIncompleteWlFiles = OFFalse;
     cmd->endOptionBlock();
+
     cmd->beginOptionBlock();
-    if( cmd->findOption("--return-no-char-set") )  opt_returnedCharacterSet = RETURN_NO_CHARACTER_SET;
-    if( cmd->findOption("--return-iso-ir-100") )  opt_returnedCharacterSet = RETURN_CHARACTER_SET_ISO_IR_100;
+    if( cmd->findOption("--return-no-char-set") ) opt_returnedCharacterSet = RETURN_NO_CHARACTER_SET;
+    if( cmd->findOption("--return-iso-ir-100") ) opt_returnedCharacterSet = RETURN_CHARACTER_SET_ISO_IR_100;
+    if( cmd->findOption("--keep-char-set") ) opt_returnedCharacterSet = RETURN_CHARACTER_SET_FROM_FILE;
     cmd->endOptionBlock();
+
+    if( cmd->findOption("--no-sq-expansion") ) opt_noSequenceExpansion = OFTrue;
+
     cmd->beginOptionBlock();
-    if( cmd->findOption("--prefer-uncompr") )  opt_networkTransferSyntax = EXS_Unknown;
-    if( cmd->findOption("--prefer-little") )   opt_networkTransferSyntax = EXS_LittleEndianExplicit;
-    if( cmd->findOption("--prefer-big") )      opt_networkTransferSyntax = EXS_BigEndianExplicit;
-    if( cmd->findOption("--implicit") )        opt_networkTransferSyntax = EXS_LittleEndianImplicit;
+    if( cmd->findOption("--prefer-uncompr") ) opt_networkTransferSyntax = EXS_Unknown;
+    if( cmd->findOption("--prefer-little") ) opt_networkTransferSyntax = EXS_LittleEndianExplicit;
+    if( cmd->findOption("--prefer-big") ) opt_networkTransferSyntax = EXS_BigEndianExplicit;
+    if( cmd->findOption("--implicit") ) opt_networkTransferSyntax = EXS_LittleEndianImplicit;
     cmd->endOptionBlock();
+
 #ifdef WITH_TCPWRAPPER
     cmd->beginOptionBlock();
     if (cmd->findOption("--access-full")) dcmTCPWrapperDaemonName.set(NULL);
@@ -235,6 +253,19 @@ WlmConsoleEngineFileSystem::WlmConsoleEngineFileSystem( int argc, char *argv[],
     cmd->endOptionBlock();
 #endif
 
+    cmd->beginOptionBlock();
+    if( cmd->findOption("--enable-new-vr") )
+    {
+      dcmEnableUnknownVRGeneration.set(OFTrue);
+      dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
+    }
+    if( cmd->findOption("--disable-new-vr") )
+    {
+      dcmEnableUnknownVRGeneration.set(OFFalse);
+      dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
+    }
+    cmd->endOptionBlock();
+
     if (cmd->findOption("--acse-timeout"))
     {
       OFCmdSignedInt opt_timeout = 0;
@@ -250,7 +281,7 @@ WlmConsoleEngineFileSystem::WlmConsoleEngineFileSystem( int argc, char *argv[],
       opt_blockMode = DIMSE_NONBLOCKING;
     }
 
-    if( cmd->findOption("--max-associations") ) 
+    if( cmd->findOption("--max-associations") )
     {
         OFCmdSignedInt maxAssoc = 1;
         app->checkValue(cmd->getValueAndCheckMin(maxAssoc, 1));
@@ -263,28 +294,16 @@ WlmConsoleEngineFileSystem::WlmConsoleEngineFileSystem( int argc, char *argv[],
     if( cmd->findOption("--sleep-during") ) app->checkValue(cmd->getValueAndCheckMin(opt_sleepDuringFind, 0));
     if( cmd->findOption("--max-pdu") ) app->checkValue(cmd->getValueAndCheckMinMax(opt_maxPDU, ASC_MINIMUMPDUSIZE, ASC_MAXIMUMPDUSIZE));
     if( cmd->findOption("--disable-host-lookup") ) dcmDisableGethostbyaddr.set(OFTrue);
-    cmd->beginOptionBlock();
-    if( cmd->findOption("--enable-new-vr") )
-    {
-      dcmEnableUnknownVRGeneration.set(OFTrue);
-      dcmEnableUnlimitedTextVRGeneration.set(OFTrue);
-    }
-    if( cmd->findOption("--disable-new-vr") )
-    {
-      dcmEnableUnknownVRGeneration.set(OFFalse);
-      dcmEnableUnlimitedTextVRGeneration.set(OFFalse);
-    }
-    cmd->endOptionBlock();
   }
 
   // dump application information
-  DumpMessage( rcsid );
-  DumpMessage( "" );
+  if (!opt_forkedChild)
+  {
+    /* print resource identifier */
+    OFLOG_DEBUG(wlmscpfsLogger, rcsid << OFendl);
+  }
 
   // set general parameters in data source object
-  dataSource->SetLogStream( &ofConsole );
-  dataSource->SetVerbose( opt_verbose );
-  dataSource->SetDebug( opt_debug );
   dataSource->SetNoSequenceExpansion( opt_noSequenceExpansion );
   dataSource->SetReturnedCharacterSet( opt_returnedCharacterSet );
 
@@ -324,28 +343,28 @@ int WlmConsoleEngineFileSystem::StartProvidingService()
   if( cond.bad() )
   {
     // in case something unexpected happened, dump a corresponding message
-    DumpMessage( cond.text() );
+    OFLOG_ERROR(wlmscpfsLogger, cond.text());
 
     // return error
     return( 1 );
   }
 
   // start providing the basic worklist management service
-  WlmActivityManager *activityManager = new WlmActivityManager( 
+  WlmActivityManager *activityManager = new WlmActivityManager(
       dataSource, opt_port,
       opt_refuseAssociation,
       opt_rejectWithoutImplementationUID,
       opt_sleepAfterFind, opt_sleepDuringFind,
       opt_maxPDU, opt_networkTransferSyntax,
-      opt_verbose, opt_debug, opt_failInvalidQuery,
+      opt_failInvalidQuery,
       opt_singleProcess, opt_maxAssociations,
       opt_blockMode, opt_dimse_timeout, opt_acse_timeout,
-      &ofConsole );
+      opt_forkedChild, command_argc, command_argv );
   cond = activityManager->StartProvidingService();
   if( cond.bad() )
   {
     // in case something unexpected happened, dump a corresponding message
-    DumpMessage( cond.text() );
+    OFLOG_ERROR(wlmscpfsLogger, cond.text());
 
     // disconnect from data source
     dataSource->DisconnectFromDataSource();
@@ -365,7 +384,7 @@ int WlmConsoleEngineFileSystem::StartProvidingService()
   if( cond.bad() )
   {
     // in case something unexpected happened, dump a corresponding message
-    DumpMessage( cond.text() );
+    OFLOG_ERROR(wlmscpfsLogger, cond.text());
 
     // return error
     return( 1 );
@@ -377,27 +396,75 @@ int WlmConsoleEngineFileSystem::StartProvidingService()
 
 // ----------------------------------------------------------------------------
 
-void WlmConsoleEngineFileSystem::DumpMessage( const char *message )
-// Date         : August 6, 2002
-// Author       : Thomas Wilkens
-// Task         : This function dumps the given (runtime) information on the out stream.
-//                Used for dumping information in normal, debug and verbose mode.
-// Parameters   : message - [in] The message to dump.
-// Return Value : none.
-{
-  if( message != NULL )
-  {
-    ofConsole.lockCout();
-    ofConsole.getCout() << message << endl;
-    ofConsole.unlockCout();
-  }
-}
-
-// ----------------------------------------------------------------------------
-
 /*
 ** CVS Log
 ** $Log: wlcefs.cc,v $
+** Revision 1.29  2010-11-01 13:37:32  uli
+** Fixed some compiler warnings reported by gcc with additional flags.
+**
+** Revision 1.28  2010-10-14 13:13:53  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.27  2010-05-28 13:23:16  joergr
+** Changed logger name from "dcmtk.apps.wlcefs" to "dcmtk.apps.wlmscpfs".
+**
+** Revision 1.26  2009-11-24 10:40:01  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.25  2009-11-18 12:17:30  uli
+** Fix compiler errors due to removal of DUL_Debug() and DIMSE_Debug().
+**
+** Revision 1.24  2009-04-21 14:14:05  joergr
+** Fixed minor inconsistencies in manpage / syntax usage.
+**
+** Revision 1.23  2009-04-17 11:54:13  joergr
+** Added new command line option --fork in order to explicitly indicate what
+** the default behavior is (multi-processing).
+**
+** Revision 1.22  2009-03-02 17:14:38  joergr
+** Restructured command line options (be more consistent with other tools).
+**
+** Revision 1.21  2009-01-07 17:20:21  joergr
+** Avoid double output of resource identifier for forked children (Win32).
+**
+** Revision 1.20  2008-09-26 12:05:17  joergr
+** Changed the way exclusive command line options are checked.
+**
+** Revision 1.19  2008-09-25 15:16:17  joergr
+** Added support for printing the expanded command line arguments.
+**
+** Revision 1.18  2007/08/10 14:25:20  meichel
+** Added new command line option --keep-char-set that returns
+**   any specific character set as encoded in the worklist file.
+**
+** Revision 1.17  2006/12/15 14:44:09  onken
+** Changed member variable from char* to OFString and reintegrated correct
+** intending of command line options, that were lost in of of last revisions.
+** Removed (unchecked) command line options for group / sequence length
+** calculations.
+**
+** Revision 1.16  2006/08/16 13:14:35  onken
+** Hid (internal) "--forked-child" option from user
+**
+** Revision 1.15  2006/08/15 16:15:47  meichel
+** Updated the code in module dcmwlm to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.14  2006/08/15 11:32:06  onken
+** Added WIN32 multiprocess mode capabilities to wlmscpfs
+**
+** Revision 1.13  2006/08/14 15:30:40  onken
+** Added WIN32 multiprocess mode to wlmscpfs.
+**
+** Revision 1.12  2006/07/27 14:53:49  joergr
+** Changed parameter "exclusive" of method addOption() from type OFBool into an
+** integer parameter "flags". Prepended prefix "PF_" to parseLine() flags.
+** Option "--help" is no longer an exclusive option by default.
+** Added optional library "LIBWRAP" to output of option "--version".
+**
+** Revision 1.11  2006/02/23 12:50:30  joergr
+** Fixed layout and formatting issues.
+**
 ** Revision 1.10  2005/12/08 15:48:30  meichel
 ** Changed include path schema for all DCMTK header files
 **
