@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmwlm
  *
@@ -22,10 +18,9 @@
  *  Purpose: Class representing a console engine for basic worklist
  *           management service class providers based on the file system.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:46:50 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmwlm/apps/wlcefs.h,v $
- *  CVS/RCS Revision: $Revision: 1.7 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:20:01 $
+ *  CVS/RCS Revision: $Revision: 1.11 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -53,7 +48,7 @@ class WlmConsoleEngineFileSystem
     /// returned character set type
     WlmReturnedCharacterSetType opt_returnedCharacterSet;
     /// path to database files
-    const char *opt_dfPath;
+    OFString opt_dfPath;
     /// port on which this application is listening
     OFCmdUnsignedInt opt_port;
     /// indicates if incoming associations shall be refused or not
@@ -68,14 +63,12 @@ class WlmConsoleEngineFileSystem
     OFCmdUnsignedInt opt_maxPDU;
     /// preferred network transfer syntax
     E_TransferSyntax opt_networkTransferSyntax;
-    /// indicates if this application is run in verbose mode
-    OFBool opt_verbose;
-    /// indicates if this application is run in debug mode
-    OFBool opt_debug;
     /// indicates if find shall fail on an invalid query or not
     OFBool opt_failInvalidQuery;
     /// indicates if this application is run in single process mode or not
     OFBool opt_singleProcess;
+    /// indicates if this process is called as a child process, used by dcmnet
+    OFBool opt_forkedChild;
     /// indicates how many associations can be accepted at the same time
     int opt_maxAssociations;
     /// indicates if an expansion of empty sequences in C-Find RQ messages shall take place or not
@@ -92,15 +85,13 @@ class WlmConsoleEngineFileSystem
     OFConsoleApplication *app;
     /// instance of command line class (for handling command line arguments)
     OFCommandLine *cmd;
+    /// number of command line arguments, needed for multiprocess mode on WIN32
+    int command_argc;
+    /// complete command line, needed for mulitprocess mode on WIN32
+    char **command_argv;
     /// data source which shall be queried on incoming C-Find RQ messages
     WlmDataSource *dataSource;
 
-      /** This function dumps the given information on a stream.
-       *  Used for dumping information in normal, debug and verbose mode.
-       *  @param message The message to dump.
-       */
-    void DumpMessage( const char *message );
-
       /** Protected undefined copy-constructor. Shall never be called.
        *  @param Src Source object.
        */
@@ -112,7 +103,6 @@ class WlmConsoleEngineFileSystem
        */
     WlmConsoleEngineFileSystem &operator=( const WlmConsoleEngineFileSystem &Src );
 
-
   public:
       /** constructor.
        *  @param argc            Number of arguments that were passed to main.
