@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmwlm
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: Class for connecting to a file-based data source.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:33 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmwlm/libsrc/wldsfs.cc,v $
- *  CVS/RCS Revision: $Revision: 1.19 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:49 $
+ *  CVS/RCS Revision: $Revision: 1.27 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -62,10 +57,9 @@ WlmDataSourceFileSystem::WlmDataSourceFileSystem()
 // Task         : Constructor.
 // Parameters   : none.
 // Return Value : none.
-  : fileSystemInteractionManager( NULL ), dfPath( NULL ), enableRejectionOfIncompleteWlFiles( OFTrue ),
+  : fileSystemInteractionManager( ), dfPath( "" ), enableRejectionOfIncompleteWlFiles( OFTrue ),
     handleToReadLockFile( 0 )
 {
-  fileSystemInteractionManager = new WlmFileSystemInteractionManager();
 }
 
 // ----------------------------------------------------------------------------
@@ -80,9 +74,6 @@ WlmDataSourceFileSystem::~WlmDataSourceFileSystem()
   // release read lock on data source if it is set
   if( readLockSetOnDataSource ) ReleaseReadlock();
 
-  //free memory
-  delete fileSystemInteractionManager;
-  if( dfPath != NULL ) delete dfPath;
 }
 
 // ----------------------------------------------------------------------------
@@ -95,13 +86,10 @@ OFCondition WlmDataSourceFileSystem::ConnectToDataSource()
 // Return Value : Indicates if the connection was established succesfully.
 {
   // set variables in fileSystemInteractionManager object
-  fileSystemInteractionManager->SetLogStream( logStream );
-  fileSystemInteractionManager->SetVerbose( verbose );
-  fileSystemInteractionManager->SetDebug( debug );
-  fileSystemInteractionManager->SetEnableRejectionOfIncompleteWlFiles( enableRejectionOfIncompleteWlFiles );
+  fileSystemInteractionManager.SetEnableRejectionOfIncompleteWlFiles( enableRejectionOfIncompleteWlFiles );
 
   // connect to file system
-  OFCondition cond = fileSystemInteractionManager->ConnectToFileSystem( dfPath );
+  OFCondition cond = fileSystemInteractionManager.ConnectToFileSystem( dfPath );
 
   // return result
   return( cond );
@@ -117,7 +105,7 @@ OFCondition WlmDataSourceFileSystem::DisconnectFromDataSource()
 // Return Value : Indicates if the disconnection was completed succesfully.
 {
   // disconnect from file system
-  OFCondition cond = fileSystemInteractionManager->DisconnectFromFileSystem();
+  OFCondition cond = fileSystemInteractionManager.DisconnectFromFileSystem();
 
   // return result
   return( cond );
@@ -125,19 +113,14 @@ OFCondition WlmDataSourceFileSystem::DisconnectFromDataSource()
 
 // ----------------------------------------------------------------------------
 
-void WlmDataSourceFileSystem::SetDfPath( const char *value )
+void WlmDataSourceFileSystem::SetDfPath( const OFString& value )
 // Date         : March 14, 2002
 // Author       : Thomas Wilkens
 // Task         : Set member variable.
 // Parameters   : value - Value for member variable.
 // Return Value : none.
 {
-  if( value != NULL )
-  {
-    if( dfPath != NULL ) delete dfPath;
-    dfPath = new char[ strlen(value) + 1 ];
-    strcpy( dfPath, value );
-  }
+  dfPath = value;
 }
 
 // ----------------------------------------------------------------------------
@@ -166,10 +149,10 @@ OFBool WlmDataSourceFileSystem::IsCalledApplicationEntityTitleSupported()
 //                OFFalse - The called application entity title is not supported or it is not given.
 {
   // Check if calledApplicationEntityTitle does not have a valid value
-  if( calledApplicationEntityTitle == NULL )
+  if( calledApplicationEntityTitle.length() == 0 )
     return( OFFalse );
   else
-    return( fileSystemInteractionManager->IsCalledApplicationEntityTitleSupported( calledApplicationEntityTitle ) );
+    return( fileSystemInteractionManager.IsCalledApplicationEntityTitleSupported( calledApplicationEntityTitle ) );
 }
 
 // ----------------------------------------------------------------------------
@@ -262,7 +245,7 @@ void WlmDataSourceFileSystem::HandleExistentButEmptyReferencedStudyOrPatientSequ
 
 // ----------------------------------------------------------------------------
 
-WlmDataSourceStatusType WlmDataSourceFileSystem::StartFindRequest( DcmDataset &findRequestIdentifiers )
+WlmDataSourceStatusType WlmDataSourceFileSystem::StartFindRequest( const DcmDataset &findRequestIdentifiers )
 // Date         : July 11, 2002
 // Author       : Thomas Wilkens
 // Task         : Based on the search mask which was passed, this function determines all the records in the
@@ -280,7 +263,6 @@ WlmDataSourceStatusType WlmDataSourceFileSystem::StartFindRequest( DcmDataset &f
 //                WLM_FAILED_IDENTIFIER_DOES_NOT_MATCH_SOP_CLASS - Error in the search mask encountered.
 {
   unsigned long i, j;
-  char msg[200];
   DcmElement *scheduledProcedureStepSequenceAttribute = NULL;
 
   // Initialize offending elements, error elements and error comment.
@@ -299,16 +281,13 @@ WlmDataSourceStatusType WlmDataSourceFileSystem::StartFindRequest( DcmDataset &f
   // Remove group length and padding elements from the search mask.
   identifiers->computeGroupLengthAndPadding( EGL_withoutGL, EPD_withoutPadding );
 
-  // Actually there should be no elements in array matchingDatasets. But just to make sure,
-  // remove all elements in the array and the array itself, if the array is not NULL; note
-  // that this variable will in the end contain all records (datasets) that match the search mask.
-  if( matchingDatasets != NULL )
+  // Actually there should be no elements in array matchingDatasets. Delete them to be sure.
+  // matchingDatasets will in the end contain all records (datasets) that match the search mask.
+  while ( !matchingDatasets.empty() )
   {
-    for( i=0 ; i<numOfMatchingDatasets ; i++ )
-      delete matchingDatasets[i];
-    delete[] matchingDatasets;
-    matchingDatasets = NULL;
-    numOfMatchingDatasets = 0;
+    DcmDataset *dset = matchingDatasets.front();
+    delete dset; dset = NULL;
+    matchingDatasets.pop_front();
   }
 
   // This member variable indicates if we encountered an unsupported
@@ -326,32 +305,22 @@ WlmDataSourceStatusType WlmDataSourceFileSystem::StartFindRequest( DcmDataset &f
   }
 
   // dump search mask (it might have been expanded)
-  if( verbose && logStream != NULL )
-  {
-    logStream->lockCout();
-    logStream->getCout() << "Expanded Find SCP Request Identifiers:" << endl;
-    identifiers->print( logStream->getCout() );
-    logStream->getCout() << "=============================" << endl;
-    logStream->unlockCout();
-  }
+  DCMWLM_INFO("Expanded Find SCP Request Identifiers:" << OFendl
+    << DcmObject::PrintHelper(*identifiers) << OFendl
+    << "=============================");
 
   // Set a read lock on the worklist files which shall be read from.
   if( !SetReadlock() )
     return( WLM_REFUSED_OUT_OF_RESOURCES );
 
   // dump some information if required
-  if( verbose )
-    DumpMessage( "Determining matching records from worklist files." );
+  DCMWLM_INFO("Determining matching records from worklist files");
 
   // Determine records from worklist files which match the search mask
-  unsigned long numOfMatchingRecords = fileSystemInteractionManager->DetermineMatchingRecords( identifiers );
+  unsigned long numOfMatchingRecords = fileSystemInteractionManager.DetermineMatchingRecords( identifiers );
 
   // dump some information if required
-  if( verbose )
-  {
-    sprintf( msg, "Matching results: %lu matching records found in worklist files.", numOfMatchingRecords );
-    DumpMessage( msg );
-  }
+  DCMWLM_INFO("Matching results: " << numOfMatchingRecords << " matching records found in worklist files");
 
   // determine a correct return value. In case no matching records
   // were found, WLM_SUCCESS shall be returned. This is our assumption.
@@ -361,96 +330,76 @@ WlmDataSourceStatusType WlmDataSourceFileSystem::StartFindRequest( DcmDataset &f
   // If that is the case, do the following:
   if( numOfMatchingRecords != 0 )
   {
-    // create a container array that captures all result DcmDatasets
-    numOfMatchingDatasets = numOfMatchingRecords;
-    matchingDatasets = new DcmDataset*[ numOfMatchingDatasets ];
-
     // for each matching record do the following
     for( i=0 ; i<numOfMatchingRecords ; i++ )
     {
-      // this variable is needed later, it must be initialized with NULL
-      DcmElement *specificCharacterSetElement = NULL;
+      // For every matching record ID, add one result dataset to result list and
+      // initialize it with search mask
+      DcmDataset *resultRecord = new DcmDataset(*identifiers);
+      matchingDatasets.push_back(resultRecord);
 
       // dump some information if required
-      if( verbose )
-      {
-        sprintf( msg, "  Processing matching result no. %lu.", i );
-        DumpMessage( msg );
-      }
-
-      // copy the search mask into matchingDatasets[i]
-      matchingDatasets[i] = new DcmDataset( *identifiers );
+      DCMWLM_INFO("  Processing matching result no. " << i);
 
       // Determine the number of elements in matchingDatasets[i].
-      unsigned long numOfElementsInDataset = matchingDatasets[i]->card();
+      unsigned long numOfElementsInDataset = resultRecord->card();
 
       // Go through all the elements in matchingDatasets[i].
       for( j=0 ; j < numOfElementsInDataset ; j++ )
       {
         // Determine the current element.
-        DcmElement *element = matchingDatasets[i]->getElement(j);
+        DcmElement *element = resultRecord->getElement(j);
 
         // Depending on if the current element is a sequence or not, process this element.
         if( element->ident() != EVR_SQ )
           HandleNonSequenceElementInResultDataset( element, i );
         else
           HandleSequenceElementInResultDataset( element, i );
-
-        // in case the current element is the "Specific Character Set" attribute, remember this element for later
-        if( element->getTag().getXTag() == DCM_SpecificCharacterSet )
-          specificCharacterSetElement = element;
-      }
-
-      // after having created the entire returned data set, deal with the "Specific Character Set" attribute.
-      // If it shall not be contained in the returned data set
-      if( returnedCharacterSet == RETURN_NO_CHARACTER_SET )
-      {
-        // and it is already included, delete it
-        if( specificCharacterSetElement != NULL )
-        {
-          DcmElement *elem = matchingDatasets[i]->remove( specificCharacterSetElement );
-          delete elem;
-        }
-      }
-      else
-      {
-        // if it shall be contained in the returned data set, check if it is not already included
-        if( specificCharacterSetElement == NULL )
-        {
-          // if it is not included in the returned dataset, create a new element and insert it
-          specificCharacterSetElement = new DcmCodeString( DcmTag( DCM_SpecificCharacterSet ) );
-          if( matchingDatasets[i]->insert( specificCharacterSetElement ) != EC_Normal )
-          {
-            delete specificCharacterSetElement;
-            specificCharacterSetElement = NULL;
-            DumpMessage( "WlmDataSourceDatabase::StartFindRequest: Could not insert specific character set element into dataset.\n" );
-          }
-        }
-        // and set the value of the attribute accordingly
-        if( specificCharacterSetElement != NULL )
-        {
-          if( returnedCharacterSet == RETURN_CHARACTER_SET_ISO_IR_100 )
-          {
-            OFCondition cond = specificCharacterSetElement->putString( "ISO_IR 100" );
-            if( cond.bad() )
-              DumpMessage( "WlmDataSourceDatabase::StartFindRequest: Could not set value in result element.\n" );
-          }
-        }
       }
 
       // if the ScheduledProcedureStepSequence can be found in the current dataset, handle
       // existent but empty ScheduledProcedureStepDescription and ScheduledProtocolCodeSequence
-      if( matchingDatasets[i]->findAndGetElement( DCM_ScheduledProcedureStepSequence, scheduledProcedureStepSequenceAttribute, OFFalse ).good() )
+      if( resultRecord->findAndGetElement( DCM_ScheduledProcedureStepSequence, scheduledProcedureStepSequenceAttribute, OFFalse ).good() )
         HandleExistentButEmptyDescriptionAndCodeSequenceAttributes( ((DcmDataset*)((DcmSequenceOfItems*)scheduledProcedureStepSequenceAttribute)->getItem(0)), DCM_ScheduledProcedureStepDescription, DCM_ScheduledProtocolCodeSequence );
 
       // handle existent but empty RequestedProcedureDescription and RequestedProcedureCodeSequence
-      HandleExistentButEmptyDescriptionAndCodeSequenceAttributes( matchingDatasets[i], DCM_RequestedProcedureDescription, DCM_RequestedProcedureCodeSequence );
+      HandleExistentButEmptyDescriptionAndCodeSequenceAttributes( resultRecord, DCM_RequestedProcedureDescription, DCM_RequestedProcedureCodeSequence );
 
       // handle existent but empty ReferencedStudySequence
-      HandleExistentButEmptyReferencedStudyOrPatientSequenceAttributes( matchingDatasets[i], DCM_ReferencedStudySequence );
+      HandleExistentButEmptyReferencedStudyOrPatientSequenceAttributes( resultRecord, DCM_ReferencedStudySequence );
 
       // handle existent but empty ReferencedPatientSequence
-      HandleExistentButEmptyReferencedStudyOrPatientSequenceAttributes( matchingDatasets[i], DCM_ReferencedPatientSequence );
+      HandleExistentButEmptyReferencedStudyOrPatientSequenceAttributes( resultRecord, DCM_ReferencedPatientSequence );
+
+      // after having created the entire returned data set, deal with the "Specific Character Set" attribute.
+      // first option: remove character set element from result dataset
+      if( returnedCharacterSet == RETURN_NO_CHARACTER_SET )
+      {
+        // nothing to do since it was already removed from the search mask
+        // resultRecord->findAndDeleteElement( DCM_SpecificCharacterSet );
+      }
+      // check whether extended characters maybe used in the result dataset
+      else if ( resultRecord->isAffectedBySpecificCharacterSet() )
+      {
+        OFCondition cond = EC_Normal;
+        // second option: specify ISO 8859-1 (Latin-1) character set
+        if( returnedCharacterSet == RETURN_CHARACTER_SET_ISO_IR_100 )
+        {
+          cond = resultRecord->putAndInsertString( DCM_SpecificCharacterSet, "ISO_IR 100" );
+        }
+        // third option: use charactet set from worklist file
+        else if( returnedCharacterSet == RETURN_CHARACTER_SET_FROM_FILE )
+        {
+          char *value = NULL;
+          fileSystemInteractionManager.GetAttributeValueForMatchingRecord( DCM_SpecificCharacterSet, NULL, 0, i, value );
+          if( (value != NULL) && (strlen(value) > 0) )
+          {
+            cond = resultRecord->putAndInsertString( DCM_SpecificCharacterSet, value );
+          }
+        }
+        if( cond.bad() )
+          DCMWLM_WARN("Could not set value of attribute SpecificCharacterSet in result dataset");
+      }
     }
 
     // Determine a corresponding return value: If matching records were found, WLM_PENDING or
@@ -463,7 +412,7 @@ WlmDataSourceStatusType WlmDataSourceFileSystem::StartFindRequest( DcmDataset &f
   }
 
   // forget the matching records in the fileSystemInteractionManager (free memory)
-  fileSystemInteractionManager->ClearMatchingRecords();
+  fileSystemInteractionManager.ClearMatchingRecords();
 
   // Now all the resulting data sets are contained in the member array matchingDatasets.
   // The variable numOfMatchingDatasets specifies the number of array fields.
@@ -493,7 +442,7 @@ DcmDataset *WlmDataSourceFileSystem::NextFindResponse( WlmDataSourceStatusType &
   DcmDataset *resultDataset = NULL;
 
   // If there are no more datasets that can be returned, do the following
-  if( numOfMatchingDatasets == 0 )
+  if( matchingDatasets.empty() )
   {
     // Set the return status to WLM_SUCCESS and return an empty dataset.
     rStatus = WLM_SUCCESS;
@@ -501,21 +450,11 @@ DcmDataset *WlmDataSourceFileSystem::NextFindResponse( WlmDataSourceStatusType &
   }
   else
   {
-    // We want to return the last array element.
-    resultDataset = matchingDatasets[ numOfMatchingDatasets - 1 ];
+    // We want to return the last array element and forget the pointer to this dataset here
+    resultDataset = matchingDatasets.back();
+    matchingDatasets.pop_back();
 
-    // Forget the pointer to this dataset here.
-    matchingDatasets[ numOfMatchingDatasets - 1 ] = NULL;
-    numOfMatchingDatasets--;
-
-    // If there are no more elements to return, delete the array itself.
-    if( numOfMatchingDatasets == 0 )
-    {
-      delete[] matchingDatasets;
-      matchingDatasets = NULL;
-    }
-
-    // Determine a return status.
+     // Determine a return status.
     if( foundUnsupportedOptionalKey )
       rStatus = WLM_PENDING_WARNING;
     else
@@ -547,15 +486,14 @@ void WlmDataSourceFileSystem::HandleNonSequenceElementInResultDataset( DcmElemen
   DcmTagKey tag( element->getTag().getXTag() );
 
   // check if the current element is the "Specific Character Set" (0008,0005) attribute;
-  // we do not want to deal with this attribute here, this attribute will be taken care
-  // of when the entire result dataset is completed.
+  // we do not want to deal with this attribute here.
   if( tag != DCM_SpecificCharacterSet )
   {
     // in case the current element is not the "Specific Character Set" (0008,0005) attribute,
     // get a value for the current element from database; note that all values for return key
     // attributes are returned as strings by GetAttributeValueForMatchingRecord().
     char *value = NULL;
-    fileSystemInteractionManager->GetAttributeValueForMatchingRecord( tag, superiorSequenceArray, numOfSuperiorSequences, idx, value );
+    fileSystemInteractionManager.GetAttributeValueForMatchingRecord( tag, superiorSequenceArray, numOfSuperiorSequences, idx, value );
 
     // put value in element
     // (note that there is currently one attribute (DCM_PregnancyStatus) for which the value must not
@@ -570,7 +508,7 @@ void WlmDataSourceFileSystem::HandleNonSequenceElementInResultDataset( DcmElemen
     else
       cond = element->putString( value );
     if( cond.bad() )
-      DumpMessage( "WlmDataSourceFileSystem::HandleNonSequenceElementInResultDataset: Could not set value in result element.\n" );
+      DCMWLM_WARN("WlmDataSourceFileSystem::HandleNonSequenceElementInResultDataset: Could not set value in result element");
 
     // free memory
     delete[] value;
@@ -604,7 +542,8 @@ void WlmDataSourceFileSystem::HandleSequenceElementInResultDataset( DcmElement *
   if( sequenceOfItemsElement->card() != 1 )
   {
     // if the sequence's cardinality does not equal 1, we want to dump a warning and do nothing here
-    DumpMessage( "    - Sequence with not exactly one item encountered in the search mask.\n      The corresponding sequence of the currently processed result data set will show the exact same structure as in the given search mask." );
+    DCMWLM_WARN( "    - Sequence with not exactly one item encountered in the search mask" << OFendl
+      << "      The corresponding sequence of the currently processed result data set will show the exact same structure as in the given search mask" );
   }
   else
   {
@@ -615,7 +554,7 @@ void WlmDataSourceFileSystem::HandleSequenceElementInResultDataset( DcmElement *
     DcmTagKey sequenceTag( sequenceOfItemsElement->getTag().getXTag() );
 
     // determine how many items this sequence has in the matching record in the data source
-    numOfItemsInResultSequence = fileSystemInteractionManager->GetNumberOfSequenceItemsForMatchingRecord( sequenceTag, superiorSequenceArray, numOfSuperiorSequences, idx );
+    numOfItemsInResultSequence = fileSystemInteractionManager.GetNumberOfSequenceItemsForMatchingRecord( sequenceTag, superiorSequenceArray, numOfSuperiorSequences, idx );
 
     // remember all relevant information about this and all
     // superior sequence elements in superiorSequenceArray
@@ -708,23 +647,22 @@ OFBool WlmDataSourceFileSystem::SetReadlock()
 // Return Value : OFTrue - The read lock has been set successfully.
 //                OFFalse - The read lock has not been set successfully.
 {
-  char msg[2500];
 #ifndef _WIN32
   struct flock lockdata;
 #endif
   int result;
 
   // if no path or no calledApplicationEntityTitle is specified, return
-  if( dfPath == NULL || calledApplicationEntityTitle == NULL )
+  if( dfPath.length() == 0 || calledApplicationEntityTitle.length() == 0 )
   {
-    DumpMessage("WlmDataSourceFileSystem::SetReadlock : Path to data source files not specified.");
+    DCMWLM_ERROR("WlmDataSourceFileSystem::SetReadlock: Path to data source files not specified");
     return OFFalse;
   }
 
   // if a read lock has already been set, return
   if( readLockSetOnDataSource )
   {
-    DumpMessage("WlmDataSourceFileSystem::SetReadlock : Nested read locks not allowed!");
+    DCMWLM_ERROR("WlmDataSourceFileSystem::SetReadlock: Nested read locks not allowed!");
     return OFFalse;
   }
 
@@ -745,9 +683,10 @@ OFBool WlmDataSourceFileSystem::SetReadlock()
   handleToReadLockFile = open( lockname.c_str(), O_RDWR );
   if( handleToReadLockFile == -1 )
   {
+    char buf[256];
     handleToReadLockFile = 0;
-    sprintf( msg, "WlmDataSourceFileSystem::SetReadlock : Cannot open file %s (return code: %s).", lockname.c_str(), strerror(errno) );
-    DumpMessage( msg );
+    DCMWLM_ERROR("WlmDataSourceFileSystem::SetReadlock: Cannot open file " << lockname
+      << " (return code: " << OFStandard::strerror(errno, buf, sizeof(buf)) << ")");
     return OFFalse;
   }
 
@@ -773,8 +712,7 @@ OFBool WlmDataSourceFileSystem::SetReadlock()
 #endif
   if( result == -1 )
   {
-    sprintf( msg, "WlmDataSourceFileSystem::SetReadlock : Cannot set read lock on file %s.", lockname.c_str() );
-    DumpMessage( msg );
+    DCMWLM_ERROR("WlmDataSourceFileSystem::SetReadlock: Cannot set read lock on file " << lockname);
     dcmtk_plockerr("return code");
     close( handleToReadLockFile );
     handleToReadLockFile = 0;
@@ -806,7 +744,7 @@ OFBool WlmDataSourceFileSystem::ReleaseReadlock()
   // if no read lock is set, return
   if( !readLockSetOnDataSource )
   {
-    DumpMessage("WlmDataSourceFileSystem::ReleaseReadlock : No readlock to release.");
+    DCMWLM_WARN("WlmDataSourceFileSystem::ReleaseReadlock: No readlock to release");
     return OFFalse;
   }
 
@@ -828,7 +766,7 @@ OFBool WlmDataSourceFileSystem::ReleaseReadlock()
 #endif
   if( result == -1 )
   {
-    DumpMessage("WlmDataSourceFileSystem::ReleaseReadlock : Cannot release read lock");
+    DCMWLM_WARN("WlmDataSourceFileSystem::ReleaseReadlock: Cannot release read lock");
     dcmtk_plockerr("return code");
     return OFFalse;
   }
@@ -849,6 +787,36 @@ OFBool WlmDataSourceFileSystem::ReleaseReadlock()
 /*
 ** CVS Log
 ** $Log: wldsfs.cc,v $
+** Revision 1.27  2010-10-14 13:14:49  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.26  2010-06-03 10:31:21  joergr
+** Replaced calls to strerror() by new helper function OFStandard::strerror()
+** which results in using the thread safe version of strerror() if available.
+**
+** Revision 1.25  2010-05-31 09:21:45  joergr
+** Fixed incorrect handling of SpecificCharacterSet attribute in C-FIND request
+** and response messages.
+**
+** Revision 1.24  2010-05-18 16:43:01  joergr
+** Slightly modified log messages and log levels in order to be more consistent.
+** Replaced '\n' by OFendl in log messages.
+**
+** Revision 1.23  2009-11-24 10:40:01  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.22  2007-08-10 14:25:21  meichel
+** Added new command line option --keep-char-set that returns
+**   any specific character set as encoded in the worklist file.
+**
+** Revision 1.21  2006/12/15 14:49:28  onken
+** Removed excessive use char* and C-array in favour of OFString and
+** OFList. Simplified some implementation details.
+**
+** Revision 1.20  2006/08/15 16:15:48  meichel
+** Updated the code in module dcmwlm to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
 ** Revision 1.19  2005/12/08 15:48:33  meichel
 ** Changed include path schema for all DCMTK header files
 **
