@@ -1,35 +1,30 @@
 /*
-*
-*  Copyright (C) 1996-2005, OFFIS
-*
-*  This software and supporting documentation were developed by
-*
-*    Kuratorium OFFIS e.V.
-*    Healthcare Information and Communication Systems
-*    Escherweg 2
-*    D-26121 Oldenburg, Germany
-*
-*  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
-*  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
-*  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
-*  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
-*  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
-*
-*  Module:  dcmwlm
-*
-*  Author:  Thomas Wilkens
-*
-*  Purpose: Class for managing file system interaction.
-*
-*  Last Update:      $Author: meichel $
-*  Update Date:      $Date: 2005/12/08 15:48:34 $
-*  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmwlm/libsrc/wlfsim.cc,v $
-*  CVS/RCS Revision: $Revision: 1.16 $
-*  Status:           $State: Exp $
-*
-*  CVS/RCS Log at end of file
-*
-*/
+ *
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
+ *
+ *  This software and supporting documentation were developed by
+ *
+ *    OFFIS e.V.
+ *    R&D Division Health
+ *    Escherweg 2
+ *    D-26121 Oldenburg, Germany
+ *
+ *
+ *  Module:  dcmwlm
+ *
+ *  Author:  Thomas Wilkens
+ *
+ *  Purpose: Class for managing file system interaction.
+ *
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:49 $
+ *  CVS/RCS Revision: $Revision: 1.26 $
+ *  Status:           $State: Exp $
+ *
+ *  CVS/RCS Log at end of file
+ *
+ */
 
 // ----------------------------------------------------------------------------
 
@@ -64,6 +59,7 @@ END_EXTERN_C
 #include "dcmtk/dcmdata/dcvrda.h"
 #include "dcmtk/dcmdata/dcvrtm.h"
 #include "dcmtk/dcmwlm/wltypdef.h"
+#include "dcmtk/dcmwlm/wlds.h"
 #include "dcmtk/dcmdata/dctk.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -78,8 +74,8 @@ WlmFileSystemInteractionManager::WlmFileSystemInteractionManager()
 // Task         : Constructor.
 // Parameters   : none.
 // Return Value : none.
-  : verboseMode( OFFalse ), debugMode( OFFalse ), logStream( NULL ), dfPath( NULL ),
-    enableRejectionOfIncompleteWlFiles( OFTrue ), calledApplicationEntityTitle( NULL ),
+  : dfPath( "" ),
+    enableRejectionOfIncompleteWlFiles( OFTrue ), calledApplicationEntityTitle( "" ),
     matchingRecords( NULL ), numOfMatchingRecords( 0 )
 {
 }
@@ -93,43 +89,6 @@ WlmFileSystemInteractionManager::~WlmFileSystemInteractionManager()
 // Parameters   : none.
 // Return Value : none.
 {
-  if( dfPath != NULL ) delete dfPath;
-}
-
-// ----------------------------------------------------------------------------
-
-void WlmFileSystemInteractionManager::SetLogStream( OFConsole *value )
-// Date         : July 11, 2002
-// Author       : Thomas Wilkens
-// Task         : Set value in member variable.
-// Parameters   : value - [in] The value to set.
-// Return Value : none.
-{
-  logStream = value;
-}
-
-// ----------------------------------------------------------------------------
-
-void WlmFileSystemInteractionManager::SetVerbose( OFBool value )
-// Date         : July 11, 2002
-// Author       : Thomas Wilkens
-// Task         : Set value in member variable.
-// Parameters   : value - [in] The value to set.
-// Return Value : none.
-{
-  verboseMode = value;
-}
-
-// ----------------------------------------------------------------------------
-
-void WlmFileSystemInteractionManager::SetDebug( OFBool value )
-// Date         : July 11, 2002
-// Author       : Thomas Wilkens
-// Task         : Set value in member variable.
-// Parameters   : value - [in] The value to set.
-// Return Value : none.
-{
-  debugMode = value;
 }
 
 // ----------------------------------------------------------------------------
@@ -146,7 +105,7 @@ void WlmFileSystemInteractionManager::SetEnableRejectionOfIncompleteWlFiles( OFB
 
 // ----------------------------------------------------------------------------
 
-OFCondition WlmFileSystemInteractionManager::ConnectToFileSystem( char *dfPathv )
+OFCondition WlmFileSystemInteractionManager::ConnectToFileSystem( const OFString& dfPathv )
 // Date         : July 11, 2002
 // Author       : Thomas Wilkens
 // Task         : Connects to the worklist file system database.
@@ -154,18 +113,17 @@ OFCondition WlmFileSystemInteractionManager::ConnectToFileSystem( char *dfPathv
 // Return Value : Indicates if the connection could be established or not.
 {
   // check parameter
-  if( dfPathv == NULL )
+  if( dfPathv.length() == 0 )
   {
-    DumpMessage("Invalid parameters, cannot connect to worklist file system database...");
+    DCMWLM_ERROR("Invalid parameters, cannot connect to worklist file system database");
     return( WLM_EC_CannotConnectToDataSource );
   }
 
   // copy value
-  dfPath = new char[ strlen( dfPathv ) + 1 ];
-  strcpy( dfPath, dfPathv );
+  dfPath = dfPathv;
 
   // check if the specified path is existent and accessible for reading
-  if( !OFStandard::dirExists( OFString( dfPath ) ) || !OFStandard::isReadable( OFString( dfPath ) ) )
+  if( !OFStandard::dirExists( dfPath ) || !OFStandard::isReadable( dfPath ) )
     return( WLM_EC_CannotConnectToDataSource );
   else
     return( EC_Normal );
@@ -185,25 +143,7 @@ OFCondition WlmFileSystemInteractionManager::DisconnectFromFileSystem()
 
 // ----------------------------------------------------------------------------
 
-void WlmFileSystemInteractionManager::DumpMessage( const char *message )
-// Date         : July 11, 2002
-// Author       : Thomas Wilkens
-// Task         : This function dumps the given information on a stream.
-//                Used for dumping information in normal, debug and verbose mode.
-// Parameters   : message - [in] The message to dump.
-// Return Value : none.
-{
-  if( logStream != NULL && message != NULL )
-  {
-    logStream->lockCout();
-    logStream->getCout() << message << endl;
-    logStream->unlockCout();
-  }
-}
-
-// ----------------------------------------------------------------------------
-
-OFBool WlmFileSystemInteractionManager::IsCalledApplicationEntityTitleSupported( char *calledApplicationEntityTitlev )
+OFBool WlmFileSystemInteractionManager::IsCalledApplicationEntityTitleSupported( const OFString& calledApplicationEntityTitlev )
 // Date         : July 11, 2002
 // Author       : Thomas Wilkens
 // Task         : Checks if the given called application entity title is supported. If this is the case,
@@ -214,8 +154,7 @@ OFBool WlmFileSystemInteractionManager::IsCalledApplicationEntityTitleSupported(
 //                OFFalse - The called application entity title is not supported or it is not given.
 {
   // copy value
-  calledApplicationEntityTitle = new char[ strlen( calledApplicationEntityTitlev ) + 1 ];
-  strcpy( calledApplicationEntityTitle, calledApplicationEntityTitlev );
+  calledApplicationEntityTitle = calledApplicationEntityTitlev;
 
   // Determine complete path to the files that make up the data source.
   OFString fullPath( dfPath );
@@ -244,7 +183,6 @@ unsigned long WlmFileSystemInteractionManager::DetermineMatchingRecords( DcmData
 // Return Value : Number of matching records.
 {
   OFOrderedSet<OFString> worklistFiles;
-  char msg[500];
 
   // initialize member variables
   matchingRecords = NULL;
@@ -260,11 +198,7 @@ unsigned long WlmFileSystemInteractionManager::DetermineMatchingRecords( DcmData
     DcmFileFormat fileform;
     if (fileform.loadFile(worklistFiles[i].c_str()).bad())
     {
-      if( verboseMode )
-      {
-        sprintf( msg, "Could not read worklist file %s properly. File will be ignored.", worklistFiles[i].c_str() );
-        DumpMessage( msg );
-      }
+      DCMWLM_WARN("Could not read worklist file " << worklistFiles[i] << " properly, file will be ignored");
     }
     else
     {
@@ -272,14 +206,12 @@ unsigned long WlmFileSystemInteractionManager::DetermineMatchingRecords( DcmData
       DcmDataset *dataset = fileform.getDataset();
       if( dataset == NULL )
       {
-        if( verboseMode )
-        {
-          sprintf( msg, "Worklist file %s is empty. File will be ignored.", worklistFiles[i].c_str() );
-          DumpMessage( msg );
-        }
+        DCMWLM_WARN("Worklist file " << worklistFiles[i] << " is empty, file will be ignored");
       }
       else
       {
+        if( enableRejectionOfIncompleteWlFiles )
+          DCMWLM_INFO("Checking whether worklist file " << worklistFiles[i] << " is complete");
         // in case option --enable-file-reject is set, we have to check if the current
         // .wl-file meets certain conditions; in detail, the file's dataset has to be
         // checked whether it contains all necessary return type 1 attributes and contains
@@ -287,30 +219,18 @@ unsigned long WlmFileSystemInteractionManager::DetermineMatchingRecords( DcmData
         // .wl-file shall be rejected
         if( enableRejectionOfIncompleteWlFiles && !DatasetIsComplete( dataset ) )
         {
-          if( verboseMode )
-          {
-            sprintf( msg, "Worklist file %s is incomplete. File will be ignored.", worklistFiles[i].c_str() );
-            DumpMessage( msg );
-          }
+          DCMWLM_WARN("Worklist file " << worklistFiles[i] << " is incomplete, file will be ignored");
         }
         else
         {
           // check if the current dataset matches the matching key attribute values
           if( !DatasetMatchesSearchMask( dataset, searchMask ) )
           {
-            if( verboseMode )
-            {
-              sprintf( msg, "Information from worklist file %s does not match query.", worklistFiles[i].c_str() );
-              DumpMessage( msg );
-            }
+            DCMWLM_INFO("Information from worklist file " << worklistFiles[i] << " does not match query");
           }
           else
           {
-            if( verboseMode )
-            {
-              sprintf( msg, "Information from worklist file %s matches query.", worklistFiles[i].c_str() );
-              DumpMessage( msg );
-            }
+            DCMWLM_INFO("Information from worklist file " << worklistFiles[i] << " matches query");
 
             // since the dataset matches the matching key attribute values
             // we need to insert it into the matchingRecords array
@@ -596,22 +516,22 @@ void WlmFileSystemInteractionManager::DetermineWorklistFiles( OFOrderedSet<OFStr
 #endif
 
   // in case we are running in verbose mode, dump all worklist file information
-  if( verboseMode )
+  if (DCM_dcmwlmGetLogger().isEnabledFor(OFLogger::INFO_LOG_LEVEL))
   {
-    DumpMessage("=============================");
-    DumpMessage("Worklist Database Files:");
+    DCMWLM_INFO("=============================");
+    DCMWLM_INFO("Worklist Database Files:");
     if( worklistFiles.NumberOfElements() == 0 )
-      DumpMessage("<no files found>");
+      DCMWLM_INFO("<no files found>");
     else
     {
       OFSetIterator<OFString> iter( worklistFiles );
       while( iter.Object() )
       {
-        DumpMessage( iter.Object()->c_str() );
+        DCMWLM_INFO(*iter.Object());
         iter.Next();
       }
     }
-    DumpMessage("=============================");
+    DCMWLM_INFO("=============================");
   }
 }
 
@@ -655,7 +575,6 @@ OFBool WlmFileSystemInteractionManager::DatasetIsComplete( DcmDataset *dataset )
 //                DICOM standard part 4 annex K, the following attributes are type 1 attributes in
 //                C-Find RSP messages:
 //                      Attribute                             Tag      Return Key Type
-//                  SpecificCharacterSet                  (0008,0005)        1C (will be checked in WlmDataSourceFileSystem::StartFindRequest(...); this attribute does not have to be checked here)
 //                  ScheduledProcedureStepSequence        (0040,0100)        1
 //                   > ScheduledStationAETitle            (0040,0001)        1
 //                   > ScheduledProcedureStepStartDate    (0040,0002)        1
@@ -678,7 +597,7 @@ OFBool WlmFileSystemInteractionManager::DatasetIsComplete( DcmDataset *dataset )
 //                  ReferencedPatientSequence             (0008,1120)        2
 //                   > ReferencedSOPClassUID              (0008,1150)        1C (Required if a sequence item is present)
 //                   > ReferencedSOPInstanceUID           (0008,1155)        1C (Required if a sequence item is present)
-//                  PatientsName                          (0010,0010)        1
+//                  PatientName                           (0010,0010)        1
 //                  PatientID                             (0010,0020)        1
 // Parameters   : dataset - [in] The dataset of the worklist file which is currently examined.
 // Return Value : OFTrue in case the given dataset contains all necessary return type 1 information,
@@ -689,11 +608,16 @@ OFBool WlmFileSystemInteractionManager::DatasetIsComplete( DcmDataset *dataset )
   // intialize returnValue
   OFBool complete = OFTrue;
 
+  DCMWLM_DEBUG("Checking whether dataset is complete ...");
+
   // the dataset is considered to be incomplete...
   // ...if the ScheduledProcedureStepSequence is missing or
   // ...if the ScheduledProcedureStepSequence does not have exactly one item
   if( dataset->findAndGetElement( DCM_ScheduledProcedureStepSequence, scheduledProcedureStepSequence ).bad() || ((DcmSequenceOfItems*)scheduledProcedureStepSequence)->card() != 1 )
+  {
+    DCMWLM_DEBUG("- ScheduledProcedureStepSequence " << DCM_ScheduledProcedureStepSequence << " is missing or does not have exactly one item");
     complete = OFFalse;
+  }
   else
   {
     // so the ScheduledProcedureStepSequence is existent and has exactly one item;
@@ -708,7 +632,7 @@ OFBool WlmFileSystemInteractionManager::DatasetIsComplete( DcmDataset *dataset )
     // ...if ScheduledProcedureStepID is missing or empty in the ScheduledProcedureStepSequence, or
     // ...if RequestedProcedureID is missing or empty in the dataset, or
     // ...if StudyInstanceUID is missing or empty in the dataset, or
-    // ...if PatientsName is missing or empty in the dataset, or
+    // ...if PatientName is missing or empty in the dataset, or
     // ...if PatientID is missing or empty in the dataset, or
     // ...if inside the ScheduledProcedureStepSequence, no information can be retrieved from
     //    the ScheduledProcedureStepDescription attribute and (at the same time) also no
@@ -725,7 +649,7 @@ OFBool WlmFileSystemInteractionManager::DatasetIsComplete( DcmDataset *dataset )
         AttributeIsAbsentOrEmpty( DCM_ScheduledProcedureStepID, scheduledProcedureStepSequenceItem ) ||
         AttributeIsAbsentOrEmpty( DCM_RequestedProcedureID, dataset ) ||
         AttributeIsAbsentOrEmpty( DCM_StudyInstanceUID, dataset ) ||
-        AttributeIsAbsentOrEmpty( DCM_PatientsName, dataset ) ||
+        AttributeIsAbsentOrEmpty( DCM_PatientName, dataset ) ||
         AttributeIsAbsentOrEmpty( DCM_PatientID, dataset ) ||
         DescriptionAndCodeSequenceAttributesAreIncomplete( DCM_ScheduledProcedureStepDescription, DCM_ScheduledProtocolCodeSequence, scheduledProcedureStepSequenceItem ) ||
         DescriptionAndCodeSequenceAttributesAreIncomplete( DCM_RequestedProcedureDescription, DCM_RequestedProcedureCodeSequence, dataset ) ||
@@ -733,7 +657,6 @@ OFBool WlmFileSystemInteractionManager::DatasetIsComplete( DcmDataset *dataset )
         ReferencedStudyOrPatientSequenceIsAbsentOrExistentButNonEmptyAndIncomplete( DCM_ReferencedPatientSequence, dataset ) )
       complete = OFFalse;
   }
-
   // return result
   return( complete );
 }
@@ -747,14 +670,25 @@ OFBool WlmFileSystemInteractionManager::ReferencedStudyOrPatientSequenceIsAbsent
 //                and incomplete in the given dataset.
 // Parameters   : sequenceTagKey - [in] The sequence attribute which shall be checked.
 //                dset           - [in] The dataset in which the attribute is contained.
-// Return Value : OFTrue in case the sequence attribute is absent or existent but non-empty and incomplete, OFFalse otherwise.
+// Return Value : OFTrue in case the sequence attribute is absent (and cannot be added to the dataset)
+//                or existent but non-empty and incomplete, OFFalse otherwise.
 {
   DcmElement *sequence = NULL;
   OFBool result;
 
-  // if the sequence attribute is absent, we want to return OFTrue
+  // check whether the type 2 sequence attribute is absent
   if( dset->findAndGetElement( sequenceTagKey, sequence ).bad() )
-    result = OFTrue;
+  {
+    DCMWLM_DEBUG("- " << DcmTag(sequenceTagKey).getTagName() << " " << sequenceTagKey << " is missing");
+    // try to add it to the dataset and return OFFalse if successful
+    if ( dset->insertEmptyElement( sequenceTagKey ).good() )
+    {
+      DCMWLM_WARN("Added missing type 2 sequence attribute " << sequenceTagKey << " to the current record");
+      result = OFFalse;
+    }
+    else
+      result = OFTrue;
+  }
   else
   {
     // if the sequence attribute is existent but empty, we want to return OFFalse
@@ -772,6 +706,8 @@ OFBool WlmFileSystemInteractionManager::ReferencedStudyOrPatientSequenceIsAbsent
             AttributeIsAbsentOrEmpty( DCM_ReferencedSOPInstanceUID, ((DcmSequenceOfItems*)sequence)->getItem(i) ) )
           result = OFTrue;
       }
+      if ( result )
+        DCMWLM_DEBUG("- " << DcmTag(sequenceTagKey).getTagName() << " " << sequenceTagKey << " is incomplete");
     }
   }
 
@@ -798,7 +734,10 @@ OFBool WlmFileSystemInteractionManager::DescriptionAndCodeSequenceAttributesAreI
   // if the attribute is not existent or has no items, we consider it incomplete
   OFBool codeSequenceComplete = OFTrue;
   if( dset->findAndGetElement( codeSequenceTagKey, codeSequence ).bad() || ((DcmSequenceOfItems*)codeSequence)->card() == 0 )
+  {
+    DCMWLM_DEBUG("- " << DcmTag(codeSequenceTagKey).getTagName() << " " << codeSequenceTagKey << " is missing or empty");
     codeSequenceComplete = OFFalse;
+  }
   else
   {
     // if it is existent and has items, check every item for completeness
@@ -808,6 +747,8 @@ OFBool WlmFileSystemInteractionManager::DescriptionAndCodeSequenceAttributesAreI
           AttributeIsAbsentOrEmpty( DCM_CodingSchemeDesignator, ((DcmSequenceOfItems*)codeSequence)->getItem(i) ) )
         codeSequenceComplete = OFFalse;
     }
+    if( !codeSequenceComplete )
+      DCMWLM_DEBUG("- " << DcmTag(codeSequenceTagKey).getTagName() << " " << codeSequenceTagKey << " is incomplete");
   }
 
   // now check the above condition
@@ -830,7 +771,10 @@ OFBool WlmFileSystemInteractionManager::AttributeIsAbsentOrEmpty( DcmTagKey elem
   DcmElement *elem = NULL;
 
   if( dset->findAndGetElement( elemTagKey, elem ).bad() || elem->getLength() == 0 )
+  {
+    DCMWLM_DEBUG("- " << DcmTag(elemTagKey).getTagName() << " " << elemTagKey << " is missing or empty");
     return( OFTrue );
+  }
   else
     return( OFFalse );
 }
@@ -892,18 +836,18 @@ OFBool WlmFileSystemInteractionManager::DatasetMatchesSearchMask( DcmDataset *da
           break;
 
         case 4:
-          // matching key attribute is DCM_ScheduledPerformingPhysiciansName (PN, 1)
-          matchFound = ScheduledPerformingPhysiciansNamesMatch( mkaValuesDataset[4], mkaValuesSearchMask[4] );
+          // matching key attribute is DCM_ScheduledPerformingPhysicianName (PN, 1)
+          matchFound = ScheduledPerformingPhysicianNamesMatch( mkaValuesDataset[4], mkaValuesSearchMask[4] );
           break;
 
         case 5:
-          // matching key attribute is DCM_PatientsName (PN, 1)
+          // matching key attribute is DCM_PatientName (PN, 1)
           matchFound = PatientsNamesMatch( mkaValuesDataset[5], mkaValuesSearchMask[5] );
           break;
 
         case 6:
           // matching key attribute is DCM_PatientID (LO, 1)
-          matchFound = PatientIdsMatch( mkaValuesDataset[6], mkaValuesSearchMask[6] );
+          matchFound = PatientsIDsMatch( mkaValuesDataset[6], mkaValuesSearchMask[6] );
           break;
 
         case 7:
@@ -917,12 +861,12 @@ OFBool WlmFileSystemInteractionManager::DatasetMatchesSearchMask( DcmDataset *da
           break;
 
         case 9:
-          // matching key attribute is DCM_ReferringPhysiciansName (PN, 2)
-          matchFound = ReferringPhysiciansNamesMatch( mkaValuesDataset[9], mkaValuesSearchMask[9] );
+          // matching key attribute is DCM_ReferringPhysicianName (PN, 2)
+          matchFound = ReferringPhysicianNamesMatch( mkaValuesDataset[9], mkaValuesSearchMask[9] );
           break;
 
         case 10:
-          // matching key attribute is DCM_PatientsSex (CS, 2)
+          // matching key attribute is DCM_PatientSex (CS, 2)
           matchFound = PatientsSexesMatch( mkaValuesDataset[10], mkaValuesSearchMask[10] );
           break;
 
@@ -942,7 +886,7 @@ OFBool WlmFileSystemInteractionManager::DatasetMatchesSearchMask( DcmDataset *da
           break;
 
         case 14:
-          // matching key attribute is DCM_PatientsBirthDate (DA, 2)
+          // matching key attribute is DCM_PatientBirthDate (DA, 2)
           matchFound = PatientsBirthDatesMatch( mkaValuesDataset[14], mkaValuesSearchMask[14] );
           break;
 
@@ -985,17 +929,17 @@ void WlmFileSystemInteractionManager::DetermineMatchingKeyAttributeValues( DcmDa
       case 1 : tag = DCM_ScheduledProcedureStepStartDate   ; break;
       case 2 : tag = DCM_ScheduledProcedureStepStartTime   ; break;
       case 3 : tag = DCM_Modality                          ; break;
-      case 4 : tag = DCM_ScheduledPerformingPhysiciansName ; break;
-      case 5 : tag = DCM_PatientsName                      ; break;
+      case 4 : tag = DCM_ScheduledPerformingPhysicianName  ; break;
+      case 5 : tag = DCM_PatientName                       ; break;
       case 6 : tag = DCM_PatientID                         ; break;
       case 7 : tag = DCM_AccessionNumber                   ; break;
       case 8 : tag = DCM_RequestedProcedureID              ; break;
-      case 9 : tag = DCM_ReferringPhysiciansName           ; break;
-      case 10 : tag = DCM_PatientsSex                      ; break;
+      case 9 : tag = DCM_ReferringPhysicianName            ; break;
+      case 10 : tag = DCM_PatientSex                       ; break;
       case 11 : tag = DCM_RequestingPhysician              ; break;
       case 12 : tag = DCM_AdmissionID                      ; break;
       case 13 : tag = DCM_RequestedProcedurePriority       ; break;
-      case 14 : tag = DCM_PatientsBirthDate                ; break;
+      case 14 : tag = DCM_PatientBirthDate                 ; break;
       default:                                               break;
     }
 
@@ -1124,7 +1068,7 @@ OFBool WlmFileSystemInteractionManager::ModalitiesMatch( const char *datasetValu
 
 // ----------------------------------------------------------------------------
 
-OFBool WlmFileSystemInteractionManager::ScheduledPerformingPhysiciansNamesMatch( const char *datasetValue, const char *searchMaskValue )
+OFBool WlmFileSystemInteractionManager::ScheduledPerformingPhysicianNamesMatch( const char *datasetValue, const char *searchMaskValue )
 // Date         : July 12, 2002
 // Author       : Thomas Wilkens
 // Task         : This function returns OFTrue if the dataset's and the search mask's values in
@@ -1194,7 +1138,7 @@ OFBool WlmFileSystemInteractionManager::PatientsNamesMatch( const char *datasetV
 
 // ----------------------------------------------------------------------------
 
-OFBool WlmFileSystemInteractionManager::PatientIdsMatch( const char *datasetValue, const char *searchMaskValue )
+OFBool WlmFileSystemInteractionManager::PatientsIDsMatch( const char *datasetValue, const char *searchMaskValue )
 // Date         : July 12, 2002
 // Author       : Thomas Wilkens
 // Task         : This function returns OFTrue if the dataset's and the search mask's values in
@@ -1285,7 +1229,7 @@ OFBool WlmFileSystemInteractionManager::RequestedProcedureIdsMatch( const char *
 
 // ----------------------------------------------------------------------------
 
-OFBool WlmFileSystemInteractionManager::ReferringPhysiciansNamesMatch( const char *datasetValue, const char *searchMaskValue )
+OFBool WlmFileSystemInteractionManager::ReferringPhysicianNamesMatch( const char *datasetValue, const char *searchMaskValue )
 // Date         : December 22, 2003
 // Author       : Thomas Wilkens
 // Task         : This function returns OFTrue if the dataset's and the search mask's values in
@@ -2213,12 +2157,50 @@ void WlmFileSystemInteractionManager::ExtractValuesFromRange( const char *range,
 /*
 ** CVS Log
 ** $Log: wlfsim.cc,v $
+** Revision 1.26  2010-10-14 13:14:49  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.25  2010-08-09 13:30:34  joergr
+** Updated data dictionary to 2009 edition of the DICOM standard. From now on,
+** the official "keyword" is used for the attribute name which results in a
+** number of minor changes (e.g. "PatientsName" is now called "PatientName").
+**
+** Revision 1.24  2010-05-31 09:16:55  joergr
+** Fixed incorrect handling of SpecificCharacterSet attribute in C-FIND request
+** and response messages.
+**
+** Revision 1.23  2010-05-18 16:37:04  joergr
+** Slightly modified log messages and log levels in order to be more consistent.
+**
+** Revision 1.22  2010-03-12 12:12:34  joergr
+** Enhanced log output on incomplete worklist files (in debug mode).
+** Changed some log messages from level "info" to "warn".
+** Use return value of getTag() for stream output where possible.
+**
+** Revision 1.21  2010-02-15 13:11:13  joergr
+** Fixed wrong output in verbose mode (string pointer instead of string value).
+**
+** Revision 1.20  2009-11-24 10:40:01  uli
+** Switched to logging mechanism provided by the "new" oflog module.
+**
+** Revision 1.19  2006-12-15 14:49:28  onken
+** Removed excessive use char* and C-array in favour of OFString and
+** OFList. Simplified some implementation details.
+**
+** Revision 1.18  2006/08/15 16:15:48  meichel
+** Updated the code in module dcmwlm to correctly compile when
+**   all standard C++ classes remain in namespace std.
+**
+** Revision 1.17  2006/01/27 15:07:33  joergr
+** Fixed issue with missing type 2 attributes in worklist files being reported
+** as incomplete.  Now, the attributes are inserted automatically if required.
+** Removed email address from CVS log.
+**
 ** Revision 1.16  2005/12/08 15:48:34  meichel
 ** Changed include path schema for all DCMTK header files
 **
 ** Revision 1.15  2005/09/23 12:57:02  wilkens
 ** Added attribute PatientsBirthDate as a matching key attribute to wlmscpfs.
-** Thanks to Andre M. Descombes <andre@descombes.info> for the code template.
 **
 ** Revision 1.14  2005/07/01 10:01:31  wilkens
 ** Modified a couple of "delete" statements to "delete[]" in order to get rid of
@@ -2288,5 +2270,4 @@ void WlmFileSystemInteractionManager::ExtractValuesFromRange( const char *range,
 ** of wlmscps.
 **
 **
-**
 */
