@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmwlm
  *
@@ -37,12 +33,11 @@
  *
  *   A perl fcntl call using these (packed binary) values will lock/unlock a
  *   whole file, which must be a successfully opened perl  file  descriptor.
- *   See perl man page for details. 
+ *   See perl man page for details.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:37 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmwlm/wwwapps/preplock.cc,v $
- *  CVS/RCS Revision: $Revision: 1.3 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-12-17 10:07:45 $
+ *  CVS/RCS Revision: $Revision: 1.6 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -50,6 +45,7 @@
  */
 
 #include "dcmtk/config/osconfig.h"
+#include "dcmtk/ofstd/ofstream.h"
 
 #define INCLUDE_CSTDIO
 #include "dcmtk/ofstd/ofstdinc.h"
@@ -68,7 +64,7 @@ int main()
   unsigned int i;
   unsigned char *c;
 
-  /* first, we initialize the data */  
+  /* first, we initialize the data */
   c = (unsigned char *)(&lockdata);
   for (i=0; i<sizeof(struct flock); i++) c[i]=0;
 
@@ -85,14 +81,14 @@ int main()
   printf("\"");
   for (i=0; i<sizeof(struct flock); i++) printf(",%d",(int)(c[i]));
   printf(");\n");
-  
+
   lockdata.l_type = F_WRLCK;
   printf("$const_WRLCK_STRUCT = pack(\"");
   for (i=0; i<sizeof(struct flock); i++) printf("c");
   printf("\"");
   for (i=0; i<sizeof(struct flock); i++) printf(",%d",(int)(c[i]));
   printf(");\n");
-  
+
   lockdata.l_type = F_UNLCK;
   printf("$const_UNLCK_STRUCT = pack(\"");
   for (i=0; i<sizeof(struct flock); i++) printf("c");
@@ -101,13 +97,22 @@ int main()
   printf(");\n");
 
 #endif
-  return 0;  
+  return 0;
 }
 
 /*
  * CVS/RCS Log
  *   $Log: preplock.cc,v $
- *   Revision 1.3  2005/12/08 15:48:37  meichel
+ *   Revision 1.6  2010-12-17 10:07:45  joergr
+ *   Include another system header (stdio.h) needed for IRIX 6.3 with gcc 2.95.3.
+ *
+ *   Revision 1.5  2010-10-14 13:20:03  joergr
+ *   Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *   Revision 1.4  2009-08-19 11:55:44  meichel
+ *   Added additional includes needed for Sun Studio 11 on Solaris.
+ *
+ *   Revision 1.3  2005-12-08 15:48:37  meichel
  *   Changed include path schema for all DCMTK header files
  *
  *   Revision 1.2  2003/07/03 14:26:57  meichel
