@@ -1,32 +1,27 @@
 /*
  *
- *  Copyright (C) 1996-2005, OFFIS
+ *  Copyright (C) 1996-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  dcmwlm
  *
  *  Author:  Andrew Hewett
  *
  *  Purpose:
- *   Program to create a worklist file from a WWW CGI perl script generated 
+ *   Program to create a worklist file from a WWW CGI perl script generated
  *   hexedecimal encoded string.
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:40 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/dcmwlm/wwwapps/writwlst.cc,v $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-11-01 13:37:32 $
+ *  CVS/RCS Revision: $Revision: 1.10 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -42,7 +37,6 @@
 
 #include "dcmtk/ofstd/ofstream.h"
 #include "dcmtk/dcmdata/dctk.h"
-#include "dcmtk/dcmdata/dcdebug.h"
 #include "dcmtk/dcmdata/dcuid.h"    /* for dcmtk version name */
 
 static char rcsid[] = "$dcmtk: writwlst v"
@@ -66,7 +60,7 @@ usage()
 	"    -f    write dataset\n"
 	"    +o    overwrite dcmfile-out if existing (default)\n"
 	"    -o    update dcmfile-out if existing\n"
-	"  group length encoding:\n" 
+	"  group length encoding:\n"
 	"    +g    write with group lengths\n"
 	"    -g    write without group lengths (default)\n"
 	"  length encoding in sequences and items:\n"
@@ -79,7 +73,7 @@ usage()
 	"  other test/debug options:\n"
 	"    +V    verbose mode, print actions\n"
 	"    +v    validate input data (currently almost useless)\n"
-	"    +dn   set debug level to n (n=1..9)\n";
+	"    +d    enable debug output\n";
 }
 
 
@@ -98,15 +92,15 @@ private:
     }
     void expand(int newlen);
 public:
-    int length() const { 
-	return len; 
+    int length() const {
+	return len;
     }
-    int maxlength() const { 
-	return maxlen; 
+    int maxlength() const {
+	return maxlen;
     }
 
-    const char* c_str() const { 
-	return str; 
+    const char* c_str() const {
+	return str;
     }
 
     void append(char c) {
@@ -142,7 +136,7 @@ public:
     : str(NULL)
     , len(0)
     , maxlen(0)
-    { 
+    {
 	expand(capacity);
     }
     SimpleStr(const char* s)
@@ -165,7 +159,7 @@ private:
     /*undefined*/ SimpleStr& operator=(const SimpleStr&);
 };
 
-void SimpleStr::expand(int newlen) 
+void SimpleStr::expand(int newlen)
 {
     if (newlen >= maxlen) {
         maxlen = max(newlen, maxlen+SimpleStr_defaultSize);
@@ -189,25 +183,25 @@ addStringAttr(DcmItem *item, const DcmTagKey& key, const SimpleStr& str)
     DcmElement *newElement = NULL;
 
     if (item == NULL) {
-	CERR << "error: cannot add to null item" << endl;
+	CERR << "error: cannot add to null item" << OFendl;
 	return OFFalse;
     }
 
     ec = newDicomElement(newElement, tag);
     if (ec != EC_Normal) {
-	CERR << "error: cannot create element: " << key << endl;
+	CERR << "error: cannot create element: " << key << OFendl;
 	return OFFalse;
     }
 
     ec = newElement->putString(str.c_str());
     if (ec != EC_Normal) {
-	CERR << "error: cannot put element value: " << key << endl;
+	CERR << "error: cannot put element value: " << key << OFendl;
 	return OFFalse;
     }
 
     ec = item->insert(newElement, OFTrue);
     if (ec != EC_Normal) {
-	CERR << "error: cannot insert element: " << key << endl;
+	CERR << "error: cannot insert element: " << key << OFendl;
 	return OFFalse;
     }
 
@@ -216,7 +210,7 @@ addStringAttr(DcmItem *item, const DcmTagKey& key, const SimpleStr& str)
 
 
 static DcmItem*
-getOrInsertSequenceItem(DcmItem *dset, const DcmTagKey& key, 
+getOrInsertSequenceItem(DcmItem *dset, const DcmTagKey& key,
 			unsigned int itemNumber)
 {
     OFCondition ec = EC_Normal;
@@ -224,7 +218,7 @@ getOrInsertSequenceItem(DcmItem *dset, const DcmTagKey& key,
     DcmItem *foundItem = NULL;
 
     if (dset == NULL) {
-	CERR << "error: cannot add to null item" << endl;
+	CERR << "error: cannot add to null item" << OFendl;
 	return NULL;
     }
 
@@ -243,15 +237,15 @@ getOrInsertSequenceItem(DcmItem *dset, const DcmTagKey& key,
     } else if (stack.top()->ident() == EVR_SQ) {
 	DcmSequenceOfItems *sq = (DcmSequenceOfItems*)stack.top();
 	if (itemNumber > sq->card()) {
-	    /* we need to create some more items */ 
+	    /* we need to create some more items */
 	    for (unsigned long i=sq->card(); i<=itemNumber; i++) {
 		DcmItem *item = new DcmItem;
 		sq->insert(item, OFTrue);
 	    }
-	} 
+	}
 	foundItem = sq->getItem(itemNumber);
     } else {
-	CERR << "error: not a sequence: " << key << endl;
+	CERR << "error: not a sequence: " << key << OFendl;
 	return NULL;
     }
 
@@ -287,17 +281,17 @@ addValue(int valCount, SimpleStr& val, DcmDataset& dset)
 	KeyPos(  3, DCM_RequestedProcedurePriority ),
 	KeyPos(  4, DCM_AccessionNumber ),
 	KeyPos(  5, DCM_RequestingPhysician ),
-	KeyPos(  6, DCM_PatientsName ),
+	KeyPos(  6, DCM_PatientName ),
 	KeyPos(  7, DCM_PatientID ),
-	KeyPos(  8, DCM_PatientsBirthDate ),
-	KeyPos(  9, DCM_PatientsSex ),
+	KeyPos(  8, DCM_PatientBirthDate ),
+	KeyPos(  9, DCM_PatientSex ),
 	KeyPos( 10, DCM_MedicalAlerts ),
-	KeyPos( 11, DCM_ContrastAllergies ),
+	KeyPos( 11, DCM_Allergies ),
 	KeyPos( 12, DCM_ScheduledStationAETitle, OFTrue ),
 	KeyPos( 13, DCM_ScheduledProcedureStepStartDate, OFTrue ),
 	KeyPos( 14, DCM_ScheduledProcedureStepStartTime, OFTrue ),
 	KeyPos( 15, DCM_Modality, OFTrue ),
-	KeyPos( 16, DCM_ScheduledPerformingPhysiciansName, OFTrue ),
+	KeyPos( 16, DCM_ScheduledPerformingPhysicianName, OFTrue ),
 	KeyPos( 17, DCM_ScheduledProcedureStepDescription, OFTrue ),
 	KeyPos( 18, DCM_ScheduledStationName, OFTrue ),
 	KeyPos( 19, DCM_ScheduledProcedureStepLocation, OFTrue ),
@@ -312,11 +306,11 @@ addValue(int valCount, SimpleStr& val, DcmDataset& dset)
 	/* ignore extra values */
 	return OFTrue;
     }
-    
+
     KeyPos *kp = &posTab[valCount];
     if (kp->position != valCount) {
-	CERR << "internal error: inconsistent posTab (valCount=" 
-	     << valCount <<")" << endl;
+	CERR << "internal error: inconsistent posTab (valCount="
+	     << valCount <<")" << OFendl;
 	return OFFalse;
     }
 
@@ -353,7 +347,7 @@ parseWorklist(FILE* f, DcmDataset& dset)
     }
     if (c != SEPARATOR_CHAR) {
 	CERR << "error: expected \'" << char(SEPARATOR_CHAR) << "\' " <<
-	    "as first input character" << endl;
+	    "as first input character" << OFendl;
 	return OFFalse;
     }
 
@@ -363,20 +357,20 @@ parseWorklist(FILE* f, DcmDataset& dset)
 	    val.clear();
 	    valCount++;
 	} else if (isxdigit(c)) {
-	    hexChar.append(c);
+	    hexChar.append(OFstatic_cast(char, c));
 	    if (hexChar.length() == 2) {
 		/* convert into normal character */
 		unsigned int h;
 		const char *s = hexChar.c_str();
 		sscanf(s, "%x", &h);
-		char newc = (h & 0xff);
+		char newc = OFstatic_cast(char, h & 0xff);
 		val.append(newc);
 		hexChar.clear();
 	    }
 	} else if (isspace(c)) {
 	    /* ignore */
 	} else {
-	    CERR << "error bad hex value: " << char(c) << endl;
+	    CERR << "error bad hex value: " << char(c) << OFendl;
 	    return OFFalse;
 	}
     }
@@ -391,8 +385,6 @@ parseWorklist(FILE* f, DcmDataset& dset)
 
 int main(int argc, char *argv[])
 {
-    SetDebugLevel(( 0 ));
-
     if (argc < 3) {
 	usage();
         return 1;
@@ -408,16 +400,17 @@ int main(int argc, char *argv[])
     OFBool verifymode = OFFalse;
     OFBool verbosemode = OFFalse;
     // OFBool createFileFormat = OFTrue;
-    int localDebugLevel = 0;
     OFBool keepOverride = OFFalse;
 
+    OFLog::configure();
+
     for (int i=1; i<argc; i++) {
 	char* arg = argv[i];
 	if ((strcmp(arg, "-") == 0) && (ifname == NULL)) {
 	    ifname = arg;
 	} else if (arg[0] == '-' || arg[0] == '+') {
 	    if (strlen(arg) < 2) {
-		CERR << "unknown argument: " << arg << endl;
+		CERR << "unknown argument: " << arg << OFendl;
 		usage();
 		return 1;
 	    }
@@ -464,7 +457,7 @@ int main(int argc, char *argv[])
 		    xfer = EXS_BigEndianExplicit;
 		    break;
 		default:
-		    CERR << "unknown option: " << arg << endl;
+		    CERR << "unknown option: " << arg << OFendl;
 		    return 1;
 		}
 		break;
@@ -472,7 +465,7 @@ int main(int argc, char *argv[])
 		if (arg[0] == '+' && arg[2] == '\0') {
 		    verifymode = OFTrue;
 		} else {
-		    CERR << "unknown option: " << arg << endl;
+		    CERR << "unknown option: " << arg << OFendl;
 		    return 1;
 		}
 		break;
@@ -480,18 +473,15 @@ int main(int argc, char *argv[])
 		if (arg[0] == '+' && arg[2] == '\0') {
 		    verbosemode = OFTrue;
 		} else {
-		    CERR << "unknown option: " << arg << endl;
+		    CERR << "unknown option: " << arg << OFendl;
 		    return 1;
 		}
 		break;
 	    case 'd':
-		if (sscanf(arg+2, "%d", &localDebugLevel) != 1) {
-		    CERR << "unknown option: " << arg << endl;
-		    return 1;
-		}
+		OFLog::configure(OFLogger::DEBUG_LOG_LEVEL);
 		break;
 	    default:
-		CERR << "unknown option: " << arg << endl;
+		CERR << "unknown option: " << arg << OFendl;
 		return 1;
 	    }
 	} else if ( ifname == NULL ) {
@@ -499,7 +489,7 @@ int main(int argc, char *argv[])
 	} else if ( ofname == NULL ) {
 	    ofname = arg;
 	} else {
-	    CERR << "too many arguments: " << arg << endl;
+	    CERR << "too many arguments: " << arg << OFendl;
 	    usage();
 	    return 1;
 	}
@@ -519,19 +509,17 @@ int main(int argc, char *argv[])
     if (!dcmDataDict.isDictionaryLoaded()) {
 	CERR << "Warning: no data dictionary loaded, "
 	     << "check environment variable: "
-	     << DCM_DICT_ENVIRONMENT_VARIABLE << endl;
+	     << DCM_DICT_ENVIRONMENT_VARIABLE << OFendl;
     }
-    
-    SetDebugLevel(( localDebugLevel ));
 
     // create dicom metaheader and dataset
 
     fileformat = new DcmFileFormat();
     if (! fileformat) {
-	CERR << "virtual memory exhausted" << endl;
+	CERR << "virtual memory exhausted" << OFendl;
 	return 1;
     }
-    
+
     if (keepOverride)
     {
       // update old WL file
@@ -539,20 +527,20 @@ int main(int argc, char *argv[])
     }
 
     dataset=fileformat->getDataset();
-        
+
     OFBool parseOK = OFTrue;
 
     if (strcmp(ifname, "-") == 0) {
 	/* read from stdin */
 	parseOK = parseWorklist(stdin, *dataset);
-	
+
     } else {
 	FILE* f = NULL;
 	if ((f = fopen(ifname, "r")) != NULL) {
 	    parseOK = parseWorklist(f, *dataset);
 	    fclose(f);
 	} else {
-	    CERR << "cannot open file: " << ifname << endl;
+	    CERR << "cannot open file: " << ifname << OFendl;
 	}
     }
 
@@ -567,20 +555,20 @@ int main(int argc, char *argv[])
 
     if (verifymode) {
 	if (verbosemode)
-	    COUT << "verifying dataset" << endl;
+	    COUT << "verifying dataset" << OFendl;
 	dataset->verify(OFTrue);
     }
 
     /* write to file */
-    
+
     if (verbosemode)
-	COUT << "writing file: " << ofname << endl;
+	COUT << "writing file: " << ofname << OFendl;
 
     OFCondition l_error = fileformat->saveFile(ofname, xfer, enctype, ogltype);
 
     if (l_error.bad()) {
 	CERR << "Error: " << l_error.text()
-	    << ": writing file: "  << ofname << endl;
+	    << ": writing file: "  << ofname << OFendl;
 	return 1;
     }
 
@@ -590,6 +578,27 @@ int main(int argc, char *argv[])
 /*
  * CVS/RCS Log
  *   $Log: writwlst.cc,v $
+ *   Revision 1.10  2010-11-01 13:37:32  uli
+ *   Fixed some compiler warnings reported by gcc with additional flags.
+ *
+ *   Revision 1.9  2010-10-14 13:20:03  joergr
+ *   Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *   Revision 1.8  2010-08-09 13:32:08  joergr
+ *   Updated data dictionary to 2009 edition of the DICOM standard. From now on,
+ *   the official "keyword" is used for the attribute name which results in a
+ *   number of minor changes (e.g. "PatientsName" is now called "PatientName").
+ *
+ *   Revision 1.7  2009-11-24 10:40:01  uli
+ *   Switched to logging mechanism provided by the "new" oflog module.
+ *
+ *   Revision 1.6  2008-04-30 12:38:43  meichel
+ *   Fixed compile errors due to changes in attribute tag names
+ *
+ *   Revision 1.5  2006/08/15 16:15:48  meichel
+ *   Updated the code in module dcmwlm to correctly compile when
+ *     all standard C++ classes remain in namespace std.
+ *
  *   Revision 1.4  2005/12/08 15:48:40  meichel
  *   Changed include path schema for all DCMTK header files
  *
