@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1998-2005, OFFIS
+ *  Copyright (C) 1998-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  ofstd
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: Template class for command line arguments (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:49 $
- *  CVS/RCS Revision: $Revision: 1.36 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:52 $
+ *  CVS/RCS Revision: $Revision: 1.50 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -53,9 +49,12 @@
  *  constant initializations  *
  *----------------------------*/
 
-const int OFCommandLine::ExpandWildcards = 0x0001;
-const int OFCommandLine::NoCommandFiles  = 0x0002;
+const int OFCommandLine::PF_ExpandWildcards = 0x0001;
+const int OFCommandLine::PF_NoCommandFiles  = 0x0002;
 
+const int OFCommandLine::AF_Exclusive       = 0x0001;
+const int OFCommandLine::AF_Internal        = 0x0002;
+const int OFCommandLine::AF_NoWarning       = 0x0004;
 
 /*-----------------------*
  *  struct declarations  *
@@ -75,21 +74,20 @@ struct OFCmdOption
      *  @param  valueCount  number of additional values
      *  @param  valueDescr  description of optional values
      *  @param  optDescr    description of command line option
-     *  @param  exclusive   exclusive option which cannot be combined with any other command
-     *                      line argument if OFTrue, e.g. "--help" or "--version"
+     *  @param  flags       flags (see AF_xxx)
      */
     OFCmdOption(const char *longOpt,
                 const char *shortOpt,
                 const int valueCount,
                 const char *valueDescr,
                 const char *optDescr,
-                const OFBool exclusive)
+                const int flags)
       : LongOption(longOpt),
         ShortOption(shortOpt),
         ValueCount(valueCount),
         ValueDescription(valueDescr),
         OptionDescription(optDescr),
-        ExclusiveOption(exclusive),
+        Flags(flags),
         Checked(OFFalse)
     {
     }
@@ -99,9 +97,9 @@ struct OFCmdOption
     ~OFCmdOption()
     {
 #ifdef DEBUG
-        if (!Checked && !ExclusiveOption && (LongOption.length() > 0))
+        if (!Checked && !(Flags & (OFCommandLine::AF_Exclusive | OFCommandLine::AF_NoWarning)) && (LongOption.length() > 0))
         {
-            ofConsole.lockCerr() << "WARNING: option " << LongOption << " has possibly never been checked !" << endl;
+            ofConsole.lockCerr() << "WARNING: option " << LongOption << " has possibly never been checked !" << OFendl;
             ofConsole.unlockCerr();
         }
 #endif
@@ -117,8 +115,8 @@ struct OFCmdOption
     const OFString ValueDescription;
     /// description of command line option
     const OFString OptionDescription;
-    /// exclusive option cannot be combined with any other command line argument
-    const OFBool ExclusiveOption;
+    /// flags (see AF_xxx)
+    const int Flags;
     /// OFTrue if findOption has been applied to this option
     OFBool Checked;
 
@@ -174,7 +172,8 @@ private:
  *------------------*/
 
 OFCommandLine::OFCommandLine()
-  : ValidOptionList(),
+  : ProgramName(),
+    ValidOptionList(),
     ValidParamList(),
     ArgumentList(),
     ArgumentIterator(),
@@ -201,6 +200,10 @@ OFCommandLine::~OFCommandLine()
     const OFListIterator(OFCmdOption *) last_o = ValidOptionList.end();
     while (first_o != last_o)
     {
+        /* avoid wrong warning message */
+        if (ExclusiveOption)
+            (*first_o)->Checked = OFTrue;
+        /* delete object and remove from list */
         delete (*first_o);
         first_o = ValidOptionList.erase(first_o);
     }
@@ -270,7 +273,7 @@ OFBool OFCommandLine::addOption(const char *longOpt,
                                 const int valueCount,
                                 const char *valueDescr,
                                 const char *optDescr,
-                                const OFBool exclusive)
+                                const int flags)
 {
     if (checkOption(longOpt) && checkOption(shortOpt))
     {
@@ -283,14 +286,14 @@ OFBool OFCommandLine::addOption(const char *longOpt,
             {
                 if ((*iter)->LongOption == longOpt)
                 {
-                    ofConsole.lockCerr() << "WARNING: long option " << longOpt << " already defined ... not added !" << endl;
+                    ofConsole.lockCerr() << "WARNING: long option " << longOpt << " already defined ... not added !" << OFendl;
                     ofConsole.unlockCerr();
                     return OFFalse;
                 }
                 if ((strlen(shortOpt) > 0) && ((*iter)->ShortOption == shortOpt))
                 {
                     ofConsole.lockCerr() << "WARNING: short option " << shortOpt << " already defined for " << (*iter)->LongOption
-                                         << " ..." << endl << "         option " << longOpt << " not added !" << endl;
+                                         << " ..." << OFendl << "         option " << longOpt << " not added !" << OFendl;
                     ofConsole.unlockCerr();
                     return OFFalse;
                 }
@@ -298,9 +301,7 @@ OFBool OFCommandLine::addOption(const char *longOpt,
             }
         }
 #endif
-        /* consider "--help" always an exclusive option */
-        const OFBool exclMode = (longOpt != NULL) && (strcmp(longOpt, "--help") == 0) ? OFTrue : exclusive;
-        OFCmdOption *opt = new OFCmdOption(longOpt, shortOpt, valueCount, valueDescr, optDescr, exclMode);
+        OFCmdOption *opt = new OFCmdOption(longOpt, shortOpt, valueCount, valueDescr, optDescr, flags);
         if (opt != NULL)
         {
             ValidOptionList.push_back(opt);
@@ -308,7 +309,7 @@ OFBool OFCommandLine::addOption(const char *longOpt,
         }
     }
 #ifdef DEBUG
-    ofConsole.lockCerr() << "WARNING: invalid option " << shortOpt << "/" <<longOpt << " ... not added !" << endl;
+    ofConsole.lockCerr() << "WARNING: invalid option " << shortOpt << "/" <<longOpt << " ... not added !" << OFendl;
     ofConsole.unlockCerr();
 #endif
     return OFFalse;
@@ -318,9 +319,9 @@ OFBool OFCommandLine::addOption(const char *longOpt,
 OFBool OFCommandLine::addOption(const char *longOpt,
                                 const char *shortOpt,
                                 const char *optDescr,
-                                const OFBool exclusive)
+                                const int flags)
 {
-    return addOption(longOpt, shortOpt, 0, "", optDescr, exclusive);
+    return addOption(longOpt, shortOpt, 0, "", optDescr, flags);
 }
 
 
@@ -328,17 +329,17 @@ OFBool OFCommandLine::addOption(const char *longOpt,
                                 const int valueCount,
                                 const char *valueDescr,
                                 const char *optDescr,
-                                const OFBool exclusive)
+                                const int flags)
 {
-    return addOption(longOpt, "", valueCount, valueDescr, optDescr, exclusive);
+    return addOption(longOpt, "", valueCount, valueDescr, optDescr, flags);
 }
 
 
 OFBool OFCommandLine::addOption(const char *longOpt,
                                 const char *optDescr,
-                                const OFBool exclusive)
+                                const int flags)
 {
-    return addOption(longOpt, "", 0, "", optDescr, exclusive);
+    return addOption(longOpt, "", 0, "", optDescr, flags);
 }
 
 
@@ -368,26 +369,26 @@ OFBool OFCommandLine::addParam(const char *param,
         switch (LastParamMode)
         {
             case OFCmdParam::PM_Optional:
-                if (mode != OFCmdParam::PM_Optional)
+                if ((mode != OFCmdParam::PM_Optional) && (mode != OFCmdParam::PM_MultiOptional))
                 {
                     ofConsole.lockCerr() << "WARNING: " << ValidParamList.size() << ". parameter is optional => hides "
-                                         << param << " !" << endl;
+                                         << param << " !" << OFendl;
                     ofConsole.unlockCerr();
                 }
                 break;
 /*
             case OFCmdParam::PM_MultiMandatory:
                 {
-                    ofConsole.lockCerr() << "WARNING: " << ValidParamList.size() << ". parameter is multi_mandatory => hides "
-                                         << param << " !" << endl;
+                    ofConsole.lockCerr() << "WARNING: " << ValidParamList.size() << ". parameter is multi-mandatory => hides "
+                                         << param << " !" << OFendl;
                     ofConsole.unlockCerr();
                 }
                 break;
 */
             case OFCmdParam::PM_MultiOptional:
                 {
-                    ofConsole.lockCerr() << "WARNING: " << ValidParamList.size() << ". parameter is multi_optional => hides "
-                                         << param << " !" << endl;
+                    ofConsole.lockCerr() << "WARNING: " << ValidParamList.size() << ". parameter is multi-optional => hides "
+                                         << param << " !" << OFendl;
                     ofConsole.unlockCerr();
                 }
                 break;
@@ -663,38 +664,65 @@ OFBool OFCommandLine::findOption(const char *longOpt,
     }
     if (iter == last)
     {
-        ofConsole.lockCerr() << "WARNING: unknown option " << longOpt << " in 'OFCommandLine::findOption()' !" << endl;
+        ofConsole.lockCerr() << "WARNING: unknown option " << longOpt << " in OFCommandLine::findOption() !" << OFendl;
         ofConsole.unlockCerr();
         return OFFalse;
     }
 #endif
-    OFListIterator(OFListIterator_OFString) pos_iter = (mode == FOM_Next) ? OptionPosIterator : OptionPosList.end();
-    const OFListIterator(OFListIterator_OFString) pos_first = OptionPosList.begin();
-    OFListIterator(OFCmdParamPos *) param_iter;
-    int diropt = 0;
-    if (findParam(abs(pos), param_iter))                               // go to specified parameter position
+    // reverse direction (left to right)
+    if ((mode == FOM_FirstFromLeft) || (mode == FOM_NextFromLeft))
     {
-        diropt = (*param_iter)->DirectOption;                          // number of direct predecessors
-        if (((*param_iter)->OptionCount == 0) ||                       // no options in front of specified parameter or
-            ((pos < 0) && (diropt == 0)))                              // no 'direct' option ...
-                return OFFalse;
-        pos_iter = (*param_iter)->OptionIter;                          // first option in front of parameter
-        ++pos_iter;                                                    // goto next to facilitate loop condition
-    }
-    while (pos_iter != pos_first)
-    {
-        ArgumentIterator = *(--pos_iter);
-        if (OptionBlockMode && (pos_iter == OptionBlockIterator))      // new option is in front of alternative block option
-            return OFFalse;
-        else if (*ArgumentIterator == longOpt)                         // searched option
+#ifdef DEBUG
+        if (pos != 0)
         {
-            OptionPosIterator = pos_iter;                              // store option position
-            if (mode == FOM_Normal)
-                OptionBlockIterator = pos_iter;
-            return OFTrue;
+            ofConsole.lockCerr() << "WARNING: OFCommandLine::findOption() parameter 'pos' (" << pos << ") ignored !" << OFendl;
+            ofConsole.unlockCerr();
+        }
+#endif
+        OFListIterator(OFListIterator_OFString) pos_iter = OptionPosList.begin();
+        const OFListIterator(OFListIterator_OFString) pos_end = OptionPosList.end();
+        if (mode == FOM_NextFromLeft)
+            pos_iter = (OptionPosIterator == pos_end) ? pos_end : ++OptionPosIterator;
+        while (pos_iter != pos_end)
+        {
+            ArgumentIterator = *pos_iter;
+            if (*ArgumentIterator == longOpt)                              // searched option
+            {
+                OptionPosIterator = pos_iter;                              // store option position
+                return OFTrue;
+            }
+            pos_iter++;
+        }
+    } else {
+        // normal direction (right to left)
+        OFListIterator(OFListIterator_OFString) pos_iter = (mode == FOM_Next) ? OptionPosIterator : OptionPosList.end();
+        const OFListIterator(OFListIterator_OFString) pos_first = OptionPosList.begin();
+        OFListIterator(OFCmdParamPos *) param_iter;
+        int diropt = 0;
+        if (findParam(abs(pos), param_iter))                               // go to specified parameter position
+        {
+            diropt = (*param_iter)->DirectOption;                          // number of direct predecessors
+            if (((*param_iter)->OptionCount == 0) ||                       // no options in front of specified parameter or
+                ((pos < 0) && (diropt == 0)))                              // no 'direct' option ...
+                    return OFFalse;
+            pos_iter = (*param_iter)->OptionIter;                          // first option in front of parameter
+            ++pos_iter;                                                    // goto next to facilitate loop condition
+        }
+        while (pos_iter != pos_first)
+        {
+            ArgumentIterator = *(--pos_iter);
+            if (OptionBlockMode && (pos_iter == OptionBlockIterator))      // new option is in front of alternative block option
+                return OFFalse;
+            else if (*ArgumentIterator == longOpt)                         // searched option
+            {
+                OptionPosIterator = pos_iter;                              // store option position
+                if (mode == FOM_Normal)
+                    OptionBlockIterator = pos_iter;
+                return OFTrue;
+            }
+            else if ((pos < 0) && (--diropt <= 0))                         // search only for the direct predecessor
+                return OFFalse;
         }
-        else if ((pos < 0) && (--diropt <= 0))                         // search only for the direct predecessor
-            return OFFalse;
     }
     return OFFalse;
 }
@@ -1030,8 +1058,10 @@ OFCommandLine::E_ParseStatus OFCommandLine::checkParamCount()
         }
         ++iter;
     }
-    if ((getArgCount() == 0) || ((getArgCount() == 1) && hasExclusiveOption()))
+    if (getArgCount() == 0)
         return PS_NoArguments;
+    else if (hasExclusiveOption())
+        return PS_ExclusiveOption;
     else if (getParamCount() < MinParamCount)
         return PS_MissingParameter;
     else if ((MaxParamCount >= 0) && (getParamCount() > MaxParamCount))
@@ -1047,23 +1077,66 @@ OFCommandLine::E_ParseStatus OFCommandLine::parseCommandFile(const char *argValu
     /* check for command file parameter (syntax: "@filename") */
     if ((argValue != NULL) && (strlen(argValue) > 1) && (argValue[0] == COMMAND_FILE_PREFIX))
     {
+        /* skip '@' symbol in filename */
+        const char *filename = argValue + 1;
         /* open command file */
 #ifdef HAVE_IOS_NOCREATE
-        ifstream cmdFile(argValue + 1, ios::in|ios::nocreate);
+        STD_NAMESPACE ifstream cmdFile(filename, STD_NAMESPACE ios::in|STD_NAMESPACE ios::nocreate);
 #else
-        ifstream cmdFile(argValue + 1, ios::in);
+        STD_NAMESPACE ifstream cmdFile(filename, STD_NAMESPACE ios::in);
 #endif
         if (cmdFile)
         {
+            char c, block = 0;
             OFString value;
-            /* append comand file content to the list of arguments */
-            while (!cmdFile.eof())
+            /* append command file content to the list of arguments */
+            while (cmdFile.get(c))
             {
-                /* read formatted input (ignore whitespaces) */
-                cmdFile >> value;
-                if (!value.empty())
-                    argList.push_back(value);
+                /* double or single quote */
+                if ((c == '"') || (c == '\''))
+                {
+                    if (block == c)
+                    {
+                        /* closing current quote block (also empty value) */
+                        argList.push_back(value);
+                        value.clear();
+                        block = 0;
+                    }
+                    else if (block == 0)
+                    {
+                        /* starting new quote block */
+                        block = c;
+                    } else {
+                        /* append character */
+                        value += c;
+                    }
+                }
+                /* space, tab, newline or return */
+                else if ((c == ' ') || (c == '\t') || (c == '\n') || (c == '\r'))
+                {
+                    /* outside block quote? */
+                    if (block == 0)
+                    {
+                        if (!value.empty())
+                        {
+                            argList.push_back(value);
+                            value.clear();
+                        }
+                    } else
+                        value += c;
+                } else
+                    value += c;
             }
+            /* append remaining argument (if any) */
+            if (!value.empty())
+                argList.push_back(value);
+#ifdef DEBUG
+            if (block != 0)
+            {
+                ofConsole.lockCerr() << "WARNING: closing quotation mark (" << block << ") missing in command file " << filename << OFendl;
+                ofConsole.unlockCerr();
+            }
+#endif
             result = PS_Normal;
         } else
             result = PS_CannotOpenCommandFile;
@@ -1081,6 +1154,10 @@ OFCommandLine::E_ParseStatus OFCommandLine::parseLine(int argCount,
     ParamPosList.clear();
     OptionPosList.clear();
     ExclusiveOption = OFFalse;
+    if (argCount > 0)                                                    // determine program name
+        ProgramName = argValue[0];
+    else
+        ProgramName.clear();
     if (argCount > startPos)                                             // any command line arguments?
     {
         int i;
@@ -1089,7 +1166,7 @@ OFCommandLine::E_ParseStatus OFCommandLine::parseLine(int argCount,
         /* expand command files (if any) */
         for (i = startPos; i < argCount; i++)                            // skip program name (argValue[0])
         {
-            if (flags & NoCommandFiles)                                  // do not try to detect command files
+            if (flags & PF_NoCommandFiles)                               // do not try to detect command files
                 argList.push_back(argValue[i]);
             else
             {
@@ -1113,7 +1190,7 @@ OFCommandLine::E_ParseStatus OFCommandLine::parseLine(int argCount,
             if (!checkOption(*argIter, OFFalse))                         // arg = parameter
             {
 #ifdef HAVE_WINDOWS_H
-                if (flags & ExpandWildcards)                             // expand wildcards
+                if (flags & PF_ExpandWildcards)                          // expand wildcards
                     expandWildcards(*argIter, directOption);
                 else
 #endif
@@ -1125,7 +1202,7 @@ OFCommandLine::E_ParseStatus OFCommandLine::parseLine(int argCount,
                 {
                     ArgumentList.push_back(OFstatic_cast(OFString, opt->LongOption)); // convert argument to long format
                     OptionPosList.push_back(--ArgumentList.end());
-                    if (opt->ExclusiveOption)                            // check for an "exclusive" option
+                    if (opt->Flags & AF_Exclusive)                       // check for an "exclusive" option
                         ExclusiveOption = OFTrue;
                     directOption++;
                     int j = opt->ValueCount;                             // number of expected values
@@ -1208,60 +1285,70 @@ void OFCommandLine::getOptionString(OFString &optionStr) const
         const unsigned int columnSpace = 2;
         while (iter != last)
         {
-            if (newGrp)
+            /* skip internal options */
+            if (!((*iter)->Flags & OFCommandLine::AF_Internal))
             {
-                OFListConstIterator(OFCmdOption *) i = iter;
-                while ((i != last) && ((*i)->LongOption.length() > 0))
+                if (newGrp)
                 {
-                    if ((*i)->ShortOption.length() > shortSize)
-                        shortSize = (*i)->ShortOption.length();
-                    if ((*i)->LongOption.length() > longSize)
-                        longSize = (*i)->LongOption.length();
-                    i++;
+                    /* determine column width per group */
+                    OFListConstIterator(OFCmdOption *) i = iter;
+                    while ((i != last) && ((*i)->LongOption.length() > 0))
+                    {
+                        if (!((*i)->Flags & OFCommandLine::AF_Internal))
+                        {
+                            if ((*i)->ShortOption.length() > shortSize)
+                                shortSize = (*i)->ShortOption.length();
+                            if ((*i)->LongOption.length() > longSize)
+                                longSize = (*i)->LongOption.length();
+                        }
+                        i++;
+                    }
+                    newGrp = 0;
                 }
-                newGrp = 0;
-            }
-            if ((*iter)->LongOption.length() <= 0)
-            {
-                newGrp = 1;
-                unpackColumnValues((*iter)->ValueCount, longSize, shortSize);
-                if ((*iter)->OptionDescription.length() > 0)                 // new group
+                if ((*iter)->LongOption.length() <= 0)
                 {
-                    optionStr += (*iter)->OptionDescription;
-                    lineIndent = groupIndent;
-                } else {                                                     // new sub group
-                    optionStr.append(groupIndent, ' ');
-                    optionStr += (*iter)->ValueDescription;
-                    lineIndent = subGrpIndent;
-                }
-                optionStr += "\n";
-            } else {
-                optionStr.append(lineIndent, ' ');
-                if (shortSize > 0)
-                {
-                    str = (*iter)->ShortOption;
-                    str.resize(shortSize, ' ');
+                    /* group entry */
+                    newGrp = 1;
+                    unpackColumnValues((*iter)->ValueCount, longSize, shortSize);
+                    if ((*iter)->OptionDescription.length() > 0)                 // new group
+                    {
+                        optionStr += (*iter)->OptionDescription;
+                        lineIndent = groupIndent;
+                    } else {                                                     // new sub group
+                        optionStr.append(groupIndent, ' ');
+                        optionStr += (*iter)->ValueDescription;
+                        lineIndent = subGrpIndent;
+                    }
+                    optionStr += "\n";
+                } else {
+                    /* regular option */
+                    optionStr.append(lineIndent, ' ');
+                    if (shortSize > 0)
+                    {
+                        str = (*iter)->ShortOption;
+                        str.resize(shortSize, ' ');
+                        optionStr += str;
+                        optionStr.append(columnSpace, ' ');
+                    }
+                    str = (*iter)->LongOption;
+                    str.resize(longSize, ' ');
                     optionStr += str;
                     optionStr.append(columnSpace, ' ');
-                }
-                str = (*iter)->LongOption;
-                str.resize(longSize, ' ');
-                optionStr += str;
-                optionStr.append(columnSpace, ' ');
-                if ((*iter)->ValueDescription.length() > 0)
-                {
-                    optionStr += (*iter)->ValueDescription;
+                    if ((*iter)->ValueDescription.length() > 0)
+                    {
+                        optionStr += (*iter)->ValueDescription;
+                        optionStr += "\n";
+                        optionStr.append(lineIndent + shortSize + longSize + columnSpace, ' ');
+                        if (shortSize > 0)
+                            optionStr.append(columnSpace, ' ');
+                    }
+                    str = (*iter)->OptionDescription;
+                    size_t pos = 0;
+                    while (((pos = (str.find('\n', pos))) != OFString_npos) && (pos < str.length()))
+                        str.insert(++pos, OFString(lineIndent + shortSize + longSize + 2 * columnSpace, ' '));
+                    optionStr += str;
                     optionStr += "\n";
-                    optionStr.append(lineIndent + shortSize + longSize + columnSpace, ' ');
-                    if (shortSize > 0)
-                        optionStr.append(columnSpace, ' ');
                 }
-                str = (*iter)->OptionDescription;
-                size_t pos = 0;
-                while (((pos = (str.find('\n', pos))) != OFString_npos) && (pos < str.length()))
-                    str.insert(++pos, OFString(lineIndent + shortSize + longSize + 2 * columnSpace, ' '));
-                optionStr += str;
-                optionStr += "\n";
             }
             ++iter;
         }
@@ -1355,9 +1442,13 @@ void OFCommandLine::getStatusString(const E_ParseStatus status,
             statusStr = "Too many parameters";
             break;
         case PS_CannotOpenCommandFile:
-            statusStr = "Cannot open command file ";
+            statusStr = "Cannot open command file";
             if (getLastArg(str))
+            {
+                statusStr += " '";
                 statusStr += str;
+                statusStr += "'";
+            }
             break;
         default:
             statusStr.clear();
@@ -1462,6 +1553,57 @@ void OFCommandLine::getStatusString(const E_ValueStatus status,
  *
  * CVS/RCS Log:
  * $Log: ofcmdln.cc,v $
+ * Revision 1.50  2010-10-14 13:14:52  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.49  2010-06-21 16:32:51  joergr
+ * Removed wrong warning message on an optional parameter hiding another one.
+ *
+ * Revision 1.48  2009-12-23 12:19:02  joergr
+ * Added support for getting the name of the program, i.e. the value of argv[0].
+ *
+ * Revision 1.47  2009-06-04 09:52:31  joergr
+ * Added new flag that can be used to avoid wrong warning messages (in debug
+ * mode) that an option has possibly never been checked.
+ *
+ * Revision 1.46  2008-09-24 13:04:58  joergr
+ * Fixed typo in output of getStatusString().
+ *
+ * Revision 1.45  2008-04-16 12:39:40  joergr
+ * Added support for reverse search direction (left to right) to findOption().
+ *
+ * Revision 1.44  2008-03-17 10:08:41  onken
+ * Corrected "or" to "||".
+ *
+ * Revision 1.43  2008-03-11 16:18:56  joergr
+ * Moved warning message on missing quotation mark when reading command files.
+ *
+ * Revision 1.42  2008-03-03 13:16:39  joergr
+ * Enhanced support for quotation marks in command files.
+ *
+ * Revision 1.41  2007/03/16 11:20:44  joergr
+ * Fixed wrong warning message about unchecked options in debug mode.
+ *
+ * Revision 1.40  2006/08/21 12:41:52  meichel
+ * Updated code to correctly compile when
+ *   all standard C++ classes remain in namespace std.
+ *
+ * Revision 1.39  2006/08/14 16:42:46  meichel
+ * Updated all code in module ofstd to correctly compile if the standard
+ *   namespace has not included into the global one with a "using" directive.
+ *
+ * Revision 1.38  2006/07/27 15:49:08  joergr
+ * Fixed typo which caused compilation problems under Windows.
+ *
+ * Revision 1.37  2006/07/27 13:21:28  joergr
+ * Changed parameter "exclusive" of method addOption() from type OFBool into an
+ * integer parameter "flags".
+ * Added new addOption() flag for internal options that are not shown in the
+ * syntax usage output. Prepended prefix "PF_" to parseLine() flags.
+ * Option "--help" is no longer an exclusive option by default.
+ * Slightly changed behaviour of "exclusive" options like "--help" or
+ * "--version". Method parseLine() now returns PS_ExclusiveOption.
+ *
  * Revision 1.36  2005/12/08 15:48:49  meichel
  * Changed include path schema for all DCMTK header files
  *
