@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1999-2005, OFFIS
+ *  Copyright (C) 1999-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  ofstd
  *
@@ -21,10 +17,9 @@
  *
  *  Purpose: Handle console applications (Source)
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:48:50 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/ofstd/libsrc/ofconapp.cc,v $
- *  CVS/RCS Revision: $Revision: 1.21 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:14:52 $
+ *  CVS/RCS Revision: $Revision: 1.30 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -46,9 +41,9 @@
 OFConsoleApplication::OFConsoleApplication(const char *app,
                                            const char *desc,
                                            const char *rcsid)
- : Name(app),
-   Description(desc),
-   Identification(rcsid),
+ : Name(OFSTRING_GUARD(app)),
+   Description(OFSTRING_GUARD(desc)),
+   Identification(OFSTRING_GUARD(rcsid)),
    QuietMode(OFFalse),
    CmdLine(NULL)
 {
@@ -73,7 +68,14 @@ OFBool OFConsoleApplication::parseCommandLine(OFCommandLine &cmd,
     {
         case OFCommandLine::PS_NoArguments:
             /* check whether to print the "usage text" or not */
-            if (((cmd.getMinParamCount() > 0) && !cmd.hasExclusiveOption()) || cmd.findOption("--help"))
+            if (cmd.getMinParamCount() > 0)
+                printUsage();
+            else
+                result = OFTrue;
+            break;
+        case OFCommandLine::PS_ExclusiveOption:
+            /* check whether to print the "usage text" or not */
+            if (cmd.findOption("--help"))
                 printUsage();
             else
                 result = OFTrue;
@@ -97,16 +99,16 @@ void OFConsoleApplication::printHeader(const OFBool hostInfo,
                                        const OFBool stdError)
 {
     /* lock output stream */
-    ostream *output = (stdError) ? &ofConsole.lockCerr() : &ofConsole.lockCout();
+    STD_NAMESPACE ostream *output = (stdError) ? &ofConsole.lockCerr() : &ofConsole.lockCout();
     if (!Identification.empty())
-        (*output) << Identification << endl << endl;
+        (*output) << Identification << OFendl << OFendl;
     (*output) << Name;
     if (!Description.empty())
         (*output) << ": " << Description;
-    (*output) << endl;
+    (*output) << OFendl;
     /* print optional host information */
     if (hostInfo)
-        (*output) << endl << "Host type: " << CANONICAL_HOST_TYPE << endl;
+        (*output) << OFendl << "Host type: " << CANONICAL_HOST_TYPE << OFendl;
     /* release output stream */
     if (stdError)
         ofConsole.unlockCerr();
@@ -120,34 +122,68 @@ void OFConsoleApplication::printUsage(const OFCommandLine *cmd)
     if (cmd == NULL)
         cmd = CmdLine;
     printHeader();
-    ostream &output = ofConsole.lockCout();
+    STD_NAMESPACE ostream &output = ofConsole.lockCout();
     output << "usage: " << Name;
     if (cmd != NULL)
     {
         OFString str;
         cmd->getSyntaxString(str);
-        output << str << endl;
+        output << str << OFendl;
         cmd->getParamString(str);
         if (str.length() > 0)
-            output << endl << str;
+            output << OFendl << str;
         cmd->getOptionString(str);
         if (str.length() > 0)
-            output << endl << str;
+            output << OFendl << str;
     }
-    output << endl;
+    output << OFendl;
     ofConsole.unlockCout();
     /* exit code: no error */
     exit(0);
 }
 
 
+void OFConsoleApplication::printArguments(OFCommandLine *cmd)
+{
+    if (cmd == NULL)
+        cmd = CmdLine;
+    STD_NAMESPACE ostream &output = ofConsole.lockCerr();
+    if (CmdLine != NULL)
+    {
+        output << "expanded command line to " << CmdLine->getArgCount() << " arguments:" << OFendl;
+        const char *arg;
+        /* iterate over all command line arguments */
+        if (CmdLine->gotoFirstArg())
+        {
+            do {
+                if (CmdLine->getCurrentArg(arg))
+                    output << "'" << arg << "' ";
+            } while (CmdLine->gotoNextArg());
+        }
+        output << OFendl << OFendl;
+    } else
+        output << "warning: cannot print expanded command line arguments" << OFendl << OFendl;
+    ofConsole.unlockCerr();
+}
+
+
+void OFConsoleApplication::printIdentifier()
+{
+    if (!Identification.empty())
+    {
+        ofConsole.lockCerr() << Identification << OFendl << OFendl;
+        ofConsole.unlockCerr();
+    }
+}
+
+
 void OFConsoleApplication::printError(const char *str,
                                       const int code)
 {
     if (!QuietMode)
     {
         printHeader(OFFalse /*hostInfo*/, OFTrue /*stdError*/);
-        ofConsole.lockCerr() << "error: " << str << endl;
+        ofConsole.lockCerr() << "error: " << str << OFendl;
         ofConsole.unlockCerr();
     }
     exit(code);
@@ -160,9 +196,9 @@ void OFConsoleApplication::printWarning(const char *str,
     if (!QuietMode)
     {
         ofConsole.lockCerr() << Name << ": ";
-        if ((prefix != NULL) && (strlen(prefix) > 0))
+        if ((prefix != NULL) && (prefix[0] != '\0'))
             ofConsole.getCerr() << prefix << ": ";
-        ofConsole.getCerr() << str << endl;
+        ofConsole.getCerr() << str << OFendl;
         ofConsole.unlockCerr();
     }
 }
@@ -172,7 +208,7 @@ void OFConsoleApplication::printMessage(const char *str)
 {
     if (!QuietMode)
     {
-        ofConsole.lockCerr() << str << endl;
+        ofConsole.lockCerr() << str << OFendl;
         ofConsole.unlockCerr();
     }
 }
@@ -254,6 +290,36 @@ void OFConsoleApplication::checkConflict(const char *firstOpt,
  *
  * CVS/RCS Log:
  * $Log: ofconapp.cc,v $
+ * Revision 1.30  2010-10-14 13:14:52  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.29  2010-08-10 09:34:20  uli
+ * Fixed some unlikely problems with NULL pointers.
+ *
+ * Revision 1.28  2010-06-29 13:45:58  uli
+ * Fix a typo in my last commit.
+ *
+ * Revision 1.27  2010-06-29 12:56:47  uli
+ * Avoid an unneeded call to strlen().
+ *
+ * Revision 1.26  2008-09-25 11:14:58  joergr
+ * Added method for printing the resource identifier of an application.
+ *
+ * Revision 1.25  2008-09-25 10:10:21  joergr
+ * Print expanded command line arguments to stderr and not to stdout.
+ *
+ * Revision 1.24  2008-09-24 13:25:09  joergr
+ * Added support for printing the expanded command line arguments to standard
+ * output stream.
+ *
+ * Revision 1.23  2006/08/14 16:42:46  meichel
+ * Updated all code in module ofstd to correctly compile if the standard
+ *   namespace has not included into the global one with a "using" directive.
+ *
+ * Revision 1.22  2006/07/27 13:22:12  joergr
+ * Slightly changed behaviour of "exclusive" options like "--help" or
+ * "--version". Method parseLine() now returns PS_ExclusiveOption.
+ *
  * Revision 1.21  2005/12/08 15:48:50  meichel
  * Changed include path schema for all DCMTK header files
  *
