@@ -1,27 +1,22 @@
 /*
  *
- *  Copyright (C) 2001-2005, OFFIS
+ *  Copyright (C) 2001-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
- *
  *
  *  As an exception of the above notice, the code for OFStandard::strlcpy
  *  and OFStandard::strlcat in this file have been derived from the BSD
  *  implementation which carries the following copyright notice:
  *
  *  Copyright (c) 1998 Todd C. Miller <Todd.Miller@courtesan.com>
- *  All rights reserved.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -62,7 +57,7 @@
  *  which carries the following copyright notice:
  *
  *  Copyright (c) 1988 Regents of the University of California.
- *  All rights reserved.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  Redistribution and use in source and binary forms are permitted
  *  provided that the above copyright notice and this paragraph are
@@ -92,9 +87,9 @@
  *
  *  Purpose: Class for various helper functions
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:49:00 $
- *  CVS/RCS Revision: $Revision: 1.34 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2010-11-01 08:55:56 $
+ *  CVS/RCS Revision: $Revision: 1.66 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -104,6 +99,8 @@
 
 #include "dcmtk/config/osconfig.h"    /* make sure OS specific configuration is included first */
 #include "dcmtk/ofstd/ofstd.h"
+#include "dcmtk/ofstd/ofcond.h"
+#include "dcmtk/ofstd/ofstream.h"
 
 #define INCLUDE_CMATH
 #define INCLUDE_CFLOAT
@@ -156,6 +153,9 @@ END_EXTERN_C
 
 #endif /* HAVE_WINDOWS_H */
 
+#ifdef _WIN32
+#include <process.h>     /* needed for declaration of getpid() */
+#endif
 
 // --- ftoa() processing flags ---
 
@@ -293,6 +293,87 @@ size_t OFStandard::my_strlcat(char *dst, const char *src, size_t siz)
 #endif /* HAVE_STRLCAT */
 
 
+#ifdef HAVE_PROTOTYPE_STRERROR_R
+/*
+ * convert a given error code to a string. This function wraps the various
+ * approaches found on different systems. Internally, the standard function
+ * strerror() or strerror_r() is used.
+ */
+const char *OFStandard::strerror(const int errnum,
+                                 char *buf,
+                                 const size_t buflen)
+{
+    const char *result = "";
+    if ((buf != NULL) && (buflen > 0))
+    {
+        // be paranoid and initialize the buffer to empty string
+        buf[0] = 0;
+        // two incompatible interfaces for strerror_r with different return types exist
+#ifdef HAVE_CHARP_STRERROR_R
+        // we're using the GNU specific version that returns the result, which may
+        // or may not be a pointer to buf
+        result = strerror_r(errnum, buf, buflen);
+#else
+        // we're using the X/OPEN version that always stores the result in buf
+        (void) strerror_r(errnum, buf, buflen);
+        result = buf;
+#endif
+    }
+    return result;
+}
+#else
+const char *OFStandard::strerror(const int errnum,
+                                 char * /*buf*/,
+                                 const size_t /*buflen*/)
+{
+    // we only have strerror() which is thread unsafe on Posix platforms, but thread safe on Windows
+    return STDIO_NAMESPACE strerror(errnum);
+}
+#endif
+
+
+OFString &OFStandard::toUpper(OFString &result,
+                              const OFString &value)
+{
+    result = value;
+    return OFStandard::toUpper(result);
+}
+
+
+OFString &OFStandard::toUpper(OFString &value)
+{
+    const size_t length = value.length();
+    unsigned char c;
+    for (size_t i = 0; i < length; i++)
+    {
+        c = value.at(i);
+        value.at(i) = OFstatic_cast(char, toupper(c));
+    }
+    return value;
+}
+
+
+OFString &OFStandard::toLower(OFString &result,
+                              const OFString &value)
+{
+    result = value;
+    return OFStandard::toLower(result);
+}
+
+
+OFString &OFStandard::toLower(OFString &value)
+{
+    const size_t length = value.length();
+    unsigned char c;
+    for (size_t i = 0; i < length; i++)
+    {
+        c = value.at(i);
+        value.at(i) = OFstatic_cast(char, tolower(c));
+    }
+    return value;
+}
+
+
 // --- file system functions ---
 
 OFBool OFStandard::pathExists(const OFString &pathName)
@@ -407,6 +488,42 @@ OFBool OFStandard::isWriteable(const OFString &pathName)
 }
 
 
+OFString &OFStandard::getDirNameFromPath(OFString &result,
+                                         const OFString &pathName,
+                                         const OFBool assumeDirName)
+{
+    const size_t pos = pathName.find_last_of(PATH_SEPARATOR);
+    /* path separator found? */
+    if (pos == OFString_npos)
+    {
+        if (assumeDirName)
+            result = pathName;
+        else
+            result.clear();
+    } else
+        result = pathName.substr(0, pos);
+    return result;
+}
+
+
+OFString &OFStandard::getFilenameFromPath(OFString &result,
+                                          const OFString &pathName,
+                                          const OFBool assumeFilename)
+{
+    const size_t pos = pathName.find_last_of(PATH_SEPARATOR);
+    /* path separator found? */
+    if (pos == OFString_npos)
+    {
+        if (assumeFilename)
+            result = pathName;
+        else
+            result.clear();
+    } else
+        result = pathName.substr(pos + 1);
+    return result;
+}
+
+
 OFString &OFStandard::normalizeDirName(OFString &result,
                                        const OFString &dirName,
                                        const OFBool allowEmptyDirName)
@@ -434,36 +551,87 @@ OFString &OFStandard::combineDirAndFilename(OFString &result,
                                             const OFString &fileName,
                                             const OFBool allowEmptyDirName)
 {
-    // ## might use system function realpath() in the future to resolve paths including ".."?
+    // # might use system function realpath() in the future to resolve paths including ".."
+    // # or combinations of absolute paths in both 'dirName' and 'fileName'
 
     /* check whether 'fileName' contains absolute path */
+    /* (this check also covers UNC syntax, e. g. "\\server\...") */
     if (!fileName.empty() && (fileName.at(0) == PATH_SEPARATOR))
+    {
         result = fileName;
-    else {
-        /* normalize the directory name */
-        normalizeDirName(result, dirName, allowEmptyDirName);
-        /* check file name */
-        if (!fileName.empty() && (fileName != "."))
+        return result;
+    }
+#ifdef HAVE_WINDOWS_H
+    else if ((fileName.length() >= 3))
+    {
+        /* check for absolute path containing windows drive name, e. g. "c:\..." */
+        char c = fileName.at(0);
+        if (((c >= 'A') && (c <= 'Z')) || ((c >= 'a') && (c <= 'z')))
         {
-            /* add path separator (if required) ... */
-            if (!result.empty() && (result.at(result.length() - 1) != PATH_SEPARATOR))
-                result += PATH_SEPARATOR;
-            /* ...and file name */
-            result += fileName;
+            if (fileName.substr(1, 2) == ":\\")
+            {
+                result = fileName;
+                return result;
+            }
         }
     }
+#endif
+    /* we only get here, if we don't have an absolute directory in "fileName" */
+    /* now normalize the directory name */
+    normalizeDirName(result, dirName, allowEmptyDirName);
+    /* check file name */
+    if (!fileName.empty() && (fileName != "."))
+    {
+        /* add path separator (if required) ... */
+        if (!result.empty() && (result.at(result.length() - 1) != PATH_SEPARATOR))
+            result += PATH_SEPARATOR;
+        /* ...and file name */
+        result += fileName;
+    }
     return result;
 }
 
 
+OFCondition OFStandard::removeRootDirFromPathname(OFString &result,
+                                                  const OFString &rootDir,
+                                                  const OFString &pathName,
+                                                  const OFBool allowLeadingPathSeparator)
+{
+    OFCondition status = EC_IllegalParameter;
+    const size_t rootLength = rootDir.length();
+    /* check for "compatible" length */
+    if (rootLength <= pathName.length())
+    {
+        /* check for same prefix */
+        if (pathName.compare(0, rootLength, rootDir) == 0)
+        {
+            /* remove root dir prefix from path name */
+            result = pathName.substr(rootLength);
+            if (!allowLeadingPathSeparator)
+            {
+                /* remove leading path separator (if present) */
+                if (!result.empty() && (result.at(0) == PATH_SEPARATOR))
+                    result.erase(0, 1);
+            }
+            status = EC_Normal;
+        }
+    }
+    /* return empty string in case of error */
+    if (status.bad())
+        result = "";
+    return status;
+}
+
+
 size_t OFStandard::searchDirectoryRecursively(const OFString &directory,
                                               OFList<OFString> &fileList,
                                               const OFString &pattern,
-                                              const OFString &dirPrefix)
+                                              const OFString &dirPrefix,
+                                              const OFBool recurse)
 {
     const size_t initialSize = fileList.size();
     OFString dirname, pathname, tmpString;
-    combineDirAndFilename(dirname, dirPrefix, directory, OFTrue /*allowEmptyDirName*/);
+    combineDirAndFilename(dirname, dirPrefix, directory);
 #ifdef HAVE_WINDOWS_H
     /* check whether given directory exists */
     if (dirExists(dirname))
@@ -503,12 +671,17 @@ size_t OFStandard::searchDirectoryRecursively(const OFString &directory,
                         pathname = data.cFileName;
                     else
                         combineDirAndFilename(pathname, directory, data.cFileName, OFTrue /*allowEmptyDirName*/);
-                    /* recursively search sub directories */
                     if (dirExists(combineDirAndFilename(tmpString, dirPrefix, pathname, OFTrue /*allowEmptyDirName*/)))
-                        searchDirectoryRecursively(pathname, fileList, pattern, dirPrefix);
-                    /* add filename to the list (if no pattern is given) */
+                    {
+                        /* recursively search sub directories */
+                        if (recurse)
+                            searchDirectoryRecursively(pathname, fileList, pattern, dirPrefix, recurse);
+                    }
                     else if (pattern.empty())
+                    {
+                        /* add filename to the list (if no pattern is given) */
                         fileList.push_back(pathname);
+                    }
                 }
             } while (FindNextFile(handle, &data));
             FindClose(handle);
@@ -530,17 +703,20 @@ size_t OFStandard::searchDirectoryRecursively(const OFString &directory,
                     pathname = entry->d_name;
                 else
                     combineDirAndFilename(pathname, directory, entry->d_name, OFTrue /*allowEmptyDirName*/);
-                /* recursively search sub directories */
                 if (dirExists(combineDirAndFilename(tmpString, dirPrefix, pathname, OFTrue /*allowEmptyDirName*/)))
-                    searchDirectoryRecursively(pathname, fileList, pattern, dirPrefix);
-                /* check whether filename matches pattern */
-                else
+                {
+                    /* recursively search sub directories */
+                    if (recurse)
+                        searchDirectoryRecursively(pathname, fileList, pattern, dirPrefix, recurse);
+                } else {
 #ifdef HAVE_FNMATCH_H
-                if ((pattern.empty()) || (fnmatch(pattern.c_str(), entry->d_name, FNM_PATHNAME) == 0))
+                    /* check whether filename matches pattern */
+                    if ((pattern.empty()) || (fnmatch(pattern.c_str(), entry->d_name, FNM_PATHNAME) == 0))
 #else
-                    /* no pattern matching, sorry :-/ */
+                        /* no pattern matching, sorry :-/ */
 #endif
-                    fileList.push_back(pathname);
+                        fileList.push_back(pathname);
+                }
             }
         }
         closedir(dirPtr);
@@ -551,73 +727,140 @@ size_t OFStandard::searchDirectoryRecursively(const OFString &directory,
 }
 
 
-const OFString &OFStandard::convertToMarkupString(const OFString &sourceString,
-                                                  OFString &markupString,
-                                                  const OFBool convertNonASCII,
-                                                  const OFBool xmlMode,
-                                                  const OFBool newlineAllowed)
+OFBool OFStandard::deleteFile(const OFString &filename)
 {
-    /* char ptr allows fastest access to the string */
+  int err = unlink(filename.c_str());
+  return (err == 0);
+}
+
+
+size_t OFStandard::getFileSize(const OFString &filename)
+{
+    size_t fileSize = 0;
+    struct stat fileStat;
+    if (stat(filename.c_str(), &fileStat) == 0)
+        fileSize = OFstatic_cast(size_t, fileStat.st_size);
+    return fileSize;
+}
+
+
+OFBool OFStandard::checkForMarkupConversion(const OFString &sourceString,
+                                            const OFBool convertNonASCII)
+{
+    OFBool result = OFFalse;
+    /* char pointer allows faster access to the string */
     const char *str = sourceString.c_str();
-    /* start with empty string */
-    markupString.clear();
-    /* avoid to resize the string too often */
-    markupString.reserve(strlen(str));
-    /* replace HTML/XML reserved characters */
+    unsigned char c;
+    /* check for characters to be converted */
+    do {
+        c = OFstatic_cast(unsigned char, *(str++));
+        if ((c == '<') || (c == '>') || (c == '&') || (c == '"') || (c == '\'') ||
+            (c == 10) || (c == 13) || (convertNonASCII && ((c < 32) || (c >= 127))))
+        {
+            result = OFTrue;
+            c = 0;
+        }
+    } while (c != 0);
+    return result;
+}
+
+
+OFCondition OFStandard::convertToMarkupStream(STD_NAMESPACE ostream &out,
+                                              const OFString &sourceString,
+                                              const OFBool convertNonASCII,
+                                              const E_MarkupMode markupMode,
+                                              const OFBool newlineAllowed)
+{
+    /* char pointer allows faster access to the string */
+    const char *str = sourceString.c_str();
+    /* replace HTML/XHTML/XML reserved characters */
     while (*str != 0)
     {
         /* less than */
         if (*str == '<')
-            markupString += "&lt;";
+            out << "&lt;";
         /* greater than */
         else if (*str == '>')
-            markupString += "&gt;";
+            out << "&gt;";
         /* ampers and */
         else if (*str == '&')
-            markupString += "&amp;";
+            out << "&amp;";
         /* quotation mark */
         else if (*str == '"')
-            markupString += "&quot;";
+        {
+            /* entity "&quot;" is not defined in HTML 3.2 */
+            if (markupMode == MM_HTML32)
+                out << "&#34;";
+            else
+                out << "&quot;";
+        }
         /* apostrophe */
         else if (*str == '\'')
-            markupString += "&apos;";
+        {
+            /* entity "&apos;" is not defined in HTML */
+            if ((markupMode == MM_HTML) || (markupMode == MM_HTML32))
+                out << "&#39;";
+            else
+                out << "&apos;";
+        }
         /* newline: LF, CR, LF CR, CR LF */
         else if ((*str == '\012') || (*str == '\015'))
         {
-            if (xmlMode)
+            if (markupMode == MM_XML)
             {
                 /* encode CR and LF exactly as specified */
                 if (*str == '\012')
-                    markupString += "&#10;";    // '\n'
+                    out << "&#10;";    // '\n'
                 else
-                    markupString += "&#13;";    // '\r'
-            } else {  /* HTML mode */
+                    out << "&#13;";    // '\r'
+            } else {  /* HTML/XHTML mode */
                 /* skip next character if it belongs to the newline sequence */
                 if (((*str == '\012') && (*(str + 1) == '\015')) || ((*str == '\015') && (*(str + 1) == '\012')))
                     str++;
                 if (newlineAllowed)
-                    markupString += "<br>\n";
-                else
-                    markupString += "&para;";
+                {
+                    if (markupMode == MM_XHTML)
+                        out << "<br />\n";
+                    else
+                        out << "<br>\n";
+                } else
+                    out << "&para;";
             }
         } else {
             /* other character: ... */
             const size_t charValue = OFstatic_cast(unsigned char, *str);
-            if (convertNonASCII && (charValue > 127))
+            if ((convertNonASCII || (markupMode == MM_HTML32)) && ((charValue < 32) || (charValue >= 127)))
             {
-                char buffer[16];
-                sprintf(buffer, "%lu", OFstatic_cast(unsigned long, charValue));
-                /* convert > #127 to Unicode (ISO Latin-1), what is about < #32 ? */
-                markupString += "&#";
-                markupString += buffer;
-                markupString += ";";
+                /* convert < #32 and >= #127 to Unicode (ISO Latin-1) */
+                out << "&#" << charValue << ";";
             } else {
                 /* just append */
-                markupString += *str;
+                out << *str;
             }
         }
-        str++;
+        ++str;
     }
+    return EC_Normal;
+}
+
+
+const OFString &OFStandard::convertToMarkupString(const OFString &sourceString,
+                                                  OFString &markupString,
+                                                  const OFBool convertNonASCII,
+                                                  const E_MarkupMode markupMode,
+                                                  const OFBool newlineAllowed)
+{
+    OFStringStream stream;
+    /* call stream variant of convert to markup */
+    if (OFStandard::convertToMarkupStream(stream, sourceString, convertNonASCII, markupMode, newlineAllowed).good())
+    {
+        stream << OFStringStream_ends;
+        /* convert string stream into a character string */
+        OFSTRINGSTREAM_GETSTR(stream, buffer_str)
+        markupString.assign(buffer_str);
+        OFSTRINGSTREAM_FREESTR(buffer_str)
+    } else
+        markupString.clear();
     return markupString;
 }
 
@@ -625,40 +868,37 @@ const OFString &OFStandard::convertToMarkupString(const OFString &sourceString,
 // Base64 translation table as described in RFC 2045 (MIME)
 static const char enc_base64[] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
-const OFString &OFStandard::encodeBase64(const unsigned char *data,
-                                         const size_t length,
-                                         OFString &result,
-                                         const size_t width)
+OFCondition OFStandard::encodeBase64(STD_NAMESPACE ostream &out,
+                                     const unsigned char *data,
+                                     const size_t length,
+                                     const size_t width)
 {
-    result.clear();
+    OFCondition status = EC_IllegalParameter;
     /* check data buffer to be encoded */
     if (data != NULL)
     {
         unsigned char c;
         size_t w = 0;
-        /* reserve expected output size: +33%, even multiple of 4 */
-        result.reserve(((length + 2) / 3) * 4);
-        char *bufPtr = OFconst_cast(char *, result.c_str());
         /* iterate over all data elements */
         for (size_t i = 0; i < length; i++)
         {
             /* encode first 6 bits */
-            *(bufPtr++) = enc_base64[(data[i] >> 2) & 0x3f];
+            out << enc_base64[(data[i] >> 2) & 0x3f];
             /* insert line break (if width > 0) */
             if (++w == width)
             {
-                *(bufPtr++) = OFstatic_cast(unsigned char, '\n');
+                out << OFendl;
                 w = 0;
             }
             /* encode remaining 2 bits of the first byte and 4 bits of the second byte */
             c = (data[i] << 4) & 0x3f;
             if (++i < length)
                 c |= (data[i] >> 4) & 0x0f;
-            *(bufPtr++) = enc_base64[c];
+            out << enc_base64[c];
             /* insert line break (if width > 0) */
             if (++w == width)
             {
-                *(bufPtr++) = OFstatic_cast(unsigned char, '\n');
+                out << OFendl;
                 w = 0;
             }
             /* encode remaining 4 bits of the second byte and 2 bits of the third byte */
@@ -667,33 +907,54 @@ const OFString &OFStandard::encodeBase64(const unsigned char *data,
                 c = (data[i] << 2) & 0x3f;
                 if (++i < length)
                     c |= (data[i] >> 6) & 0x03;
-                *(bufPtr++) = enc_base64[c];
+                out << enc_base64[c];
             } else {
                 i++;
                 /* append fill char */
-                *(bufPtr++) = '=';
+                out << '=';
             }
             /* insert line break (if width > 0) */
             if (++w == width)
             {
-                *(bufPtr++) = '\n';
+                out << OFendl;
                 w = 0;
             }
             /* encode remaining 6 bits of the third byte */
             if (i < length)
-                *(bufPtr++) = enc_base64[data[i] & 0x3f];
+                out << enc_base64[data[i] & 0x3f];
             else /* append fill char */
-                *(bufPtr++) = '=';
+                out << '=';
             /* insert line break (if width > 0) */
             if (++w == width)
             {
-                *(bufPtr++) = '\n';
+                out << OFendl;
                 w = 0;
             }
         }
-        /* append trailing 0 byte (probably not required) */
-        *bufPtr = '\0';
+        /* flush stream */
+        out.flush();
+        status = EC_Normal;
     }
+    return status;
+}
+
+
+const OFString &OFStandard::encodeBase64(const unsigned char *data,
+                                         const size_t length,
+                                         OFString &result,
+                                         const size_t width)
+{
+    OFStringStream stream;
+    /* call stream variant of base64 encoder */
+    if (OFStandard::encodeBase64(stream, data, length, width).good())
+    {
+        stream << OFStringStream_ends;
+        /* convert string stream into a character string */
+        OFSTRINGSTREAM_GETSTR(stream, buffer_str)
+        result.assign(buffer_str);
+        OFSTRINGSTREAM_FREESTR(buffer_str)
+    } else
+        result.clear();
     return result;
 }
 
@@ -836,7 +1097,7 @@ double OFStandard::atof(const char *s, OFBool *success)
     int fracExp = 0;
 
     // Strip off leading blanks and check for a sign.
-    while (isspace(OFstatic_cast(int, *p))) ++p;
+    while (isspace(OFstatic_cast(unsigned char, *p))) ++p;
 
     if (*p == '-')
     {
@@ -856,7 +1117,7 @@ double OFStandard::atof(const char *s, OFBool *success)
     for (mantSize = 0; ; ++mantSize)
     {
         c = *p;
-        if (!isdigit(OFstatic_cast(int, c)))
+        if (!isdigit(OFstatic_cast(unsigned char, c)))
         {
             if ((c != '.') || (decPt >= 0)) break;
             decPt = mantSize;
@@ -937,7 +1198,7 @@ double OFStandard::atof(const char *s, OFBool *success)
             if (*p == '+') ++p;
             expSign = 0;
         }
-        while (isdigit(OFstatic_cast(int, *p)))
+        while (isdigit(OFstatic_cast(unsigned char, *p)))
         {
             exponent = exponent * 10 + (*p - '0');
             ++p;
@@ -1373,7 +1634,7 @@ eformat:
        * conversion is less than -4 or greater than the precision.''
        *      -- ANSI X3J11
        */
-      if (expcnt > prec || !expcnt && fract && fract < .0001)
+      if (expcnt > prec || (!expcnt && fract && fract < .0001))
       {
         /*
          * g/G format counts "significant digits, not digits of
@@ -1502,7 +1763,7 @@ void OFStandard::ftoa(
   // so buffer size stays rational.
   if (prec > FTOA_MAXFRACT)
   {
-    if (fmtch != 'g' && fmtch != 'G' || (flags&FTOA_ALTERNATE_FORM)) fpprec = prec - FTOA_MAXFRACT;
+    if ((fmtch != 'g' && fmtch != 'G') || (flags&FTOA_ALTERNATE_FORM)) fpprec = prec - FTOA_MAXFRACT;
     prec = FTOA_MAXFRACT;
   }
   else if (prec == -1) prec = FTOA_DEFPREC;
@@ -1577,31 +1838,6 @@ void OFStandard::ftoa(
 #endif /* DISABLE_OFSTD_FTOA */
 
 
-OFBool OFStandard::stringMatchesCharacterSet( const char *str, const char *charset )
-{
-  if( charset == NULL || str == NULL )
-    return OFTrue;
-
-  OFBool result = OFTrue;
-  unsigned int lenStr = strlen( str );
-  unsigned int lenCharset = strlen( charset );
-  for( unsigned int i=0 ; i<lenStr && result ; i++ )
-  {
-    OFBool charFound = OFFalse;
-    for( unsigned int j=0 ; j<lenCharset && !charFound ; j++ )
-    {
-      if( str[i] == charset[j] )
-        charFound = OFTrue;
-    }
-
-    if( !charFound )
-      result = OFFalse;
-  }
-
-  return( result );
-}
-
-
 unsigned int OFStandard::my_sleep(unsigned int seconds)
 {
 #ifdef HAVE_WINDOWS_H
@@ -1621,9 +1857,137 @@ unsigned int OFStandard::my_sleep(unsigned int seconds)
 #endif
 }
 
+long OFStandard::getProcessID()
+{
+#ifdef _WIN32
+  return _getpid();
+#elif defined(HAVE_GETPID)
+  return getpid();
+#else
+  return 0; // Workaround for MAC
+#endif
+}
+
 
 /*
  *  $Log: ofstd.cc,v $
+ *  Revision 1.66  2010-11-01 08:55:56  uli
+ *  Moved variable declarations in front of their loop.
+ *
+ *  Revision 1.65  2010-10-20 08:09:34  uli
+ *  Also made sure toupper() and tolower() get a valid argument.
+ *
+ *  Revision 1.64  2010-10-20 07:41:37  uli
+ *  Made sure isalpha() & friends are only called with valid arguments.
+ *
+ *  Revision 1.63  2010-10-14 13:14:53  joergr
+ *  Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ *  Revision 1.62  2010-08-19 08:43:09  uli
+ *  Fixed a comparision that checks for a valid buffer.
+ *
+ *  Revision 1.61  2010-08-10 09:34:20  uli
+ *  Fixed some unlikely problems with NULL pointers.
+ *
+ *  Revision 1.60  2010-06-02 12:56:54  joergr
+ *  Introduced new helper function strerror() which is used as a wrapper to the
+ *  various approaches found on different systems.
+ *
+ *  Revision 1.59  2010-06-02 12:36:48  joergr
+ *  Appended missing OFStringStream_ends to the end of output streams because
+ *  this is required when OFOStringStream is mapped to ostrstream.
+ *
+ *  Revision 1.58  2010-05-20 09:20:32  joergr
+ *  Added new method for determining the size of a given file (in bytes).
+ *
+ *  Revision 1.57  2010-04-28 13:27:38  joergr
+ *  Added type cast to integer variable in order to avoid compiler warnings
+ *  reported by VisualStudio 2005.
+ *  Fixed wrong use of comparison operator in if statement.
+ *
+ *  Revision 1.56  2010-01-21 14:38:38  joergr
+ *  Added stream variant of method convertToMarkupString().
+ *  Changed implementation of convertToMarkupString(). This helper function is
+ *  now based on the new stream variant which is much more efficient when
+ *  converting large text strings with many special characters.
+ *
+ *  Revision 1.55  2010-01-20 13:49:47  uli
+ *  Added OFStandard::getProcessID().
+ *
+ *  Revision 1.54  2010-01-04 16:02:46  joergr
+ *  Added new method getDirNameFromPath() and enhanced existing method
+ *  getFilenameFromPath().
+ *
+ *  Revision 1.53  2009-09-15 10:48:37  joergr
+ *  Changed implementation of string variant of encodeBase64(). This helper
+ *  function is now based on the stream variant of encodeBase64() because the
+ *  previous implementation had an issue with HAVE_STD_STRING defined.
+ *
+ *  Revision 1.52  2009-08-26 07:44:31  joergr
+ *  Added parentheses around && within || in order to avoid warnings reported by
+ *  gcc 4.3.2.
+ *
+ *  Revision 1.51  2009-08-19 10:40:54  joergr
+ *  Added new string helper functions toUpper() and toLower().
+ *
+ *  Revision 1.50  2009-04-27 14:25:31  joergr
+ *  Added comment on absolute path names e.g. in UNC syntax.
+ *
+ *  Revision 1.49  2009-03-13 09:46:40  joergr
+ *  Added new helper function getFilenameFromPath().
+ *
+ *  Revision 1.48  2008-08-28 10:44:30  onken
+ *  Introduced deleteFile() method.
+ *
+ *  Revision 1.47  2008-08-28 10:34:02  onken
+ *  Added #ifdef to combineDirAndFilename() to only check for absolute paths with
+ *  driver letter when on Windows.
+ *
+ *  Revision 1.46  2008-08-28 10:20:43  onken
+ *  Modified combineDirAndFilename() to also recognize Windows absolute paths
+ *  starting with a drive letter.
+ *
+ *  Revision 1.45  2008-07-15 09:49:38  joergr
+ *  Removed unused function OFStandard::stringMatchesCharacterSet().
+ *
+ *  Revision 1.44  2008-04-28 12:02:49  joergr
+ *  Adapted OFStandard::checkForMarkupConversion() to the new behavior of
+ *  parameter "convertNonASCII" of OFStandard::convertToMarkupString().
+ *
+ *  Revision 1.43  2008-04-28 09:05:06  meichel
+ *  OFStandard::convertToMarkupString now also converts control characters
+ *    less than 32 and 127 (which does not exist in ASCII or ISO 8859)
+ *    when run in "convert non-ASCII" or MM_HTML32 markup mode.
+ *
+ *  Revision 1.42  2008-04-18 09:11:29  joergr
+ *  Added support for current directory (".") to searchDirectoryRecursively().
+ *
+ *  Revision 1.41  2008-03-10 12:02:57  joergr
+ *  Added "ofstream.h" include in order to compile when HAVE_STL is defined.
+ *
+ *  Revision 1.40  2007/11/15 16:12:53  joergr
+ *  Introduced new markup mode for convertToMarkupString() that is used to
+ *  distinguish between HTML, HTML 3.2, XHTML and XML.
+ *  Enhanced convertToMarkupString() in order to be more compliant to the HTML
+ *  specification (e.g. do not use "&apos;").
+ *
+ *  Revision 1.39  2007/06/26 16:20:39  joergr
+ *  Added new variant of encodeBase64() method that outputs directly to a stream
+ *  (avoids using a memory buffer for large binary data).
+ *
+ *  Revision 1.38  2007/03/09 16:35:49  joergr
+ *  Fixed issue with new parameter "recurse" in searchDirectoryRecursively().
+ *
+ *  Revision 1.37  2007/03/09 14:55:38  joergr
+ *  Added optional parameter "recurse" to searchDirectoryRecursively().
+ *
+ *  Revision 1.36  2007/02/20 13:13:38  joergr
+ *  Added function that removes a given prefix from a pathname (e.g. root dir).
+ *
+ *  Revision 1.35  2006/10/13 10:01:36  joergr
+ *  Added new helper function that allows to check whether the conversion to an
+ *  HTML/XML markup string is required.
+ *
  *  Revision 1.34  2005/12/08 15:49:00  meichel
  *  Changed include path schema for all DCMTK header files
  *
