@@ -1,41 +1,36 @@
 /*
  *
- *  Copyright (C) 1997-2003, OFFIS
+ *  Copyright (C) 2000-2011, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  ofstd
  *
  *  Author:  Marco Eichelberg
  *
- *  Purpose: Provides operating system independent abstractions for basic 
- *           multi-thread concepts: threads, thread specific data, 
- *           semaphores, mutexes and read/write locks. The implementation 
- *           of these classes supports the Solaris, POSIX and Win32 
+ *  Purpose: Provides operating system independent abstractions for basic
+ *           multi-thread concepts: threads, thread specific data,
+ *           semaphores, mutexes and read/write locks. The implementation
+ *           of these classes supports the Solaris, POSIX and Win32
  *           multi-thread APIs.
  *
- *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2004/04/22 10:45:33 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/ofstd/libsrc/ofthread.cc,v $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Last Update:      $Author: onken $
+ *  Update Date:      $Date: 2011-01-04 14:47:11 $
+ *  CVS/RCS Revision: $Revision: 1.22 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
  *
  */
 
-#include "osconfig.h"
+#include "dcmtk/config/osconfig.h"
 
 /* if WITH_THREADS is undefined, we don't even attempt to implement a thread interface. */
 #ifdef WITH_THREADS
@@ -43,7 +38,9 @@
 #define INCLUDE_CSTDLIB
 #define INCLUDE_CSTRING
 #define INCLUDE_CERRNO
-#include "ofstdinc.h"
+#include "dcmtk/ofstd/ofstdinc.h"
+
+#include "dcmtk/ofstd/ofstd.h"
 
 #ifdef HAVE_WINDOWS_H
 #define WINDOWS_INTERFACE
@@ -74,12 +71,12 @@ extern "C" {
 
 #endif /* WITH_THREADS */
 
-#include "ofthread.h"
-#include "ofconsol.h"
-#include "ofstring.h"
+#include "dcmtk/ofstd/ofthread.h"
+#include "dcmtk/ofstd/ofconsol.h"
+#include "dcmtk/ofstd/ofstring.h"
 
 // The Posix interfaces are not always correctly declared as volatile,
-// so we need a two-step cast from our internal representation 
+// so we need a two-step cast from our internal representation
 // as a volatile void * to the Posix representation such as pthread_key_t *
 
 #define OFthread_cast(x,y) OFreinterpret_cast(x, OFconst_cast(void *, y))
@@ -129,29 +126,37 @@ OFThread::~OFThread()
 {
 #ifdef WINDOWS_INTERFACE
   CloseHandle((HANDLE)theThreadHandle);
-#endif  
+#endif
 }
 
 int OFThread::start()
 {
 #ifdef WINDOWS_INTERFACE
   unsigned int tid = 0;
-  theThreadHandle = _beginthreadex(NULL, 0, thread_stub, (void *)this, 0, &tid); 
+  theThreadHandle = _beginthreadex(NULL, 0, thread_stub, OFstatic_cast(void *, this), 0, &tid);
   if (theThreadHandle == 0) return errno; else
   {
+#ifdef HAVE_POINTER_TYPE_PTHREAD_T
+    theThread = OFreinterpret_cast(void *, tid);
+#else
     theThread = tid;
+#endif
     return 0;
   }
 #elif defined(POSIX_INTERFACE)
-  pthread_t tid=0;
+  pthread_t tid = 0;
   int result = pthread_create(&tid, NULL, thread_stub, OFstatic_cast(void *, this));
-  if (0 == result) theThread = OFreinterpret_cast(unsigned long, tid); else theThread = 0;      
-  return result;     
+#ifdef HAVE_POINTER_TYPE_PTHREAD_T
+  if (0 == result) theThread = OFstatic_cast(void *, tid); else theThread = 0;
+#else
+  if (0 == result) theThread = OFstatic_cast(unsigned long, tid); else theThread = 0;
+#endif
+  return result;
 #elif defined(SOLARIS_INTERFACE)
   thread_t tid=0;
   int result = thr_create(NULL, 0, thread_stub, OFstatic_cast(void *, this), 0, &tid);
-  if (0 == result) theThread = OFstatic_cast(unsigned long, tid); else theThread = 0;      
-  return result;     
+  if (0 == result) theThread = OFstatic_cast(unsigned long, tid); else theThread = 0;
+  return result;
 #else
   return -1;
 #endif
@@ -164,19 +169,24 @@ int OFThread::join()
   else return (int)GetLastError();
 #elif defined(POSIX_INTERFACE)
   void *retcode=NULL;
-  return pthread_join(OFreinterpret_cast(pthread_t, theThread), &retcode);
+  return pthread_join(OFstatic_cast(pthread_t, theThread), &retcode);
 #elif defined(SOLARIS_INTERFACE)
   void *retcode=NULL;
-  // reinterpret_cast does not work for gcc 3.x
   return thr_join(OFstatic_cast(thread_t, theThread), NULL, &retcode);
 #else
   return -1;
 #endif
 }
-  
+
 unsigned long OFThread::threadID()
 {
+#ifdef HAVE_POINTER_TYPE_PTHREAD_T
+  // dangerous - we cast a pointer type to unsigned long and hope that it
+  // remains valid after casting back to a pointer type.
+  return OFreinterpret_cast(unsigned long, theThread);
+#else
   return theThread;
+#endif
 }
 
 #if defined(WINDOWS_INTERFACE) || defined(POSIX_INTERFACE) || defined(SOLARIS_INTERFACE)
@@ -186,9 +196,18 @@ OFBool OFThread::equal(unsigned long /* tID */ )
 #endif
 {
 #ifdef WINDOWS_INTERFACE
+#ifdef HAVE_POINTER_TYPE_PTHREAD_T
+  if (theThread == OFreinterpret_cast(void *, tID)) return OFTrue; else return OFFalse;
+#else
   if (theThread == tID) return OFTrue; else return OFFalse;
+#endif
 #elif defined(POSIX_INTERFACE)
-  if (pthread_equal(OFreinterpret_cast(pthread_t, theThread), OFreinterpret_cast(pthread_t, tID))) return OFTrue; else return OFFalse;
+#ifdef HAVE_POINTER_TYPE_PTHREAD_T
+  // dangerous - we cast an unsigned long back to a pointer type and hope that it is still valid
+  if (pthread_equal(OFstatic_cast(pthread_t, theThread), OFreinterpret_cast(pthread_t, tID))) return OFTrue; else return OFFalse;
+#else
+  if (pthread_equal(OFstatic_cast(pthread_t, theThread), OFstatic_cast(pthread_t, tID))) return OFTrue; else return OFFalse;
+#endif
 #elif defined(SOLARIS_INTERFACE)
   if (OFstatic_cast(thread_t, theThread) == OFstatic_cast(thread_t, tID)) return OFTrue; else return OFFalse;
 #else
@@ -214,7 +233,11 @@ unsigned long OFThread::self()
 #ifdef WINDOWS_INTERFACE
   return OFstatic_cast(unsigned long, GetCurrentThreadId());
 #elif defined(POSIX_INTERFACE)
+#ifdef HAVE_POINTER_TYPE_PTHREAD_T
   return OFreinterpret_cast(unsigned long, pthread_self());
+#else
+  return OFstatic_cast(unsigned long, pthread_self());
+#endif
 #elif defined(SOLARIS_INTERFACE)
   return OFstatic_cast(unsigned long, thr_self());
 #else
@@ -232,15 +255,16 @@ void OFThread::errorstr(OFString& description, int /* code */ )
   if (code == OFThread::busy) description = "another thread already waiting for join"; else
   {
     LPVOID buf;
-    FormatMessage( 
-      FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, 
+    FormatMessage(
+      FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
       NULL, (DWORD)code, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
       (LPTSTR) &buf, 0, NULL);
-    if (buf) description = (const char *)buf; 
+    if (buf) description = (const char *)buf;
     LocalFree(buf);
   }
 #elif defined(POSIX_INTERFACE) || defined(SOLARIS_INTERFACE)
-  const char *str = strerror(code);
+  char buf[256];
+  const char *str = OFStandard::strerror(code, buf, sizeof(buf));
   if (str) description = str; else description.clear();
 #else
   description = "error: threads not implemented";
@@ -311,7 +335,7 @@ int OFThreadSpecificData::set(void * /* value */ )
   if (theKey)
   {
     if (0 == TlsSetValue(*((DWORD *)theKey), value)) return (int)GetLastError(); else return 0;
-  } else return ERROR_INVALID_HANDLE;    
+  } else return ERROR_INVALID_HANDLE;
 #elif defined(POSIX_INTERFACE)
   if (theKey) return pthread_setspecific(* OFthread_cast(pthread_key_t *, theKey), value); else return EINVAL;
 #elif defined(SOLARIS_INTERFACE)
@@ -322,7 +346,7 @@ int OFThreadSpecificData::set(void * /* value */ )
 }
 
 int OFThreadSpecificData::get(void *&value)
-{  
+{
 #ifdef WINDOWS_INTERFACE
   if (theKey)
   {
@@ -333,7 +357,7 @@ int OFThreadSpecificData::get(void *&value)
     return ERROR_INVALID_HANDLE;
   }
 #elif defined(POSIX_INTERFACE)
-  if (theKey) 
+  if (theKey)
   {
     value = pthread_getspecific(* OFthread_cast(pthread_key_t *, theKey));
     return 0;
@@ -347,7 +371,7 @@ int OFThreadSpecificData::get(void *&value)
 #else
   value = NULL;
   return -1;
-#endif	
+#endif
 }
 
 #if defined(WINDOWS_INTERFACE) || defined(POSIX_INTERFACE) || defined(SOLARIS_INTERFACE)
@@ -358,14 +382,15 @@ void OFThreadSpecificData::errorstr(OFString& description, int /* code */ )
 {
 #ifdef WINDOWS_INTERFACE
   LPVOID buf;
-  FormatMessage( 
-    FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, 
+  FormatMessage(
+    FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
     NULL, (DWORD)code, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
     (LPTSTR) &buf, 0, NULL);
-  if (buf) description = (const char *)buf; 
+  if (buf) description = (const char *)buf;
   LocalFree(buf);
 #elif defined(POSIX_INTERFACE) || defined(SOLARIS_INTERFACE)
-  const char *str = strerror(code);
+  char buf[256];
+  const char *str = OFStandard::strerror(code, buf, sizeof(buf));
   if (str) description = str; else description.clear();
 #else
   description = "error: thread specific data not implemented";
@@ -375,6 +400,12 @@ void OFThreadSpecificData::errorstr(OFString& description, int /* code */ )
 
 /* ------------------------------------------------------------------------- */
 
+/* Mac OS X only permits named Semaphores. The code below compiles on Mac OS X
+   but does not work. This will be corrected in the next snapshot. For now, the
+   semaphore code is completely disabled for that OS (it is not used in other
+   parts of the toolkit so far.
+ */
+#ifndef _DARWIN_C_SOURCE
 
 #ifdef WINDOWS_INTERFACE
   const int OFSemaphore::busy = -1;
@@ -395,20 +426,20 @@ OFSemaphore::OFSemaphore(unsigned int /* numResources */ )
 : theSemaphore(NULL)
 {
 #ifdef WINDOWS_INTERFACE
-  theSemaphore = (void *)(CreateSemaphore(NULL, numResources, numResources, NULL));
+  theSemaphore = OFstatic_cast(void *, CreateSemaphore(NULL, numResources, numResources, NULL));
 #elif defined(POSIX_INTERFACE)
   sem_t *sem = new sem_t;
   if (sem)
   {
     if (sem_init(sem, 0, numResources) == -1) delete sem;
-    else theSemaphore = sem;    
+    else theSemaphore = sem;
   }
 #elif defined(SOLARIS_INTERFACE)
   sema_t *sem = new sema_t;
   if (sem)
   {
     if (sema_init(sem, numResources, USYNC_THREAD, NULL)) delete sem;
-    else theSemaphore = sem;    
+    else theSemaphore = sem;
   }
 #else
 #endif
@@ -465,7 +496,7 @@ int OFSemaphore::trywait()
   if (theSemaphore)
   {
     if (sem_trywait(OFthread_cast(sem_t *, theSemaphore))) return errno; else return 0; // may return EAGAIN
-  } else return EINVAL;  
+  } else return EINVAL;
 #elif defined(SOLARIS_INTERFACE)
   if (theSemaphore) return sema_trywait(OFthread_cast(sema_t *, theSemaphore)); else return EINVAL; // may return EBUSY
 #else
@@ -481,9 +512,9 @@ int OFSemaphore::post()
   if (theSemaphore)
   {
     if (sem_post(OFthread_cast(sem_t *, theSemaphore))) return errno; else return 0;
-  } else return EINVAL;  
+  } else return EINVAL;
 #elif defined(SOLARIS_INTERFACE)
-  if (theSemaphore) return sema_post(OFthread_cast(sema_t *, theSemaphore)); else return EINVAL; 
+  if (theSemaphore) return sema_post(OFthread_cast(sema_t *, theSemaphore)); else return EINVAL;
 #else
   return -1;
 #endif
@@ -499,15 +530,16 @@ void OFSemaphore::errorstr(OFString& description, int /* code */ )
   if (code == OFSemaphore::busy) description = "semaphore is already locked"; else
   {
     LPVOID buf;
-    FormatMessage( 
-      FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, 
+    FormatMessage(
+      FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
       NULL, (DWORD)code, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
       (LPTSTR) &buf, 0, NULL);
-    if (buf) description = (const char *)buf; 
+    if (buf) description = (const char *)buf;
     LocalFree(buf);
   }
 #elif defined(POSIX_INTERFACE) || defined(SOLARIS_INTERFACE)
-  const char *str = strerror(code);
+  char buf[256];
+  const char *str = OFStandard::strerror(code, buf, sizeof(buf));
   if (str) description = str; else description.clear();
 #else
   description = "error: semaphore not implemented";
@@ -515,6 +547,7 @@ void OFSemaphore::errorstr(OFString& description, int /* code */ )
   return;
 }
 
+#endif // _DARWIN_C_SOURCE
 
 /* ------------------------------------------------------------------------- */
 
@@ -531,7 +564,7 @@ OFMutex::OFMutex()
 : theMutex(NULL)
 {
 #ifdef WINDOWS_INTERFACE
-  theMutex = (void *)(CreateMutex(NULL, FALSE, NULL));
+  theMutex = OFstatic_cast(void *, CreateMutex(NULL, FALSE, NULL));
 #elif defined(POSIX_INTERFACE)
   pthread_mutex_t *mtx = new pthread_mutex_t;
   if (mtx)
@@ -575,7 +608,7 @@ OFBool OFMutex::initialized() const
 #endif
 }
 
-  
+
 int OFMutex::lock()
 {
 #ifdef WINDOWS_INTERFACE
@@ -629,15 +662,16 @@ void OFMutex::errorstr(OFString& description, int /* code */ )
   if (code == OFSemaphore::busy) description = "mutex is already locked"; else
   {
     LPVOID buf;
-    FormatMessage( 
-      FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, 
+    FormatMessage(
+      FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
       NULL, (DWORD)code, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
       (LPTSTR) &buf, 0, NULL);
-    if (buf) description = (const char *)buf; 
+    if (buf) description = (const char *)buf;
     LocalFree(buf);
   }
 #elif defined(POSIX_INTERFACE) || defined(SOLARIS_INTERFACE)
-  const char *str = strerror(code);
+  char buf[256];
+  const char *str = OFStandard::strerror(code, buf, sizeof(buf));
   if (str) description = str; else description.clear();
 #else
   description = "error: mutex not implemented";
@@ -731,7 +765,7 @@ int OFReadWriteLock::rdlock()
   if (theLock)
   {
     OFReadWriteLockHelper *rwl = (OFReadWriteLockHelper *)theLock;
-    int result =0;    
+    int result =0;
     while (1)
     {
       if (0 != (result = rwl->accessMutex.lock())) return result; // lock mutex
@@ -743,7 +777,7 @@ int OFReadWriteLock::rdlock()
           {
             rwl->accessMutex.unlock();
             return result;
-          }        
+          }
         }
         (rwl->numReaders)++;
         return rwl->accessMutex.unlock();
@@ -769,7 +803,7 @@ int OFReadWriteLock::wrlock()
   if (theLock)
   {
     OFReadWriteLockHelper *rwl = (OFReadWriteLockHelper *)theLock;
-    int result =0;    
+    int result =0;
     while (1)
     {
       if (0 != (result = rwl->accessMutex.lock())) return result; // lock mutex
@@ -779,11 +813,11 @@ int OFReadWriteLock::wrlock()
         {
           rwl->accessMutex.unlock();
           return result;
-        }        
+        }
         rwl->numReaders = -1;
         return rwl->accessMutex.unlock();
       }
-    
+
       // we cannot grant the write lock, block thread.
       if (0 != (result = rwl->accessMutex.unlock())) return result;
       if (0 != (result = rwl->usageSemaphore.wait())) return result;
@@ -806,7 +840,7 @@ int OFReadWriteLock::tryrdlock()
   if (theLock)
   {
     OFReadWriteLockHelper *rwl = (OFReadWriteLockHelper *)theLock;
-    int result =0;    
+    int result =0;
     if (0 != (result = rwl->accessMutex.lock())) return result; // lock mutex
     if (rwl->numReaders >= 0) // we can grant the read lock
     {
@@ -816,7 +850,7 @@ int OFReadWriteLock::tryrdlock()
         {
           rwl->accessMutex.unlock();
           return result;
-        }        
+        }
       }
       (rwl->numReaders)++;
       return rwl->accessMutex.unlock();
@@ -839,7 +873,7 @@ int OFReadWriteLock::trywrlock()
   if (theLock)
   {
     OFReadWriteLockHelper *rwl = (OFReadWriteLockHelper *)theLock;
-    int result =0;    
+    int result =0;
     if (0 != (result = rwl->accessMutex.lock())) return result; // lock mutex
     if (rwl->numReaders == 0) // we can grant the write lock
     {
@@ -847,7 +881,7 @@ int OFReadWriteLock::trywrlock()
       {
         rwl->accessMutex.unlock();
         return result;
-      }        
+      }
       rwl->numReaders = -1;
       return rwl->accessMutex.unlock();
     }
@@ -870,7 +904,7 @@ int OFReadWriteLock::unlock()
   if (theLock)
   {
     OFReadWriteLockHelper *rwl = (OFReadWriteLockHelper *)theLock;
-    int result =0;    
+    int result =0;
     if (0 != (result = rwl->accessMutex.lock())) return result; // lock mutex
     if (rwl->numReaders == -1) rwl->numReaders = 0; else (rwl->numReaders)--;
     if ((rwl->numReaders == 0) && (0 != (result = rwl->usageSemaphore.post())))
@@ -899,15 +933,16 @@ void OFReadWriteLock::errorstr(OFString& description, int /* code */ )
   if (code == OFSemaphore::busy) description = "read/write lock is already locked"; else
   {
     LPVOID buf;
-    FormatMessage( 
-      FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM, 
+    FormatMessage(
+      FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
       NULL, (DWORD)code, MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
       (LPTSTR) &buf, 0, NULL);
-    if (buf) description = (const char *)buf; 
+    if (buf) description = (const char *)buf;
     LocalFree(buf);
   }
 #elif defined(POSIX_INTERFACE) || defined(SOLARIS_INTERFACE)
-  const char *str = strerror(code);
+  char buf[256];
+  const char *str = OFStandard::strerror(code, buf, sizeof(buf));
   if (str) description = str; else description.clear();
 #else
   description = "error: read/write lock not implemented";
@@ -916,11 +951,94 @@ void OFReadWriteLock::errorstr(OFString& description, int /* code */ )
 }
 
 
+OFReadWriteLocker::OFReadWriteLocker(OFReadWriteLock& lock)
+    : theLock(lock), locked(OFFalse)
+{
+}
+
+OFReadWriteLocker::~OFReadWriteLocker()
+{
+  if (locked)
+    theLock.unlock();
+}
+
+#ifdef DEBUG
+#define lockWarn(name, locked) \
+  if (locked == OFTrue)        \
+  {                            \
+    ofConsole.lockCout() << "OFReadWriteLocker::" name "(): Already locked?!" << OFendl; \
+    ofConsole.unlockCout();    \
+  }
+#else
+#define lockWarn(name, locked)
+#endif
+
+#define OFReadWriteLockerFunction(name) \
+int OFReadWriteLocker::name()           \
+{                                       \
+  lockWarn(#name, locked);              \
+  int ret = theLock. name ();           \
+  if (ret == 0)                         \
+    locked = OFTrue;                    \
+  return ret;                           \
+}
+
+OFReadWriteLockerFunction(rdlock)
+OFReadWriteLockerFunction(wrlock)
+OFReadWriteLockerFunction(tryrdlock)
+OFReadWriteLockerFunction(trywrlock)
+
+int OFReadWriteLocker::unlock()
+{
+#ifdef DEBUG
+  if (locked == OFFalse)
+  {
+    ofConsole.lockCout() << "OFReadWriteLocker::unlock(): Nothing to unlock?!" << OFendl;
+    ofConsole.unlockCout();
+  }
+#endif
+
+  int ret = theLock.unlock();
+  if (ret == 0)
+    locked = OFFalse;
+  return ret;
+}
 
 /*
  *
  * CVS/RCS Log:
  * $Log: ofthread.cc,v $
+ * Revision 1.22  2011-01-04 14:47:11  onken
+ * Disable and hide OFSemaphore class on Mac OS X since implementation is
+ * broken on that OS (needs named semaphores instead).
+ *
+ * Revision 1.21  2010-10-14 13:14:53  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.20  2010-06-28 07:22:00  joergr
+ * Introduced explicit type casts in order to compile with new gcc versions on
+ * MinGW/MSYS. Use type cast macros (e.g. OFstatic_cast) where appropriate.
+ *
+ * Revision 1.19  2010-06-04 14:18:20  uli
+ * Removed an outdated comment.
+ *
+ * Revision 1.18  2010-06-04 13:58:42  uli
+ * Added class OFReadWriteLocker which simplifies unlocking OFReadWriteLocks.
+ *
+ * Revision 1.17  2010-06-03 10:27:04  joergr
+ * Replaced calls to strerror() by new helper function OFStandard::strerror()
+ * which results in using the thread safe version of strerror() if available.
+ *
+ * Revision 1.16  2005/12/08 15:49:02  meichel
+ * Changed include path schema for all DCMTK header files
+ *
+ * Revision 1.15  2005/07/27 17:07:52  joergr
+ * Fixed problem with pthread_t type cast and gcc 4.0.
+ *
+ * Revision 1.14  2004/08/03 16:44:17  meichel
+ * Updated code to correctly handle pthread_t both as an integral integer type
+ *   (e.g. Linux, Solaris) and as a pointer type (e.g. BSD, OSF/1).
+ *
  * Revision 1.13  2004/04/22 10:45:33  joergr
  * Changed typecast from OFreinterpret_cast to OFstatic_cast to avoid compilation
  * error on Solaris with gcc 3.x.
