@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2002-2004, OFFIS
+ *  Copyright (C) 2002-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  ofstd
  *
@@ -22,8 +18,8 @@
  *  Purpose: Class for time functions (Source)
  *
  *  Last Update:      $Author: joergr $
- *  Update Date:      $Date: 2004/01/16 10:35:18 $
- *  CVS/RCS Revision: $Revision: 1.13 $
+ *  Update Date:      $Date: 2010-10-14 13:14:53 $
+ *  CVS/RCS Revision: $Revision: 1.17 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -31,11 +27,12 @@
  */
 
 
-#include "osconfig.h"
+#include "dcmtk/config/osconfig.h"
 
 #define INCLUDE_CSTDIO
 #define INCLUDE_CTIME
-#include "ofstdinc.h"
+#define INCLUDE_CSTRING
+#include "dcmtk/ofstd/ofstdinc.h"
 
 BEGIN_EXTERN_C
 #ifdef HAVE_SYS_TIME_H
@@ -54,8 +51,8 @@ END_EXTERN_C
 #include <windows.h>      /* for Windows time functions */
 #endif
 
-#include "oftime.h"
-#include "ofstd.h"
+#include "dcmtk/ofstd/oftime.h"
+#include "dcmtk/ofstd/ofstd.h"
 
 
 /*------------------*
@@ -593,7 +590,7 @@ double OFTime::getLocalTimeZone()
 }
 
 
-ostream& operator<<(ostream& stream, const OFTime &timeVal)
+STD_NAMESPACE ostream& operator<<(STD_NAMESPACE ostream& stream, const OFTime &timeVal)
 {
     OFString tmpString;
     /* print the given time in ISO format to the stream */
@@ -607,6 +604,19 @@ ostream& operator<<(ostream& stream, const OFTime &timeVal)
  *
  * CVS/RCS Log:
  * $Log: oftime.cc,v $
+ * Revision 1.17  2010-10-14 13:14:53  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.16  2009-08-19 11:55:45  meichel
+ * Added additional includes needed for Sun Studio 11 on Solaris.
+ *
+ * Revision 1.15  2006-08-14 16:42:46  meichel
+ * Updated all code in module ofstd to correctly compile if the standard
+ *   namespace has not included into the global one with a "using" directive.
+ *
+ * Revision 1.14  2005/12/08 15:49:03  meichel
+ * Changed include path schema for all DCMTK header files
+ *
  * Revision 1.13  2004/01/16 10:35:18  joergr
  * Added setISOFormattedXXX() methods for Date, Time and DateTime.
  *
