@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1997-2005, OFFIS
+ *  Copyright (C) 1997-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  ofstd
  *
@@ -22,10 +18,9 @@
  *  Purpose: Test code of ascii/double conversion methods in class OFStandard
  *
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:49:07 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/ofstd/tests/tstatof.cc,v $
- *  CVS/RCS Revision: $Revision: 1.4 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:15:16 $
+ *  CVS/RCS Revision: $Revision: 1.6 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -111,7 +106,7 @@ int main()
         {
           passed = OFFalse;
           CERR << "test #" << i << " failed: conversion error, atof=" << d2 << ", ref="
-               << d1 << ", delta=" << delta << endl;
+               << d1 << ", delta=" << delta << OFendl;
         }
       }
     }
@@ -121,27 +116,27 @@ int main()
       {
         passed = OFFalse;
         if (r)
-          CERR << "test #" << i << " failed: conversion did not flag error as expected, atof=" << d2 << endl;
+          CERR << "test #" << i << " failed: conversion did not flag error as expected, atof=" << d2 << OFendl;
         else
-          CERR << "test #" << i << " failed: conversion did not succeed as expected" << endl;
+          CERR << "test #" << i << " failed: conversion did not succeed as expected" << OFendl;
       }
     }
 
     if (passed)
     {
-      CERR << "test #" << i << " passed" << endl;
+      CERR << "test #" << i << " passed" << OFendl;
       numPassed++;
     }
   }
 
   if (numVp == numPassed)
   {
-    CERR << "All tests passed." << endl;
+    CERR << "All tests passed." << OFendl;
     return 0;
   }
   else
   {
-    CERR << "Failures: " << numPassed << " of " << numVp << " tests passed." << endl;
+    CERR << "Failures: " << numPassed << " of " << numVp << " tests passed." << OFendl;
   }
 
   return 1;
@@ -151,6 +146,13 @@ int main()
  *
  * CVS/RCS Log:
  * $Log: tstatof.cc,v $
+ * Revision 1.6  2010-10-14 13:15:16  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.5  2006/08/14 16:42:48  meichel
+ * Updated all code in module ofstd to correctly compile if the standard
+ *   namespace has not included into the global one with a "using" directive.
+ *
  * Revision 1.4  2005/12/08 15:49:07  meichel
  * Changed include path schema for all DCMTK header files
  *
