@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1997-2005, OFFIS
+ *  Copyright (C) 1997-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  ofstd
  *
@@ -21,9 +17,9 @@
  *
  *  Purpose: test programm for classes OFList and OFListIterator
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:49:09 $
- *  CVS/RCS Revision: $Revision: 1.8 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:15:16 $
+ *  CVS/RCS Revision: $Revision: 1.12 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -43,8 +39,8 @@ void print(OFList<int> & l)
     OFListIterator(int) e(l.end());
     COUT << "Werte der List: ";
     for (OFListIterator(int) i(l.begin()); i != e; ++i)
-	COUT << *i << " ";
-    COUT << endl;
+        COUT << *i << " ";
+    COUT << OFendl;
 }
 
 
@@ -61,7 +57,7 @@ int main()
 
     OFListIterator(int) a(l.begin());
     ++a; ++a;
-    COUT << "2xa++ :Was ist jetzt a? " << *a << endl;
+    COUT << "2xa++ :Was ist jetzt a? " << *a << OFendl;
     l.insert(a, 50);
     l.insert(a, 10, 100);
 
@@ -69,9 +65,9 @@ int main()
 
     COUT << "Finde 50: ";
     if (OFFind(OFListIterator(int), int, l.begin(), e, 50) != e)
-	COUT << "gefunden, wie erwartet\n";
+        COUT << "gefunden, wie erwartet\n";
     else
-	COUT << "nicht gefunden, Fehler\n";
+        COUT << "nicht gefunden, Fehler\n";
 
     COUT << "Ausgabe der Liste l\n";
     print(l);
@@ -81,42 +77,41 @@ int main()
     COUT << "Ausgabe der List l1\n";
     print(l1);
 
-    COUT << "Loesche alle 100er (nacheinander) aus l" << endl;
+    COUT << "Loesche alle 100er (nacheinander) aus l" << OFendl;
 
     OFListIterator(int) del;
     a = l.begin();
     while(a != e)
     {
-	del = a++;
-	if (*del == 100)
-	{
-	    l.erase(del);
-	    COUT << "Ein 100er Element geloescht\n";
-	    print(l);
-	}
+        del = a++;
+        if (*del == 100)
+        {
+            l.erase(del);
+            COUT << "Ein 100er Element geloescht\n";
+            print(l);
+        }
     }
 
-
-    COUT << "Anzahl Elemente in l: " << l.size() << endl;
+    COUT << "Anzahl Elemente in l: " << l.size() << OFendl;
     COUT << "Loesche Werte mit pop_front aus l: ";
     while(!l.empty())
     {
-	COUT << l.front() << " ";
-	l.pop_front();
+        COUT << l.front() << " ";
+        l.pop_front();
     }
-    COUT << endl;
+    COUT << OFendl;
 
     COUT << "Loesche letztes Element aus l1: " << l1.back()
-	 << " und gebe l aus:\n";
+         << " und gebe l aus:\n";
     l1.pop_back();
     print(l1);
 
-    COUT << "Suche 1 in l1: " << endl;
-    a = OFFind(OFIterator<int>, int, l1.begin(), l1.end(), 1);
+    COUT << "Suche 1 in l1: " << OFendl;
+    a = OFFind(OFListIterator(int), int, l1.begin(), l1.end(), 1);
     if ( a == l1.end())
-	COUT << "Fehler, 1 nicht gefunden\n";
+        COUT << "Fehler, 1 nicht gefunden\n";
     else
-	COUT << "1 gefunden (wie erwartet)\n";
+        COUT << "1 gefunden (wie erwartet)\n";
 
     COUT << "Loesche alle Elemente hinter ab der  1 und gebe Ergebnis aus.\n";
     l1.erase(a, l1.end());
@@ -133,6 +128,20 @@ int main()
 **
 ** CVS/RCS Log:
 ** $Log: tstlist.cc,v $
+** Revision 1.12  2010-10-14 13:15:16  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.11  2006/08/14 16:42:48  meichel
+** Updated all code in module ofstd to correctly compile if the standard
+**   namespace has not included into the global one with a "using" directive.
+**
+** Revision 1.10  2006/02/09 15:41:25  joergr
+** Fixed typo in CVS log.
+**
+** Revision 1.9  2006/02/09 15:19:53  joergr
+** Replaced OFIterator<> by OFListIterator() in order to compile if HAVE_STL
+** is defined.
+**
 ** Revision 1.8  2005/12/08 15:49:09  meichel
 ** Changed include path schema for all DCMTK header files
 **
