@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 1997-2005, OFFIS
+ *  Copyright (C) 1997-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  ofstd
  *
@@ -37,17 +33,17 @@
  *  Software Foundation, 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:49:10 $
- *  Source File:      $Source: /share/dicom/cvs-depot/dcmtk/ofstd/tests/tstring.cc,v $
- *  CVS/RCS Revision: $Revision: 1.7 $
+ *  Last Update:      $Author: joergr $
+ *  Update Date:      $Date: 2010-10-14 13:15:16 $
+ *  CVS/RCS Revision: $Revision: 1.10 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
  *
  */
 
-#include "dcmtk/config/osconfig.h"
+#include "dcmtk/config/osconfig.h"     /* include OS specific configuration first */
+
 #include "dcmtk/ofstd/ofstring.h"
 #include "dcmtk/ofstd/ofconsol.h"
 #include "dcmtk/ofstd/ofstd.h"
@@ -57,7 +53,8 @@
 
 
 OFString X = "Hello";
-OFString Y = "world";
+#define Y_str "world\0How are you?"
+OFString Y(Y_str, sizeof(Y_str)/sizeof(char) - 1);
 OFString N = "123";
 OFString c;
 const char *s = ",";
@@ -105,43 +102,47 @@ void decltest()
 
 void cattest()
 {
+#define assert_eq(ofstr, c_str) \
+  assert(ofstr == OFString(c_str, sizeof(c_str)/sizeof(char) - 1))
+
   OFString x = X;
   OFString y = Y;
   OFString z = x + y;
   COUT << "z = x + y = " << z << "\n";
-  assert(z == "Helloworld");
+  assert_eq(z, "Helloworld\0How are you?");
 
   x += y;
   COUT << "x += y; x = " << x << "\n";
-  assert(x == "Helloworld");
+  assert_eq(x, "Helloworld\0How are you?");
 
   y = Y;
   x = X;
   y.insert (0, x);
   COUT << "y.insert (0, x); y = " << y << "\n";
-  assert(y == "Helloworld");
+  assert_eq(y, "Helloworld\0How are you?");
 
   y = Y;
   x = X;
   x = x + y + x;
   COUT << "x = x + y + x; x = " << x << "\n";
-  assert(x == "HelloworldHello");
+  assert_eq(x, "Helloworld\0How are you?Hello");
 
   y = Y;
   x = X;
   x = y + x + x;
   COUT << "x = y + x + x; x = " << x << "\n";
-  assert(x == "worldHelloHello");
+  assert_eq(x, "world\0How are you?HelloHello");
 
   x = X;
   y = Y;
-  z = x + s + ' ' + y.substr (y.find ('w'), 1) + y.substr (y.find ('w') + 1) + ".";
-  COUT << "z = x + s +  + y.substr (y.find (w), 1) + y.substr (y.find (w) + 1) + . = " << z << "\n";
-  assert(z == "Hello, world.");
+  z = x + s + ' ' + y.substr (y.find ('w'), 1) + y.substr (y.find ('w') + 1, y.find('\0') - y.find('w')) + ".";
+  COUT << "z = x + s +  + y.substr (y.find (w), 1) + y.substr (y.find (w) + 1, y.find('\\0') - y.find('w')) + . = " << z << "\n";
+  assert_eq(z, "Hello, world\0.");
+#undef assert_eq
 }
 
 void comparetest()
-{  
+{
   OFString x = X;
   OFString y = Y;
   OFString n = N;
@@ -183,12 +184,36 @@ void substrtest()
 void iotest()
 {
   OFString z;
-  COUT << "enter a word:";
-  cin >> z;
-  COUT << "word =" << z << " ";
+  COUT << "enter a word: ";
+  STD_NAMESPACE cin >> z;
+  COUT << "word = " << z << " ";
   COUT << "length = " << z.length() << "\n";
 }
 
+void reservetest()
+{
+  OFString z;
+
+  z.reserve(5);
+  assert(z.length() == 0);
+  assert(z.capacity() >= 5);
+
+  z.assign(20, 'z');
+  assert(z == "zzzzzzzzzzzzzzzzzzzz");
+  assert(z.length() == 20);
+  assert(z.capacity() >= 20);
+
+  z.reserve(5);
+  assert(z == "zzzzzzzzzzzzzzzzzzzz");
+  assert(z.length() == 20);
+  assert(z.capacity() >= 20);
+
+  z.resize(5);
+  assert(z == "zzzzz");
+  assert(z.length() == 5);
+  assert(z.capacity() >= 5);
+}
+
 void identitytest(OFString a, OFString b)
 {
   OFString x = a;
@@ -198,7 +223,7 @@ void identitytest(OFString a, OFString b)
   assert((a + b) == x);
   assert((a + b) == y);
   assert(x == y);
-  
+
   assert((a + b + a) == (a + (b + a)));
 
   x.erase (x.rfind (b));
@@ -216,6 +241,7 @@ int main()
   cattest();
   comparetest();
   substrtest();
+  reservetest();
   identitytest(X, X);
   identitytest(X, Y);
   identitytest(X+Y+N+X+Y+N, "A string that will be used in identitytest but is otherwise just another useless string.");
@@ -229,6 +255,17 @@ int main()
 **
 ** CVS/RCS Log:
 ** $Log: tstring.cc,v $
+** Revision 1.10  2010-10-14 13:15:16  joergr
+** Updated copyright header. Added reference to COPYRIGHT file.
+**
+** Revision 1.9  2009-09-28 14:08:32  joergr
+** Added support for strings that contain null bytes ('\0') in order to be more
+** compliant with the standard C++ string class.
+**
+** Revision 1.8  2006-08-14 16:42:48  meichel
+** Updated all code in module ofstd to correctly compile if the standard
+**   namespace has not included into the global one with a "using" directive.
+**
 ** Revision 1.7  2005/12/08 15:49:10  meichel
 ** Changed include path schema for all DCMTK header files
 **
