@@ -1,19 +1,15 @@
 /*
  *
- *  Copyright (C) 2000-2005, OFFIS
+ *  Copyright (C) 2000-2010, OFFIS e.V.
+ *  All rights reserved.  See COPYRIGHT file for details.
  *
  *  This software and supporting documentation were developed by
  *
- *    Kuratorium OFFIS e.V.
- *    Healthcare Information and Communication Systems
+ *    OFFIS e.V.
+ *    R&D Division Health
  *    Escherweg 2
  *    D-26121 Oldenburg, Germany
  *
- *  THIS SOFTWARE IS MADE AVAILABLE,  AS IS,  AND OFFIS MAKES NO  WARRANTY
- *  REGARDING  THE  SOFTWARE,  ITS  PERFORMANCE,  ITS  MERCHANTABILITY  OR
- *  FITNESS FOR ANY PARTICULAR USE, FREEDOM FROM ANY COMPUTER DISEASES  OR
- *  ITS CONFORMITY TO ANY SPECIFICATION. THE ENTIRE RISK AS TO QUALITY AND
- *  PERFORMANCE OF THE SOFTWARE IS WITH THE USER.
  *
  *  Module:  ofstd
  *
@@ -23,9 +19,9 @@
  *           as used by most multithread implementations
  *
  *
- *  Last Update:      $Author: meichel $
- *  Update Date:      $Date: 2005/12/08 15:49:12 $
- *  CVS/RCS Revision: $Revision: 1.10 $
+ *  Last Update:      $Author: uli $
+ *  Update Date:      $Date: 2011-01-05 12:31:30 $
+ *  CVS/RCS Revision: $Revision: 1.15 $
  *  Status:           $State: Exp $
  *
  *  CVS/RCS Log at end of file
@@ -42,7 +38,7 @@
 
 static void bailout(const char *message, int line)
 {
-  CERR << "[" << line << "]: " << message << endl;
+  CERR << "[" << line << "]: " << message << OFendl;
   exit(10);
 }
 
@@ -127,9 +123,13 @@ void mutex_test()
   if ((!mtx_cond2) || (!mtx_cond3)) bailout("mutex lock/unlock test failed", __LINE__);
 
   delete mutex;
-  CERR << "mutex test passed." << endl;
+  CERR << "mutex test passed." << OFendl;
 }
 
+/* Currently OFSemaphore is not working and disabled on Mac OS X. Thus,
+ * it is not tested on Mac OS X.
+ */
+#ifndef _DARWIN_C_SOURCE
 
 static OFSemaphore *semaphore=NULL;
 static int sem_cond1=0;
@@ -215,9 +215,11 @@ void semaphore_test()
 
   delete mutex;
   delete semaphore;
-  CERR << "semaphore test passed." << endl;
+  CERR << "semaphore test passed." << OFendl;
 }
 
+#endif //_DARWIN_C_SOURCE
+
 static OFReadWriteLock *rwlock=NULL;
 static OFMutex *mutex2=NULL;
 static int rw_cond1=0;
@@ -328,9 +330,129 @@ void rwlock_test()
   delete mutex;
   delete mutex2;
   delete rwlock;
-  CERR << "read/write lock test passed." << endl;
+  CERR << "read/write lock test passed." << OFendl;
 }
 
+class RWLockerT1: public OFThread
+{
+public:
+  RWLockerT1(): OFThread() {}
+  ~RWLockerT1() {}
+
+  virtual void run()
+  {
+    OFReadWriteLocker locker(*rwlock);
+    if (0 == locker.rdlock())
+    {
+      rw_cond1 = 1; // acquired read lock
+      mutex->lock();
+      mutex->unlock();
+      if (0== locker.unlock()) rw_cond2=1;
+      mutex2->lock();
+      mutex2->unlock();
+      if (OFReadWriteLock::busy == locker.tryrdlock()) rw_cond3=1;
+      if (0 == locker.rdlock()) rw_cond4=1;
+      // Implicit unlock() at the end
+    }
+    return;
+  }
+};
+
+class RWLockerT2: public OFThread
+{
+public:
+  RWLockerT2(): OFThread() {}
+  ~RWLockerT2() {}
+
+  virtual void run()
+  {
+    OFReadWriteLocker locker(*rwlock);
+    if ((0==mutex2->trylock())&&(OFReadWriteLock::busy == locker.trywrlock())) rw_cond5=1;
+    if (0 == locker.wrlock())
+    {
+      rw_cond6=1;
+      mutex2->unlock();
+      OFStandard::sleep(1);
+      // Explicite unlock(), check if this causes one unlock() too much
+      if (0==locker.unlock()) rw_cond7=1;
+    }
+    return;
+  }
+};
+
+void rwlocker_test()
+{
+  OFString errmsg;
+
+  // Reset global state
+  rwlock=NULL;
+  mutex2=NULL;
+  rw_cond1=0;
+  rw_cond2=0;
+  rw_cond3=0;
+  rw_cond4=0;
+  rw_cond5=0;
+  rw_cond6=0;
+  rw_cond7=0;
+
+  mutex = new OFMutex();
+  if ((!mutex)||(! mutex->initialized())) bailout("creation of mutex failed", __LINE__);
+  mutex2 = new OFMutex();
+  if ((!mutex2)||(! mutex2->initialized())) bailout("creation of mutex failed", __LINE__);
+  rwlock = new OFReadWriteLock();
+  if ((!rwlock)||(! rwlock->initialized())) bailout("creation of read/write lock failed", __LINE__);
+
+  int condition = mutex->trylock();
+  if (condition)
+  {
+    mutex->errorstr(errmsg, condition);
+    CERR << "mutex lock failed: ";
+    bailout(errmsg.c_str(), __LINE__);
+  }
+
+  OFReadWriteLocker rwlockLocker(*rwlock);
+  condition = rwlockLocker.tryrdlock();
+  if (condition)
+  {
+    rwlock->errorstr(errmsg, condition);
+    CERR << "read lock failed: ";
+    bailout(errmsg.c_str(), __LINE__);
+  }
+
+  RWLockerT1 t1;
+  if (0 != t1.start()) bailout("unable to create thread, semaphore test failed", __LINE__);
+
+  RWLockerT2 t2;
+  if (0 != t2.start()) bailout("unable to create thread, semaphore test failed", __LINE__);
+
+
+  int i=0;
+  while ((i++<5) && ((!rw_cond1)||(!rw_cond5))) OFStandard::sleep(1);
+
+  if ((!rw_cond1)||(!rw_cond5)) bailout("read/write lock/unlock test failed", __LINE__);
+  condition = rwlockLocker.unlock();
+  if (condition)
+  {
+    rwlock->errorstr(errmsg, condition);
+    CERR << "read lock failed: ";
+    bailout(errmsg.c_str(), __LINE__);
+  }
+  OFStandard::sleep(1);
+  if (rw_cond6) bailout("read/write lock test failed", __LINE__);
+
+  mutex->unlock();
+
+  i=0;
+  while ((i++<5) && ((!rw_cond2)||(!rw_cond3)||(!rw_cond4)||(!rw_cond5)||(!rw_cond6)||(!rw_cond7))) OFStandard::sleep(1);
+  if ((!rw_cond2)||(!rw_cond3)||(!rw_cond4)||(!rw_cond5)||(!rw_cond6)||(!rw_cond7)) bailout("read/write lock/unlock test failed", __LINE__);
+
+  delete mutex;
+  delete mutex2;
+  delete rwlock;
+  CERR << "read/write lock locker test passed." << OFendl;
+}
+
+
 static OFThreadSpecificData *tsdata=NULL;
 static int tsd_cond1=0;
 static int tsd_cond2=0;
@@ -442,17 +564,20 @@ void tsdata_test()
   delete mutex;
   delete mutex2;
   delete tsdata;
-  CERR << "thread specific data test passed." << endl;
+  CERR << "thread specific data test passed." << OFendl;
 }
 
 
 int main()
 {
   mutex_test();
+#ifndef _DARWIN_C_SOURCE  
   semaphore_test(); // may assume that mutexes work correctly
+#endif
   rwlock_test();    // may assume that mutexes and semaphores work correctly
+  rwlocker_test();  // may assume that mutexes, semaphores and read/write locks work correctly
   tsdata_test();
-  CERR << "all tests passed." << endl;
+  CERR << "all tests passed." << OFendl;
   return 0;
 }
 
@@ -461,6 +586,23 @@ int main()
  *
  * CVS/RCS Log:
  * $Log: tstthred.cc,v $
+ * Revision 1.15  2011-01-05 12:31:30  uli
+ * Remove all windows line endings that were recently introduced.
+ *
+ * Revision 1.14  2011-01-05 11:03:45  onken
+ * Updated thread test in order to reflect missing OFSemaphore class
+ * on Mac OS X.
+ *
+ * Revision 1.13  2010-10-14 13:15:16  joergr
+ * Updated copyright header. Added reference to COPYRIGHT file.
+ *
+ * Revision 1.12  2010-06-04 13:58:42  uli
+ * Added class OFReadWriteLocker which simplifies unlocking OFReadWriteLocks.
+ *
+ * Revision 1.11  2006-08-14 16:42:48  meichel
+ * Updated all code in module ofstd to correctly compile if the standard
+ *   namespace has not included into the global one with a "using" directive.
+ *
  * Revision 1.10  2005/12/08 15:49:12  meichel
  * Changed include path schema for all DCMTK header files
  *
